Module: Google::Apis::HealthV4

Defined in:
lib/google/apis/health_v4.rb,
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/service.rb,
lib/google/apis/health_v4/gem_version.rb,
lib/google/apis/health_v4/representations.rb

Overview

Google Health API

The Google Health API lets you view and manage health and fitness metrics and measurement data.

Defined Under Namespace

Classes: ActiveEnergyBurned, ActiveEnergyBurnedRollupValue, ActiveMinutes, ActiveMinutesByActivityLevel, ActiveMinutesRollupByActivityLevel, ActiveMinutesRollupValue, ActiveZoneMinutes, ActiveZoneMinutesRollupValue, ActivityLevel, ActivityLevelRollupByActivityLevelType, ActivityLevelRollupValue, AlertWindow, Altitude, AltitudeRollupValue, Application, BasalEnergyBurned, BatchDeleteDataPointsRequest, BloodGlucose, BloodGlucoseRollupValue, BodyFat, BodyFatRollupValue, CaloriesInHeartRateZoneRollupValue, CaloriesInHeartRateZoneValue, CivilDateTime, CivilTimeInterval, CoreBodyTemperature, CoreBodyTemperatureRollupValue, CreateSubscriberPayload, CreateSubscriptionPayload, DailyHeartRateVariability, DailyHeartRateZones, DailyOxygenSaturation, DailyRespiratoryRate, DailyRestingHeartRate, DailyRestingHeartRateMetadata, DailyRollUpDataPointsRequest, DailyRollUpDataPointsResponse, DailyRollupDataPoint, DailySleepTemperatureDerivations, DailyVo2Max, DataPoint, DataSource, Date, DateTime, Device, Distance, DistanceRollupValue, Electrocardiogram, Empty, EndpointAuthorization, EnergyQuantity, EnergyQuantityRollup, Exercise, ExerciseEvent, ExerciseMetadata, ExportExerciseTcxResponse, Floors, FloorsRollupValue, Food, FoodMeasurementUnit, FoodServing, GoogleDevicesandservicesHealthV4DataType, GoogleDevicesandservicesHealthV4User, GoogleDevicesandservicesHealthV4WebhookNotificationCloudLog, GoogleHealthAPIService, HeartBeat, HeartRate, HeartRateMetadata, HeartRateRollupValue, HeartRateVariability, HeartRateVariabilityPersonalRangeRollupValue, HeartRateZone, Height, HttpHeader, HttpResponse, HydrationLog, HydrationLogRollupValue, Identity, Interval, IrnProfile, IrregularRhythmNotification, ListDataPointsResponse, ListPairedDevicesResponse, ListSubscribersResponse, ListSubscriptionsResponse, MedicalDeviceInfo, MetricsSummary, MobilityMetrics, NutrientQuantity, NutrientQuantityRollup, NutritionLog, NutritionLogRollupValue, ObservationSampleTime, ObservationTimeInterval, Operation, OutOfBedSegment, OxygenSaturation, PairedDevice, Profile, ReconcileDataPointsResponse, ReconciledDataPoint, RespiratoryRateSleepSummary, RespiratoryRateSleepSummaryStatistics, RestingHeartRatePersonalRangeRollupValue, RollUpDataPointsRequest, RollUpDataPointsResponse, RollupDataPoint, RunVo2Max, RunVo2MaxRollupValue, SedentaryPeriod, SedentaryPeriodRollupValue, Serving, SessionTimeInterval, Settings, Sleep, SleepMetadata, SleepStage, SleepSummary, SplitSummary, StageSummary, Status, Steps, StepsRollupValue, Subscriber, SubscriberConfig, Subscription, SwimLengthsData, SwimLengthsDataRollupValue, TimeInHeartRateZone, TimeInHeartRateZoneRollupValue, TimeInHeartRateZoneValue, TimeInHeartRateZones, TimeOfDay, TimeZone, TotalCaloriesRollupValue, Vo2Max, VolumeQuantity, VolumeQuantityRollup, Weight, WeightQuantity, WeightQuantityRollup, WeightRollupValue

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-health_v4 gem

"0.5.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260527"
VERSION =

Version of the Google Health API this client connects to. This is NOT the gem version.

'V4'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'
AUTH_GOOGLEHEALTH_ACTIVITY_AND_FITNESS_READONLY =

See your Google Health activity and fitness data

'https://www.googleapis.com/auth/googlehealth.activity_and_fitness.readonly'
AUTH_GOOGLEHEALTH_ECG_READONLY =

See your Google Health ECG data

'https://www.googleapis.com/auth/googlehealth.ecg.readonly'
AUTH_GOOGLEHEALTH_HEALTH_METRICS_AND_MEASUREMENTS_READONLY =

See your Google Health health metrics and measurement data

'https://www.googleapis.com/auth/googlehealth.health_metrics_and_measurements.readonly'
AUTH_GOOGLEHEALTH_IRN_READONLY =

See your Google Health Irregular Rhythm Notifications data

'https://www.googleapis.com/auth/googlehealth.irn.readonly'
AUTH_GOOGLEHEALTH_LOCATION_READONLY =

See exercise GPS location data in Google Health

'https://www.googleapis.com/auth/googlehealth.location.readonly'
AUTH_GOOGLEHEALTH_PROFILE_READONLY =

See your Google Health profile data

'https://www.googleapis.com/auth/googlehealth.profile.readonly'
AUTH_GOOGLEHEALTH_SETTINGS_READONLY =

See your Google Health settings

'https://www.googleapis.com/auth/googlehealth.settings.readonly'
AUTH_GOOGLEHEALTH_SLEEP_READONLY =

See your Google Health sleep data

'https://www.googleapis.com/auth/googlehealth.sleep.readonly'