Class: Google::Apis::HealthV4::ActiveMinutes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Record of active minutes in a given time interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActiveMinutes

Returns a new instance of ActiveMinutes.



84
85
86
# File 'lib/google/apis/health_v4/classes.rb', line 84

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_minutes_by_activity_levelArray<Google::Apis::HealthV4::ActiveMinutesByActivityLevel>

Required. Active minutes by activity level. At most one record per activity level is allowed. Corresponds to the JSON property activeMinutesByActivityLevel



77
78
79
# File 'lib/google/apis/health_v4/classes.rb', line 77

def active_minutes_by_activity_level
  @active_minutes_by_activity_level
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



82
83
84
# File 'lib/google/apis/health_v4/classes.rb', line 82

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



89
90
91
92
# File 'lib/google/apis/health_v4/classes.rb', line 89

def update!(**args)
  @active_minutes_by_activity_level = args[:active_minutes_by_activity_level] if args.key?(:active_minutes_by_activity_level)
  @interval = args[:interval] if args.key?(:interval)
end