Class: Google::Apis::HealthV4::ActiveMinutesRollupValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the result of the rollup of the active minutes data type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActiveMinutesRollupValue

Returns a new instance of ActiveMinutesRollupValue.



155
156
157
# File 'lib/google/apis/health_v4/classes.rb', line 155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_minutes_rollup_by_activity_levelArray<Google::Apis::HealthV4::ActiveMinutesRollupByActivityLevel>

Active minutes by activity level. At most one record per activity level is allowed. Corresponds to the JSON property activeMinutesRollupByActivityLevel



153
154
155
# File 'lib/google/apis/health_v4/classes.rb', line 153

def active_minutes_rollup_by_activity_level
  @active_minutes_rollup_by_activity_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



160
161
162
# File 'lib/google/apis/health_v4/classes.rb', line 160

def update!(**args)
  @active_minutes_rollup_by_activity_level = args[:active_minutes_rollup_by_activity_level] if args.key?(:active_minutes_rollup_by_activity_level)
end