Class: Google::Apis::HealthV4::ActiveZoneMinutes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Record of active zone minutes in a given time interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActiveZoneMinutes

Returns a new instance of ActiveZoneMinutes.



143
144
145
# File 'lib/google/apis/health_v4/classes.rb', line 143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_zone_minutesFixnum

Required. Number of Active Zone Minutes earned in the given time interval. Note: active_zone_minutes equals to 1 for low intensity (fat burn) zones or 2 for high intensity zones (cardio, peak). Corresponds to the JSON property activeZoneMinutes

Returns:

  • (Fixnum)


130
131
132
# File 'lib/google/apis/health_v4/classes.rb', line 130

def active_zone_minutes
  @active_zone_minutes
end

#heart_rate_zoneString

Required. Heart rate zone in which the active zone minutes have been earned, in the given time interval. Corresponds to the JSON property heartRateZone

Returns:

  • (String)


136
137
138
# File 'lib/google/apis/health_v4/classes.rb', line 136

def heart_rate_zone
  @heart_rate_zone
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



141
142
143
# File 'lib/google/apis/health_v4/classes.rb', line 141

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



148
149
150
151
152
# File 'lib/google/apis/health_v4/classes.rb', line 148

def update!(**args)
  @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes)
  @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone)
  @interval = args[:interval] if args.key?(:interval)
end