Class: Google::Apis::HealthV4::ActivityLevel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Internal type to capture activity level during a certain time interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActivityLevel

Returns a new instance of ActivityLevel.



244
245
246
# File 'lib/google/apis/health_v4/classes.rb', line 244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activity_level_typeString

Required. Activity level type in the given time interval. Corresponds to the JSON property activityLevelType

Returns:

  • (String)


237
238
239
# File 'lib/google/apis/health_v4/classes.rb', line 237

def activity_level_type
  @activity_level_type
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



242
243
244
# File 'lib/google/apis/health_v4/classes.rb', line 242

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



249
250
251
252
# File 'lib/google/apis/health_v4/classes.rb', line 249

def update!(**args)
  @activity_level_type = args[:activity_level_type] if args.key?(:activity_level_type)
  @interval = args[:interval] if args.key?(:interval)
end