Class: Google::Apis::HealthV4::ActivityLevelRollupValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the result of the rollup of the activity level data type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActivityLevelRollupValue

Returns a new instance of ActivityLevelRollupValue.



289
290
291
# File 'lib/google/apis/health_v4/classes.rb', line 289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activity_level_rollups_by_activity_level_typeArray<Google::Apis::HealthV4::ActivityLevelRollupByActivityLevelType>

List of total durations in each activity level type. Corresponds to the JSON property activityLevelRollupsByActivityLevelType



287
288
289
# File 'lib/google/apis/health_v4/classes.rb', line 287

def activity_level_rollups_by_activity_level_type
  @activity_level_rollups_by_activity_level_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



294
295
296
# File 'lib/google/apis/health_v4/classes.rb', line 294

def update!(**args)
  @activity_level_rollups_by_activity_level_type = args[:activity_level_rollups_by_activity_level_type] if args.key?(:activity_level_rollups_by_activity_level_type)
end