Class: Google::Apis::HealthV4::AlertWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

An analysis window evaluated for AFib. Note: The current version of the algorithm will only produce alerts if all windows are positive. So anything returned from the API will always have the positive bit set to true. Internally, windows can be negative, however. We never save "inconclusive" windows (they aren't produced by the algorithm).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlertWindow

Returns a new instance of AlertWindow.



355
356
357
# File 'lib/google/apis/health_v4/classes.rb', line 355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



312
313
314
# File 'lib/google/apis/health_v4/classes.rb', line 312

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



319
320
321
# File 'lib/google/apis/health_v4/classes.rb', line 319

def civil_start_time
  @civil_start_time
end

#end_timeString

Required. The end time of the analysis window. Corresponds to the JSON property endTime

Returns:

  • (String)


324
325
326
# File 'lib/google/apis/health_v4/classes.rb', line 324

def end_time
  @end_time
end

#end_utc_offsetString

Required. The UTC offset of the user's timezone when the analysis window ended. Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


329
330
331
# File 'lib/google/apis/health_v4/classes.rb', line 329

def end_utc_offset
  @end_utc_offset
end

#heart_beatsArray<Google::Apis::HealthV4::HeartBeat>

Optional. All heart beats in the interval contained in this analysis window. Corresponds to the JSON property heartBeats



334
335
336
# File 'lib/google/apis/health_v4/classes.rb', line 334

def heart_beats
  @heart_beats
end

#positiveBoolean Also known as: positive?

Optional. Flag indicating whether the window was positive for AFib or not. A true value indicates that AFib was detected in this window. A false value means AFib was not detected, but does not guarantee the absence of AFib. Corresponds to the JSON property positive

Returns:

  • (Boolean)


341
342
343
# File 'lib/google/apis/health_v4/classes.rb', line 341

def positive
  @positive
end

#start_timeString

Required. Observed interval. The start time of the analysis window. Corresponds to the JSON property startTime

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/health_v4/classes.rb', line 347

def start_time
  @start_time
end

#start_utc_offsetString

Required. The UTC offset of the user's timezone when the analysis window started. Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


353
354
355
# File 'lib/google/apis/health_v4/classes.rb', line 353

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



360
361
362
363
364
365
366
367
368
369
# File 'lib/google/apis/health_v4/classes.rb', line 360

def update!(**args)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @heart_beats = args[:heart_beats] if args.key?(:heart_beats)
  @positive = args[:positive] if args.key?(:positive)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end