Class: Google::Apis::HealthV4::BasalEnergyBurned

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Number of calories burned due to basal metabolic rate (BMR) over a period of time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BasalEnergyBurned

Returns a new instance of BasalEnergyBurned.



359
360
361
# File 'lib/google/apis/health_v4/classes.rb', line 359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



351
352
353
# File 'lib/google/apis/health_v4/classes.rb', line 351

def interval
  @interval
end

#kcalFloat

Required. Number of calories burned due to basal metabolic rate in kilocalories over the observed interval. Corresponds to the JSON property kcal

Returns:

  • (Float)


357
358
359
# File 'lib/google/apis/health_v4/classes.rb', line 357

def kcal
  @kcal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



364
365
366
367
# File 'lib/google/apis/health_v4/classes.rb', line 364

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @kcal = args[:kcal] if args.key?(:kcal)
end