Class: Google::Apis::HealthV4::BatchDeleteDataPointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Request to delete a batch of identifiable data points.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchDeleteDataPointsRequest

Returns a new instance of BatchDeleteDataPointsRequest.



497
498
499
# File 'lib/google/apis/health_v4/classes.rb', line 497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namesArray<String>

Required. The names of the DataPoints to delete. A maximum of 10000 data points can be deleted in a single request. Corresponds to the JSON property names

Returns:

  • (Array<String>)


495
496
497
# File 'lib/google/apis/health_v4/classes.rb', line 495

def names
  @names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



502
503
504
# File 'lib/google/apis/health_v4/classes.rb', line 502

def update!(**args)
  @names = args[:names] if args.key?(:names)
end