Class: Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the result of the rollup of the calories in heart rate zone data type.
Instance Attribute Summary collapse
-
#calories_in_heart_rate_zones ⇒ Array<Google::Apis::HealthV4::CaloriesInHeartRateZoneValue>
List of calories burned in each heart rate zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CaloriesInHeartRateZoneRollupValue
constructor
A new instance of CaloriesInHeartRateZoneRollupValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CaloriesInHeartRateZoneRollupValue
Returns a new instance of CaloriesInHeartRateZoneRollupValue.
417 418 419 |
# File 'lib/google/apis/health_v4/classes.rb', line 417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#calories_in_heart_rate_zones ⇒ Array<Google::Apis::HealthV4::CaloriesInHeartRateZoneValue>
List of calories burned in each heart rate zone.
Corresponds to the JSON property caloriesInHeartRateZones
415 416 417 |
# File 'lib/google/apis/health_v4/classes.rb', line 415 def calories_in_heart_rate_zones @calories_in_heart_rate_zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
422 423 424 |
# File 'lib/google/apis/health_v4/classes.rb', line 422 def update!(**args) @calories_in_heart_rate_zones = args[:calories_in_heart_rate_zones] if args.key?(:calories_in_heart_rate_zones) end |