Class: Google::Apis::HealthV4::CreateSubscriberPayload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Payload for creating a subscriber.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateSubscriberPayload

Returns a new instance of CreateSubscriberPayload.



832
833
834
# File 'lib/google/apis/health_v4/classes.rb', line 832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_authorizationGoogle::Apis::HealthV4::EndpointAuthorization

Authorization mechanism for a subscriber endpoint. For all requests sent by the Webhooks service, the JSON payload is cryptographically signed. The signature is delivered in the X-HEALTHAPI-SIGNATURE HTTP header. This is an ECDSA (NIST P256) signature of the JSON payload. Clients must verify this signature using Google Health API's public key to confirm the payload was sent by the Health API. Corresponds to the JSON property endpointAuthorization



817
818
819
# File 'lib/google/apis/health_v4/classes.rb', line 817

def endpoint_authorization
  @endpoint_authorization
end

#endpoint_uriString

Required. The full HTTPS URI where update notifications will be sent. The URI must be a valid URL and use HTTPS as the scheme. This endpoint will be verified during the CreateSubscriber call. See CreateSubscriber RPC documentation for verification details. Corresponds to the JSON property endpointUri

Returns:

  • (String)


825
826
827
# File 'lib/google/apis/health_v4/classes.rb', line 825

def endpoint_uri
  @endpoint_uri
end

#subscriber_configsArray<Google::Apis::HealthV4::SubscriberConfig>

Optional. Configuration for the subscriber. Corresponds to the JSON property subscriberConfigs



830
831
832
# File 'lib/google/apis/health_v4/classes.rb', line 830

def subscriber_configs
  @subscriber_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



837
838
839
840
841
# File 'lib/google/apis/health_v4/classes.rb', line 837

def update!(**args)
  @endpoint_authorization = args[:endpoint_authorization] if args.key?(:endpoint_authorization)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @subscriber_configs = args[:subscriber_configs] if args.key?(:subscriber_configs)
end