Class: Google::Apis::HealthV4::DailyHeartRateZones

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

User's heart rate zone thresholds based on the Karvonen algorithm for a specific day.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyHeartRateZones

Returns a new instance of DailyHeartRateZones.



636
637
638
# File 'lib/google/apis/health_v4/classes.rb', line 636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dateGoogle::Apis::HealthV4::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



629
630
631
# File 'lib/google/apis/health_v4/classes.rb', line 629

def date
  @date
end

#heart_rate_zonesArray<Google::Apis::HealthV4::HeartRateZone>

Required. The heart rate zones. Corresponds to the JSON property heartRateZones



634
635
636
# File 'lib/google/apis/health_v4/classes.rb', line 634

def heart_rate_zones
  @heart_rate_zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



641
642
643
644
# File 'lib/google/apis/health_v4/classes.rb', line 641

def update!(**args)
  @date = args[:date] if args.key?(:date)
  @heart_rate_zones = args[:heart_rate_zones] if args.key?(:heart_rate_zones)
end