Class: Google::Apis::HealthV4::DailyRespiratoryRate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

A daily average respiratory rate (breaths per minute) for a day of the year. One data point per day calculated for the main sleep.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyRespiratoryRate

Returns a new instance of DailyRespiratoryRate.



723
724
725
# File 'lib/google/apis/health_v4/classes.rb', line 723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#breaths_per_minuteFloat

Required. The average number of breaths taken per minute. Corresponds to the JSON property breathsPerMinute

Returns:

  • (Float)


709
710
711
# File 'lib/google/apis/health_v4/classes.rb', line 709

def breaths_per_minute
  @breaths_per_minute
end

#dateGoogle::Apis::HealthV4::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



721
722
723
# File 'lib/google/apis/health_v4/classes.rb', line 721

def date
  @date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



728
729
730
731
# File 'lib/google/apis/health_v4/classes.rb', line 728

def update!(**args)
  @breaths_per_minute = args[:breaths_per_minute] if args.key?(:breaths_per_minute)
  @date = args[:date] if args.key?(:date)
end