Class: Google::Apis::HealthV4::DailyRestingHeartRate
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DailyRestingHeartRate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Measures the daily resting heart rate for a user, calculated using the all day heart rate measurements.
Instance Attribute Summary collapse
-
#beats_per_minute ⇒ Fixnum
Required.
-
#daily_resting_heart_rate_metadata ⇒ Google::Apis::HealthV4::DailyRestingHeartRateMetadata
Metadata for the daily resting heart rate.
-
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyRestingHeartRate
constructor
A new instance of DailyRestingHeartRate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyRestingHeartRate
Returns a new instance of DailyRestingHeartRate.
788 789 790 |
# File 'lib/google/apis/health_v4/classes.rb', line 788 def initialize(**args) update!(**args) end |
Instance Attribute Details
#beats_per_minute ⇒ Fixnum
Required. The resting heart rate value in beats per minute.
Corresponds to the JSON property beatsPerMinute
769 770 771 |
# File 'lib/google/apis/health_v4/classes.rb', line 769 def beats_per_minute @beats_per_minute end |
#daily_resting_heart_rate_metadata ⇒ Google::Apis::HealthV4::DailyRestingHeartRateMetadata
Metadata for the daily resting heart rate.
Corresponds to the JSON property dailyRestingHeartRateMetadata
774 775 776 |
# File 'lib/google/apis/health_v4/classes.rb', line 774 def @daily_resting_heart_rate_metadata end |
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property date
786 787 788 |
# File 'lib/google/apis/health_v4/classes.rb', line 786 def date @date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
793 794 795 796 797 |
# File 'lib/google/apis/health_v4/classes.rb', line 793 def update!(**args) @beats_per_minute = args[:beats_per_minute] if args.key?(:beats_per_minute) @daily_resting_heart_rate_metadata = args[:daily_resting_heart_rate_metadata] if args.key?(:daily_resting_heart_rate_metadata) @date = args[:date] if args.key?(:date) end |