Class: Google::Apis::HealthV4::DailyRollUpDataPointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Request to roll up data points by civil time intervals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyRollUpDataPointsRequest

Returns a new instance of DailyRollUpDataPointsRequest.



1150
1151
1152
# File 'lib/google/apis/health_v4/classes.rb', line 1150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_familyString

Optional. The data source family name to roll up. If empty, data points from all available data sources will be rolled up. Format: users/me/ dataSourceFamilies/data_source_family`The supported values are: -users/me/ dataSourceFamilies/all-sources- Default value. Includes data from all available data sources. -users/me/dataSourceFamilies/google-wearables- Includes data from Google and Fitbit tracker devices (such as Fitbit trackers and Pixel Watch). Excludes manually logged data. -users/me/ dataSourceFamilies/google-sources- Includes first-party Google data, such as data from tracker devices, manually logged data, and Health Connect. Corresponds to the JSON propertydataSourceFamily`

Returns:

  • (String)


1123
1124
1125
# File 'lib/google/apis/health_v4/classes.rb', line 1123

def data_source_family
  @data_source_family
end

#page_sizeFixnum

Optional. The maximum number of data points to return. If unspecified, at most 1440 data points will be returned. The maximum page size is 10000; values above that will be truncated accordingly. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1130
1131
1132
# File 'lib/google/apis/health_v4/classes.rb', line 1130

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token from a previous request, if any. All other request fields need to be the same as in the initial request when the page token is specified. Corresponds to the JSON property pageToken

Returns:

  • (String)


1137
1138
1139
# File 'lib/google/apis/health_v4/classes.rb', line 1137

def page_token
  @page_token
end

#rangeGoogle::Apis::HealthV4::CivilTimeInterval

Counterpart of google.type.Interval, but using CivilDateTime. Corresponds to the JSON property range



1142
1143
1144
# File 'lib/google/apis/health_v4/classes.rb', line 1142

def range
  @range
end

#window_size_daysFixnum

Optional. Aggregation window size, in number of days. Defaults to 1 if not specified. Corresponds to the JSON property windowSizeDays

Returns:

  • (Fixnum)


1148
1149
1150
# File 'lib/google/apis/health_v4/classes.rb', line 1148

def window_size_days
  @window_size_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1155
1156
1157
1158
1159
1160
1161
# File 'lib/google/apis/health_v4/classes.rb', line 1155

def update!(**args)
  @data_source_family = args[:data_source_family] if args.key?(:data_source_family)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @range = args[:range] if args.key?(:range)
  @window_size_days = args[:window_size_days] if args.key?(:window_size_days)
end