Class: Google::Apis::HealthV4::DailySleepTemperatureDerivations
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DailySleepTemperatureDerivations
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep.
Instance Attribute Summary collapse
-
#baseline_temperature_celsius ⇒ Float
Optional.
-
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday.
-
#nightly_temperature_celsius ⇒ Float
Required.
-
#relative_nightly_stddev30d_celsius ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailySleepTemperatureDerivations
constructor
A new instance of DailySleepTemperatureDerivations.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailySleepTemperatureDerivations
Returns a new instance of DailySleepTemperatureDerivations.
1394 1395 1396 |
# File 'lib/google/apis/health_v4/classes.rb', line 1394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#baseline_temperature_celsius ⇒ Float
Optional. The user's baseline skin temperature. It is the median of the user's
nightly skin temperature over the past 30 days.
Corresponds to the JSON property baselineTemperatureCelsius
1368 1369 1370 |
# File 'lib/google/apis/health_v4/classes.rb', line 1368 def baseline_temperature_celsius @baseline_temperature_celsius end |
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property date
1380 1381 1382 |
# File 'lib/google/apis/health_v4/classes.rb', line 1380 def date @date end |
#nightly_temperature_celsius ⇒ Float
Required. The user's nightly skin temperature. It is the mean of skin
temperature samples taken from the user’s sleep.
Corresponds to the JSON property nightlyTemperatureCelsius
1386 1387 1388 |
# File 'lib/google/apis/health_v4/classes.rb', line 1386 def nightly_temperature_celsius @nightly_temperature_celsius end |
#relative_nightly_stddev30d_celsius ⇒ Float
Optional. The standard deviation of the user’s relative nightly skin
temperature (temperature - baseline) over the past 30 days.
Corresponds to the JSON property relativeNightlyStddev30dCelsius
1392 1393 1394 |
# File 'lib/google/apis/health_v4/classes.rb', line 1392 def relative_nightly_stddev30d_celsius @relative_nightly_stddev30d_celsius end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1399 1400 1401 1402 1403 1404 |
# File 'lib/google/apis/health_v4/classes.rb', line 1399 def update!(**args) @baseline_temperature_celsius = args[:baseline_temperature_celsius] if args.key?(:baseline_temperature_celsius) @date = args[:date] if args.key?(:date) @nightly_temperature_celsius = args[:nightly_temperature_celsius] if args.key?(:nightly_temperature_celsius) @relative_nightly_stddev30d_celsius = args[:relative_nightly_stddev30d_celsius] if args.key?(:relative_nightly_stddev30d_celsius) end |