Class: Google::Apis::HealthV4::DailyVo2Max

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyVo2Max

Returns a new instance of DailyVo2Max.



1450
1451
1452
# File 'lib/google/apis/health_v4/classes.rb', line 1450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardio_fitness_levelString

Optional. Represents the user's cardio fitness level based on their VO2 max. Corresponds to the JSON property cardioFitnessLevel

Returns:

  • (String)


1418
1419
1420
# File 'lib/google/apis/health_v4/classes.rb', line 1418

def cardio_fitness_level
  @cardio_fitness_level
end

#dateGoogle::Apis::HealthV4::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



1430
1431
1432
# File 'lib/google/apis/health_v4/classes.rb', line 1430

def date
  @date
end

#estimatedBoolean Also known as: estimated?

Optional. An estimated field is added to indicate when the confidence has decreased sufficiently to consider the value an estimation. Corresponds to the JSON property estimated

Returns:

  • (Boolean)


1436
1437
1438
# File 'lib/google/apis/health_v4/classes.rb', line 1436

def estimated
  @estimated
end

#vo2_maxFloat

Required. Daily VO2 max value measured as in ml consumed oxygen / kg of body weight / min. Corresponds to the JSON property vo2Max

Returns:

  • (Float)


1443
1444
1445
# File 'lib/google/apis/health_v4/classes.rb', line 1443

def vo2_max
  @vo2_max
end

#vo2_max_covarianceFloat

Optional. The covariance of the VO2 max value. Corresponds to the JSON property vo2MaxCovariance

Returns:

  • (Float)


1448
1449
1450
# File 'lib/google/apis/health_v4/classes.rb', line 1448

def vo2_max_covariance
  @vo2_max_covariance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1455
1456
1457
1458
1459
1460
1461
# File 'lib/google/apis/health_v4/classes.rb', line 1455

def update!(**args)
  @cardio_fitness_level = args[:cardio_fitness_level] if args.key?(:cardio_fitness_level)
  @date = args[:date] if args.key?(:date)
  @estimated = args[:estimated] if args.key?(:estimated)
  @vo2_max = args[:vo2_max] if args.key?(:vo2_max)
  @vo2_max_covariance = args[:vo2_max_covariance] if args.key?(:vo2_max_covariance)
end