Class: Google::Apis::HealthV4::Distance
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Distance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Distance traveled over an interval of time.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
-
#millimeters ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Distance
constructor
A new instance of Distance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Distance
Returns a new instance of Distance.
1592 1593 1594 |
# File 'lib/google/apis/health_v4/classes.rb', line 1592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
1585 1586 1587 |
# File 'lib/google/apis/health_v4/classes.rb', line 1585 def interval @interval end |
#millimeters ⇒ Fixnum
Required. Distance in millimeters over the observed interval.
Corresponds to the JSON property millimeters
1590 1591 1592 |
# File 'lib/google/apis/health_v4/classes.rb', line 1590 def millimeters @millimeters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1597 1598 1599 1600 |
# File 'lib/google/apis/health_v4/classes.rb', line 1597 def update!(**args) @interval = args[:interval] if args.key?(:interval) @millimeters = args[:millimeters] if args.key?(:millimeters) end |