Class: Google::Apis::HealthV4::Floors

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Gained elevation measured in floors over the time interval

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Floors

Returns a new instance of Floors.



2387
2388
2389
# File 'lib/google/apis/health_v4/classes.rb', line 2387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Required. Number of floors in the recorded interval Corresponds to the JSON property count

Returns:

  • (Fixnum)


2380
2381
2382
# File 'lib/google/apis/health_v4/classes.rb', line 2380

def count
  @count
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



2385
2386
2387
# File 'lib/google/apis/health_v4/classes.rb', line 2385

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2392
2393
2394
2395
# File 'lib/google/apis/health_v4/classes.rb', line 2392

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @interval = args[:interval] if args.key?(:interval)
end