Class: Google::Apis::HealthV4::HeartRate
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::HeartRate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
A heart rate measurement.
Instance Attribute Summary collapse
-
#beats_per_minute ⇒ Fixnum
Required.
-
#metadata ⇒ Google::Apis::HealthV4::HeartRateMetadata
Heart rate metadata.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HeartRate
constructor
A new instance of HeartRate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HeartRate
Returns a new instance of HeartRate.
1875 1876 1877 |
# File 'lib/google/apis/health_v4/classes.rb', line 1875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#beats_per_minute ⇒ Fixnum
Required. The heart rate value in beats per minute.
Corresponds to the JSON property beatsPerMinute
1863 1864 1865 |
# File 'lib/google/apis/health_v4/classes.rb', line 1863 def beats_per_minute @beats_per_minute end |
#metadata ⇒ Google::Apis::HealthV4::HeartRateMetadata
Heart rate metadata.
Corresponds to the JSON property metadata
1868 1869 1870 |
# File 'lib/google/apis/health_v4/classes.rb', line 1868 def @metadata end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
1873 1874 1875 |
# File 'lib/google/apis/health_v4/classes.rb', line 1873 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1880 1881 1882 1883 1884 |
# File 'lib/google/apis/health_v4/classes.rb', line 1880 def update!(**args) @beats_per_minute = args[:beats_per_minute] if args.key?(:beats_per_minute) @metadata = args[:metadata] if args.key?(:metadata) @sample_time = args[:sample_time] if args.key?(:sample_time) end |