Class: Google::Apis::HealthV4::HeartRateMetadata
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::HeartRateMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Heart rate metadata.
Instance Attribute Summary collapse
-
#motion_context ⇒ String
Optional.
-
#sensor_location ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HeartRateMetadata
constructor
A new instance of HeartRateMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HeartRateMetadata
Returns a new instance of HeartRateMetadata.
2749 2750 2751 |
# File 'lib/google/apis/health_v4/classes.rb', line 2749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#motion_context ⇒ String
Optional. Indicates the user’s level of activity when the heart rate sample
was measured
Corresponds to the JSON property motionContext
2742 2743 2744 |
# File 'lib/google/apis/health_v4/classes.rb', line 2742 def motion_context @motion_context end |
#sensor_location ⇒ String
Optional. Indicates the location of the sensor that measured the heart rate.
Corresponds to the JSON property sensorLocation
2747 2748 2749 |
# File 'lib/google/apis/health_v4/classes.rb', line 2747 def sensor_location @sensor_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2754 2755 2756 2757 |
# File 'lib/google/apis/health_v4/classes.rb', line 2754 def update!(**args) @motion_context = args[:motion_context] if args.key?(:motion_context) @sensor_location = args[:sensor_location] if args.key?(:sensor_location) end |