Class: Google::Apis::HealthV4::HeartRateVariability
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::HeartRateVariability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).
Instance Attribute Summary collapse
-
#root_mean_square_of_successive_differences_milliseconds ⇒ Float
Optional.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#standard_deviation_milliseconds ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HeartRateVariability
constructor
A new instance of HeartRateVariability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HeartRateVariability
Returns a new instance of HeartRateVariability.
2777 2778 2779 |
# File 'lib/google/apis/health_v4/classes.rb', line 2777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#root_mean_square_of_successive_differences_milliseconds ⇒ Float
Optional. The root mean square of successive differences between normal
heartbeats. This is a measure of heart rate variability used by Google Health.
Corresponds to the JSON property rootMeanSquareOfSuccessiveDifferencesMilliseconds
2765 2766 2767 |
# File 'lib/google/apis/health_v4/classes.rb', line 2765 def root_mean_square_of_successive_differences_milliseconds @root_mean_square_of_successive_differences_milliseconds end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
2770 2771 2772 |
# File 'lib/google/apis/health_v4/classes.rb', line 2770 def sample_time @sample_time end |
#standard_deviation_milliseconds ⇒ Float
Optional. The standard deviation of the heart rate variability measurement.
Corresponds to the JSON property standardDeviationMilliseconds
2775 2776 2777 |
# File 'lib/google/apis/health_v4/classes.rb', line 2775 def standard_deviation_milliseconds @standard_deviation_milliseconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2782 2783 2784 2785 2786 |
# File 'lib/google/apis/health_v4/classes.rb', line 2782 def update!(**args) @root_mean_square_of_successive_differences_milliseconds = args[:root_mean_square_of_successive_differences_milliseconds] if args.key?(:root_mean_square_of_successive_differences_milliseconds) @sample_time = args[:sample_time] if args.key?(:sample_time) @standard_deviation_milliseconds = args[:standard_deviation_milliseconds] if args.key?(:standard_deviation_milliseconds) end |