Class: Google::Apis::HealthV4::HeartRateZone

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

The heart rate zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeartRateZone

Returns a new instance of HeartRateZone.



2870
2871
2872
# File 'lib/google/apis/health_v4/classes.rb', line 2870

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#heart_rate_zone_typeString

Required. The heart rate zone type. Corresponds to the JSON property heartRateZoneType

Returns:

  • (String)


2858
2859
2860
# File 'lib/google/apis/health_v4/classes.rb', line 2858

def heart_rate_zone_type
  @heart_rate_zone_type
end

#max_beats_per_minuteFixnum

Required. Maximum heart rate for this zone in beats per minute. Corresponds to the JSON property maxBeatsPerMinute

Returns:

  • (Fixnum)


2863
2864
2865
# File 'lib/google/apis/health_v4/classes.rb', line 2863

def max_beats_per_minute
  @max_beats_per_minute
end

#min_beats_per_minuteFixnum

Required. Minimum heart rate for this zone in beats per minute. Corresponds to the JSON property minBeatsPerMinute

Returns:

  • (Fixnum)


2868
2869
2870
# File 'lib/google/apis/health_v4/classes.rb', line 2868

def min_beats_per_minute
  @min_beats_per_minute
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2875
2876
2877
2878
2879
# File 'lib/google/apis/health_v4/classes.rb', line 2875

def update!(**args)
  @heart_rate_zone_type = args[:heart_rate_zone_type] if args.key?(:heart_rate_zone_type)
  @max_beats_per_minute = args[:max_beats_per_minute] if args.key?(:max_beats_per_minute)
  @min_beats_per_minute = args[:min_beats_per_minute] if args.key?(:min_beats_per_minute)
end