Class: Google::Apis::HealthV4::Height
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Height
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Body height measurement.
Instance Attribute Summary collapse
-
#height_millimeters ⇒ Fixnum
Required.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Height
constructor
A new instance of Height.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Height
Returns a new instance of Height.
2103 2104 2105 |
# File 'lib/google/apis/health_v4/classes.rb', line 2103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#height_millimeters ⇒ Fixnum
Required. Height of the user in millimeters.
Corresponds to the JSON property heightMillimeters
2096 2097 2098 |
# File 'lib/google/apis/health_v4/classes.rb', line 2096 def height_millimeters @height_millimeters end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
2101 2102 2103 |
# File 'lib/google/apis/health_v4/classes.rb', line 2101 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2108 2109 2110 2111 |
# File 'lib/google/apis/health_v4/classes.rb', line 2108 def update!(**args) @height_millimeters = args[:height_millimeters] if args.key?(:height_millimeters) @sample_time = args[:sample_time] if args.key?(:sample_time) end |