Class: Google::Apis::HealthV4::Identity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents details about the Google user's identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Identity

Returns a new instance of Identity.



3093
3094
3095
# File 'lib/google/apis/health_v4/classes.rb', line 3093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_user_idString

Output only. The Google User Identifier in the Google Health APIs. It matches the user resource ID segment in the resource name paths, e.g. users/user /dataTypes/steps. Valid values are strings of 1-63 characters, and valid characters are lowercase and uppercase letters, numbers, and hyphens. Corresponds to the JSON property healthUserId

Returns:

  • (String)


3074
3075
3076
# File 'lib/google/apis/health_v4/classes.rb', line 3074

def health_user_id
  @health_user_id
end

#legacy_user_idString

Output only. The legacy Fitbit User identifier. This is the Fitbit ID used in the legacy Fitbit APIs (v1-v3). It can be referenced by clients migrating from the legacy Fitbit APIs to map their existing identifiers to the new Google user ID. It must not be used for any other purpose. It is not of any use for new clients using only the Google Health APIs. Valid values are strings of 1-63 characters, and valid characters are lowercase and uppercase letters, numbers, and hyphens. Corresponds to the JSON property legacyUserId

Returns:

  • (String)


3085
3086
3087
# File 'lib/google/apis/health_v4/classes.rb', line 3085

def legacy_user_id
  @legacy_user_id
end

#nameString

Identifier. The resource name of this Identity resource. Format: users/me/ identity Corresponds to the JSON property name

Returns:

  • (String)


3091
3092
3093
# File 'lib/google/apis/health_v4/classes.rb', line 3091

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3098
3099
3100
3101
3102
# File 'lib/google/apis/health_v4/classes.rb', line 3098

def update!(**args)
  @health_user_id = args[:health_user_id] if args.key?(:health_user_id)
  @legacy_user_id = args[:legacy_user_id] if args.key?(:legacy_user_id)
  @name = args[:name] if args.key?(:name)
end