Class: Google::Apis::HealthV4::ListDataPointsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Response containing raw data points matching the query

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDataPointsResponse

Returns a new instance of ListDataPointsResponse.



3236
3237
3238
# File 'lib/google/apis/health_v4/classes.rb', line 3236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_pointsArray<Google::Apis::HealthV4::DataPoint>

Data points matching the query Corresponds to the JSON property dataPoints



3229
3230
3231
# File 'lib/google/apis/health_v4/classes.rb', line 3229

def data_points
  @data_points
end

#next_page_tokenString

Next page token, empty if the response is complete Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3234
3235
3236
# File 'lib/google/apis/health_v4/classes.rb', line 3234

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3241
3242
3243
3244
# File 'lib/google/apis/health_v4/classes.rb', line 3241

def update!(**args)
  @data_points = args[:data_points] if args.key?(:data_points)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end