Class: Google::Apis::HealthV4::MedicalDeviceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Software as Medical Device (SaMD) metadata. Used to construct the Unique Device Identifier (UDI).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MedicalDeviceInfo

Returns a new instance of MedicalDeviceInfo.



3397
3398
3399
# File 'lib/google/apis/health_v4/classes.rb', line 3397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithm_versionString

Output only. The algorithm version used by the feature. Corresponds to the JSON property algorithmVersion

Returns:

  • (String)


3373
3374
3375
# File 'lib/google/apis/health_v4/classes.rb', line 3373

def algorithm_version
  @algorithm_version
end

#device_modelString

Output only. The model name or device type of the compatible device used to collect the data. Corresponds to the JSON property deviceModel

Returns:

  • (String)


3379
3380
3381
# File 'lib/google/apis/health_v4/classes.rb', line 3379

def device_model
  @device_model
end

#feature_versionString

Output only. The version of the feature/app running on the device. Corresponds to the JSON property featureVersion

Returns:

  • (String)


3384
3385
3386
# File 'lib/google/apis/health_v4/classes.rb', line 3384

def feature_version
  @feature_version
end

#firmware_versionString

Output only. The firmware version running on the compatible device used to collect the data. Corresponds to the JSON property firmwareVersion

Returns:

  • (String)


3390
3391
3392
# File 'lib/google/apis/health_v4/classes.rb', line 3390

def firmware_version
  @firmware_version
end

#service_versionString

Output only. The service version used by the feature. Corresponds to the JSON property serviceVersion

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/health_v4/classes.rb', line 3395

def service_version
  @service_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3402
3403
3404
3405
3406
3407
3408
# File 'lib/google/apis/health_v4/classes.rb', line 3402

def update!(**args)
  @algorithm_version = args[:algorithm_version] if args.key?(:algorithm_version)
  @device_model = args[:device_model] if args.key?(:device_model)
  @feature_version = args[:feature_version] if args.key?(:feature_version)
  @firmware_version = args[:firmware_version] if args.key?(:firmware_version)
  @service_version = args[:service_version] if args.key?(:service_version)
end