Class: Google::Apis::HealthV4::MenstrualPeriod
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::MenstrualPeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Menstrual period record.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
-
#notes ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MenstrualPeriod
constructor
A new instance of MenstrualPeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MenstrualPeriod
Returns a new instance of MenstrualPeriod.
3425 3426 3427 |
# File 'lib/google/apis/health_v4/classes.rb', line 3425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
3418 3419 3420 |
# File 'lib/google/apis/health_v4/classes.rb', line 3418 def interval @interval end |
#notes ⇒ String
Optional. Standard free-form notes captured at manual logging.
Corresponds to the JSON property notes
3423 3424 3425 |
# File 'lib/google/apis/health_v4/classes.rb', line 3423 def notes @notes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3430 3431 3432 3433 |
# File 'lib/google/apis/health_v4/classes.rb', line 3430 def update!(**args) @interval = args[:interval] if args.key?(:interval) @notes = args[:notes] if args.key?(:notes) end |