Class: Google::Apis::HealthV4::MetricsSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Summary metrics for an exercise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricsSummary

Returns a new instance of MetricsSummary.



3503
3504
3505
# File 'lib/google/apis/health_v4/classes.rb', line 3503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_zone_minutesFixnum

Optional. Total active zone minutes for the exercise. Corresponds to the JSON property activeZoneMinutes

Returns:

  • (Fixnum)


3443
3444
3445
# File 'lib/google/apis/health_v4/classes.rb', line 3443

def active_zone_minutes
  @active_zone_minutes
end

#average_heart_rate_beats_per_minuteFixnum

Optional. Average heart rate during the exercise. Corresponds to the JSON property averageHeartRateBeatsPerMinute

Returns:

  • (Fixnum)


3448
3449
3450
# File 'lib/google/apis/health_v4/classes.rb', line 3448

def average_heart_rate_beats_per_minute
  @average_heart_rate_beats_per_minute
end

#average_pace_seconds_per_meterFloat

Optional. Average pace in seconds per meter. Corresponds to the JSON property averagePaceSecondsPerMeter

Returns:

  • (Float)


3453
3454
3455
# File 'lib/google/apis/health_v4/classes.rb', line 3453

def average_pace_seconds_per_meter
  @average_pace_seconds_per_meter
end

#average_speed_millimeters_per_secondFloat

Optional. Average speed in millimeters per second. Corresponds to the JSON property averageSpeedMillimetersPerSecond

Returns:

  • (Float)


3458
3459
3460
# File 'lib/google/apis/health_v4/classes.rb', line 3458

def average_speed_millimeters_per_second
  @average_speed_millimeters_per_second
end

#calories_kcalFloat

Optional. Total calories burned by the user during the exercise. Corresponds to the JSON property caloriesKcal

Returns:

  • (Float)


3463
3464
3465
# File 'lib/google/apis/health_v4/classes.rb', line 3463

def calories_kcal
  @calories_kcal
end

#distance_millimetersFloat

Optional. Total distance covered by the user during the exercise. Corresponds to the JSON property distanceMillimeters

Returns:

  • (Float)


3468
3469
3470
# File 'lib/google/apis/health_v4/classes.rb', line 3468

def distance_millimeters
  @distance_millimeters
end

#elevation_gain_millimetersFloat

Optional. Total elevation gain during the exercise. Corresponds to the JSON property elevationGainMillimeters

Returns:

  • (Float)


3473
3474
3475
# File 'lib/google/apis/health_v4/classes.rb', line 3473

def elevation_gain_millimeters
  @elevation_gain_millimeters
end

#heart_rate_zone_durationsGoogle::Apis::HealthV4::TimeInHeartRateZones

Time spent in each heart rate zone. Corresponds to the JSON property heartRateZoneDurations



3478
3479
3480
# File 'lib/google/apis/health_v4/classes.rb', line 3478

def heart_rate_zone_durations
  @heart_rate_zone_durations
end

#mobility_metricsGoogle::Apis::HealthV4::MobilityMetrics

Mobility workouts specific metrics Corresponds to the JSON property mobilityMetrics



3483
3484
3485
# File 'lib/google/apis/health_v4/classes.rb', line 3483

def mobility_metrics
  @mobility_metrics
end

#run_vo2_maxFloat

Optional. Run VO2 max value for the exercise. Only present in the running exercises at the top level as in the summary of the whole exercise. Corresponds to the JSON property runVo2Max

Returns:

  • (Float)


3489
3490
3491
# File 'lib/google/apis/health_v4/classes.rb', line 3489

def run_vo2_max
  @run_vo2_max
end

#stepsFixnum

Optional. Total steps taken during the exercise. Corresponds to the JSON property steps

Returns:

  • (Fixnum)


3494
3495
3496
# File 'lib/google/apis/health_v4/classes.rb', line 3494

def steps
  @steps
end

#total_swim_lengthsFloat

Optional. Number of full pool lengths completed during the exercise. Only present in the swimming exercises at the top level as in the summary of the whole exercise. Corresponds to the JSON property totalSwimLengths

Returns:

  • (Float)


3501
3502
3503
# File 'lib/google/apis/health_v4/classes.rb', line 3501

def total_swim_lengths
  @total_swim_lengths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
# File 'lib/google/apis/health_v4/classes.rb', line 3508

def update!(**args)
  @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes)
  @average_heart_rate_beats_per_minute = args[:average_heart_rate_beats_per_minute] if args.key?(:average_heart_rate_beats_per_minute)
  @average_pace_seconds_per_meter = args[:average_pace_seconds_per_meter] if args.key?(:average_pace_seconds_per_meter)
  @average_speed_millimeters_per_second = args[:average_speed_millimeters_per_second] if args.key?(:average_speed_millimeters_per_second)
  @calories_kcal = args[:calories_kcal] if args.key?(:calories_kcal)
  @distance_millimeters = args[:distance_millimeters] if args.key?(:distance_millimeters)
  @elevation_gain_millimeters = args[:elevation_gain_millimeters] if args.key?(:elevation_gain_millimeters)
  @heart_rate_zone_durations = args[:heart_rate_zone_durations] if args.key?(:heart_rate_zone_durations)
  @mobility_metrics = args[:mobility_metrics] if args.key?(:mobility_metrics)
  @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max)
  @steps = args[:steps] if args.key?(:steps)
  @total_swim_lengths = args[:total_swim_lengths] if args.key?(:total_swim_lengths)
end