Class: Google::Apis::HealthV4::Moods
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Moods
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Moods record.
Instance Attribute Summary collapse
-
#moods ⇒ Array<String>
Required.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#valences ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Moods
constructor
A new instance of Moods.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Moods
Returns a new instance of Moods.
3590 3591 3592 |
# File 'lib/google/apis/health_v4/classes.rb', line 3590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#moods ⇒ Array<String>
Required. The moods logged.
Corresponds to the JSON property moods
3578 3579 3580 |
# File 'lib/google/apis/health_v4/classes.rb', line 3578 def moods @moods end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
3583 3584 3585 |
# File 'lib/google/apis/health_v4/classes.rb', line 3583 def sample_time @sample_time end |
#valences ⇒ Array<String>
Optional. The valences.
Corresponds to the JSON property valences
3588 3589 3590 |
# File 'lib/google/apis/health_v4/classes.rb', line 3588 def valences @valences end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3595 3596 3597 3598 3599 |
# File 'lib/google/apis/health_v4/classes.rb', line 3595 def update!(**args) @moods = args[:moods] if args.key?(:moods) @sample_time = args[:sample_time] if args.key?(:sample_time) @valences = args[:valences] if args.key?(:valences) end |