Class: Google::Apis::HealthV4::OvulationTest
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::OvulationTest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Ovulation test record.
Instance Attribute Summary collapse
-
#result ⇒ String
Required.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OvulationTest
constructor
A new instance of OvulationTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OvulationTest
Returns a new instance of OvulationTest.
3985 3986 3987 |
# File 'lib/google/apis/health_v4/classes.rb', line 3985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#result ⇒ String
Required. The result of the ovulation test.
Corresponds to the JSON property result
3978 3979 3980 |
# File 'lib/google/apis/health_v4/classes.rb', line 3978 def result @result end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
3983 3984 3985 |
# File 'lib/google/apis/health_v4/classes.rb', line 3983 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3990 3991 3992 3993 |
# File 'lib/google/apis/health_v4/classes.rb', line 3990 def update!(**args) @result = args[:result] if args.key?(:result) @sample_time = args[:sample_time] if args.key?(:sample_time) end |