Class: Google::Apis::HealthV4::OxygenSaturation
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::OxygenSaturation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Captures the user's instantaneous oxygen saturation percentage (SpO2).
Instance Attribute Summary collapse
-
#percentage ⇒ Float
Required.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OxygenSaturation
constructor
A new instance of OxygenSaturation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OxygenSaturation
Returns a new instance of OxygenSaturation.
4010 4011 4012 |
# File 'lib/google/apis/health_v4/classes.rb', line 4010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percentage ⇒ Float
Required. The oxygen saturation percentage. Valid values are from 0 to 100.
Corresponds to the JSON property percentage
4003 4004 4005 |
# File 'lib/google/apis/health_v4/classes.rb', line 4003 def percentage @percentage end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
4008 4009 4010 |
# File 'lib/google/apis/health_v4/classes.rb', line 4008 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4015 4016 4017 4018 |
# File 'lib/google/apis/health_v4/classes.rb', line 4015 def update!(**args) @percentage = args[:percentage] if args.key?(:percentage) @sample_time = args[:sample_time] if args.key?(:sample_time) end |