Class: Google::Apis::HealthV4::Profile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Profile details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Profile

Returns a new instance of Profile.



4200
4201
4202
# File 'lib/google/apis/health_v4/classes.rb', line 4200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ageFixnum

Optional. The age in years based on the user's birth date. Updates to this field are currently not supported. Corresponds to the JSON property age

Returns:

  • (Fixnum)


4143
4144
4145
# File 'lib/google/apis/health_v4/classes.rb', line 4143

def age
  @age
end

#auto_running_stride_length_mmFixnum

Output only. The automatically calculated running stride length, in millimeters. The user must consent to one of the following access scopes to access this field: - https://www.googleapis.com/auth/googlehealth. activity_and_fitness.readonly - https://www.googleapis.com/auth/googlehealth. activity_and_fitness Corresponds to the JSON property autoRunningStrideLengthMm

Returns:

  • (Fixnum)


4152
4153
4154
# File 'lib/google/apis/health_v4/classes.rb', line 4152

def auto_running_stride_length_mm
  @auto_running_stride_length_mm
end

#auto_walking_stride_length_mmFixnum

Output only. The automatically calculated walking stride length, in millimeters. The user must consent to one of the following access scopes to access this field: - https://www.googleapis.com/auth/googlehealth. activity_and_fitness.readonly - https://www.googleapis.com/auth/googlehealth. activity_and_fitness Corresponds to the JSON property autoWalkingStrideLengthMm

Returns:

  • (Fixnum)


4161
4162
4163
# File 'lib/google/apis/health_v4/classes.rb', line 4161

def auto_walking_stride_length_mm
  @auto_walking_stride_length_mm
end

#membership_start_dateGoogle::Apis::HealthV4::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property membershipStartDate



4173
4174
4175
# File 'lib/google/apis/health_v4/classes.rb', line 4173

def membership_start_date
  @membership_start_date
end

#nameString

Identifier. The resource name of this Profile resource. Format: users/user/ profile Example: users/1234567890/profile or users/me/profile The user ID is a system-generated Google Health API user ID, a string of 1-63 characters consisting of lowercase and uppercase letters, numbers, and hyphens. The literal me can also be used to refer to the authenticated user. Corresponds to the JSON property name

Returns:

  • (String)


4182
4183
4184
# File 'lib/google/apis/health_v4/classes.rb', line 4182

def name
  @name
end

#user_configured_running_stride_length_mmFixnum

Optional. The user's user configured running stride length, in millimeters. The user must consent to one of the following access scopes to access this field: - https://www.googleapis.com/auth/googlehealth.activity_and_fitness. readonly - https://www.googleapis.com/auth/googlehealth.activity_and_fitness Corresponds to the JSON property userConfiguredRunningStrideLengthMm

Returns:

  • (Fixnum)


4190
4191
4192
# File 'lib/google/apis/health_v4/classes.rb', line 4190

def user_configured_running_stride_length_mm
  @user_configured_running_stride_length_mm
end

#user_configured_walking_stride_length_mmFixnum

Optional. The user's user configured walking stride length, in millimeters. The user must consent to one of the following access scopes to access this field: - https://www.googleapis.com/auth/googlehealth.activity_and_fitness. readonly - https://www.googleapis.com/auth/googlehealth.activity_and_fitness Corresponds to the JSON property userConfiguredWalkingStrideLengthMm

Returns:

  • (Fixnum)


4198
4199
4200
# File 'lib/google/apis/health_v4/classes.rb', line 4198

def user_configured_walking_stride_length_mm
  @user_configured_walking_stride_length_mm
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4205
4206
4207
4208
4209
4210
4211
4212
4213
# File 'lib/google/apis/health_v4/classes.rb', line 4205

def update!(**args)
  @age = args[:age] if args.key?(:age)
  @auto_running_stride_length_mm = args[:auto_running_stride_length_mm] if args.key?(:auto_running_stride_length_mm)
  @auto_walking_stride_length_mm = args[:auto_walking_stride_length_mm] if args.key?(:auto_walking_stride_length_mm)
  @membership_start_date = args[:membership_start_date] if args.key?(:membership_start_date)
  @name = args[:name] if args.key?(:name)
  @user_configured_running_stride_length_mm = args[:user_configured_running_stride_length_mm] if args.key?(:user_configured_running_stride_length_mm)
  @user_configured_walking_stride_length_mm = args[:user_configured_walking_stride_length_mm] if args.key?(:user_configured_walking_stride_length_mm)
end