Class: Google::Apis::HealthV4::RespiratoryRateSleepSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Records respiratory rate details during sleep. Can have multiple per day if the user sleeps multiple times.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RespiratoryRateSleepSummary

Returns a new instance of RespiratoryRateSleepSummary.



4530
4531
4532
# File 'lib/google/apis/health_v4/classes.rb', line 4530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deep_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property deepSleepStats



4508
4509
4510
# File 'lib/google/apis/health_v4/classes.rb', line 4508

def deep_sleep_stats
  @deep_sleep_stats
end

#full_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property fullSleepStats



4513
4514
4515
# File 'lib/google/apis/health_v4/classes.rb', line 4513

def full_sleep_stats
  @full_sleep_stats
end

#light_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property lightSleepStats



4518
4519
4520
# File 'lib/google/apis/health_v4/classes.rb', line 4518

def light_sleep_stats
  @light_sleep_stats
end

#rem_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property remSleepStats



4523
4524
4525
# File 'lib/google/apis/health_v4/classes.rb', line 4523

def rem_sleep_stats
  @rem_sleep_stats
end

#sample_timeGoogle::Apis::HealthV4::ObservationSampleTime

Represents a sample time of an observed data point. Corresponds to the JSON property sampleTime



4528
4529
4530
# File 'lib/google/apis/health_v4/classes.rb', line 4528

def sample_time
  @sample_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4535
4536
4537
4538
4539
4540
4541
# File 'lib/google/apis/health_v4/classes.rb', line 4535

def update!(**args)
  @deep_sleep_stats = args[:deep_sleep_stats] if args.key?(:deep_sleep_stats)
  @full_sleep_stats = args[:full_sleep_stats] if args.key?(:full_sleep_stats)
  @light_sleep_stats = args[:light_sleep_stats] if args.key?(:light_sleep_stats)
  @rem_sleep_stats = args[:rem_sleep_stats] if args.key?(:rem_sleep_stats)
  @sample_time = args[:sample_time] if args.key?(:sample_time)
end