Class: Google::Apis::HealthV4::RollUpDataPointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Request to roll up data points by physical time intervals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollUpDataPointsRequest

Returns a new instance of RollUpDataPointsRequest.



4645
4646
4647
# File 'lib/google/apis/health_v4/classes.rb', line 4645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_familyString

Optional. The data source family name to roll up. If empty, data points from all available data sources will be rolled up. Format: users/me/ dataSourceFamilies/data_source_family`The supported values are: -users/me/ dataSourceFamilies/all-sources- Default value. Includes data from all available data sources. -users/me/dataSourceFamilies/google-wearables- Includes data from Google and Fitbit tracker devices (such as Fitbit trackers and Pixel Watch). Excludes manually logged data. -users/me/ dataSourceFamilies/google-sources- Includes first-party Google data, such as data from tracker devices, manually logged data, and Health Connect. Corresponds to the JSON propertydataSourceFamily`

Returns:

  • (String)


4615
4616
4617
# File 'lib/google/apis/health_v4/classes.rb', line 4615

def data_source_family
  @data_source_family
end

#page_sizeFixnum

Optional. The maximum number of data points to return. If unspecified, at most 1440 data points will be returned. The maximum page size is 10000; values above that will be truncated accordingly. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


4622
4623
4624
# File 'lib/google/apis/health_v4/classes.rb', line 4622

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token from a previous request, if any. All other request fields need to be the same as in the initial request when the page token is specified. Corresponds to the JSON property pageToken

Returns:

  • (String)


4629
4630
4631
# File 'lib/google/apis/health_v4/classes.rb', line 4629

def page_token
  @page_token
end

#rangeGoogle::Apis::HealthV4::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property range



4637
4638
4639
# File 'lib/google/apis/health_v4/classes.rb', line 4637

def range
  @range
end

#window_sizeString

Required. The size of the time window to group data points into before applying the aggregation functions. Must be at least 1 second. Corresponds to the JSON property windowSize

Returns:

  • (String)


4643
4644
4645
# File 'lib/google/apis/health_v4/classes.rb', line 4643

def window_size
  @window_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4650
4651
4652
4653
4654
4655
4656
# File 'lib/google/apis/health_v4/classes.rb', line 4650

def update!(**args)
  @data_source_family = args[:data_source_family] if args.key?(:data_source_family)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @range = args[:range] if args.key?(:range)
  @window_size = args[:window_size] if args.key?(:window_size)
end