Class: Google::Apis::HealthV4::RollUpDataPointsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Response containing the list of rolled up data points.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollUpDataPointsResponse

Returns a new instance of RollUpDataPointsResponse.



4674
4675
4676
# File 'lib/google/apis/health_v4/classes.rb', line 4674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4667
4668
4669
# File 'lib/google/apis/health_v4/classes.rb', line 4667

def next_page_token
  @next_page_token
end

#rollup_data_pointsArray<Google::Apis::HealthV4::RollupDataPoint>

Values for each aggregation time window. Corresponds to the JSON property rollupDataPoints



4672
4673
4674
# File 'lib/google/apis/health_v4/classes.rb', line 4672

def rollup_data_points
  @rollup_data_points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4679
4680
4681
4682
# File 'lib/google/apis/health_v4/classes.rb', line 4679

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @rollup_data_points = args[:rollup_data_points] if args.key?(:rollup_data_points)
end