Class: Google::Apis::HealthV4::SleepMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Additional information about how the sleep was processed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SleepMetadata

Returns a new instance of SleepMetadata.



5146
5147
5148
# File 'lib/google/apis/health_v4/classes.rb', line 5146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_idString

Optional. Sleep identifier relevant in the context of the data source. Corresponds to the JSON property externalId

Returns:

  • (String)


5108
5109
5110
# File 'lib/google/apis/health_v4/classes.rb', line 5108

def external_id
  @external_id
end

#main_sleepBoolean Also known as: main_sleep?

Output only. main_sleep: the longest sleep session with stages within one day. If no sleep session has stages, then the longest sleep is the main_sleep . If there are multiple days of sleep in the response, there is one main_sleep per day. Corresponds to the JSON property mainSleep

Returns:

  • (Boolean)


5116
5117
5118
# File 'lib/google/apis/health_v4/classes.rb', line 5116

def main_sleep
  @main_sleep
end

#manually_editedBoolean Also known as: manually_edited?

Output only. Some sleeps autodetected by algorithms can be manually edited by users. Corresponds to the JSON property manuallyEdited

Returns:

  • (Boolean)


5123
5124
5125
# File 'lib/google/apis/health_v4/classes.rb', line 5123

def manually_edited
  @manually_edited
end

#napBoolean Also known as: nap?

Output only. Naps are sleeps without stages and relatively short durations. Corresponds to the JSON property nap

Returns:

  • (Boolean)


5129
5130
5131
# File 'lib/google/apis/health_v4/classes.rb', line 5129

def nap
  @nap
end

#processedBoolean Also known as: processed?

Output only. Sleep and sleep stages algorithms finished processing. A true value indicates whether all data processing for the session is complete. A false value means sleep period is detected but sleep stages is still processing. Corresponds to the JSON property processed

Returns:

  • (Boolean)


5138
5139
5140
# File 'lib/google/apis/health_v4/classes.rb', line 5138

def processed
  @processed
end

#stages_statusString

Output only. Sleep stages algorithm processing status. Corresponds to the JSON property stagesStatus

Returns:

  • (String)


5144
5145
5146
# File 'lib/google/apis/health_v4/classes.rb', line 5144

def stages_status
  @stages_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5151
5152
5153
5154
5155
5156
5157
5158
# File 'lib/google/apis/health_v4/classes.rb', line 5151

def update!(**args)
  @external_id = args[:external_id] if args.key?(:external_id)
  @main_sleep = args[:main_sleep] if args.key?(:main_sleep)
  @manually_edited = args[:manually_edited] if args.key?(:manually_edited)
  @nap = args[:nap] if args.key?(:nap)
  @processed = args[:processed] if args.key?(:processed)
  @stages_status = args[:stages_status] if args.key?(:stages_status)
end