Class: Google::Apis::HealthV4::Steps
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Steps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Step count over the time interval.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Required.
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Steps
constructor
A new instance of Steps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Steps
Returns a new instance of Steps.
3906 3907 3908 |
# File 'lib/google/apis/health_v4/classes.rb', line 3906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Required. Number of steps in the recorded interval.
Corresponds to the JSON property count
3899 3900 3901 |
# File 'lib/google/apis/health_v4/classes.rb', line 3899 def count @count end |
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
3904 3905 3906 |
# File 'lib/google/apis/health_v4/classes.rb', line 3904 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3911 3912 3913 3914 |
# File 'lib/google/apis/health_v4/classes.rb', line 3911 def update!(**args) @count = args[:count] if args.key?(:count) @interval = args[:interval] if args.key?(:interval) end |