Class: Google::Apis::HealthV4::SwimLengthsData
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SwimLengthsData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Swim lengths data over the time interval.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
-
#stroke_count ⇒ Fixnum
Required.
-
#swim_stroke_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SwimLengthsData
constructor
A new instance of SwimLengthsData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SwimLengthsData
Returns a new instance of SwimLengthsData.
5502 5503 5504 |
# File 'lib/google/apis/health_v4/classes.rb', line 5502 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
5490 5491 5492 |
# File 'lib/google/apis/health_v4/classes.rb', line 5490 def interval @interval end |
#stroke_count ⇒ Fixnum
Required. Number of strokes in the lap.
Corresponds to the JSON property strokeCount
5495 5496 5497 |
# File 'lib/google/apis/health_v4/classes.rb', line 5495 def stroke_count @stroke_count end |
#swim_stroke_type ⇒ String
Required. Swim stroke type.
Corresponds to the JSON property swimStrokeType
5500 5501 5502 |
# File 'lib/google/apis/health_v4/classes.rb', line 5500 def swim_stroke_type @swim_stroke_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5507 5508 5509 5510 5511 |
# File 'lib/google/apis/health_v4/classes.rb', line 5507 def update!(**args) @interval = args[:interval] if args.key?(:interval) @stroke_count = args[:stroke_count] if args.key?(:stroke_count) @swim_stroke_type = args[:swim_stroke_type] if args.key?(:swim_stroke_type) end |