Class: Google::Apis::HealthV4::Symptoms
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Symptoms
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Symptoms logged by the user.
Instance Attribute Summary collapse
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#symptoms ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Symptoms
constructor
A new instance of Symptoms.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Symptoms
Returns a new instance of Symptoms.
5771 5772 5773 |
# File 'lib/google/apis/health_v4/classes.rb', line 5771 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
5764 5765 5766 |
# File 'lib/google/apis/health_v4/classes.rb', line 5764 def sample_time @sample_time end |
#symptoms ⇒ Array<String>
Required. List of symptoms experienced.
Corresponds to the JSON property symptoms
5769 5770 5771 |
# File 'lib/google/apis/health_v4/classes.rb', line 5769 def symptoms @symptoms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5776 5777 5778 5779 |
# File 'lib/google/apis/health_v4/classes.rb', line 5776 def update!(**args) @sample_time = args[:sample_time] if args.key?(:sample_time) @symptoms = args[:symptoms] if args.key?(:symptoms) end |