Class: Google::Apis::HealthV4::TimeInHeartRateZoneValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the total time spent in a specific heart rate zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeInHeartRateZoneValue

Returns a new instance of TimeInHeartRateZoneValue.



5685
5686
5687
# File 'lib/google/apis/health_v4/classes.rb', line 5685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The total time spent in the specified heart rate zone. Corresponds to the JSON property duration

Returns:

  • (String)


5678
5679
5680
# File 'lib/google/apis/health_v4/classes.rb', line 5678

def duration
  @duration
end

#heart_rate_zoneString

The heart rate zone. Corresponds to the JSON property heartRateZone

Returns:

  • (String)


5683
5684
5685
# File 'lib/google/apis/health_v4/classes.rb', line 5683

def heart_rate_zone
  @heart_rate_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5690
5691
5692
5693
# File 'lib/google/apis/health_v4/classes.rb', line 5690

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone)
end