Class: Google::Apis::HealthV4::TotalCaloriesRollupValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the result of the rollup of the user's total calories. Note: Queries for the total-calories data type must include a time interval filter (such as total_calories.interval.start_time or total_calories.interval. civil_start_time). The maximum range is 14 days. Example filter query: total_calories.interval.start_time >= "2026-04-20T00:00:00Z" AND total_calories.interval.start_time < "2026-04-21T00:00:00Z"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TotalCaloriesRollupValue

Returns a new instance of TotalCaloriesRollupValue.



5818
5819
5820
# File 'lib/google/apis/health_v4/classes.rb', line 5818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kcal_sumFloat

Sum of the total calories in kilocalories. Corresponds to the JSON property kcalSum

Returns:

  • (Float)


5816
5817
5818
# File 'lib/google/apis/health_v4/classes.rb', line 5816

def kcal_sum
  @kcal_sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5823
5824
5825
# File 'lib/google/apis/health_v4/classes.rb', line 5823

def update!(**args)
  @kcal_sum = args[:kcal_sum] if args.key?(:kcal_sum)
end