Class: Google::Apis::HealthV4::Vo2Max
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Vo2Max
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
VO2 max measurement.
Instance Attribute Summary collapse
-
#measurement_method ⇒ String
Optional.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#vo2_max ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Vo2Max
constructor
A new instance of Vo2Max.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Vo2Max
Returns a new instance of Vo2Max.
5833 5834 5835 |
# File 'lib/google/apis/health_v4/classes.rb', line 5833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#measurement_method ⇒ String
Optional. The method used to measure the VO2 max value.
Corresponds to the JSON property measurementMethod
5820 5821 5822 |
# File 'lib/google/apis/health_v4/classes.rb', line 5820 def measurement_method @measurement_method end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
5825 5826 5827 |
# File 'lib/google/apis/health_v4/classes.rb', line 5825 def sample_time @sample_time end |
#vo2_max ⇒ Float
Required. VO2 max value measured as in ml consumed oxygen / kg of body weight /
min.
Corresponds to the JSON property vo2Max
5831 5832 5833 |
# File 'lib/google/apis/health_v4/classes.rb', line 5831 def vo2_max @vo2_max end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5838 5839 5840 5841 5842 |
# File 'lib/google/apis/health_v4/classes.rb', line 5838 def update!(**args) @measurement_method = args[:measurement_method] if args.key?(:measurement_method) @sample_time = args[:sample_time] if args.key?(:sample_time) @vo2_max = args[:vo2_max] if args.key?(:vo2_max) end |