Class: Google::Apis::HealthV4::Weight
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Weight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Body weight measurement.
Instance Attribute Summary collapse
-
#notes ⇒ String
Optional.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#weight_grams ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Weight
constructor
A new instance of Weight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Weight
Returns a new instance of Weight.
5931 5932 5933 |
# File 'lib/google/apis/health_v4/classes.rb', line 5931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#notes ⇒ String
Optional. Standard free-form notes captured at manual logging.
Corresponds to the JSON property notes
5919 5920 5921 |
# File 'lib/google/apis/health_v4/classes.rb', line 5919 def notes @notes end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
5924 5925 5926 |
# File 'lib/google/apis/health_v4/classes.rb', line 5924 def sample_time @sample_time end |
#weight_grams ⇒ Float
Required. Weight of a user in grams.
Corresponds to the JSON property weightGrams
5929 5930 5931 |
# File 'lib/google/apis/health_v4/classes.rb', line 5929 def weight_grams @weight_grams end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5936 5937 5938 5939 5940 |
# File 'lib/google/apis/health_v4/classes.rb', line 5936 def update!(**args) @notes = args[:notes] if args.key?(:notes) @sample_time = args[:sample_time] if args.key?(:sample_time) @weight_grams = args[:weight_grams] if args.key?(:weight_grams) end |