Module: Google::Apis::HealthV4

Defined in:
lib/google/apis/health_v4.rb,
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/service.rb,
lib/google/apis/health_v4/gem_version.rb,
lib/google/apis/health_v4/representations.rb

Overview

Google Health API

The Google Health API lets you view and manage health and fitness metrics and measurement data.

Defined Under Namespace

Classes: ActiveMinutes, ActiveMinutesByActivityLevel, ActiveMinutesRollupByActivityLevel, ActiveMinutesRollupValue, ActiveZoneMinutes, ActiveZoneMinutesRollupValue, ActivityLevel, ActivityLevelRollupByActivityLevelType, ActivityLevelRollupValue, Altitude, AltitudeRollupValue, Application, BatchDeleteDataPointsRequest, BodyFat, BodyFatRollupValue, CaloriesInHeartRateZoneRollupValue, CaloriesInHeartRateZoneValue, CivilDateTime, CivilTimeInterval, CreateSubscriberPayload, DailyHeartRateVariability, DailyHeartRateZones, DailyOxygenSaturation, DailyRespiratoryRate, DailyRestingHeartRate, DailyRestingHeartRateMetadata, DailyRollUpDataPointsRequest, DailyRollUpDataPointsResponse, DailyRollupDataPoint, DailySleepTemperatureDerivations, DailyVo2Max, DataPoint, DataSource, Date, DateTime, Device, Distance, DistanceRollupValue, EndpointAuthorization, Exercise, ExerciseEvent, ExerciseMetadata, ExportExerciseTcxResponse, Floors, FloorsRollupValue, GoogleDevicesandservicesHealthV4DataType, GoogleHealthAPIService, HeartRate, HeartRateMetadata, HeartRateRollupValue, HeartRateVariability, HeartRateVariabilityPersonalRangeRollupValue, HeartRateZone, Height, HttpHeader, HttpResponse, HydrationLog, HydrationLogRollupValue, Identity, Interval, ListDataPointsResponse, ListSubscribersResponse, MetricsSummary, MobilityMetrics, ObservationSampleTime, ObservationTimeInterval, Operation, OutOfBedSegment, OxygenSaturation, Profile, ReconcileDataPointsResponse, ReconciledDataPoint, RespiratoryRateSleepSummary, RespiratoryRateSleepSummaryStatistics, RestingHeartRatePersonalRangeRollupValue, RollUpDataPointsRequest, RollUpDataPointsResponse, RollupDataPoint, RunVo2Max, RunVo2MaxRollupValue, SedentaryPeriod, SedentaryPeriodRollupValue, SessionTimeInterval, Settings, Sleep, SleepMetadata, SleepStage, SleepSummary, SplitSummary, StageSummary, Status, Steps, StepsRollupValue, Subscriber, SubscriberConfig, SwimLengthsData, SwimLengthsDataRollupValue, TimeInHeartRateZone, TimeInHeartRateZoneRollupValue, TimeInHeartRateZoneValue, TimeInHeartRateZones, TimeOfDay, TimeZone, TotalCaloriesRollupValue, Vo2Max, VolumeQuantity, VolumeQuantityRollup, WebhookNotificationCloudLog, Weight, WeightRollupValue

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-health_v4 gem

"0.1.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260416"
VERSION =

Version of the Google Health API this client connects to. This is NOT the gem version.

'V4'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'