Class: Google::Apis::HealthV4::ActiveMinutes
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ActiveMinutes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Record of active minutes in a given time interval.
Instance Attribute Summary collapse
-
#active_minutes_by_activity_level ⇒ Array<Google::Apis::HealthV4::ActiveMinutesByActivityLevel>
Required.
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActiveMinutes
constructor
A new instance of ActiveMinutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActiveMinutes
Returns a new instance of ActiveMinutes.
40 41 42 |
# File 'lib/google/apis/health_v4/classes.rb', line 40 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_minutes_by_activity_level ⇒ Array<Google::Apis::HealthV4::ActiveMinutesByActivityLevel>
Required. Active minutes by activity level. At most one record per activity
level is allowed.
Corresponds to the JSON property activeMinutesByActivityLevel
33 34 35 |
# File 'lib/google/apis/health_v4/classes.rb', line 33 def active_minutes_by_activity_level @active_minutes_by_activity_level end |
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
38 39 40 |
# File 'lib/google/apis/health_v4/classes.rb', line 38 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45 46 47 48 |
# File 'lib/google/apis/health_v4/classes.rb', line 45 def update!(**args) @active_minutes_by_activity_level = args[:active_minutes_by_activity_level] if args.key?(:active_minutes_by_activity_level) @interval = args[:interval] if args.key?(:interval) end |