Class: Google::Apis::HealthV4::ActivityLevel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Internal type to capture activity level during a certain time interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActivityLevel

Returns a new instance of ActivityLevel.



200
201
202
# File 'lib/google/apis/health_v4/classes.rb', line 200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activity_level_typeString

Required. Activity level type in the given time interval. Corresponds to the JSON property activityLevelType

Returns:

  • (String)


193
194
195
# File 'lib/google/apis/health_v4/classes.rb', line 193

def activity_level_type
  @activity_level_type
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



198
199
200
# File 'lib/google/apis/health_v4/classes.rb', line 198

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



205
206
207
208
# File 'lib/google/apis/health_v4/classes.rb', line 205

def update!(**args)
  @activity_level_type = args[:activity_level_type] if args.key?(:activity_level_type)
  @interval = args[:interval] if args.key?(:interval)
end