Class: Google::Apis::HealthV4::Application

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Optional metadata for the application that provided this data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Application

Returns a new instance of Application.



331
332
333
# File 'lib/google/apis/health_v4/classes.rb', line 331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_web_client_idString

Output only. The Google OAuth 2.0 client ID of the web application or service that recorded the data. This is the client ID used during the Google OAuth flow to obtain user credentials. This field is system-populated when the data is uploaded from Google Web API. Corresponds to the JSON property googleWebClientId

Returns:

  • (String)


310
311
312
# File 'lib/google/apis/health_v4/classes.rb', line 310

def google_web_client_id
  @google_web_client_id
end

#package_nameString

Output only. A unique identifier for the mobile application that was the source of the data. This is typically the application's package name on Android (e.g., com.google.fitbit) or the bundle ID on iOS. This field is informational and helps trace data origin. This field is system-populated when the data is uploaded from the Fitbit mobile application, Health Connect or Health Kit. Corresponds to the JSON property packageName

Returns:

  • (String)


320
321
322
# File 'lib/google/apis/health_v4/classes.rb', line 320

def package_name
  @package_name
end

#web_client_idString

Output only. The client ID of the application that recorded the data. This ID is a legacy Fitbit API client ID, which is different from a Google OAuth client ID. Example format: ABC123. This field is system-populated and used for tracing data from legacy Fitbit API integrations. This field is system- populated when the data is uploaded from a legacy Fitbit API integration. Corresponds to the JSON property webClientId

Returns:

  • (String)


329
330
331
# File 'lib/google/apis/health_v4/classes.rb', line 329

def web_client_id
  @web_client_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



336
337
338
339
340
# File 'lib/google/apis/health_v4/classes.rb', line 336

def update!(**args)
  @google_web_client_id = args[:google_web_client_id] if args.key?(:google_web_client_id)
  @package_name = args[:package_name] if args.key?(:package_name)
  @web_client_id = args[:web_client_id] if args.key?(:web_client_id)
end