Class: Google::Apis::HealthV4::BloodGlucose
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::BloodGlucose
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents a blood glucose level measurement. LINT: LEGACY_NAMES
Instance Attribute Summary collapse
-
#blood_glucose_milligrams_per_deciliter ⇒ Float
Required.
-
#meal_type ⇒ String
Optional.
-
#measurement_source ⇒ String
Optional.
-
#measurement_timing ⇒ String
Optional.
-
#notes ⇒ String
Optional.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#specimen ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BloodGlucose
constructor
A new instance of BloodGlucose.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BloodGlucose
Returns a new instance of BloodGlucose.
546 547 548 |
# File 'lib/google/apis/health_v4/classes.rb', line 546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blood_glucose_milligrams_per_deciliter ⇒ Float
Required. Blood glucose level concentration in mg/dL.
Corresponds to the JSON property bloodGlucoseMilligramsPerDeciliter
514 515 516 |
# File 'lib/google/apis/health_v4/classes.rb', line 514 def blood_glucose_milligrams_per_deciliter @blood_glucose_milligrams_per_deciliter end |
#meal_type ⇒ String
Optional. Meal type of the measurement.
Corresponds to the JSON property mealType
519 520 521 |
# File 'lib/google/apis/health_v4/classes.rb', line 519 def meal_type @meal_type end |
#measurement_source ⇒ String
Optional. Source of the measurement.
Corresponds to the JSON property measurementSource
524 525 526 |
# File 'lib/google/apis/health_v4/classes.rb', line 524 def measurement_source @measurement_source end |
#measurement_timing ⇒ String
Optional. Timing of the measurement.
Corresponds to the JSON property measurementTiming
529 530 531 |
# File 'lib/google/apis/health_v4/classes.rb', line 529 def measurement_timing @measurement_timing end |
#notes ⇒ String
Optional. Standard free-form notes captured at manual logging.
Corresponds to the JSON property notes
534 535 536 |
# File 'lib/google/apis/health_v4/classes.rb', line 534 def notes @notes end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
539 540 541 |
# File 'lib/google/apis/health_v4/classes.rb', line 539 def sample_time @sample_time end |
#specimen ⇒ String
Optional. Type of body fluid used to measure the blood glucose.
Corresponds to the JSON property specimen
544 545 546 |
# File 'lib/google/apis/health_v4/classes.rb', line 544 def specimen @specimen end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
551 552 553 554 555 556 557 558 559 |
# File 'lib/google/apis/health_v4/classes.rb', line 551 def update!(**args) @blood_glucose_milligrams_per_deciliter = args[:blood_glucose_milligrams_per_deciliter] if args.key?(:blood_glucose_milligrams_per_deciliter) @meal_type = args[:meal_type] if args.key?(:meal_type) @measurement_source = args[:measurement_source] if args.key?(:measurement_source) @measurement_timing = args[:measurement_timing] if args.key?(:measurement_timing) @notes = args[:notes] if args.key?(:notes) @sample_time = args[:sample_time] if args.key?(:sample_time) @specimen = args[:specimen] if args.key?(:specimen) end |