Class: Google::Apis::HealthV4::CaloriesInHeartRateZoneValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::CaloriesInHeartRateZoneValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the amount of kilocalories burned in a specific heart rate zone.
Instance Attribute Summary collapse
-
#heart_rate_zone ⇒ String
The heart rate zone.
-
#kcal ⇒ Float
The amount of kilocalories burned in the specified heart rate zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CaloriesInHeartRateZoneValue
constructor
A new instance of CaloriesInHeartRateZoneValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CaloriesInHeartRateZoneValue
Returns a new instance of CaloriesInHeartRateZoneValue.
468 469 470 |
# File 'lib/google/apis/health_v4/classes.rb', line 468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#heart_rate_zone ⇒ String
The heart rate zone.
Corresponds to the JSON property heartRateZone
461 462 463 |
# File 'lib/google/apis/health_v4/classes.rb', line 461 def heart_rate_zone @heart_rate_zone end |
#kcal ⇒ Float
The amount of kilocalories burned in the specified heart rate zone.
Corresponds to the JSON property kcal
466 467 468 |
# File 'lib/google/apis/health_v4/classes.rb', line 466 def kcal @kcal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
473 474 475 476 |
# File 'lib/google/apis/health_v4/classes.rb', line 473 def update!(**args) @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone) @kcal = args[:kcal] if args.key?(:kcal) end |