Class: Google::Apis::HealthV4::CaloriesInHeartRateZoneValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the amount of kilocalories burned in a specific heart rate zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CaloriesInHeartRateZoneValue

Returns a new instance of CaloriesInHeartRateZoneValue.



441
442
443
# File 'lib/google/apis/health_v4/classes.rb', line 441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#heart_rate_zoneString

The heart rate zone. Corresponds to the JSON property heartRateZone

Returns:

  • (String)


434
435
436
# File 'lib/google/apis/health_v4/classes.rb', line 434

def heart_rate_zone
  @heart_rate_zone
end

#kcalFloat

The amount of kilocalories burned in the specified heart rate zone. Corresponds to the JSON property kcal

Returns:

  • (Float)


439
440
441
# File 'lib/google/apis/health_v4/classes.rb', line 439

def kcal
  @kcal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



446
447
448
449
# File 'lib/google/apis/health_v4/classes.rb', line 446

def update!(**args)
  @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone)
  @kcal = args[:kcal] if args.key?(:kcal)
end