Class: Google::Apis::HealthV4::CivilTimeInterval
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::CivilTimeInterval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Counterpart of google.type.Interval, but using CivilDateTime.
Instance Attribute Summary collapse
-
#end ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#start ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CivilTimeInterval
constructor
A new instance of CivilTimeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CivilTimeInterval
Returns a new instance of CivilTimeInterval.
725 726 727 |
# File 'lib/google/apis/health_v4/classes.rb', line 725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property end
716 717 718 |
# File 'lib/google/apis/health_v4/classes.rb', line 716 def end @end end |
#start ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property start
723 724 725 |
# File 'lib/google/apis/health_v4/classes.rb', line 723 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
730 731 732 733 |
# File 'lib/google/apis/health_v4/classes.rb', line 730 def update!(**args) @end = args[:end] if args.key?(:end) @start = args[:start] if args.key?(:start) end |