Class: Google::Apis::HealthV4::CivilTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Counterpart of google.type.Interval, but using CivilDateTime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CivilTimeInterval

Returns a new instance of CivilTimeInterval.



533
534
535
# File 'lib/google/apis/health_v4/classes.rb', line 533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property end



524
525
526
# File 'lib/google/apis/health_v4/classes.rb', line 524

def end
  @end
end

#startGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property start



531
532
533
# File 'lib/google/apis/health_v4/classes.rb', line 531

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



538
539
540
541
# File 'lib/google/apis/health_v4/classes.rb', line 538

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @start = args[:start] if args.key?(:start)
end