Class: Google::Apis::HealthV4::CoreBodyTemperature
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::CoreBodyTemperature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Core body temperature measurement, distinct from peripheral body temperature, reflects the temperature of the body's internal organs.
Instance Attribute Summary collapse
-
#id ⇒ String
Optional.
-
#measurement_location ⇒ String
Optional.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#temperature_celsius ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CoreBodyTemperature
constructor
A new instance of CoreBodyTemperature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CoreBodyTemperature
Returns a new instance of CoreBodyTemperature.
761 762 763 |
# File 'lib/google/apis/health_v4/classes.rb', line 761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Optional. The unique identifier of the core body temperature measurement.
Corresponds to the JSON property id
744 745 746 |
# File 'lib/google/apis/health_v4/classes.rb', line 744 def id @id end |
#measurement_location ⇒ String
Optional. The location of the core body temperature measurement.
Corresponds to the JSON property measurementLocation
749 750 751 |
# File 'lib/google/apis/health_v4/classes.rb', line 749 def measurement_location @measurement_location end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
754 755 756 |
# File 'lib/google/apis/health_v4/classes.rb', line 754 def sample_time @sample_time end |
#temperature_celsius ⇒ Float
Required. The core body temperature in Celsius.
Corresponds to the JSON property temperatureCelsius
759 760 761 |
# File 'lib/google/apis/health_v4/classes.rb', line 759 def temperature_celsius @temperature_celsius end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
766 767 768 769 770 771 |
# File 'lib/google/apis/health_v4/classes.rb', line 766 def update!(**args) @id = args[:id] if args.key?(:id) @measurement_location = args[:measurement_location] if args.key?(:measurement_location) @sample_time = args[:sample_time] if args.key?(:sample_time) @temperature_celsius = args[:temperature_celsius] if args.key?(:temperature_celsius) end |