Class: Google::Apis::HealthV4::DailyOxygenSaturation
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DailyOxygenSaturation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
A daily oxygen saturation (SpO2) record. Represents the user's daily oxygen saturation summary, typically calculated during sleep.
Instance Attribute Summary collapse
-
#average_percentage ⇒ Float
Required.
-
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday.
-
#lower_bound_percentage ⇒ Float
Required.
-
#standard_deviation_percentage ⇒ Float
Optional.
-
#upper_bound_percentage ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyOxygenSaturation
constructor
A new instance of DailyOxygenSaturation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyOxygenSaturation
Returns a new instance of DailyOxygenSaturation.
714 715 716 |
# File 'lib/google/apis/health_v4/classes.rb', line 714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_percentage ⇒ Float
Required. The average value of the oxygen saturation samples during the sleep.
Corresponds to the JSON property averagePercentage
682 683 684 |
# File 'lib/google/apis/health_v4/classes.rb', line 682 def average_percentage @average_percentage end |
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property date
694 695 696 |
# File 'lib/google/apis/health_v4/classes.rb', line 694 def date @date end |
#lower_bound_percentage ⇒ Float
Required. The lower bound of the confidence interval of oxygen saturation
samples during sleep.
Corresponds to the JSON property lowerBoundPercentage
700 701 702 |
# File 'lib/google/apis/health_v4/classes.rb', line 700 def lower_bound_percentage @lower_bound_percentage end |
#standard_deviation_percentage ⇒ Float
Optional. Standard deviation of the daily oxygen saturation averages from the
past 7-30 days.
Corresponds to the JSON property standardDeviationPercentage
706 707 708 |
# File 'lib/google/apis/health_v4/classes.rb', line 706 def standard_deviation_percentage @standard_deviation_percentage end |
#upper_bound_percentage ⇒ Float
Required. The upper bound of the confidence interval of oxygen saturation
samples during sleep.
Corresponds to the JSON property upperBoundPercentage
712 713 714 |
# File 'lib/google/apis/health_v4/classes.rb', line 712 def upper_bound_percentage @upper_bound_percentage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
719 720 721 722 723 724 725 |
# File 'lib/google/apis/health_v4/classes.rb', line 719 def update!(**args) @average_percentage = args[:average_percentage] if args.key?(:average_percentage) @date = args[:date] if args.key?(:date) @lower_bound_percentage = args[:lower_bound_percentage] if args.key?(:lower_bound_percentage) @standard_deviation_percentage = args[:standard_deviation_percentage] if args.key?(:standard_deviation_percentage) @upper_bound_percentage = args[:upper_bound_percentage] if args.key?(:upper_bound_percentage) end |