Class: Google::Apis::HealthV4::DailyOxygenSaturation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

A daily oxygen saturation (SpO2) record. Represents the user's daily oxygen saturation summary, typically calculated during sleep.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyOxygenSaturation

Returns a new instance of DailyOxygenSaturation.



687
688
689
# File 'lib/google/apis/health_v4/classes.rb', line 687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_percentageFloat

Required. The average value of the oxygen saturation samples during the sleep. Corresponds to the JSON property averagePercentage

Returns:

  • (Float)


655
656
657
# File 'lib/google/apis/health_v4/classes.rb', line 655

def average_percentage
  @average_percentage
end

#dateGoogle::Apis::HealthV4::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



667
668
669
# File 'lib/google/apis/health_v4/classes.rb', line 667

def date
  @date
end

#lower_bound_percentageFloat

Required. The lower bound of the confidence interval of oxygen saturation samples during sleep. Corresponds to the JSON property lowerBoundPercentage

Returns:

  • (Float)


673
674
675
# File 'lib/google/apis/health_v4/classes.rb', line 673

def lower_bound_percentage
  @lower_bound_percentage
end

#standard_deviation_percentageFloat

Optional. Standard deviation of the daily oxygen saturation averages from the past 7-30 days. Corresponds to the JSON property standardDeviationPercentage

Returns:

  • (Float)


679
680
681
# File 'lib/google/apis/health_v4/classes.rb', line 679

def standard_deviation_percentage
  @standard_deviation_percentage
end

#upper_bound_percentageFloat

Required. The upper bound of the confidence interval of oxygen saturation samples during sleep. Corresponds to the JSON property upperBoundPercentage

Returns:

  • (Float)


685
686
687
# File 'lib/google/apis/health_v4/classes.rb', line 685

def upper_bound_percentage
  @upper_bound_percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



692
693
694
695
696
697
698
# File 'lib/google/apis/health_v4/classes.rb', line 692

def update!(**args)
  @average_percentage = args[:average_percentage] if args.key?(:average_percentage)
  @date = args[:date] if args.key?(:date)
  @lower_bound_percentage = args[:lower_bound_percentage] if args.key?(:lower_bound_percentage)
  @standard_deviation_percentage = args[:standard_deviation_percentage] if args.key?(:standard_deviation_percentage)
  @upper_bound_percentage = args[:upper_bound_percentage] if args.key?(:upper_bound_percentage)
end