Class: Google::Apis::HealthV4::DailyRollUpDataPointsRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DailyRollUpDataPointsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Request to roll up data points by civil time intervals.
Instance Attribute Summary collapse
-
#data_source_family ⇒ String
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#range ⇒ Google::Apis::HealthV4::CivilTimeInterval
Counterpart of google.type.Interval, but using CivilDateTime.
-
#window_size_days ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyRollUpDataPointsRequest
constructor
A new instance of DailyRollUpDataPointsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyRollUpDataPointsRequest
Returns a new instance of DailyRollUpDataPointsRequest.
1147 1148 1149 |
# File 'lib/google/apis/health_v4/classes.rb', line 1147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_source_family ⇒ String
Optional. The data source family name to roll up. If empty, data points from
all available data sources will be rolled up. Format: users/me/
dataSourceFamilies/data_source_family`The supported values are: -users/me/
dataSourceFamilies/all-sources- default value -users/me/dataSourceFamilies/
google-wearables- tracker devices -users/me/dataSourceFamilies/google-
sources- Google first party sources
Corresponds to the JSON propertydataSourceFamily`
1120 1121 1122 |
# File 'lib/google/apis/health_v4/classes.rb', line 1120 def data_source_family @data_source_family end |
#page_size ⇒ Fixnum
Optional. The maximum number of data points to return. If unspecified, at most
1440 data points will be returned. The maximum page size is 10000; values
above that will be truncated accordingly.
Corresponds to the JSON property pageSize
1127 1128 1129 |
# File 'lib/google/apis/health_v4/classes.rb', line 1127 def page_size @page_size end |
#page_token ⇒ String
Optional. The next_page_token from a previous request, if any. All other
request fields need to be the same as in the initial request when the page
token is specified.
Corresponds to the JSON property pageToken
1134 1135 1136 |
# File 'lib/google/apis/health_v4/classes.rb', line 1134 def page_token @page_token end |
#range ⇒ Google::Apis::HealthV4::CivilTimeInterval
Counterpart of google.type.Interval, but using CivilDateTime.
Corresponds to the JSON property range
1139 1140 1141 |
# File 'lib/google/apis/health_v4/classes.rb', line 1139 def range @range end |
#window_size_days ⇒ Fixnum
Optional. Aggregation window size, in number of days. Defaults to 1 if not
specified.
Corresponds to the JSON property windowSizeDays
1145 1146 1147 |
# File 'lib/google/apis/health_v4/classes.rb', line 1145 def window_size_days @window_size_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1152 1153 1154 1155 1156 1157 1158 |
# File 'lib/google/apis/health_v4/classes.rb', line 1152 def update!(**args) @data_source_family = args[:data_source_family] if args.key?(:data_source_family) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @range = args[:range] if args.key?(:range) @window_size_days = args[:window_size_days] if args.key?(:window_size_days) end |