Class: Google::Apis::HealthV4::DailyRollUpDataPointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Request to roll up data points by civil time intervals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyRollUpDataPointsRequest

Returns a new instance of DailyRollUpDataPointsRequest.



858
859
860
# File 'lib/google/apis/health_v4/classes.rb', line 858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_familyString

Optional. The data source family name to roll up. If empty, data points from all available data sources will be rolled up. Format: users/me/ dataSourceFamilies/data_source_family`The supported values are: -users/me/ dataSourceFamilies/all-sources- default value -users/me/dataSourceFamilies/ google-wearables- tracker devices -users/me/dataSourceFamilies/google- sources- Google first party sources Corresponds to the JSON propertydataSourceFamily`

Returns:

  • (String)


831
832
833
# File 'lib/google/apis/health_v4/classes.rb', line 831

def data_source_family
  @data_source_family
end

#page_sizeFixnum

Optional. The maximum number of data points to return. If unspecified, at most 1440 data points will be returned. The maximum page size is 10000; values above that will be truncated accordingly. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


838
839
840
# File 'lib/google/apis/health_v4/classes.rb', line 838

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token from a previous request, if any. All other request fields need to be the same as in the initial request when the page token is specified. Corresponds to the JSON property pageToken

Returns:

  • (String)


845
846
847
# File 'lib/google/apis/health_v4/classes.rb', line 845

def page_token
  @page_token
end

#rangeGoogle::Apis::HealthV4::CivilTimeInterval

Counterpart of google.type.Interval, but using CivilDateTime. Corresponds to the JSON property range



850
851
852
# File 'lib/google/apis/health_v4/classes.rb', line 850

def range
  @range
end

#window_size_daysFixnum

Optional. Aggregation window size, in number of days. Defaults to 1 if not specified. Corresponds to the JSON property windowSizeDays

Returns:

  • (Fixnum)


856
857
858
# File 'lib/google/apis/health_v4/classes.rb', line 856

def window_size_days
  @window_size_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



863
864
865
866
867
868
869
# File 'lib/google/apis/health_v4/classes.rb', line 863

def update!(**args)
  @data_source_family = args[:data_source_family] if args.key?(:data_source_family)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @range = args[:range] if args.key?(:range)
  @window_size_days = args[:window_size_days] if args.key?(:window_size_days)
end