Class: Google::Apis::HealthV4::DailyRollupDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DailyRollupDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Value of a daily rollup for a single civil time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.
Instance Attribute Summary collapse
-
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurnedRollupValue
Represents the result of the rollup of active energy burned.
-
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
-
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
-
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
-
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
-
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucoseRollupValue
Represents the result of the rollup of the blood glucose data type.
-
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
-
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data type.
-
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperatureRollupValue
Represents the result of the rollup of the core body temperature data type.
-
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
-
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
-
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
-
#heart_rate_variability_personal_range ⇒ Google::Apis::HealthV4::HeartRateVariabilityPersonalRangeRollupValue
Represents the result of the rollup of the user's daily heart rate variability personal range.
-
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
-
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLogRollupValue
Represents the result of the rollup of the nutrition log data type.
-
#resting_heart_rate_personal_range ⇒ Google::Apis::HealthV4::RestingHeartRatePersonalRangeRollupValue
Represents the rollup value for the daily resting heart rate data type.
-
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability personal range.
-
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
-
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
-
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
-
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
-
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories.
-
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyRollupDataPoint
constructor
A new instance of DailyRollupDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyRollupDataPoint
Returns a new instance of DailyRollupDataPoint.
1328 1329 1330 |
# File 'lib/google/apis/health_v4/classes.rb', line 1328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurnedRollupValue
Represents the result of the rollup of active energy burned.
Corresponds to the JSON property activeEnergyBurned
1193 1194 1195 |
# File 'lib/google/apis/health_v4/classes.rb', line 1193 def active_energy_burned @active_energy_burned end |
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
Corresponds to the JSON property activeMinutes
1198 1199 1200 |
# File 'lib/google/apis/health_v4/classes.rb', line 1198 def active_minutes @active_minutes end |
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
Corresponds to the JSON property activeZoneMinutes
1203 1204 1205 |
# File 'lib/google/apis/health_v4/classes.rb', line 1203 def active_zone_minutes @active_zone_minutes end |
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
Corresponds to the JSON property activityLevel
1208 1209 1210 |
# File 'lib/google/apis/health_v4/classes.rb', line 1208 def activity_level @activity_level end |
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
Corresponds to the JSON property altitude
1213 1214 1215 |
# File 'lib/google/apis/health_v4/classes.rb', line 1213 def altitude @altitude end |
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucoseRollupValue
Represents the result of the rollup of the blood glucose data type. LINT:
LEGACY_NAMES
Corresponds to the JSON property bloodGlucose
1219 1220 1221 |
# File 'lib/google/apis/health_v4/classes.rb', line 1219 def blood_glucose @blood_glucose end |
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
Corresponds to the JSON property bodyFat
1224 1225 1226 |
# File 'lib/google/apis/health_v4/classes.rb', line 1224 def body_fat @body_fat end |
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data
type.
Corresponds to the JSON property caloriesInHeartRateZone
1230 1231 1232 |
# File 'lib/google/apis/health_v4/classes.rb', line 1230 def calories_in_heart_rate_zone @calories_in_heart_rate_zone end |
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilEndTime
1237 1238 1239 |
# File 'lib/google/apis/health_v4/classes.rb', line 1237 def civil_end_time @civil_end_time end |
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilStartTime
1244 1245 1246 |
# File 'lib/google/apis/health_v4/classes.rb', line 1244 def civil_start_time @civil_start_time end |
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperatureRollupValue
Represents the result of the rollup of the core body temperature data type.
Corresponds to the JSON property coreBodyTemperature
1249 1250 1251 |
# File 'lib/google/apis/health_v4/classes.rb', line 1249 def core_body_temperature @core_body_temperature end |
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
Corresponds to the JSON property distance
1254 1255 1256 |
# File 'lib/google/apis/health_v4/classes.rb', line 1254 def distance @distance end |
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
Corresponds to the JSON property floors
1259 1260 1261 |
# File 'lib/google/apis/health_v4/classes.rb', line 1259 def floors @floors end |
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
Corresponds to the JSON property heartRate
1264 1265 1266 |
# File 'lib/google/apis/health_v4/classes.rb', line 1264 def heart_rate @heart_rate end |
#heart_rate_variability_personal_range ⇒ Google::Apis::HealthV4::HeartRateVariabilityPersonalRangeRollupValue
Represents the result of the rollup of the user's daily heart rate variability
personal range.
Corresponds to the JSON property heartRateVariabilityPersonalRange
1270 1271 1272 |
# File 'lib/google/apis/health_v4/classes.rb', line 1270 def heart_rate_variability_personal_range @heart_rate_variability_personal_range end |
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
Corresponds to the JSON property hydrationLog
1275 1276 1277 |
# File 'lib/google/apis/health_v4/classes.rb', line 1275 def hydration_log @hydration_log end |
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLogRollupValue
Represents the result of the rollup of the nutrition log data type.
Corresponds to the JSON property nutritionLog
1280 1281 1282 |
# File 'lib/google/apis/health_v4/classes.rb', line 1280 def nutrition_log @nutrition_log end |
#resting_heart_rate_personal_range ⇒ Google::Apis::HealthV4::RestingHeartRatePersonalRangeRollupValue
Represents the rollup value for the daily resting heart rate data type.
Corresponds to the JSON property restingHeartRatePersonalRange
1285 1286 1287 |
# File 'lib/google/apis/health_v4/classes.rb', line 1285 def resting_heart_rate_personal_range @resting_heart_rate_personal_range end |
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability
personal range.
Corresponds to the JSON property runVo2Max
1291 1292 1293 |
# File 'lib/google/apis/health_v4/classes.rb', line 1291 def run_vo2_max @run_vo2_max end |
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
Corresponds to the JSON property sedentaryPeriod
1296 1297 1298 |
# File 'lib/google/apis/health_v4/classes.rb', line 1296 def sedentary_period @sedentary_period end |
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
Corresponds to the JSON property steps
1301 1302 1303 |
# File 'lib/google/apis/health_v4/classes.rb', line 1301 def steps @steps end |
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
Corresponds to the JSON property swimLengthsData
1306 1307 1308 |
# File 'lib/google/apis/health_v4/classes.rb', line 1306 def swim_lengths_data @swim_lengths_data end |
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
Corresponds to the JSON property timeInHeartRateZone
1311 1312 1313 |
# File 'lib/google/apis/health_v4/classes.rb', line 1311 def time_in_heart_rate_zone @time_in_heart_rate_zone end |
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories. Note:
Queries for the total-calories data type must include a time interval filter
(such as total_calories.interval.start_time or total_calories.interval.
civil_start_time). The maximum range is 14 days. Example filter query:
total_calories.interval.start_time >= "2026-04-20T00:00:00Z" AND
total_calories.interval.start_time < "2026-04-21T00:00:00Z"
Corresponds to the JSON property totalCalories
1321 1322 1323 |
# File 'lib/google/apis/health_v4/classes.rb', line 1321 def total_calories @total_calories end |
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Corresponds to the JSON property weight
1326 1327 1328 |
# File 'lib/google/apis/health_v4/classes.rb', line 1326 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 |
# File 'lib/google/apis/health_v4/classes.rb', line 1333 def update!(**args) @active_energy_burned = args[:active_energy_burned] if args.key?(:active_energy_burned) @active_minutes = args[:active_minutes] if args.key?(:active_minutes) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @activity_level = args[:activity_level] if args.key?(:activity_level) @altitude = args[:altitude] if args.key?(:altitude) @blood_glucose = args[:blood_glucose] if args.key?(:blood_glucose) @body_fat = args[:body_fat] if args.key?(:body_fat) @calories_in_heart_rate_zone = args[:calories_in_heart_rate_zone] if args.key?(:calories_in_heart_rate_zone) @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time) @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time) @core_body_temperature = args[:core_body_temperature] if args.key?(:core_body_temperature) @distance = args[:distance] if args.key?(:distance) @floors = args[:floors] if args.key?(:floors) @heart_rate = args[:heart_rate] if args.key?(:heart_rate) @heart_rate_variability_personal_range = args[:heart_rate_variability_personal_range] if args.key?(:heart_rate_variability_personal_range) @hydration_log = args[:hydration_log] if args.key?(:hydration_log) @nutrition_log = args[:nutrition_log] if args.key?(:nutrition_log) @resting_heart_rate_personal_range = args[:resting_heart_rate_personal_range] if args.key?(:resting_heart_rate_personal_range) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period) @steps = args[:steps] if args.key?(:steps) @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data) @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone) @total_calories = args[:total_calories] if args.key?(:total_calories) @weight = args[:weight] if args.key?(:weight) end |