Class: Google::Apis::HealthV4::DailyRollupDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Value of a daily rollup for a single civil time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyRollupDataPoint

Returns a new instance of DailyRollupDataPoint.



1320
1321
1322
# File 'lib/google/apis/health_v4/classes.rb', line 1320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_energy_burnedGoogle::Apis::HealthV4::ActiveEnergyBurnedRollupValue

Represents the result of the rollup of active energy burned. Corresponds to the JSON property activeEnergyBurned



1190
1191
1192
# File 'lib/google/apis/health_v4/classes.rb', line 1190

def active_energy_burned
  @active_energy_burned
end

#active_minutesGoogle::Apis::HealthV4::ActiveMinutesRollupValue

Represents the result of the rollup of the active minutes data type. Corresponds to the JSON property activeMinutes



1195
1196
1197
# File 'lib/google/apis/health_v4/classes.rb', line 1195

def active_minutes
  @active_minutes
end

#active_zone_minutesGoogle::Apis::HealthV4::ActiveZoneMinutesRollupValue

Represents the result of the rollup of the active zone minutes data type. Corresponds to the JSON property activeZoneMinutes



1200
1201
1202
# File 'lib/google/apis/health_v4/classes.rb', line 1200

def active_zone_minutes
  @active_zone_minutes
end

#activity_levelGoogle::Apis::HealthV4::ActivityLevelRollupValue

Represents the result of the rollup of the activity level data type. Corresponds to the JSON property activityLevel



1205
1206
1207
# File 'lib/google/apis/health_v4/classes.rb', line 1205

def activity_level
  @activity_level
end

#altitudeGoogle::Apis::HealthV4::AltitudeRollupValue

Represents the result of the rollup of the user's altitude. Corresponds to the JSON property altitude



1210
1211
1212
# File 'lib/google/apis/health_v4/classes.rb', line 1210

def altitude
  @altitude
end

#blood_glucoseGoogle::Apis::HealthV4::BloodGlucoseRollupValue

Represents the result of the rollup of the blood glucose data type. LINT: LEGACY_NAMES Corresponds to the JSON property bloodGlucose



1216
1217
1218
# File 'lib/google/apis/health_v4/classes.rb', line 1216

def blood_glucose
  @blood_glucose
end

#body_fatGoogle::Apis::HealthV4::BodyFatRollupValue

Represents the result of the rollup of the body fat data type. Corresponds to the JSON property bodyFat



1221
1222
1223
# File 'lib/google/apis/health_v4/classes.rb', line 1221

def body_fat
  @body_fat
end

#calories_in_heart_rate_zoneGoogle::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue

Represents the result of the rollup of the calories in heart rate zone data type. Corresponds to the JSON property caloriesInHeartRateZone



1227
1228
1229
# File 'lib/google/apis/health_v4/classes.rb', line 1227

def calories_in_heart_rate_zone
  @calories_in_heart_rate_zone
end

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



1234
1235
1236
# File 'lib/google/apis/health_v4/classes.rb', line 1234

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



1241
1242
1243
# File 'lib/google/apis/health_v4/classes.rb', line 1241

def civil_start_time
  @civil_start_time
end

#core_body_temperatureGoogle::Apis::HealthV4::CoreBodyTemperatureRollupValue

Represents the result of the rollup of the core body temperature data type. Corresponds to the JSON property coreBodyTemperature



1246
1247
1248
# File 'lib/google/apis/health_v4/classes.rb', line 1246

def core_body_temperature
  @core_body_temperature
end

#distanceGoogle::Apis::HealthV4::DistanceRollupValue

Result of the rollup of the user's distance. Corresponds to the JSON property distance



1251
1252
1253
# File 'lib/google/apis/health_v4/classes.rb', line 1251

def distance
  @distance
end

#floorsGoogle::Apis::HealthV4::FloorsRollupValue

Represents the result of the rollup of the user's floors. Corresponds to the JSON property floors



1256
1257
1258
# File 'lib/google/apis/health_v4/classes.rb', line 1256

def floors
  @floors
end

#heart_rateGoogle::Apis::HealthV4::HeartRateRollupValue

Represents the result of the rollup of the heart rate data type. Corresponds to the JSON property heartRate



1261
1262
1263
# File 'lib/google/apis/health_v4/classes.rb', line 1261

def heart_rate
  @heart_rate
end

#heart_rate_variability_personal_rangeGoogle::Apis::HealthV4::HeartRateVariabilityPersonalRangeRollupValue

Represents the result of the rollup of the user's daily heart rate variability personal range. Corresponds to the JSON property heartRateVariabilityPersonalRange



1267
1268
1269
# File 'lib/google/apis/health_v4/classes.rb', line 1267

def heart_rate_variability_personal_range
  @heart_rate_variability_personal_range
end

#hydration_logGoogle::Apis::HealthV4::HydrationLogRollupValue

Represents the result of the rollup of the hydration log data type. Corresponds to the JSON property hydrationLog



1272
1273
1274
# File 'lib/google/apis/health_v4/classes.rb', line 1272

def hydration_log
  @hydration_log
end

#nutrition_logGoogle::Apis::HealthV4::NutritionLogRollupValue

Represents the result of the rollup of the nutrition log data type. Corresponds to the JSON property nutritionLog



1277
1278
1279
# File 'lib/google/apis/health_v4/classes.rb', line 1277

def nutrition_log
  @nutrition_log
end

#resting_heart_rate_personal_rangeGoogle::Apis::HealthV4::RestingHeartRatePersonalRangeRollupValue

Represents the rollup value for the daily resting heart rate data type. Corresponds to the JSON property restingHeartRatePersonalRange



1282
1283
1284
# File 'lib/google/apis/health_v4/classes.rb', line 1282

def resting_heart_rate_personal_range
  @resting_heart_rate_personal_range
end

#run_vo2_maxGoogle::Apis::HealthV4::RunVo2MaxRollupValue

Represents the result of the rollup of the user's daily heart rate variability personal range. Corresponds to the JSON property runVo2Max



1288
1289
1290
# File 'lib/google/apis/health_v4/classes.rb', line 1288

def run_vo2_max
  @run_vo2_max
end

#sedentary_periodGoogle::Apis::HealthV4::SedentaryPeriodRollupValue

Represents the result of the rollup of the user's sedentary periods. Corresponds to the JSON property sedentaryPeriod



1293
1294
1295
# File 'lib/google/apis/health_v4/classes.rb', line 1293

def sedentary_period
  @sedentary_period
end

#stepsGoogle::Apis::HealthV4::StepsRollupValue

Represents the result of the rollup of the steps data type. Corresponds to the JSON property steps



1298
1299
1300
# File 'lib/google/apis/health_v4/classes.rb', line 1298

def steps
  @steps
end

#swim_lengths_dataGoogle::Apis::HealthV4::SwimLengthsDataRollupValue

Represents the result of the rollup of the swim lengths data type. Corresponds to the JSON property swimLengthsData



1303
1304
1305
# File 'lib/google/apis/health_v4/classes.rb', line 1303

def swim_lengths_data
  @swim_lengths_data
end

#time_in_heart_rate_zoneGoogle::Apis::HealthV4::TimeInHeartRateZoneRollupValue

Represents the result of the rollup of the time in heart rate zone data type. Corresponds to the JSON property timeInHeartRateZone



1308
1309
1310
# File 'lib/google/apis/health_v4/classes.rb', line 1308

def time_in_heart_rate_zone
  @time_in_heart_rate_zone
end

#total_caloriesGoogle::Apis::HealthV4::TotalCaloriesRollupValue

Represents the result of the rollup of the user's total calories. Corresponds to the JSON property totalCalories



1313
1314
1315
# File 'lib/google/apis/health_v4/classes.rb', line 1313

def total_calories
  @total_calories
end

#weightGoogle::Apis::HealthV4::WeightRollupValue

Represents the result of the rollup of the weight data type. Corresponds to the JSON property weight



1318
1319
1320
# File 'lib/google/apis/health_v4/classes.rb', line 1318

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
# File 'lib/google/apis/health_v4/classes.rb', line 1325

def update!(**args)
  @active_energy_burned = args[:active_energy_burned] if args.key?(:active_energy_burned)
  @active_minutes = args[:active_minutes] if args.key?(:active_minutes)
  @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes)
  @activity_level = args[:activity_level] if args.key?(:activity_level)
  @altitude = args[:altitude] if args.key?(:altitude)
  @blood_glucose = args[:blood_glucose] if args.key?(:blood_glucose)
  @body_fat = args[:body_fat] if args.key?(:body_fat)
  @calories_in_heart_rate_zone = args[:calories_in_heart_rate_zone] if args.key?(:calories_in_heart_rate_zone)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @core_body_temperature = args[:core_body_temperature] if args.key?(:core_body_temperature)
  @distance = args[:distance] if args.key?(:distance)
  @floors = args[:floors] if args.key?(:floors)
  @heart_rate = args[:heart_rate] if args.key?(:heart_rate)
  @heart_rate_variability_personal_range = args[:heart_rate_variability_personal_range] if args.key?(:heart_rate_variability_personal_range)
  @hydration_log = args[:hydration_log] if args.key?(:hydration_log)
  @nutrition_log = args[:nutrition_log] if args.key?(:nutrition_log)
  @resting_heart_rate_personal_range = args[:resting_heart_rate_personal_range] if args.key?(:resting_heart_rate_personal_range)
  @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max)
  @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period)
  @steps = args[:steps] if args.key?(:steps)
  @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data)
  @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone)
  @total_calories = args[:total_calories] if args.key?(:total_calories)
  @weight = args[:weight] if args.key?(:weight)
end