Class: Google::Apis::HealthV4::DailyRollupDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DailyRollupDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Value of a daily rollup for a single civil time interval (aggregation window)
Instance Attribute Summary collapse
-
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
-
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
-
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
-
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
-
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
-
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data type.
-
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
-
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
-
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
-
#heart_rate_variability_personal_range ⇒ Google::Apis::HealthV4::HeartRateVariabilityPersonalRangeRollupValue
Represents the result of the rollup of the user's daily heart rate variability personal range.
-
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
-
#resting_heart_rate_personal_range ⇒ Google::Apis::HealthV4::RestingHeartRatePersonalRangeRollupValue
Represents the rollup value for the daily resting heart rate data type.
-
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability personal range.
-
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
-
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
-
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
-
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
-
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories.
-
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyRollupDataPoint
constructor
A new instance of DailyRollupDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyRollupDataPoint
Returns a new instance of DailyRollupDataPoint.
1007 1008 1009 |
# File 'lib/google/apis/health_v4/classes.rb', line 1007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
Corresponds to the JSON property activeMinutes
898 899 900 |
# File 'lib/google/apis/health_v4/classes.rb', line 898 def active_minutes @active_minutes end |
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
Corresponds to the JSON property activeZoneMinutes
903 904 905 |
# File 'lib/google/apis/health_v4/classes.rb', line 903 def active_zone_minutes @active_zone_minutes end |
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
Corresponds to the JSON property activityLevel
908 909 910 |
# File 'lib/google/apis/health_v4/classes.rb', line 908 def activity_level @activity_level end |
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
Corresponds to the JSON property altitude
913 914 915 |
# File 'lib/google/apis/health_v4/classes.rb', line 913 def altitude @altitude end |
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
Corresponds to the JSON property bodyFat
918 919 920 |
# File 'lib/google/apis/health_v4/classes.rb', line 918 def body_fat @body_fat end |
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data
type.
Corresponds to the JSON property caloriesInHeartRateZone
924 925 926 |
# File 'lib/google/apis/health_v4/classes.rb', line 924 def calories_in_heart_rate_zone @calories_in_heart_rate_zone end |
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilEndTime
931 932 933 |
# File 'lib/google/apis/health_v4/classes.rb', line 931 def civil_end_time @civil_end_time end |
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilStartTime
938 939 940 |
# File 'lib/google/apis/health_v4/classes.rb', line 938 def civil_start_time @civil_start_time end |
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
Corresponds to the JSON property distance
943 944 945 |
# File 'lib/google/apis/health_v4/classes.rb', line 943 def distance @distance end |
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
Corresponds to the JSON property floors
948 949 950 |
# File 'lib/google/apis/health_v4/classes.rb', line 948 def floors @floors end |
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
Corresponds to the JSON property heartRate
953 954 955 |
# File 'lib/google/apis/health_v4/classes.rb', line 953 def heart_rate @heart_rate end |
#heart_rate_variability_personal_range ⇒ Google::Apis::HealthV4::HeartRateVariabilityPersonalRangeRollupValue
Represents the result of the rollup of the user's daily heart rate variability
personal range.
Corresponds to the JSON property heartRateVariabilityPersonalRange
959 960 961 |
# File 'lib/google/apis/health_v4/classes.rb', line 959 def heart_rate_variability_personal_range @heart_rate_variability_personal_range end |
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
Corresponds to the JSON property hydrationLog
964 965 966 |
# File 'lib/google/apis/health_v4/classes.rb', line 964 def hydration_log @hydration_log end |
#resting_heart_rate_personal_range ⇒ Google::Apis::HealthV4::RestingHeartRatePersonalRangeRollupValue
Represents the rollup value for the daily resting heart rate data type.
Corresponds to the JSON property restingHeartRatePersonalRange
969 970 971 |
# File 'lib/google/apis/health_v4/classes.rb', line 969 def resting_heart_rate_personal_range @resting_heart_rate_personal_range end |
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability
personal range.
Corresponds to the JSON property runVo2Max
975 976 977 |
# File 'lib/google/apis/health_v4/classes.rb', line 975 def run_vo2_max @run_vo2_max end |
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
Corresponds to the JSON property sedentaryPeriod
980 981 982 |
# File 'lib/google/apis/health_v4/classes.rb', line 980 def sedentary_period @sedentary_period end |
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
Corresponds to the JSON property steps
985 986 987 |
# File 'lib/google/apis/health_v4/classes.rb', line 985 def steps @steps end |
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
Corresponds to the JSON property swimLengthsData
990 991 992 |
# File 'lib/google/apis/health_v4/classes.rb', line 990 def swim_lengths_data @swim_lengths_data end |
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
Corresponds to the JSON property timeInHeartRateZone
995 996 997 |
# File 'lib/google/apis/health_v4/classes.rb', line 995 def time_in_heart_rate_zone @time_in_heart_rate_zone end |
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories.
Corresponds to the JSON property totalCalories
1000 1001 1002 |
# File 'lib/google/apis/health_v4/classes.rb', line 1000 def total_calories @total_calories end |
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Corresponds to the JSON property weight
1005 1006 1007 |
# File 'lib/google/apis/health_v4/classes.rb', line 1005 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 |
# File 'lib/google/apis/health_v4/classes.rb', line 1012 def update!(**args) @active_minutes = args[:active_minutes] if args.key?(:active_minutes) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @activity_level = args[:activity_level] if args.key?(:activity_level) @altitude = args[:altitude] if args.key?(:altitude) @body_fat = args[:body_fat] if args.key?(:body_fat) @calories_in_heart_rate_zone = args[:calories_in_heart_rate_zone] if args.key?(:calories_in_heart_rate_zone) @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time) @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time) @distance = args[:distance] if args.key?(:distance) @floors = args[:floors] if args.key?(:floors) @heart_rate = args[:heart_rate] if args.key?(:heart_rate) @heart_rate_variability_personal_range = args[:heart_rate_variability_personal_range] if args.key?(:heart_rate_variability_personal_range) @hydration_log = args[:hydration_log] if args.key?(:hydration_log) @resting_heart_rate_personal_range = args[:resting_heart_rate_personal_range] if args.key?(:resting_heart_rate_personal_range) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period) @steps = args[:steps] if args.key?(:steps) @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data) @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone) @total_calories = args[:total_calories] if args.key?(:total_calories) @weight = args[:weight] if args.key?(:weight) end |