Class: Google::Apis::HealthV4::DailySleepTemperatureDerivations
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DailySleepTemperatureDerivations
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep.
Instance Attribute Summary collapse
-
#baseline_temperature_celsius ⇒ Float
Optional.
-
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday.
-
#nightly_temperature_celsius ⇒ Float
Required.
-
#relative_nightly_stddev30d_celsius ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailySleepTemperatureDerivations
constructor
A new instance of DailySleepTemperatureDerivations.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailySleepTemperatureDerivations
Returns a new instance of DailySleepTemperatureDerivations.
1045 1046 1047 |
# File 'lib/google/apis/health_v4/classes.rb', line 1045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#baseline_temperature_celsius ⇒ Float
Optional. The user's baseline skin temperature. It is the median of the user's
nightly skin temperature over the past 30 days.
Corresponds to the JSON property baselineTemperatureCelsius
1019 1020 1021 |
# File 'lib/google/apis/health_v4/classes.rb', line 1019 def baseline_temperature_celsius @baseline_temperature_celsius end |
#date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property date
1031 1032 1033 |
# File 'lib/google/apis/health_v4/classes.rb', line 1031 def date @date end |
#nightly_temperature_celsius ⇒ Float
Required. The user's nightly skin temperature. It is the mean of skin
temperature samples taken from the user’s sleep.
Corresponds to the JSON property nightlyTemperatureCelsius
1037 1038 1039 |
# File 'lib/google/apis/health_v4/classes.rb', line 1037 def nightly_temperature_celsius @nightly_temperature_celsius end |
#relative_nightly_stddev30d_celsius ⇒ Float
Optional. The standard deviation of the user’s relative nightly skin
temperature (temperature - baseline) over the past 30 days.
Corresponds to the JSON property relativeNightlyStddev30dCelsius
1043 1044 1045 |
# File 'lib/google/apis/health_v4/classes.rb', line 1043 def relative_nightly_stddev30d_celsius @relative_nightly_stddev30d_celsius end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1050 1051 1052 1053 1054 1055 |
# File 'lib/google/apis/health_v4/classes.rb', line 1050 def update!(**args) @baseline_temperature_celsius = args[:baseline_temperature_celsius] if args.key?(:baseline_temperature_celsius) @date = args[:date] if args.key?(:date) @nightly_temperature_celsius = args[:nightly_temperature_celsius] if args.key?(:nightly_temperature_celsius) @relative_nightly_stddev30d_celsius = args[:relative_nightly_stddev30d_celsius] if args.key?(:relative_nightly_stddev30d_celsius) end |