Class: Google::Apis::HealthV4::DailyVo2Max

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyVo2Max

Returns a new instance of DailyVo2Max.



1128
1129
1130
# File 'lib/google/apis/health_v4/classes.rb', line 1128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardio_fitness_levelString

Optional. Represents the user's cardio fitness level based on their VO2 max. Corresponds to the JSON property cardioFitnessLevel

Returns:

  • (String)


1096
1097
1098
# File 'lib/google/apis/health_v4/classes.rb', line 1096

def cardio_fitness_level
  @cardio_fitness_level
end

#dateGoogle::Apis::HealthV4::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



1108
1109
1110
# File 'lib/google/apis/health_v4/classes.rb', line 1108

def date
  @date
end

#estimatedBoolean Also known as: estimated?

Optional. An estimated field is added to indicate when the confidence has decreased sufficiently to consider the value an estimation. Corresponds to the JSON property estimated

Returns:

  • (Boolean)


1114
1115
1116
# File 'lib/google/apis/health_v4/classes.rb', line 1114

def estimated
  @estimated
end

#vo2_maxFloat

Required. Daily VO2 max value measured as in ml consumed oxygen / kg of body weight / min. Corresponds to the JSON property vo2Max

Returns:

  • (Float)


1121
1122
1123
# File 'lib/google/apis/health_v4/classes.rb', line 1121

def vo2_max
  @vo2_max
end

#vo2_max_covarianceFloat

Optional. The covariance of the VO2 max value. Corresponds to the JSON property vo2MaxCovariance

Returns:

  • (Float)


1126
1127
1128
# File 'lib/google/apis/health_v4/classes.rb', line 1126

def vo2_max_covariance
  @vo2_max_covariance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1133
1134
1135
1136
1137
1138
1139
# File 'lib/google/apis/health_v4/classes.rb', line 1133

def update!(**args)
  @cardio_fitness_level = args[:cardio_fitness_level] if args.key?(:cardio_fitness_level)
  @date = args[:date] if args.key?(:date)
  @estimated = args[:estimated] if args.key?(:estimated)
  @vo2_max = args[:vo2_max] if args.key?(:vo2_max)
  @vo2_max_covariance = args[:vo2_max_covariance] if args.key?(:vo2_max_covariance)
end