Class: Google::Apis::HealthV4::DataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

A computed or recorded metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataPoint

Returns a new instance of DataPoint.



1707
1708
1709
# File 'lib/google/apis/health_v4/classes.rb', line 1707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_energy_burnedGoogle::Apis::HealthV4::ActiveEnergyBurned

Energy burned as part of an activity, excluding the basal energy burn. Corresponds to the JSON property activeEnergyBurned



1468
1469
1470
# File 'lib/google/apis/health_v4/classes.rb', line 1468

def active_energy_burned
  @active_energy_burned
end

#active_minutesGoogle::Apis::HealthV4::ActiveMinutes

Record of active minutes in a given time interval. Corresponds to the JSON property activeMinutes



1473
1474
1475
# File 'lib/google/apis/health_v4/classes.rb', line 1473

def active_minutes
  @active_minutes
end

#active_zone_minutesGoogle::Apis::HealthV4::ActiveZoneMinutes

Record of active zone minutes in a given time interval. Corresponds to the JSON property activeZoneMinutes



1478
1479
1480
# File 'lib/google/apis/health_v4/classes.rb', line 1478

def active_zone_minutes
  @active_zone_minutes
end

#activity_levelGoogle::Apis::HealthV4::ActivityLevel

Internal type to capture activity level during a certain time interval. Corresponds to the JSON property activityLevel



1483
1484
1485
# File 'lib/google/apis/health_v4/classes.rb', line 1483

def activity_level
  @activity_level
end

#altitudeGoogle::Apis::HealthV4::Altitude

Captures the altitude gain (i.e. deltas), and not level above sea, for a user in millimeters. Corresponds to the JSON property altitude



1489
1490
1491
# File 'lib/google/apis/health_v4/classes.rb', line 1489

def altitude
  @altitude
end

#basal_energy_burnedGoogle::Apis::HealthV4::BasalEnergyBurned

Number of calories burned due to basal metabolic rate (BMR) over a period of time. Corresponds to the JSON property basalEnergyBurned



1495
1496
1497
# File 'lib/google/apis/health_v4/classes.rb', line 1495

def basal_energy_burned
  @basal_energy_burned
end

#blood_glucoseGoogle::Apis::HealthV4::BloodGlucose

Represents a blood glucose level measurement. LINT: LEGACY_NAMES Corresponds to the JSON property bloodGlucose



1500
1501
1502
# File 'lib/google/apis/health_v4/classes.rb', line 1500

def blood_glucose
  @blood_glucose
end

#body_fatGoogle::Apis::HealthV4::BodyFat

Body fat measurement. Corresponds to the JSON property bodyFat



1505
1506
1507
# File 'lib/google/apis/health_v4/classes.rb', line 1505

def body_fat
  @body_fat
end

#core_body_temperatureGoogle::Apis::HealthV4::CoreBodyTemperature

Core body temperature measurement, distinct from peripheral body temperature, reflects the temperature of the body's internal organs. Corresponds to the JSON property coreBodyTemperature



1511
1512
1513
# File 'lib/google/apis/health_v4/classes.rb', line 1511

def core_body_temperature
  @core_body_temperature
end

#daily_heart_rate_variabilityGoogle::Apis::HealthV4::DailyHeartRateVariability

Represents the daily heart rate variability data type. At least one of the following fields must be set: - average_heart_rate_variability_milliseconds - non_rem_heart_rate_beats_per_minute - entropy - deep_sleep_root_mean_square_of_successive_differences_milliseconds Corresponds to the JSON property dailyHeartRateVariability



1519
1520
1521
# File 'lib/google/apis/health_v4/classes.rb', line 1519

def daily_heart_rate_variability
  @daily_heart_rate_variability
end

#daily_heart_rate_zonesGoogle::Apis::HealthV4::DailyHeartRateZones

User's heart rate zone thresholds based on the Karvonen algorithm for a specific day. Corresponds to the JSON property dailyHeartRateZones



1525
1526
1527
# File 'lib/google/apis/health_v4/classes.rb', line 1525

def daily_heart_rate_zones
  @daily_heart_rate_zones
end

#daily_oxygen_saturationGoogle::Apis::HealthV4::DailyOxygenSaturation

A daily oxygen saturation (SpO2) record. Represents the user's daily oxygen saturation summary, typically calculated during sleep. Corresponds to the JSON property dailyOxygenSaturation



1531
1532
1533
# File 'lib/google/apis/health_v4/classes.rb', line 1531

def daily_oxygen_saturation
  @daily_oxygen_saturation
end

#daily_respiratory_rateGoogle::Apis::HealthV4::DailyRespiratoryRate

A daily average respiratory rate (breaths per minute) for a day of the year. One data point per day calculated for the main sleep. Corresponds to the JSON property dailyRespiratoryRate



1537
1538
1539
# File 'lib/google/apis/health_v4/classes.rb', line 1537

def daily_respiratory_rate
  @daily_respiratory_rate
end

#daily_resting_heart_rateGoogle::Apis::HealthV4::DailyRestingHeartRate

Measures the daily resting heart rate for a user, calculated using the all day heart rate measurements. Corresponds to the JSON property dailyRestingHeartRate



1543
1544
1545
# File 'lib/google/apis/health_v4/classes.rb', line 1543

def daily_resting_heart_rate
  @daily_resting_heart_rate
end

#daily_sleep_temperature_derivationsGoogle::Apis::HealthV4::DailySleepTemperatureDerivations

Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep. Corresponds to the JSON property dailySleepTemperatureDerivations



1549
1550
1551
# File 'lib/google/apis/health_v4/classes.rb', line 1549

def daily_sleep_temperature_derivations
  @daily_sleep_temperature_derivations
end

#daily_vo2_maxGoogle::Apis::HealthV4::DailyVo2Max

Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise. Corresponds to the JSON property dailyVo2Max



1555
1556
1557
# File 'lib/google/apis/health_v4/classes.rb', line 1555

def daily_vo2_max
  @daily_vo2_max
end

#data_sourceGoogle::Apis::HealthV4::DataSource

Data Source definition to track the origin of data. Each health data point, regardless of the complexity or data model (whether a simple step count or a detailed sleep session) must retain information about its source of origin (e. g. the device or app that collected it). Corresponds to the JSON property dataSource



1563
1564
1565
# File 'lib/google/apis/health_v4/classes.rb', line 1563

def data_source
  @data_source
end

#distanceGoogle::Apis::HealthV4::Distance

Distance traveled over an interval of time. Corresponds to the JSON property distance



1568
1569
1570
# File 'lib/google/apis/health_v4/classes.rb', line 1568

def distance
  @distance
end

#electrocardiogramGoogle::Apis::HealthV4::Electrocardiogram

Represents an Electrocardiogram (ECG) measurement session. This data type is based on SaMD feature and any changes to it may require additional review. Corresponds to the JSON property electrocardiogram



1574
1575
1576
# File 'lib/google/apis/health_v4/classes.rb', line 1574

def electrocardiogram
  @electrocardiogram
end

#exerciseGoogle::Apis::HealthV4::Exercise

An exercise that stores information about a physical activity. Corresponds to the JSON property exercise



1579
1580
1581
# File 'lib/google/apis/health_v4/classes.rb', line 1579

def exercise
  @exercise
end

#floorsGoogle::Apis::HealthV4::Floors

Gained elevation measured in floors over the time interval Corresponds to the JSON property floors



1584
1585
1586
# File 'lib/google/apis/health_v4/classes.rb', line 1584

def floors
  @floors
end

#foodGoogle::Apis::HealthV4::Food

Represents a food item. Corresponds to the JSON property food



1589
1590
1591
# File 'lib/google/apis/health_v4/classes.rb', line 1589

def food
  @food
end

#food_measurement_unitGoogle::Apis::HealthV4::FoodMeasurementUnit

Represents a food measurement unit. Corresponds to the JSON property foodMeasurementUnit



1594
1595
1596
# File 'lib/google/apis/health_v4/classes.rb', line 1594

def food_measurement_unit
  @food_measurement_unit
end

#heart_rateGoogle::Apis::HealthV4::HeartRate

A heart rate measurement. Corresponds to the JSON property heartRate



1599
1600
1601
# File 'lib/google/apis/health_v4/classes.rb', line 1599

def heart_rate
  @heart_rate
end

#heart_rate_variabilityGoogle::Apis::HealthV4::HeartRateVariability

Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN). Corresponds to the JSON property heartRateVariability



1606
1607
1608
# File 'lib/google/apis/health_v4/classes.rb', line 1606

def heart_rate_variability
  @heart_rate_variability
end

#heightGoogle::Apis::HealthV4::Height

Body height measurement. Corresponds to the JSON property height



1611
1612
1613
# File 'lib/google/apis/health_v4/classes.rb', line 1611

def height
  @height
end

#hydration_logGoogle::Apis::HealthV4::HydrationLog

Holds information about a user logged hydration. Corresponds to the JSON property hydrationLog



1616
1617
1618
# File 'lib/google/apis/health_v4/classes.rb', line 1616

def hydration_log
  @hydration_log
end

#irregular_rhythm_notificationGoogle::Apis::HealthV4::IrregularRhythmNotification

Represents an Irregular Rhythm Notification alert, indicating a potential sign of atrial fibrillation (AFib). This data type is based on SaMD feature and any changes to it may require additional review. Corresponds to the JSON property irregularRhythmNotification



1623
1624
1625
# File 'lib/google/apis/health_v4/classes.rb', line 1623

def irregular_rhythm_notification
  @irregular_rhythm_notification
end

#nameString

Identifier. Data point name, only supported for the subset of identifiable data types. For the majority of the data types, individual data points do not need to be identified and this field would be empty. Format: users/user/ dataTypes/data_type/dataPoints/data_pointExample: `users/abcd1234/ dataTypes/sleep/dataPoints/a1b2c3d4-e5f6-7890-1234-567890abcdef` Theuser ID is a system-generated identifier, as described in Identity.health_user_id. Thedata_typeID corresponds to the kebab-case version of the field names in the DataPoint data union field, e.g. `heart-rate` for the `heart_rate` field. Thedata_point`ID can be client-provided or system-generated. If client-provided, it must be a string of 4-63 characters, containing only lowercase letters, numbers, and hyphens. Corresponds to the JSON propertyname`

Returns:

  • (String)


1638
1639
1640
# File 'lib/google/apis/health_v4/classes.rb', line 1638

def name
  @name
end

#nutrition_logGoogle::Apis::HealthV4::NutritionLog

Holds information about food logged by a user. There are two ways of creating a nutrition log based on the food type: 1. Identified food: Using the food field, which is a reference to a Food resource. In this case fields nutrients , energy, energy_from_fat, total_carbohydrate, total_fat, food_display_name will be populated based on the referenced food. 2. Anonymous food: Using the food_display_name field and setting the nutrients , energy, energy_from_fat, total_carbohydrate, total_fat fields manually. The identified food is preferred over the anonymous food. Nutrition logs created from anonymous food are not editable. Corresponds to the JSON property nutritionLog



1651
1652
1653
# File 'lib/google/apis/health_v4/classes.rb', line 1651

def nutrition_log
  @nutrition_log
end

#oxygen_saturationGoogle::Apis::HealthV4::OxygenSaturation

Captures the user's instantaneous oxygen saturation percentage (SpO2). Corresponds to the JSON property oxygenSaturation



1656
1657
1658
# File 'lib/google/apis/health_v4/classes.rb', line 1656

def oxygen_saturation
  @oxygen_saturation
end

#respiratory_rate_sleep_summaryGoogle::Apis::HealthV4::RespiratoryRateSleepSummary

Records respiratory rate details during sleep. Can have multiple per day if the user sleeps multiple times. Corresponds to the JSON property respiratoryRateSleepSummary



1662
1663
1664
# File 'lib/google/apis/health_v4/classes.rb', line 1662

def respiratory_rate_sleep_summary
  @respiratory_rate_sleep_summary
end

#run_vo2_maxGoogle::Apis::HealthV4::RunVo2Max

VO2 max value calculated based on the user's running activity. Value stored in ml/kg/min. Corresponds to the JSON property runVo2Max



1668
1669
1670
# File 'lib/google/apis/health_v4/classes.rb', line 1668

def run_vo2_max
  @run_vo2_max
end

#sedentary_periodGoogle::Apis::HealthV4::SedentaryPeriod

SedentaryPeriod SedentaryPeriod data represents the periods of time that the user was sedentary (i.e. not moving while wearing the device). Corresponds to the JSON property sedentaryPeriod



1674
1675
1676
# File 'lib/google/apis/health_v4/classes.rb', line 1674

def sedentary_period
  @sedentary_period
end

#sleepGoogle::Apis::HealthV4::Sleep

A sleep session possibly including stages. Corresponds to the JSON property sleep



1679
1680
1681
# File 'lib/google/apis/health_v4/classes.rb', line 1679

def sleep
  @sleep
end

#stepsGoogle::Apis::HealthV4::Steps

Step count over the time interval. Corresponds to the JSON property steps



1684
1685
1686
# File 'lib/google/apis/health_v4/classes.rb', line 1684

def steps
  @steps
end

#swim_lengths_dataGoogle::Apis::HealthV4::SwimLengthsData

Swim lengths data over the time interval. Corresponds to the JSON property swimLengthsData



1689
1690
1691
# File 'lib/google/apis/health_v4/classes.rb', line 1689

def swim_lengths_data
  @swim_lengths_data
end

#time_in_heart_rate_zoneGoogle::Apis::HealthV4::TimeInHeartRateZone

Time in heart rate zone record. It's an interval spent in specific heart rate zone. Corresponds to the JSON property timeInHeartRateZone



1695
1696
1697
# File 'lib/google/apis/health_v4/classes.rb', line 1695

def time_in_heart_rate_zone
  @time_in_heart_rate_zone
end

#vo2_maxGoogle::Apis::HealthV4::Vo2Max

VO2 max measurement. Corresponds to the JSON property vo2Max



1700
1701
1702
# File 'lib/google/apis/health_v4/classes.rb', line 1700

def vo2_max
  @vo2_max
end

#weightGoogle::Apis::HealthV4::Weight

Body weight measurement. Corresponds to the JSON property weight



1705
1706
1707
# File 'lib/google/apis/health_v4/classes.rb', line 1705

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
# File 'lib/google/apis/health_v4/classes.rb', line 1712

def update!(**args)
  @active_energy_burned = args[:active_energy_burned] if args.key?(:active_energy_burned)
  @active_minutes = args[:active_minutes] if args.key?(:active_minutes)
  @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes)
  @activity_level = args[:activity_level] if args.key?(:activity_level)
  @altitude = args[:altitude] if args.key?(:altitude)
  @basal_energy_burned = args[:basal_energy_burned] if args.key?(:basal_energy_burned)
  @blood_glucose = args[:blood_glucose] if args.key?(:blood_glucose)
  @body_fat = args[:body_fat] if args.key?(:body_fat)
  @core_body_temperature = args[:core_body_temperature] if args.key?(:core_body_temperature)
  @daily_heart_rate_variability = args[:daily_heart_rate_variability] if args.key?(:daily_heart_rate_variability)
  @daily_heart_rate_zones = args[:daily_heart_rate_zones] if args.key?(:daily_heart_rate_zones)
  @daily_oxygen_saturation = args[:daily_oxygen_saturation] if args.key?(:daily_oxygen_saturation)
  @daily_respiratory_rate = args[:daily_respiratory_rate] if args.key?(:daily_respiratory_rate)
  @daily_resting_heart_rate = args[:daily_resting_heart_rate] if args.key?(:daily_resting_heart_rate)
  @daily_sleep_temperature_derivations = args[:daily_sleep_temperature_derivations] if args.key?(:daily_sleep_temperature_derivations)
  @daily_vo2_max = args[:daily_vo2_max] if args.key?(:daily_vo2_max)
  @data_source = args[:data_source] if args.key?(:data_source)
  @distance = args[:distance] if args.key?(:distance)
  @electrocardiogram = args[:electrocardiogram] if args.key?(:electrocardiogram)
  @exercise = args[:exercise] if args.key?(:exercise)
  @floors = args[:floors] if args.key?(:floors)
  @food = args[:food] if args.key?(:food)
  @food_measurement_unit = args[:food_measurement_unit] if args.key?(:food_measurement_unit)
  @heart_rate = args[:heart_rate] if args.key?(:heart_rate)
  @heart_rate_variability = args[:heart_rate_variability] if args.key?(:heart_rate_variability)
  @height = args[:height] if args.key?(:height)
  @hydration_log = args[:hydration_log] if args.key?(:hydration_log)
  @irregular_rhythm_notification = args[:irregular_rhythm_notification] if args.key?(:irregular_rhythm_notification)
  @name = args[:name] if args.key?(:name)
  @nutrition_log = args[:nutrition_log] if args.key?(:nutrition_log)
  @oxygen_saturation = args[:oxygen_saturation] if args.key?(:oxygen_saturation)
  @respiratory_rate_sleep_summary = args[:respiratory_rate_sleep_summary] if args.key?(:respiratory_rate_sleep_summary)
  @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max)
  @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period)
  @sleep = args[:sleep] if args.key?(:sleep)
  @steps = args[:steps] if args.key?(:steps)
  @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data)
  @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone)
  @vo2_max = args[:vo2_max] if args.key?(:vo2_max)
  @weight = args[:weight] if args.key?(:weight)
end