Class: Google::Apis::HealthV4::DataPoint
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::DataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
A computed or recorded metric.
Instance Attribute Summary collapse
-
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutes
Record of active minutes in a given time interval.
-
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutes
Record of active zone minutes in a given time interval.
-
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevel
Internal type to capture activity level during a certain time interval.
-
#altitude ⇒ Google::Apis::HealthV4::Altitude
Captures the altitude gain (i.e. deltas), and not level above sea, for a user in millimeters.
-
#basal_energy_burned ⇒ Google::Apis::HealthV4::BasalEnergyBurned
Number of calories burned due to basal metabolic rate (BMR) over a period of time.
-
#body_fat ⇒ Google::Apis::HealthV4::BodyFat
Body fat measurement.
-
#daily_heart_rate_variability ⇒ Google::Apis::HealthV4::DailyHeartRateVariability
Represents the daily heart rate variability data type.
-
#daily_heart_rate_zones ⇒ Google::Apis::HealthV4::DailyHeartRateZones
User's heart rate zone thresholds based on the Karvonen algorithm for a specific day.
-
#daily_oxygen_saturation ⇒ Google::Apis::HealthV4::DailyOxygenSaturation
A daily oxygen saturation (SpO2) record.
-
#daily_respiratory_rate ⇒ Google::Apis::HealthV4::DailyRespiratoryRate
A daily average respiratory rate (breaths per minute) for a day of the year.
-
#daily_resting_heart_rate ⇒ Google::Apis::HealthV4::DailyRestingHeartRate
Measures the daily resting heart rate for a user, calculated using the all day heart rate measurements.
-
#daily_sleep_temperature_derivations ⇒ Google::Apis::HealthV4::DailySleepTemperatureDerivations
Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep.
-
#daily_vo2_max ⇒ Google::Apis::HealthV4::DailyVo2Max
Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise.
-
#data_source ⇒ Google::Apis::HealthV4::DataSource
Data Source definition to track the origin of data.
-
#distance ⇒ Google::Apis::HealthV4::Distance
Distance traveled over an interval of time.
-
#exercise ⇒ Google::Apis::HealthV4::Exercise
An exercise that stores information about a physical activity.
-
#floors ⇒ Google::Apis::HealthV4::Floors
Gained elevation measured in floors over the time interval Corresponds to the JSON property
floors. -
#heart_rate ⇒ Google::Apis::HealthV4::HeartRate
A heart rate measurement.
-
#heart_rate_variability ⇒ Google::Apis::HealthV4::HeartRateVariability
Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).
-
#height ⇒ Google::Apis::HealthV4::Height
Body height measurement.
-
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLog
Holds information about a user logged hydration.
-
#name ⇒ String
Identifier.
-
#oxygen_saturation ⇒ Google::Apis::HealthV4::OxygenSaturation
Captures the user's instantaneous oxygen saturation percentage (SpO2).
-
#respiratory_rate_sleep_summary ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummary
Records respiratory rate details during sleep.
-
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2Max
VO2 max value calculated based on the user's running activity.
-
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriod
SedentaryPeriod SedentaryPeriod data represents the periods of time that the user was sedentary (i.e. not moving while wearing the device).
-
#sleep ⇒ Google::Apis::HealthV4::Sleep
A sleep session possibly including stages.
-
#steps ⇒ Google::Apis::HealthV4::Steps
Step count over the time interval.
-
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsData
Swim lengths data over the time interval.
-
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZone
Time in heart rate zone record.
-
#vo2_max ⇒ Google::Apis::HealthV4::Vo2Max
VO2 max measurement.
-
#weight ⇒ Google::Apis::HealthV4::Weight
Body weight measurement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataPoint
constructor
A new instance of DataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataPoint
Returns a new instance of DataPoint.
1336 1337 1338 |
# File 'lib/google/apis/health_v4/classes.rb', line 1336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutes
Record of active minutes in a given time interval.
Corresponds to the JSON property activeMinutes
1149 1150 1151 |
# File 'lib/google/apis/health_v4/classes.rb', line 1149 def active_minutes @active_minutes end |
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutes
Record of active zone minutes in a given time interval.
Corresponds to the JSON property activeZoneMinutes
1154 1155 1156 |
# File 'lib/google/apis/health_v4/classes.rb', line 1154 def active_zone_minutes @active_zone_minutes end |
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevel
Internal type to capture activity level during a certain time interval.
Corresponds to the JSON property activityLevel
1159 1160 1161 |
# File 'lib/google/apis/health_v4/classes.rb', line 1159 def activity_level @activity_level end |
#altitude ⇒ Google::Apis::HealthV4::Altitude
Captures the altitude gain (i.e. deltas), and not level above sea, for a user
in millimeters.
Corresponds to the JSON property altitude
1165 1166 1167 |
# File 'lib/google/apis/health_v4/classes.rb', line 1165 def altitude @altitude end |
#basal_energy_burned ⇒ Google::Apis::HealthV4::BasalEnergyBurned
Number of calories burned due to basal metabolic rate (BMR) over a period of
time.
Corresponds to the JSON property basalEnergyBurned
1171 1172 1173 |
# File 'lib/google/apis/health_v4/classes.rb', line 1171 def basal_energy_burned @basal_energy_burned end |
#body_fat ⇒ Google::Apis::HealthV4::BodyFat
Body fat measurement.
Corresponds to the JSON property bodyFat
1176 1177 1178 |
# File 'lib/google/apis/health_v4/classes.rb', line 1176 def body_fat @body_fat end |
#daily_heart_rate_variability ⇒ Google::Apis::HealthV4::DailyHeartRateVariability
Represents the daily heart rate variability data type. At least one of the
following fields must be set: - average_heart_rate_variability_milliseconds -
non_rem_heart_rate_beats_per_minute - entropy -
deep_sleep_root_mean_square_of_successive_differences_milliseconds
Corresponds to the JSON property dailyHeartRateVariability
1184 1185 1186 |
# File 'lib/google/apis/health_v4/classes.rb', line 1184 def daily_heart_rate_variability @daily_heart_rate_variability end |
#daily_heart_rate_zones ⇒ Google::Apis::HealthV4::DailyHeartRateZones
User's heart rate zone thresholds based on the Karvonen algorithm for a
specific day.
Corresponds to the JSON property dailyHeartRateZones
1190 1191 1192 |
# File 'lib/google/apis/health_v4/classes.rb', line 1190 def daily_heart_rate_zones @daily_heart_rate_zones end |
#daily_oxygen_saturation ⇒ Google::Apis::HealthV4::DailyOxygenSaturation
A daily oxygen saturation (SpO2) record. Represents the user's daily oxygen
saturation summary, typically calculated during sleep.
Corresponds to the JSON property dailyOxygenSaturation
1196 1197 1198 |
# File 'lib/google/apis/health_v4/classes.rb', line 1196 def daily_oxygen_saturation @daily_oxygen_saturation end |
#daily_respiratory_rate ⇒ Google::Apis::HealthV4::DailyRespiratoryRate
A daily average respiratory rate (breaths per minute) for a day of the year.
One data point per day calculated for the main sleep.
Corresponds to the JSON property dailyRespiratoryRate
1202 1203 1204 |
# File 'lib/google/apis/health_v4/classes.rb', line 1202 def daily_respiratory_rate @daily_respiratory_rate end |
#daily_resting_heart_rate ⇒ Google::Apis::HealthV4::DailyRestingHeartRate
Measures the daily resting heart rate for a user, calculated using the all day
heart rate measurements.
Corresponds to the JSON property dailyRestingHeartRate
1208 1209 1210 |
# File 'lib/google/apis/health_v4/classes.rb', line 1208 def daily_resting_heart_rate @daily_resting_heart_rate end |
#daily_sleep_temperature_derivations ⇒ Google::Apis::HealthV4::DailySleepTemperatureDerivations
Provides derived sleep temperature values, calculated from skin or internal
device temperature readings during sleep.
Corresponds to the JSON property dailySleepTemperatureDerivations
1214 1215 1216 |
# File 'lib/google/apis/health_v4/classes.rb', line 1214 def daily_sleep_temperature_derivations @daily_sleep_temperature_derivations end |
#daily_vo2_max ⇒ Google::Apis::HealthV4::DailyVo2Max
Contains a daily summary of the user's VO2 max (cardio fitness score), which
is the maximum rate of oxygen the body can use during exercise.
Corresponds to the JSON property dailyVo2Max
1220 1221 1222 |
# File 'lib/google/apis/health_v4/classes.rb', line 1220 def daily_vo2_max @daily_vo2_max end |
#data_source ⇒ Google::Apis::HealthV4::DataSource
Data Source definition to track the origin of data. Each health data point,
regardless of the complexity or data model (whether a simple step count or a
detailed sleep session) must retain information about its source of origin (e.
g. the device or app that collected it).
Corresponds to the JSON property dataSource
1228 1229 1230 |
# File 'lib/google/apis/health_v4/classes.rb', line 1228 def data_source @data_source end |
#distance ⇒ Google::Apis::HealthV4::Distance
Distance traveled over an interval of time.
Corresponds to the JSON property distance
1233 1234 1235 |
# File 'lib/google/apis/health_v4/classes.rb', line 1233 def distance @distance end |
#exercise ⇒ Google::Apis::HealthV4::Exercise
An exercise that stores information about a physical activity.
Corresponds to the JSON property exercise
1238 1239 1240 |
# File 'lib/google/apis/health_v4/classes.rb', line 1238 def exercise @exercise end |
#floors ⇒ Google::Apis::HealthV4::Floors
Gained elevation measured in floors over the time interval
Corresponds to the JSON property floors
1243 1244 1245 |
# File 'lib/google/apis/health_v4/classes.rb', line 1243 def floors @floors end |
#heart_rate ⇒ Google::Apis::HealthV4::HeartRate
A heart rate measurement.
Corresponds to the JSON property heartRate
1248 1249 1250 |
# File 'lib/google/apis/health_v4/classes.rb', line 1248 def heart_rate @heart_rate end |
#heart_rate_variability ⇒ Google::Apis::HealthV4::HeartRateVariability
Captures user's heart rate variability (HRV) as measured by the root mean
square of successive differences (RMSSD) between normal heartbeats or by
standard deviation of the inter-beat intervals (SDNN).
Corresponds to the JSON property heartRateVariability
1255 1256 1257 |
# File 'lib/google/apis/health_v4/classes.rb', line 1255 def heart_rate_variability @heart_rate_variability end |
#height ⇒ Google::Apis::HealthV4::Height
Body height measurement.
Corresponds to the JSON property height
1260 1261 1262 |
# File 'lib/google/apis/health_v4/classes.rb', line 1260 def height @height end |
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLog
Holds information about a user logged hydration.
Corresponds to the JSON property hydrationLog
1265 1266 1267 |
# File 'lib/google/apis/health_v4/classes.rb', line 1265 def hydration_log @hydration_log end |
#name ⇒ String
Identifier. Data point name, only supported for the subset of identifiable
data types. For the majority of the data types, individual data points do not
need to be identified and this field would be empty. Format: users/user/
dataTypes/data_type/dataPoints/data_pointExample: `users/abcd1234/
dataTypes/sleep/dataPoints/a1b2c3d4-e5f6-7890-1234-567890abcdef` Theuser
ID is a system-generated identifier, as described in Identity.health_user_id.
Thedata_typeID corresponds to the kebab-case version of the field names
in the DataPoint data union field, e.g. `total-calories` for the `
total_calories` field. Thedata_point`ID can be client-provided or system-
generated. If client-provided, it must be a string of 4-63 characters,
containing only lowercase letters, numbers, and hyphens.
Corresponds to the JSON propertyname`
1280 1281 1282 |
# File 'lib/google/apis/health_v4/classes.rb', line 1280 def name @name end |
#oxygen_saturation ⇒ Google::Apis::HealthV4::OxygenSaturation
Captures the user's instantaneous oxygen saturation percentage (SpO2).
Corresponds to the JSON property oxygenSaturation
1285 1286 1287 |
# File 'lib/google/apis/health_v4/classes.rb', line 1285 def oxygen_saturation @oxygen_saturation end |
#respiratory_rate_sleep_summary ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummary
Records respiratory rate details during sleep. Can have multiple per day if
the user sleeps multiple times.
Corresponds to the JSON property respiratoryRateSleepSummary
1291 1292 1293 |
# File 'lib/google/apis/health_v4/classes.rb', line 1291 def respiratory_rate_sleep_summary @respiratory_rate_sleep_summary end |
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2Max
VO2 max value calculated based on the user's running activity. Value stored in
ml/kg/min.
Corresponds to the JSON property runVo2Max
1297 1298 1299 |
# File 'lib/google/apis/health_v4/classes.rb', line 1297 def run_vo2_max @run_vo2_max end |
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriod
SedentaryPeriod SedentaryPeriod data represents the periods of time that the
user was sedentary (i.e. not moving while wearing the device).
Corresponds to the JSON property sedentaryPeriod
1303 1304 1305 |
# File 'lib/google/apis/health_v4/classes.rb', line 1303 def sedentary_period @sedentary_period end |
#sleep ⇒ Google::Apis::HealthV4::Sleep
A sleep session possibly including stages.
Corresponds to the JSON property sleep
1308 1309 1310 |
# File 'lib/google/apis/health_v4/classes.rb', line 1308 def sleep @sleep end |
#steps ⇒ Google::Apis::HealthV4::Steps
Step count over the time interval.
Corresponds to the JSON property steps
1313 1314 1315 |
# File 'lib/google/apis/health_v4/classes.rb', line 1313 def steps @steps end |
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsData
Swim lengths data over the time interval.
Corresponds to the JSON property swimLengthsData
1318 1319 1320 |
# File 'lib/google/apis/health_v4/classes.rb', line 1318 def swim_lengths_data @swim_lengths_data end |
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZone
Time in heart rate zone record. It's an interval spent in specific heart rate
zone.
Corresponds to the JSON property timeInHeartRateZone
1324 1325 1326 |
# File 'lib/google/apis/health_v4/classes.rb', line 1324 def time_in_heart_rate_zone @time_in_heart_rate_zone end |
#vo2_max ⇒ Google::Apis::HealthV4::Vo2Max
VO2 max measurement.
Corresponds to the JSON property vo2Max
1329 1330 1331 |
# File 'lib/google/apis/health_v4/classes.rb', line 1329 def vo2_max @vo2_max end |
#weight ⇒ Google::Apis::HealthV4::Weight
Body weight measurement.
Corresponds to the JSON property weight
1334 1335 1336 |
# File 'lib/google/apis/health_v4/classes.rb', line 1334 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 |
# File 'lib/google/apis/health_v4/classes.rb', line 1341 def update!(**args) @active_minutes = args[:active_minutes] if args.key?(:active_minutes) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @activity_level = args[:activity_level] if args.key?(:activity_level) @altitude = args[:altitude] if args.key?(:altitude) @basal_energy_burned = args[:basal_energy_burned] if args.key?(:basal_energy_burned) @body_fat = args[:body_fat] if args.key?(:body_fat) @daily_heart_rate_variability = args[:daily_heart_rate_variability] if args.key?(:daily_heart_rate_variability) @daily_heart_rate_zones = args[:daily_heart_rate_zones] if args.key?(:daily_heart_rate_zones) @daily_oxygen_saturation = args[:daily_oxygen_saturation] if args.key?(:daily_oxygen_saturation) @daily_respiratory_rate = args[:daily_respiratory_rate] if args.key?(:daily_respiratory_rate) @daily_resting_heart_rate = args[:daily_resting_heart_rate] if args.key?(:daily_resting_heart_rate) @daily_sleep_temperature_derivations = args[:daily_sleep_temperature_derivations] if args.key?(:daily_sleep_temperature_derivations) @daily_vo2_max = args[:daily_vo2_max] if args.key?(:daily_vo2_max) @data_source = args[:data_source] if args.key?(:data_source) @distance = args[:distance] if args.key?(:distance) @exercise = args[:exercise] if args.key?(:exercise) @floors = args[:floors] if args.key?(:floors) @heart_rate = args[:heart_rate] if args.key?(:heart_rate) @heart_rate_variability = args[:heart_rate_variability] if args.key?(:heart_rate_variability) @height = args[:height] if args.key?(:height) @hydration_log = args[:hydration_log] if args.key?(:hydration_log) @name = args[:name] if args.key?(:name) @oxygen_saturation = args[:oxygen_saturation] if args.key?(:oxygen_saturation) @respiratory_rate_sleep_summary = args[:respiratory_rate_sleep_summary] if args.key?(:respiratory_rate_sleep_summary) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period) @sleep = args[:sleep] if args.key?(:sleep) @steps = args[:steps] if args.key?(:steps) @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data) @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone) @vo2_max = args[:vo2_max] if args.key?(:vo2_max) @weight = args[:weight] if args.key?(:weight) end |