Class: Google::Apis::HealthV4::Distance
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Distance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Distance traveled over an interval of time.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
-
#millimeters ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Distance
constructor
A new instance of Distance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Distance
Returns a new instance of Distance.
1555 1556 1557 |
# File 'lib/google/apis/health_v4/classes.rb', line 1555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
1548 1549 1550 |
# File 'lib/google/apis/health_v4/classes.rb', line 1548 def interval @interval end |
#millimeters ⇒ Fixnum
Required. Distance in millimeters over the observed interval.
Corresponds to the JSON property millimeters
1553 1554 1555 |
# File 'lib/google/apis/health_v4/classes.rb', line 1553 def millimeters @millimeters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1560 1561 1562 1563 |
# File 'lib/google/apis/health_v4/classes.rb', line 1560 def update!(**args) @interval = args[:interval] if args.key?(:interval) @millimeters = args[:millimeters] if args.key?(:millimeters) end |