Class: Google::Apis::HealthV4::Electrocardiogram
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Electrocardiogram
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents an Electrocardiogram (ECG) measurement session. This data type is based on SaMD feature and any changes to it may require additional review.
Instance Attribute Summary collapse
-
#beats_per_minute_avg ⇒ Fixnum
Optional.
-
#interval ⇒ Google::Apis::HealthV4::SessionTimeInterval
Represents a time interval of session data point, which bundles multiple observed metrics together.
-
#lead_number ⇒ Fixnum
Optional.
-
#medical_device_info ⇒ Google::Apis::HealthV4::MedicalDeviceInfo
Software as Medical Device (SaMD) metadata.
-
#millivolts_scaling_factor ⇒ Fixnum
Optional.
-
#result_classification ⇒ String
Optional.
-
#sampling_frequency_hertz ⇒ Fixnum
Optional.
-
#waveform_samples ⇒ Array<Fixnum>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Electrocardiogram
constructor
A new instance of Electrocardiogram.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Electrocardiogram
Returns a new instance of Electrocardiogram.
2078 2079 2080 |
# File 'lib/google/apis/health_v4/classes.rb', line 2078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#beats_per_minute_avg ⇒ Fixnum
Optional. Average heart rate recorded during ECG reading in beats per minute.
Corresponds to the JSON property beatsPerMinuteAvg
2036 2037 2038 |
# File 'lib/google/apis/health_v4/classes.rb', line 2036 def beats_per_minute_avg @beats_per_minute_avg end |
#interval ⇒ Google::Apis::HealthV4::SessionTimeInterval
Represents a time interval of session data point, which bundles multiple
observed metrics together.
Corresponds to the JSON property interval
2042 2043 2044 |
# File 'lib/google/apis/health_v4/classes.rb', line 2042 def interval @interval end |
#lead_number ⇒ Fixnum
Optional. The number of leads used for ECG reading.
Corresponds to the JSON property leadNumber
2047 2048 2049 |
# File 'lib/google/apis/health_v4/classes.rb', line 2047 def lead_number @lead_number end |
#medical_device_info ⇒ Google::Apis::HealthV4::MedicalDeviceInfo
Software as Medical Device (SaMD) metadata. Used to construct the Unique
Device Identifier (UDI).
Corresponds to the JSON property medicalDeviceInfo
2053 2054 2055 |
# File 'lib/google/apis/health_v4/classes.rb', line 2053 def medical_device_info @medical_device_info end |
#millivolts_scaling_factor ⇒ Fixnum
Optional. The factor by which to divide waveform samples to get voltage in
millivolts: millivolts = waveform_sample / millivolts_scaling_factor.
Corresponds to the JSON property millivoltsScalingFactor
2059 2060 2061 |
# File 'lib/google/apis/health_v4/classes.rb', line 2059 def millivolts_scaling_factor @millivolts_scaling_factor end |
#result_classification ⇒ String
Optional. The result classification of the ECG reading.
Corresponds to the JSON property resultClassification
2064 2065 2066 |
# File 'lib/google/apis/health_v4/classes.rb', line 2064 def result_classification @result_classification end |
#sampling_frequency_hertz ⇒ Fixnum
Optional. The sampling frequency of waveform samples in hertz.
Corresponds to the JSON property samplingFrequencyHertz
2069 2070 2071 |
# File 'lib/google/apis/health_v4/classes.rb', line 2069 def sampling_frequency_hertz @sampling_frequency_hertz end |
#waveform_samples ⇒ Array<Fixnum>
Optional. An array of voltage values representing lead I ECG values. Each
sample represents voltage difference in ECG graph. The first value in array
corresponds to the start of the reading.
Corresponds to the JSON property waveformSamples
2076 2077 2078 |
# File 'lib/google/apis/health_v4/classes.rb', line 2076 def waveform_samples @waveform_samples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/google/apis/health_v4/classes.rb', line 2083 def update!(**args) @beats_per_minute_avg = args[:beats_per_minute_avg] if args.key?(:beats_per_minute_avg) @interval = args[:interval] if args.key?(:interval) @lead_number = args[:lead_number] if args.key?(:lead_number) @medical_device_info = args[:medical_device_info] if args.key?(:medical_device_info) @millivolts_scaling_factor = args[:millivolts_scaling_factor] if args.key?(:millivolts_scaling_factor) @result_classification = args[:result_classification] if args.key?(:result_classification) @sampling_frequency_hertz = args[:sampling_frequency_hertz] if args.key?(:sampling_frequency_hertz) @waveform_samples = args[:waveform_samples] if args.key?(:waveform_samples) end |