Class: Google::Apis::HealthV4::Electrocardiogram

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents an Electrocardiogram (ECG) measurement session. This data type is based on SaMD feature and any changes to it may require additional review.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Electrocardiogram

Returns a new instance of Electrocardiogram.



2051
2052
2053
# File 'lib/google/apis/health_v4/classes.rb', line 2051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#beats_per_minute_avgFixnum

Optional. Average heart rate recorded during ECG reading in beats per minute. Corresponds to the JSON property beatsPerMinuteAvg

Returns:

  • (Fixnum)


2009
2010
2011
# File 'lib/google/apis/health_v4/classes.rb', line 2009

def beats_per_minute_avg
  @beats_per_minute_avg
end

#intervalGoogle::Apis::HealthV4::SessionTimeInterval

Represents a time interval of session data point, which bundles multiple observed metrics together. Corresponds to the JSON property interval



2015
2016
2017
# File 'lib/google/apis/health_v4/classes.rb', line 2015

def interval
  @interval
end

#lead_numberFixnum

Optional. The number of leads used for ECG reading. Corresponds to the JSON property leadNumber

Returns:

  • (Fixnum)


2020
2021
2022
# File 'lib/google/apis/health_v4/classes.rb', line 2020

def lead_number
  @lead_number
end

#medical_device_infoGoogle::Apis::HealthV4::MedicalDeviceInfo

Software as Medical Device (SaMD) metadata. Used to construct the Unique Device Identifier (UDI). Corresponds to the JSON property medicalDeviceInfo



2026
2027
2028
# File 'lib/google/apis/health_v4/classes.rb', line 2026

def medical_device_info
  @medical_device_info
end

#millivolts_scaling_factorFixnum

Optional. The factor by which to divide waveform samples to get voltage in millivolts: millivolts = waveform_sample / millivolts_scaling_factor. Corresponds to the JSON property millivoltsScalingFactor

Returns:

  • (Fixnum)


2032
2033
2034
# File 'lib/google/apis/health_v4/classes.rb', line 2032

def millivolts_scaling_factor
  @millivolts_scaling_factor
end

#result_classificationString

Optional. The result classification of the ECG reading. Corresponds to the JSON property resultClassification

Returns:

  • (String)


2037
2038
2039
# File 'lib/google/apis/health_v4/classes.rb', line 2037

def result_classification
  @result_classification
end

#sampling_frequency_hertzFixnum

Optional. The sampling frequency of waveform samples in hertz. Corresponds to the JSON property samplingFrequencyHertz

Returns:

  • (Fixnum)


2042
2043
2044
# File 'lib/google/apis/health_v4/classes.rb', line 2042

def sampling_frequency_hertz
  @sampling_frequency_hertz
end

#waveform_samplesArray<Fixnum>

Optional. An array of voltage values representing lead I ECG values. Each sample represents voltage difference in ECG graph. The first value in array corresponds to the start of the reading. Corresponds to the JSON property waveformSamples

Returns:

  • (Array<Fixnum>)


2049
2050
2051
# File 'lib/google/apis/health_v4/classes.rb', line 2049

def waveform_samples
  @waveform_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
# File 'lib/google/apis/health_v4/classes.rb', line 2056

def update!(**args)
  @beats_per_minute_avg = args[:beats_per_minute_avg] if args.key?(:beats_per_minute_avg)
  @interval = args[:interval] if args.key?(:interval)
  @lead_number = args[:lead_number] if args.key?(:lead_number)
  @medical_device_info = args[:medical_device_info] if args.key?(:medical_device_info)
  @millivolts_scaling_factor = args[:millivolts_scaling_factor] if args.key?(:millivolts_scaling_factor)
  @result_classification = args[:result_classification] if args.key?(:result_classification)
  @sampling_frequency_hertz = args[:sampling_frequency_hertz] if args.key?(:sampling_frequency_hertz)
  @waveform_samples = args[:waveform_samples] if args.key?(:waveform_samples)
end