Class: Google::Apis::HealthV4::EndpointAuthorization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Authorization mechanism for a subscriber endpoint. For all requests sent by the Webhooks service, the JSON payload is cryptographically signed. The signature is delivered in the X-HEALTHAPI-SIGNATURE HTTP header. This is an ECDSA (NIST P256) signature of the JSON payload. Clients must verify this signature using Google Health API's public key to confirm the payload was sent by the Health API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndpointAuthorization

Returns a new instance of EndpointAuthorization.



1611
1612
1613
# File 'lib/google/apis/health_v4/classes.rb', line 1611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secretString

Required. Input only. Provides a client-provided secret that will be sent with each notification to the subscriber endpoint using the "Authorization" header. The value must include the authorization scheme, e.g., "Bearer " or "Basic ", as it will be used as the full Authorization header value. This secret is used by the API to test the endpoint during CreateSubscriber and UpdateSubscriber calls, and will be sent in the Authorization header for all subsequent webhook notifications to this endpoint. Corresponds to the JSON property secret

Returns:

  • (String)


1603
1604
1605
# File 'lib/google/apis/health_v4/classes.rb', line 1603

def secret
  @secret
end

#secret_setBoolean Also known as: secret_set?

Output only. Whether the secret is set. Corresponds to the JSON property secretSet

Returns:

  • (Boolean)


1608
1609
1610
# File 'lib/google/apis/health_v4/classes.rb', line 1608

def secret_set
  @secret_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1616
1617
1618
1619
# File 'lib/google/apis/health_v4/classes.rb', line 1616

def update!(**args)
  @secret = args[:secret] if args.key?(:secret)
  @secret_set = args[:secret_set] if args.key?(:secret_set)
end