Class: Google::Apis::HealthV4::ExerciseEvent
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ExerciseEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents instantaneous events that happen during an exercise, such as start, stop, pause, split.
Instance Attribute Summary collapse
-
#event_time ⇒ String
Required.
-
#event_utc_offset ⇒ String
Required.
-
#exercise_event_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExerciseEvent
constructor
A new instance of ExerciseEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExerciseEvent
Returns a new instance of ExerciseEvent.
2277 2278 2279 |
# File 'lib/google/apis/health_v4/classes.rb', line 2277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_time ⇒ String
Required. Exercise event time
Corresponds to the JSON property eventTime
2265 2266 2267 |
# File 'lib/google/apis/health_v4/classes.rb', line 2265 def event_time @event_time end |
#event_utc_offset ⇒ String
Required. Exercise event time offset from UTC
Corresponds to the JSON property eventUtcOffset
2270 2271 2272 |
# File 'lib/google/apis/health_v4/classes.rb', line 2270 def event_utc_offset @event_utc_offset end |
#exercise_event_type ⇒ String
Required. The type of the event, such as start, stop, pause, resume.
Corresponds to the JSON property exerciseEventType
2275 2276 2277 |
# File 'lib/google/apis/health_v4/classes.rb', line 2275 def exercise_event_type @exercise_event_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2282 2283 2284 2285 2286 |
# File 'lib/google/apis/health_v4/classes.rb', line 2282 def update!(**args) @event_time = args[:event_time] if args.key?(:event_time) @event_utc_offset = args[:event_utc_offset] if args.key?(:event_utc_offset) @exercise_event_type = args[:exercise_event_type] if args.key?(:exercise_event_type) end |