Class: Google::Apis::HealthV4::ExportExerciseTcxResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ExportExerciseTcxResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents a Response for exporting exercise data in TCX format.
Instance Attribute Summary collapse
-
#tcx_data ⇒ String
Contains the exported TCX data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportExerciseTcxResponse
constructor
A new instance of ExportExerciseTcxResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportExerciseTcxResponse
Returns a new instance of ExportExerciseTcxResponse.
1820 1821 1822 |
# File 'lib/google/apis/health_v4/classes.rb', line 1820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tcx_data ⇒ String
Contains the exported TCX data. This field is intended for gRPC clients, as
media download integration is not supported for gRPC. HTTP clients should
instead use the alt=media query parameter to download the raw binary TCX
file.
Corresponds to the JSON property tcxData
1818 1819 1820 |
# File 'lib/google/apis/health_v4/classes.rb', line 1818 def tcx_data @tcx_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1825 1826 1827 |
# File 'lib/google/apis/health_v4/classes.rb', line 1825 def update!(**args) @tcx_data = args[:tcx_data] if args.key?(:tcx_data) end |