Class: Google::Apis::HealthV4::Floors

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Gained elevation measured in floors over the time interval

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Floors

Returns a new instance of Floors.



2351
2352
2353
# File 'lib/google/apis/health_v4/classes.rb', line 2351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Required. Number of floors in the recorded interval Corresponds to the JSON property count

Returns:

  • (Fixnum)


2344
2345
2346
# File 'lib/google/apis/health_v4/classes.rb', line 2344

def count
  @count
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



2349
2350
2351
# File 'lib/google/apis/health_v4/classes.rb', line 2349

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2356
2357
2358
2359
# File 'lib/google/apis/health_v4/classes.rb', line 2356

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @interval = args[:interval] if args.key?(:interval)
end