Class: Google::Apis::HealthV4::Floors

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Gained elevation measured in floors over the time interval

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Floors

Returns a new instance of Floors.



1844
1845
1846
# File 'lib/google/apis/health_v4/classes.rb', line 1844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Required. Number of floors in the recorded interval Corresponds to the JSON property count

Returns:

  • (Fixnum)


1837
1838
1839
# File 'lib/google/apis/health_v4/classes.rb', line 1837

def count
  @count
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



1842
1843
1844
# File 'lib/google/apis/health_v4/classes.rb', line 1842

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1849
1850
1851
1852
# File 'lib/google/apis/health_v4/classes.rb', line 1849

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @interval = args[:interval] if args.key?(:interval)
end