Class: Google::Apis::HealthV4::Floors
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Floors
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Gained elevation measured in floors over the time interval
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Required.
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Floors
constructor
A new instance of Floors.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Floors
Returns a new instance of Floors.
1804 1805 1806 |
# File 'lib/google/apis/health_v4/classes.rb', line 1804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Required. Number of floors in the recorded interval
Corresponds to the JSON property count
1797 1798 1799 |
# File 'lib/google/apis/health_v4/classes.rb', line 1797 def count @count end |
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
1802 1803 1804 |
# File 'lib/google/apis/health_v4/classes.rb', line 1802 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1809 1810 1811 1812 |
# File 'lib/google/apis/health_v4/classes.rb', line 1809 def update!(**args) @count = args[:count] if args.key?(:count) @interval = args[:interval] if args.key?(:interval) end |