Class: Google::Apis::HealthV4::GoogleDevicesandservicesHealthV4DataType
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::GoogleDevicesandservicesHealthV4DataType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents a type of health data a user can have data points recorded for. It matches the parent resource of collection containing data points of the given type. Clients currently do not need to interact with this resource directly.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevicesandservicesHealthV4DataType
constructor
A new instance of GoogleDevicesandservicesHealthV4DataType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevicesandservicesHealthV4DataType
Returns a new instance of GoogleDevicesandservicesHealthV4DataType.
2572 2573 2574 |
# File 'lib/google/apis/health_v4/classes.rb', line 2572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The resource name of the data type. Format: users/user/
dataTypes/data_type`See DataPoint.name for examples and possible values.
Corresponds to the JSON propertyname`
2570 2571 2572 |
# File 'lib/google/apis/health_v4/classes.rb', line 2570 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2577 2578 2579 |
# File 'lib/google/apis/health_v4/classes.rb', line 2577 def update!(**args) @name = args[:name] if args.key?(:name) end |