Class: Google::Apis::HealthV4::GoogleDevicesandservicesHealthV4DataType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a type of health data a user can have data points recorded for. It matches the parent resource of collection containing data points of the given type. Clients currently do not need to interact with this resource directly.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevicesandservicesHealthV4DataType

Returns a new instance of GoogleDevicesandservicesHealthV4DataType.



1846
1847
1848
# File 'lib/google/apis/health_v4/classes.rb', line 1846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the data type. Format: users/user/ dataTypes/data_type`See DataPoint.name for examples and possible values. Corresponds to the JSON propertyname`

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/health_v4/classes.rb', line 1844

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1851
1852
1853
# File 'lib/google/apis/health_v4/classes.rb', line 1851

def update!(**args)
  @name = args[:name] if args.key?(:name)
end