Class: Google::Apis::HealthV4::GoogleDevicesandservicesHealthV4User
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::GoogleDevicesandservicesHealthV4User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents a user in the Google Health API. It matches the parent resource of collections owned by the user. Clients currently do not need to interact with this resource directly.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevicesandservicesHealthV4User
constructor
A new instance of GoogleDevicesandservicesHealthV4User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevicesandservicesHealthV4User
Returns a new instance of GoogleDevicesandservicesHealthV4User.
2600 2601 2602 |
# File 'lib/google/apis/health_v4/classes.rb', line 2600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The resource name of the user. The user ID is a system-
generated identifier, as described in Identity.health_user_id. Format: users/
user`
Corresponds to the JSON propertyname`
2598 2599 2600 |
# File 'lib/google/apis/health_v4/classes.rb', line 2598 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2605 2606 2607 |
# File 'lib/google/apis/health_v4/classes.rb', line 2605 def update!(**args) @name = args[:name] if args.key?(:name) end |