Class: Google::Apis::HealthV4::GoogleDevicesandservicesHealthV4User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a user in the Google Health API. It matches the parent resource of collections owned by the user. Clients currently do not need to interact with this resource directly.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevicesandservicesHealthV4User

Returns a new instance of GoogleDevicesandservicesHealthV4User.



2595
2596
2597
# File 'lib/google/apis/health_v4/classes.rb', line 2595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the user. The user ID is a system- generated identifier, as described in Identity.health_user_id. Format: users/ user` Corresponds to the JSON propertyname`

Returns:

  • (String)


2593
2594
2595
# File 'lib/google/apis/health_v4/classes.rb', line 2593

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2600
2601
2602
# File 'lib/google/apis/health_v4/classes.rb', line 2600

def update!(**args)
  @name = args[:name] if args.key?(:name)
end