Class: Google::Apis::HealthV4::GoogleHealthAPIService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::HealthV4::GoogleHealthAPIService
- Defined in:
- lib/google/apis/health_v4/service.rb
Overview
Google Health API
The Google Health API lets you view and manage health and fitness metrics and measurement data.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://health.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#batch_delete_data_points(parent, batch_delete_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Delete a batch of identifyable data points.
-
#create_project_subscriber(parent, create_subscriber_payload_object = nil, subscriber_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Registers a new subscriber endpoint to receive notifications.
-
#create_user_data_type_data_point(parent, data_point_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Creates a single identifiable data point.
-
#daily_roll_up_data_points(parent, daily_roll_up_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::DailyRollUpDataPointsResponse
Roll up data points over civil time intervals for supported data types.
-
#delete_project_subscriber(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Deletes a subscriber registration.
-
#export_user_data_type_data_point_exercise_tcx(name, partial_data: nil, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ExportExerciseTcxResponse
Exports exercise data in TCX format.
-
#get_user_data_type_data_point(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::DataPoint
Get a single identifyable data point.
-
#get_user_identity(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Identity
Gets the user's identity.
-
#get_user_profile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Profile
Returns user Profile details.
-
#get_user_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Settings
Returns user settings details.
-
#initialize ⇒ GoogleHealthAPIService
constructor
A new instance of GoogleHealthAPIService.
-
#list_project_subscribers(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ListSubscribersResponse
Lists all subscribers registered within the owned Google Cloud Project.
-
#list_user_data_type_data_points(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ListDataPointsResponse
Query user health and fitness data points.
-
#patch_project_subscriber(name, subscriber_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Updates the configuration of an existing subscriber, such as the endpoint URI or the data types it's interested in.
-
#patch_user_data_type_data_point(name, data_point_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Updates a single identifiable data point.
-
#reconcile_user_data_type_data_point(parent, data_source_family: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ReconcileDataPointsResponse
Reconcile data points from multiple data sources into a single data stream.
-
#roll_up_data_points(parent, roll_up_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::RollUpDataPointsResponse
Roll up data points over physical time intervals for supported data types.
-
#update_user_profile(name, profile_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Profile
Updates the user's profile details.
-
#update_user_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Settings
Updates the user's settings details.
Constructor Details
#initialize ⇒ GoogleHealthAPIService
Returns a new instance of GoogleHealthAPIService.
48 49 50 51 52 53 |
# File 'lib/google/apis/health_v4/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-health_v4', client_version: Google::Apis::HealthV4::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/health_v4/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/health_v4/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#batch_delete_data_points(parent, batch_delete_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Delete a batch of identifyable data points.
446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/google/apis/health_v4/service.rb', line 446 def batch_delete_data_points(parent, batch_delete_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v4/{+parent}/dataPoints:batchDelete', ) command.request_representation = Google::Apis::HealthV4::BatchDeleteDataPointsRequest::Representation command.request_object = batch_delete_data_points_request_object command.response_representation = Google::Apis::HealthV4::Operation::Representation command.response_class = Google::Apis::HealthV4::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_subscriber(parent, create_subscriber_payload_object = nil, subscriber_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Registers a new subscriber endpoint to receive notifications. A subscriber
represents an application or service that wishes to receive data change
notifications for users who have granted consent. Endpoint Verification:
For a subscriber to be successfully created, the provided endpoint_uri must
be a valid HTTPS endpoint and must pass an automated verification check. The
backend will send two HTTP POST requests to the endpoint_uri: 1. **
Verification with Authorization:** * Headers: Includes Content-Type:
application/json and Authorization (with the exact value from
CreateSubscriberPayload.endpoint_authorization.secret). * Body: "type":
"verification" * Expected Response: HTTP 201 Created. 2. **
Verification without Authorization:** * Headers: Includes Content-Type:
application/json. The Authorization header is OMITTED. * Body: "type":
"verification" * Expected Response: HTTP 401 Unauthorized or 403
Forbidden. Both tests must pass for the subscriber creation to succeed. If
verification fails, the operation will not be completed and an error will be
returned. This process ensures the endpoint is reachable and correctly
validates the Authorization header.
97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/google/apis/health_v4/service.rb', line 97 def create_project_subscriber(parent, create_subscriber_payload_object = nil, subscriber_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v4/{+parent}/subscribers', ) command.request_representation = Google::Apis::HealthV4::CreateSubscriberPayload::Representation command.request_object = create_subscriber_payload_object command.response_representation = Google::Apis::HealthV4::Operation::Representation command.response_class = Google::Apis::HealthV4::Operation command.params['parent'] = parent unless parent.nil? command.query['subscriberId'] = subscriber_id unless subscriber_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_user_data_type_data_point(parent, data_point_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Creates a single identifiable data point.
480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/google/apis/health_v4/service.rb', line 480 def create_user_data_type_data_point(parent, data_point_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v4/{+parent}/dataPoints', ) command.request_representation = Google::Apis::HealthV4::DataPoint::Representation command.request_object = data_point_object command.response_representation = Google::Apis::HealthV4::Operation::Representation command.response_class = Google::Apis::HealthV4::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#daily_roll_up_data_points(parent, daily_roll_up_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::DailyRollUpDataPointsResponse
Roll up data points over civil time intervals for supported data types.
516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/google/apis/health_v4/service.rb', line 516 def daily_roll_up_data_points(parent, daily_roll_up_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v4/{+parent}/dataPoints:dailyRollUp', ) command.request_representation = Google::Apis::HealthV4::DailyRollUpDataPointsRequest::Representation command.request_object = daily_roll_up_data_points_request_object command.response_representation = Google::Apis::HealthV4::DailyRollUpDataPointsResponse::Representation command.response_class = Google::Apis::HealthV4::DailyRollUpDataPointsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_subscriber(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Deletes a subscriber registration. This will stop all notifications to the subscriber's endpoint.
139 140 141 142 143 144 145 146 147 148 |
# File 'lib/google/apis/health_v4/service.rb', line 139 def delete_project_subscriber(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v4/{+name}', ) command.response_representation = Google::Apis::HealthV4::Operation::Representation command.response_class = Google::Apis::HealthV4::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#export_user_data_type_data_point_exercise_tcx(name, partial_data: nil, fields: nil, quota_user: nil, download_dest: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ExportExerciseTcxResponse
Exports exercise data in TCX format. Note: While the Authorization section
below states that any one of the listed scopes is accepted, this specific
method requires the user to provide both one of the activity_and_fitness
scopes (normal or readonly) AND one of the location scopes (normal or
readonly) in their access token to succeed.
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/google/apis/health_v4/service.rb', line 562 def export_user_data_type_data_point_exercise_tcx(name, partial_data: nil, fields: nil, quota_user: nil, download_dest: nil, options: nil, &block) if download_dest.nil? command = make_simple_command(:get, 'v4/{+name}:exportExerciseTcx', ) else command = make_download_command(:get, 'v4/{+name}:exportExerciseTcx', ) command.download_dest = download_dest end command.response_representation = Google::Apis::HealthV4::ExportExerciseTcxResponse::Representation command.response_class = Google::Apis::HealthV4::ExportExerciseTcxResponse command.params['name'] = name unless name.nil? command.query['partialData'] = partial_data unless partial_data.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_user_data_type_data_point(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::DataPoint
Get a single identifyable data point.
600 601 602 603 604 605 606 607 608 |
# File 'lib/google/apis/health_v4/service.rb', line 600 def get_user_data_type_data_point(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v4/{+name}', ) command.response_representation = Google::Apis::HealthV4::DataPoint::Representation command.response_class = Google::Apis::HealthV4::DataPoint command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_user_identity(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Identity
Gets the user's identity. It includes the legacy Fitbit user ID and the Google user ID and it can be used by migrating clients to map identifiers between the two systems.
270 271 272 273 274 275 276 277 278 |
# File 'lib/google/apis/health_v4/service.rb', line 270 def get_user_identity(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v4/{+name}', ) command.response_representation = Google::Apis::HealthV4::Identity::Representation command.response_class = Google::Apis::HealthV4::Identity command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_user_profile(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Profile
Returns user Profile details.
300 301 302 303 304 305 306 307 308 |
# File 'lib/google/apis/health_v4/service.rb', line 300 def get_user_profile(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v4/{+name}', ) command.response_representation = Google::Apis::HealthV4::Profile::Representation command.response_class = Google::Apis::HealthV4::Profile command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_user_settings(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Settings
Returns user settings details.
330 331 332 333 334 335 336 337 338 |
# File 'lib/google/apis/health_v4/service.rb', line 330 def get_user_settings(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v4/{+name}', ) command.response_representation = Google::Apis::HealthV4::Settings::Representation command.response_class = Google::Apis::HealthV4::Settings command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_subscribers(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ListSubscribersResponse
Lists all subscribers registered within the owned Google Cloud Project.
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/google/apis/health_v4/service.rb', line 180 def list_project_subscribers(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v4/{+parent}/subscribers', ) command.response_representation = Google::Apis::HealthV4::ListSubscribersResponse::Representation command.response_class = Google::Apis::HealthV4::ListSubscribersResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_user_data_type_data_points(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ListDataPointsResponse
Query user health and fitness data points.
688 689 690 691 692 693 694 695 696 697 698 699 |
# File 'lib/google/apis/health_v4/service.rb', line 688 def list_user_data_type_data_points(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v4/{+parent}/dataPoints', ) command.response_representation = Google::Apis::HealthV4::ListDataPointsResponse::Representation command.response_class = Google::Apis::HealthV4::ListDataPointsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_subscriber(name, subscriber_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Updates the configuration of an existing subscriber, such as the endpoint URI
or the data types it's interested in. Endpoint Verification: If the
endpoint_uri or endpoint_authorization field is included in the
update_mask, the backend will re-verify the endpoint. The verification
process is the same as described in CreateSubscriber: 1. Verification with
Authorization: POST to the new or existing endpoint_uri with the new or
existing Authorization secret. Expects HTTP 201 Created. 2. Verification
without Authorization: POST to the endpoint_uri without the Authorization
header. Expects HTTP 401 Unauthorized or 403 Forbidden. Both tests must
pass using the potentially updated values for the subscriber update to succeed.
If verification fails, the update will not be applied, and an error will be
returned.
235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/google/apis/health_v4/service.rb', line 235 def patch_project_subscriber(name, subscriber_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v4/{+name}', ) command.request_representation = Google::Apis::HealthV4::Subscriber::Representation command.request_object = subscriber_object command.response_representation = Google::Apis::HealthV4::Operation::Representation command.response_class = Google::Apis::HealthV4::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_user_data_type_data_point(name, data_point_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Operation
Updates a single identifiable data point. If a data point with the specified
name is not found, the request will fail.
733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/health_v4/service.rb', line 733 def patch_user_data_type_data_point(name, data_point_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v4/{+name}', ) command.request_representation = Google::Apis::HealthV4::DataPoint::Representation command.request_object = data_point_object command.response_representation = Google::Apis::HealthV4::Operation::Representation command.response_class = Google::Apis::HealthV4::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reconcile_user_data_type_data_point(parent, data_source_family: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::ReconcileDataPointsResponse
Reconcile data points from multiple data sources into a single data stream.
787 788 789 790 791 792 793 794 795 796 797 798 799 |
# File 'lib/google/apis/health_v4/service.rb', line 787 def reconcile_user_data_type_data_point(parent, data_source_family: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v4/{+parent}/dataPoints:reconcile', ) command.response_representation = Google::Apis::HealthV4::ReconcileDataPointsResponse::Representation command.response_class = Google::Apis::HealthV4::ReconcileDataPointsResponse command.params['parent'] = parent unless parent.nil? command.query['dataSourceFamily'] = data_source_family unless data_source_family.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#roll_up_data_points(parent, roll_up_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::RollUpDataPointsResponse
Roll up data points over physical time intervals for supported data types.
825 826 827 828 829 830 831 832 833 834 835 |
# File 'lib/google/apis/health_v4/service.rb', line 825 def roll_up_data_points(parent, roll_up_data_points_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v4/{+parent}/dataPoints:rollUp', ) command.request_representation = Google::Apis::HealthV4::RollUpDataPointsRequest::Representation command.request_object = roll_up_data_points_request_object command.response_representation = Google::Apis::HealthV4::RollUpDataPointsResponse::Representation command.response_class = Google::Apis::HealthV4::RollUpDataPointsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_user_profile(name, profile_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Profile
Updates the user's profile details.
367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/google/apis/health_v4/service.rb', line 367 def update_user_profile(name, profile_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v4/{+name}', ) command.request_representation = Google::Apis::HealthV4::Profile::Representation command.request_object = profile_object command.response_representation = Google::Apis::HealthV4::Profile::Representation command.response_class = Google::Apis::HealthV4::Profile command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_user_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HealthV4::Settings
Updates the user's settings details.
407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/google/apis/health_v4/service.rb', line 407 def update_user_settings(name, settings_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v4/{+name}', ) command.request_representation = Google::Apis::HealthV4::Settings::Representation command.request_object = settings_object command.response_representation = Google::Apis::HealthV4::Settings::Representation command.response_class = Google::Apis::HealthV4::Settings command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |