Class: Google::Apis::HealthV4::HeartBeat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

A single heart beat measurement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeartBeat

Returns a new instance of HeartBeat.



2659
2660
2661
# File 'lib/google/apis/health_v4/classes.rb', line 2659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#beats_per_minuteFixnum

Required. The beats-per-minute value extrapolated from the time before the following heart beat. This is calculated as 60000 / rr, where rr is the gap between heart beats in milliseconds (IBI - Interbeat Interval). Corresponds to the JSON property beatsPerMinute

Returns:

  • (Fixnum)


2639
2640
2641
# File 'lib/google/apis/health_v4/classes.rb', line 2639

def beats_per_minute
  @beats_per_minute
end

#civil_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilTime



2646
2647
2648
# File 'lib/google/apis/health_v4/classes.rb', line 2646

def civil_time
  @civil_time
end

#physical_timeString

Required. The time of the heart beat measurement. Corresponds to the JSON property physicalTime

Returns:

  • (String)


2651
2652
2653
# File 'lib/google/apis/health_v4/classes.rb', line 2651

def physical_time
  @physical_time
end

#utc_offsetString

Required. The UTC offset of the user's timezone when the heart beat measurement occurred. Corresponds to the JSON property utcOffset

Returns:

  • (String)


2657
2658
2659
# File 'lib/google/apis/health_v4/classes.rb', line 2657

def utc_offset
  @utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2664
2665
2666
2667
2668
2669
# File 'lib/google/apis/health_v4/classes.rb', line 2664

def update!(**args)
  @beats_per_minute = args[:beats_per_minute] if args.key?(:beats_per_minute)
  @civil_time = args[:civil_time] if args.key?(:civil_time)
  @physical_time = args[:physical_time] if args.key?(:physical_time)
  @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
end