Class: Google::Apis::HealthV4::HeartRateMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Heart rate metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeartRateMetadata

Returns a new instance of HeartRateMetadata.



1902
1903
1904
# File 'lib/google/apis/health_v4/classes.rb', line 1902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#motion_contextString

Optional. Indicates the user’s level of activity when the heart rate sample was measured Corresponds to the JSON property motionContext

Returns:

  • (String)


1895
1896
1897
# File 'lib/google/apis/health_v4/classes.rb', line 1895

def motion_context
  @motion_context
end

#sensor_locationString

Optional. Indicates the location of the sensor that measured the heart rate. Corresponds to the JSON property sensorLocation

Returns:

  • (String)


1900
1901
1902
# File 'lib/google/apis/health_v4/classes.rb', line 1900

def sensor_location
  @sensor_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1907
1908
1909
1910
# File 'lib/google/apis/health_v4/classes.rb', line 1907

def update!(**args)
  @motion_context = args[:motion_context] if args.key?(:motion_context)
  @sensor_location = args[:sensor_location] if args.key?(:sensor_location)
end