Class: Google::Apis::HealthV4::HeartRateVariability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeartRateVariability

Returns a new instance of HeartRateVariability.



2026
2027
2028
# File 'lib/google/apis/health_v4/classes.rb', line 2026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#root_mean_square_of_successive_differences_millisecondsFloat

Optional. The root mean square of successive differences between normal heartbeats. This is a measure of heart rate variability used by Google Health. Corresponds to the JSON property rootMeanSquareOfSuccessiveDifferencesMilliseconds

Returns:

  • (Float)


2014
2015
2016
# File 'lib/google/apis/health_v4/classes.rb', line 2014

def root_mean_square_of_successive_differences_milliseconds
  @root_mean_square_of_successive_differences_milliseconds
end

#sample_timeGoogle::Apis::HealthV4::ObservationSampleTime

Represents a sample time of an observed data point. Corresponds to the JSON property sampleTime



2019
2020
2021
# File 'lib/google/apis/health_v4/classes.rb', line 2019

def sample_time
  @sample_time
end

#standard_deviation_millisecondsFloat

Optional. The standard deviation of the heart rate variability measurement. Corresponds to the JSON property standardDeviationMilliseconds

Returns:

  • (Float)


2024
2025
2026
# File 'lib/google/apis/health_v4/classes.rb', line 2024

def standard_deviation_milliseconds
  @standard_deviation_milliseconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2031
2032
2033
2034
2035
# File 'lib/google/apis/health_v4/classes.rb', line 2031

def update!(**args)
  @root_mean_square_of_successive_differences_milliseconds = args[:root_mean_square_of_successive_differences_milliseconds] if args.key?(:root_mean_square_of_successive_differences_milliseconds)
  @sample_time = args[:sample_time] if args.key?(:sample_time)
  @standard_deviation_milliseconds = args[:standard_deviation_milliseconds] if args.key?(:standard_deviation_milliseconds)
end