Class: Google::Apis::HealthV4::HeartRateVariability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeartRateVariability

Returns a new instance of HeartRateVariability.



1966
1967
1968
# File 'lib/google/apis/health_v4/classes.rb', line 1966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#root_mean_square_of_successive_differences_millisecondsFloat

Optional. The root mean square of successive differences between normal heartbeats. This is a measure of heart rate variability used by Fitbit. Corresponds to the JSON property rootMeanSquareOfSuccessiveDifferencesMilliseconds

Returns:

  • (Float)


1954
1955
1956
# File 'lib/google/apis/health_v4/classes.rb', line 1954

def root_mean_square_of_successive_differences_milliseconds
  @root_mean_square_of_successive_differences_milliseconds
end

#sample_timeGoogle::Apis::HealthV4::ObservationSampleTime

Represents a sample time of an observed data point. Corresponds to the JSON property sampleTime



1959
1960
1961
# File 'lib/google/apis/health_v4/classes.rb', line 1959

def sample_time
  @sample_time
end

#standard_deviation_millisecondsFloat

Optional. The standard deviation of the heart rate variability measurement. Corresponds to the JSON property standardDeviationMilliseconds

Returns:

  • (Float)


1964
1965
1966
# File 'lib/google/apis/health_v4/classes.rb', line 1964

def standard_deviation_milliseconds
  @standard_deviation_milliseconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1971
1972
1973
1974
1975
# File 'lib/google/apis/health_v4/classes.rb', line 1971

def update!(**args)
  @root_mean_square_of_successive_differences_milliseconds = args[:root_mean_square_of_successive_differences_milliseconds] if args.key?(:root_mean_square_of_successive_differences_milliseconds)
  @sample_time = args[:sample_time] if args.key?(:sample_time)
  @standard_deviation_milliseconds = args[:standard_deviation_milliseconds] if args.key?(:standard_deviation_milliseconds)
end