Class: Google::Apis::HealthV4::HeartRateZone
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::HeartRateZone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
The heart rate zone.
Instance Attribute Summary collapse
-
#heart_rate_zone_type ⇒ String
Required.
-
#max_beats_per_minute ⇒ Fixnum
Required.
-
#min_beats_per_minute ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HeartRateZone
constructor
A new instance of HeartRateZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HeartRateZone
Returns a new instance of HeartRateZone.
2083 2084 2085 |
# File 'lib/google/apis/health_v4/classes.rb', line 2083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#heart_rate_zone_type ⇒ String
Required. The heart rate zone type.
Corresponds to the JSON property heartRateZoneType
2071 2072 2073 |
# File 'lib/google/apis/health_v4/classes.rb', line 2071 def heart_rate_zone_type @heart_rate_zone_type end |
#max_beats_per_minute ⇒ Fixnum
Required. Maximum heart rate for this zone in beats per minute.
Corresponds to the JSON property maxBeatsPerMinute
2076 2077 2078 |
# File 'lib/google/apis/health_v4/classes.rb', line 2076 def max_beats_per_minute @max_beats_per_minute end |
#min_beats_per_minute ⇒ Fixnum
Required. Minimum heart rate for this zone in beats per minute.
Corresponds to the JSON property minBeatsPerMinute
2081 2082 2083 |
# File 'lib/google/apis/health_v4/classes.rb', line 2081 def min_beats_per_minute @min_beats_per_minute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2088 2089 2090 2091 2092 |
# File 'lib/google/apis/health_v4/classes.rb', line 2088 def update!(**args) @heart_rate_zone_type = args[:heart_rate_zone_type] if args.key?(:heart_rate_zone_type) @max_beats_per_minute = args[:max_beats_per_minute] if args.key?(:max_beats_per_minute) @min_beats_per_minute = args[:min_beats_per_minute] if args.key?(:min_beats_per_minute) end |