Class: Google::Apis::HealthV4::HeartRateZone
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::HeartRateZone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
The heart rate zone.
Instance Attribute Summary collapse
-
#heart_rate_zone_type ⇒ String
Required.
-
#max_beats_per_minute ⇒ Fixnum
Required.
-
#min_beats_per_minute ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HeartRateZone
constructor
A new instance of HeartRateZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HeartRateZone
Returns a new instance of HeartRateZone.
2023 2024 2025 |
# File 'lib/google/apis/health_v4/classes.rb', line 2023 def initialize(**args) update!(**args) end |
Instance Attribute Details
#heart_rate_zone_type ⇒ String
Required. The heart rate zone type.
Corresponds to the JSON property heartRateZoneType
2011 2012 2013 |
# File 'lib/google/apis/health_v4/classes.rb', line 2011 def heart_rate_zone_type @heart_rate_zone_type end |
#max_beats_per_minute ⇒ Fixnum
Required. Maximum heart rate for this zone in beats per minute.
Corresponds to the JSON property maxBeatsPerMinute
2016 2017 2018 |
# File 'lib/google/apis/health_v4/classes.rb', line 2016 def max_beats_per_minute @max_beats_per_minute end |
#min_beats_per_minute ⇒ Fixnum
Required. Minimum heart rate for this zone in beats per minute.
Corresponds to the JSON property minBeatsPerMinute
2021 2022 2023 |
# File 'lib/google/apis/health_v4/classes.rb', line 2021 def min_beats_per_minute @min_beats_per_minute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2028 2029 2030 2031 2032 |
# File 'lib/google/apis/health_v4/classes.rb', line 2028 def update!(**args) @heart_rate_zone_type = args[:heart_rate_zone_type] if args.key?(:heart_rate_zone_type) @max_beats_per_minute = args[:max_beats_per_minute] if args.key?(:max_beats_per_minute) @min_beats_per_minute = args[:min_beats_per_minute] if args.key?(:min_beats_per_minute) end |