Class: Google::Apis::HealthV4::Height
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Height
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Body height measurement.
Instance Attribute Summary collapse
-
#height_millimeters ⇒ Fixnum
Required.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Height
constructor
A new instance of Height.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Height
Returns a new instance of Height.
2049 2050 2051 |
# File 'lib/google/apis/health_v4/classes.rb', line 2049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#height_millimeters ⇒ Fixnum
Required. Height of the user in millimeters.
Corresponds to the JSON property heightMillimeters
2042 2043 2044 |
# File 'lib/google/apis/health_v4/classes.rb', line 2042 def height_millimeters @height_millimeters end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
2047 2048 2049 |
# File 'lib/google/apis/health_v4/classes.rb', line 2047 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2054 2055 2056 2057 |
# File 'lib/google/apis/health_v4/classes.rb', line 2054 def update!(**args) @height_millimeters = args[:height_millimeters] if args.key?(:height_millimeters) @sample_time = args[:sample_time] if args.key?(:sample_time) end |