Class: Google::Apis::HealthV4::HttpResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::HttpResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents an HTTP response.
Instance Attribute Summary collapse
-
#body ⇒ String
The HTTP response body.
-
#headers ⇒ Array<Google::Apis::HealthV4::HttpHeader>
The HTTP response headers.
-
#reason ⇒ String
The HTTP reason phrase, such as "OK" or "Not Found".
-
#status ⇒ Fixnum
The HTTP status code, such as 200 or 404.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpResponse
constructor
A new instance of HttpResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpResponse
Returns a new instance of HttpResponse.
2970 2971 2972 |
# File 'lib/google/apis/health_v4/classes.rb', line 2970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ String
The HTTP response body. If the body is not expected, it should be empty.
Corresponds to the JSON property body
NOTE: Values are automatically base64 encoded/decoded in the client library.
2952 2953 2954 |
# File 'lib/google/apis/health_v4/classes.rb', line 2952 def body @body end |
#headers ⇒ Array<Google::Apis::HealthV4::HttpHeader>
The HTTP response headers. The ordering of the headers is significant.
Multiple headers with the same key may present for the response.
Corresponds to the JSON property headers
2958 2959 2960 |
# File 'lib/google/apis/health_v4/classes.rb', line 2958 def headers @headers end |
#reason ⇒ String
The HTTP reason phrase, such as "OK" or "Not Found".
Corresponds to the JSON property reason
2963 2964 2965 |
# File 'lib/google/apis/health_v4/classes.rb', line 2963 def reason @reason end |
#status ⇒ Fixnum
The HTTP status code, such as 200 or 404.
Corresponds to the JSON property status
2968 2969 2970 |
# File 'lib/google/apis/health_v4/classes.rb', line 2968 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2975 2976 2977 2978 2979 2980 |
# File 'lib/google/apis/health_v4/classes.rb', line 2975 def update!(**args) @body = args[:body] if args.key?(:body) @headers = args[:headers] if args.key?(:headers) @reason = args[:reason] if args.key?(:reason) @status = args[:status] if args.key?(:status) end |