Class: Google::Apis::HealthV4::HttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents an HTTP response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpResponse

Returns a new instance of HttpResponse.



2171
2172
2173
# File 'lib/google/apis/health_v4/classes.rb', line 2171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bodyString

The HTTP response body. If the body is not expected, it should be empty. Corresponds to the JSON property body NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/health_v4/classes.rb', line 2153

def body
  @body
end

#headersArray<Google::Apis::HealthV4::HttpHeader>

The HTTP response headers. The ordering of the headers is significant. Multiple headers with the same key may present for the response. Corresponds to the JSON property headers



2159
2160
2161
# File 'lib/google/apis/health_v4/classes.rb', line 2159

def headers
  @headers
end

#reasonString

The HTTP reason phrase, such as "OK" or "Not Found". Corresponds to the JSON property reason

Returns:

  • (String)


2164
2165
2166
# File 'lib/google/apis/health_v4/classes.rb', line 2164

def reason
  @reason
end

#statusFixnum

The HTTP status code, such as 200 or 404. Corresponds to the JSON property status

Returns:

  • (Fixnum)


2169
2170
2171
# File 'lib/google/apis/health_v4/classes.rb', line 2169

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2176
2177
2178
2179
2180
2181
# File 'lib/google/apis/health_v4/classes.rb', line 2176

def update!(**args)
  @body = args[:body] if args.key?(:body)
  @headers = args[:headers] if args.key?(:headers)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
end