Class: Google::Apis::HealthV4::HydrationLog
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::HydrationLog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Holds information about a user logged hydration.
Instance Attribute Summary collapse
-
#amount_consumed ⇒ Google::Apis::HealthV4::VolumeQuantity
Represents the volume quantity.
-
#interval ⇒ Google::Apis::HealthV4::SessionTimeInterval
Represents a time interval of session data point, which bundles multiple observed metrics together.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HydrationLog
constructor
A new instance of HydrationLog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HydrationLog
Returns a new instance of HydrationLog.
2950 2951 2952 |
# File 'lib/google/apis/health_v4/classes.rb', line 2950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount_consumed ⇒ Google::Apis::HealthV4::VolumeQuantity
Represents the volume quantity.
Corresponds to the JSON property amountConsumed
2942 2943 2944 |
# File 'lib/google/apis/health_v4/classes.rb', line 2942 def amount_consumed @amount_consumed end |
#interval ⇒ Google::Apis::HealthV4::SessionTimeInterval
Represents a time interval of session data point, which bundles multiple
observed metrics together.
Corresponds to the JSON property interval
2948 2949 2950 |
# File 'lib/google/apis/health_v4/classes.rb', line 2948 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2955 2956 2957 2958 |
# File 'lib/google/apis/health_v4/classes.rb', line 2955 def update!(**args) @amount_consumed = args[:amount_consumed] if args.key?(:amount_consumed) @interval = args[:interval] if args.key?(:interval) end |