Class: Google::Apis::HealthV4::Identity
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Identity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents details about the Google user's identity.
Instance Attribute Summary collapse
-
#health_user_id ⇒ String
Output only.
-
#legacy_user_id ⇒ String
Output only.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Identity
constructor
A new instance of Identity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Identity
Returns a new instance of Identity.
2258 2259 2260 |
# File 'lib/google/apis/health_v4/classes.rb', line 2258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_user_id ⇒ String
Output only. The Google User Identifier in the Google Health APIs. It matches
the user resource ID segment in the resource name paths, e.g. users/user
/dataTypes/steps. Valid values are strings of 1-63 characters, and valid
characters are lowercase and uppercase letters, numbers, and hyphens.
Corresponds to the JSON property healthUserId
2239 2240 2241 |
# File 'lib/google/apis/health_v4/classes.rb', line 2239 def health_user_id @health_user_id end |
#legacy_user_id ⇒ String
Output only. The legacy Fitbit User identifier. This is the Fitbit ID used in
the legacy Fitbit APIs (v1-v3). It can be referenced by clients migrating from
the legacy Fitbit APIs to map their existing identifiers to the new Google
user ID. It must not be used for any other purpose. It is not of any use
for new clients using only the Google Health APIs. Valid values are strings of
1-63 characters, and valid characters are lowercase and uppercase letters,
numbers, and hyphens.
Corresponds to the JSON property legacyUserId
2250 2251 2252 |
# File 'lib/google/apis/health_v4/classes.rb', line 2250 def legacy_user_id @legacy_user_id end |
#name ⇒ String
Identifier. The resource name of this Identity resource. Format: users/me/
identity
Corresponds to the JSON property name
2256 2257 2258 |
# File 'lib/google/apis/health_v4/classes.rb', line 2256 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2263 2264 2265 2266 2267 |
# File 'lib/google/apis/health_v4/classes.rb', line 2263 def update!(**args) @health_user_id = args[:health_user_id] if args.key?(:health_user_id) @legacy_user_id = args[:legacy_user_id] if args.key?(:legacy_user_id) @name = args[:name] if args.key?(:name) end |