Class: Google::Apis::HealthV4::Identity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents details about the Google user's identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Identity

Returns a new instance of Identity.



2198
2199
2200
# File 'lib/google/apis/health_v4/classes.rb', line 2198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_user_idString

Output only. The Google User Identifier in the Google Health APIs. It matches the user resource ID segment in the resource name paths, e.g. users/user /dataTypes/steps. Valid values are strings of 1-63 characters, and valid characters are lowercase and uppercase letters, numbers, and hyphens. Corresponds to the JSON property healthUserId

Returns:

  • (String)


2179
2180
2181
# File 'lib/google/apis/health_v4/classes.rb', line 2179

def health_user_id
  @health_user_id
end

#legacy_user_idString

Output only. The legacy Fitbit User identifier. This is the Fitbit ID used in the legacy Fitbit APIs (v1-v3). It can be referenced by clients migrating from the legacy Fitbit APIs to map their existing identifiers to the new Google user ID. It must not be used for any other purpose. It is not of any use for new clients using only the Google Health APIs. Valid values are strings of 1-63 characters, and valid characters are lowercase and uppercase letters, numbers, and hyphens. Corresponds to the JSON property legacyUserId

Returns:

  • (String)


2190
2191
2192
# File 'lib/google/apis/health_v4/classes.rb', line 2190

def legacy_user_id
  @legacy_user_id
end

#nameString

Identifier. The resource name of this Identity resource. Format: users/me/ identity Corresponds to the JSON property name

Returns:

  • (String)


2196
2197
2198
# File 'lib/google/apis/health_v4/classes.rb', line 2196

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2203
2204
2205
2206
2207
# File 'lib/google/apis/health_v4/classes.rb', line 2203

def update!(**args)
  @health_user_id = args[:health_user_id] if args.key?(:health_user_id)
  @legacy_user_id = args[:legacy_user_id] if args.key?(:legacy_user_id)
  @name = args[:name] if args.key?(:name)
end