Class: Google::Apis::HealthV4::IrnProfile
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::IrnProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Irregular Rhythm Notifications (IRN) Profile details. The Irregular Rhythm Notifications (IRN) feature checks for signs of atrial fibrillation (AFib). The IrnProfile details include information about the user's onboarding status, enrollment status, and the last update time of analyzable data for this feature.
Instance Attribute Summary collapse
-
#enrollment_status ⇒ Boolean
(also: #enrollment_status?)
Required.
-
#name ⇒ String
Identifier.
-
#onboarding_status ⇒ Boolean
(also: #onboarding_status?)
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IrnProfile
constructor
A new instance of IrnProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IrnProfile
Returns a new instance of IrnProfile.
3172 3173 3174 |
# File 'lib/google/apis/health_v4/classes.rb', line 3172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enrollment_status ⇒ Boolean Also known as: enrollment_status?
Required. Whether or not the user is currently enrolled in having their data
processed for IRN alerts.
Corresponds to the JSON property enrollmentStatus
3147 3148 3149 |
# File 'lib/google/apis/health_v4/classes.rb', line 3147 def enrollment_status @enrollment_status end |
#name ⇒ String
Identifier. The resource name of this IrnProfile resource. Format: users/
user/irnProfile Example: users/1234567890/irnProfile or users/me/
irnProfile The user ID is a system-generated Google Health API user ID, a
string of 1-63 characters consisting of lowercase and uppercase letters,
numbers, and hyphens. The literal me can also be used to refer to the
authenticated user.
Corresponds to the JSON property name
3158 3159 3160 |
# File 'lib/google/apis/health_v4/classes.rb', line 3158 def name @name end |
#onboarding_status ⇒ Boolean Also known as: onboarding_status?
Required. Whether or not the user has onboarded onto the IRN feature.
Corresponds to the JSON property onboardingStatus
3163 3164 3165 |
# File 'lib/google/apis/health_v4/classes.rb', line 3163 def onboarding_status @onboarding_status end |
#update_time ⇒ String
Output only. The timestamp of the last piece of analyzable data synced by the
user.
Corresponds to the JSON property updateTime
3170 3171 3172 |
# File 'lib/google/apis/health_v4/classes.rb', line 3170 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3177 3178 3179 3180 3181 3182 |
# File 'lib/google/apis/health_v4/classes.rb', line 3177 def update!(**args) @enrollment_status = args[:enrollment_status] if args.key?(:enrollment_status) @name = args[:name] if args.key?(:name) @onboarding_status = args[:onboarding_status] if args.key?(:onboarding_status) @update_time = args[:update_time] if args.key?(:update_time) end |