Class: Google::Apis::HealthV4::IrnProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Irregular Rhythm Notifications (IRN) Profile details. The Irregular Rhythm Notifications (IRN) feature checks for signs of atrial fibrillation (AFib). The IrnProfile details include information about the user's onboarding status, enrollment status, and the last update time of analyzable data for this feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IrnProfile

Returns a new instance of IrnProfile.



3141
3142
3143
# File 'lib/google/apis/health_v4/classes.rb', line 3141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enrollment_statusBoolean Also known as: enrollment_status?

Required. Whether or not the user is currently enrolled in having their data processed for IRN alerts. Corresponds to the JSON property enrollmentStatus

Returns:

  • (Boolean)


3116
3117
3118
# File 'lib/google/apis/health_v4/classes.rb', line 3116

def enrollment_status
  @enrollment_status
end

#nameString

Identifier. The resource name of this IrnProfile resource. Format: users/ user/irnProfile Example: users/1234567890/irnProfile or users/me/ irnProfile The user ID is a system-generated Google Health API user ID, a string of 1-63 characters consisting of lowercase and uppercase letters, numbers, and hyphens. The literal me can also be used to refer to the authenticated user. Corresponds to the JSON property name

Returns:

  • (String)


3127
3128
3129
# File 'lib/google/apis/health_v4/classes.rb', line 3127

def name
  @name
end

#onboarding_statusBoolean Also known as: onboarding_status?

Required. Whether or not the user has onboarded onto the IRN feature. Corresponds to the JSON property onboardingStatus

Returns:

  • (Boolean)


3132
3133
3134
# File 'lib/google/apis/health_v4/classes.rb', line 3132

def onboarding_status
  @onboarding_status
end

#update_timeString

Output only. The timestamp of the last piece of analyzable data synced by the user. Corresponds to the JSON property updateTime

Returns:

  • (String)


3139
3140
3141
# File 'lib/google/apis/health_v4/classes.rb', line 3139

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3146
3147
3148
3149
3150
3151
# File 'lib/google/apis/health_v4/classes.rb', line 3146

def update!(**args)
  @enrollment_status = args[:enrollment_status] if args.key?(:enrollment_status)
  @name = args[:name] if args.key?(:name)
  @onboarding_status = args[:onboarding_status] if args.key?(:onboarding_status)
  @update_time = args[:update_time] if args.key?(:update_time)
end