Class: Google::Apis::HealthV4::IrregularRhythmNotification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents an Irregular Rhythm Notification alert, indicating a potential sign of atrial fibrillation (AFib). This data type is based on SaMD feature and any changes to it may require additional review.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IrregularRhythmNotification

Returns a new instance of IrregularRhythmNotification.



3126
3127
3128
# File 'lib/google/apis/health_v4/classes.rb', line 3126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alert_windowsArray<Google::Apis::HealthV4::AlertWindow>

Optional. The overlapping analysis windows that were used to evaluate rhythm for potential AFib, containing specific information about the user's heart rhythm. Corresponds to the JSON property alertWindows



3112
3113
3114
# File 'lib/google/apis/health_v4/classes.rb', line 3112

def alert_windows
  @alert_windows
end

#intervalGoogle::Apis::HealthV4::SessionTimeInterval

Represents a time interval of session data point, which bundles multiple observed metrics together. Corresponds to the JSON property interval



3118
3119
3120
# File 'lib/google/apis/health_v4/classes.rb', line 3118

def interval
  @interval
end

#medical_device_infoGoogle::Apis::HealthV4::MedicalDeviceInfo

Software as Medical Device (SaMD) metadata. Used to construct the Unique Device Identifier (UDI). Corresponds to the JSON property medicalDeviceInfo



3124
3125
3126
# File 'lib/google/apis/health_v4/classes.rb', line 3124

def medical_device_info
  @medical_device_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3131
3132
3133
3134
3135
# File 'lib/google/apis/health_v4/classes.rb', line 3131

def update!(**args)
  @alert_windows = args[:alert_windows] if args.key?(:alert_windows)
  @interval = args[:interval] if args.key?(:interval)
  @medical_device_info = args[:medical_device_info] if args.key?(:medical_device_info)
end