Class: Google::Apis::HealthV4::ManifestParams
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ManifestParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the POST body contained in a GetShlManifestRequest This message is nested to represent that See https://build.fhir.org/ig/HL7/smart-health-cards- and-links/links-specification.html#smart-health-link-manifest-request
Instance Attribute Summary collapse
-
#embedded_length_max ⇒ Fixnum
Optional.
-
#passcode ⇒ String
Optional.
-
#recipient ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManifestParams
constructor
A new instance of ManifestParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManifestParams
Returns a new instance of ManifestParams.
3317 3318 3319 |
# File 'lib/google/apis/health_v4/classes.rb', line 3317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedded_length_max ⇒ Fixnum
Optional. Integer upper bound on the length of embedded payloads
Corresponds to the JSON property embeddedLengthMax
3304 3305 3306 |
# File 'lib/google/apis/health_v4/classes.rb', line 3304 def @embedded_length_max end |
#passcode ⇒ String
Optional.
Corresponds to the JSON property passcode
3309 3310 3311 |
# File 'lib/google/apis/health_v4/classes.rb', line 3309 def passcode @passcode end |
#recipient ⇒ String
Required. A string describing the recipient (e.g.,the name of an organization
or person) suitable for display to the Receiving User
Corresponds to the JSON property recipient
3315 3316 3317 |
# File 'lib/google/apis/health_v4/classes.rb', line 3315 def recipient @recipient end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3322 3323 3324 3325 3326 |
# File 'lib/google/apis/health_v4/classes.rb', line 3322 def update!(**args) @embedded_length_max = args[:embedded_length_max] if args.key?(:embedded_length_max) @passcode = args[:passcode] if args.key?(:passcode) @recipient = args[:recipient] if args.key?(:recipient) end |