Class: Google::Apis::HealthV4::MedicalDeviceInfo
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::MedicalDeviceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Software as Medical Device (SaMD) metadata. Used to construct the Unique Device Identifier (UDI).
Instance Attribute Summary collapse
-
#algorithm_version ⇒ String
Output only.
-
#device_model ⇒ String
Output only.
-
#feature_version ⇒ String
Output only.
-
#firmware_version ⇒ String
Output only.
-
#service_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MedicalDeviceInfo
constructor
A new instance of MedicalDeviceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MedicalDeviceInfo
Returns a new instance of MedicalDeviceInfo.
3397 3398 3399 |
# File 'lib/google/apis/health_v4/classes.rb', line 3397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm_version ⇒ String
Output only. The algorithm version used by the feature.
Corresponds to the JSON property algorithmVersion
3373 3374 3375 |
# File 'lib/google/apis/health_v4/classes.rb', line 3373 def algorithm_version @algorithm_version end |
#device_model ⇒ String
Output only. The model name or device type of the compatible device used to
collect the data.
Corresponds to the JSON property deviceModel
3379 3380 3381 |
# File 'lib/google/apis/health_v4/classes.rb', line 3379 def device_model @device_model end |
#feature_version ⇒ String
Output only. The version of the feature/app running on the device.
Corresponds to the JSON property featureVersion
3384 3385 3386 |
# File 'lib/google/apis/health_v4/classes.rb', line 3384 def feature_version @feature_version end |
#firmware_version ⇒ String
Output only. The firmware version running on the compatible device used to
collect the data.
Corresponds to the JSON property firmwareVersion
3390 3391 3392 |
# File 'lib/google/apis/health_v4/classes.rb', line 3390 def firmware_version @firmware_version end |
#service_version ⇒ String
Output only. The service version used by the feature.
Corresponds to the JSON property serviceVersion
3395 3396 3397 |
# File 'lib/google/apis/health_v4/classes.rb', line 3395 def service_version @service_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/google/apis/health_v4/classes.rb', line 3402 def update!(**args) @algorithm_version = args[:algorithm_version] if args.key?(:algorithm_version) @device_model = args[:device_model] if args.key?(:device_model) @feature_version = args[:feature_version] if args.key?(:feature_version) @firmware_version = args[:firmware_version] if args.key?(:firmware_version) @service_version = args[:service_version] if args.key?(:service_version) end |