Class: Google::Apis::HealthV4::MedicalDeviceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Software as Medical Device (SaMD) metadata. Used to construct the Unique Device Identifier (UDI).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MedicalDeviceInfo

Returns a new instance of MedicalDeviceInfo.



3361
3362
3363
# File 'lib/google/apis/health_v4/classes.rb', line 3361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithm_versionString

Output only. The algorithm version used by the feature. Corresponds to the JSON property algorithmVersion

Returns:

  • (String)


3337
3338
3339
# File 'lib/google/apis/health_v4/classes.rb', line 3337

def algorithm_version
  @algorithm_version
end

#device_modelString

Output only. The model name or device type of the compatible device used to collect the data. Corresponds to the JSON property deviceModel

Returns:

  • (String)


3343
3344
3345
# File 'lib/google/apis/health_v4/classes.rb', line 3343

def device_model
  @device_model
end

#feature_versionString

Output only. The version of the feature/app running on the device. Corresponds to the JSON property featureVersion

Returns:

  • (String)


3348
3349
3350
# File 'lib/google/apis/health_v4/classes.rb', line 3348

def feature_version
  @feature_version
end

#firmware_versionString

Output only. The firmware version running on the compatible device used to collect the data. Corresponds to the JSON property firmwareVersion

Returns:

  • (String)


3354
3355
3356
# File 'lib/google/apis/health_v4/classes.rb', line 3354

def firmware_version
  @firmware_version
end

#service_versionString

Output only. The service version used by the feature. Corresponds to the JSON property serviceVersion

Returns:

  • (String)


3359
3360
3361
# File 'lib/google/apis/health_v4/classes.rb', line 3359

def service_version
  @service_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3366
3367
3368
3369
3370
3371
3372
# File 'lib/google/apis/health_v4/classes.rb', line 3366

def update!(**args)
  @algorithm_version = args[:algorithm_version] if args.key?(:algorithm_version)
  @device_model = args[:device_model] if args.key?(:device_model)
  @feature_version = args[:feature_version] if args.key?(:feature_version)
  @firmware_version = args[:firmware_version] if args.key?(:firmware_version)
  @service_version = args[:service_version] if args.key?(:service_version)
end