Class: Google::Apis::HealthV4::MedicalDeviceInfo
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::MedicalDeviceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Software as Medical Device (SaMD) metadata. Used to construct the Unique Device Identifier (UDI).
Instance Attribute Summary collapse
-
#algorithm_version ⇒ String
Output only.
-
#device_model ⇒ String
Output only.
-
#feature_version ⇒ String
Output only.
-
#firmware_version ⇒ String
Output only.
-
#service_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MedicalDeviceInfo
constructor
A new instance of MedicalDeviceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MedicalDeviceInfo
Returns a new instance of MedicalDeviceInfo.
3279 3280 3281 |
# File 'lib/google/apis/health_v4/classes.rb', line 3279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm_version ⇒ String
Output only. The algorithm version used by the feature.
Corresponds to the JSON property algorithmVersion
3255 3256 3257 |
# File 'lib/google/apis/health_v4/classes.rb', line 3255 def algorithm_version @algorithm_version end |
#device_model ⇒ String
Output only. The model name or device type of the compatible device used to
collect the data.
Corresponds to the JSON property deviceModel
3261 3262 3263 |
# File 'lib/google/apis/health_v4/classes.rb', line 3261 def device_model @device_model end |
#feature_version ⇒ String
Output only. The version of the feature/app running on the device.
Corresponds to the JSON property featureVersion
3266 3267 3268 |
# File 'lib/google/apis/health_v4/classes.rb', line 3266 def feature_version @feature_version end |
#firmware_version ⇒ String
Output only. The firmware version running on the compatible device used to
collect the data.
Corresponds to the JSON property firmwareVersion
3272 3273 3274 |
# File 'lib/google/apis/health_v4/classes.rb', line 3272 def firmware_version @firmware_version end |
#service_version ⇒ String
Output only. The service version used by the feature.
Corresponds to the JSON property serviceVersion
3277 3278 3279 |
# File 'lib/google/apis/health_v4/classes.rb', line 3277 def service_version @service_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3284 3285 3286 3287 3288 3289 3290 |
# File 'lib/google/apis/health_v4/classes.rb', line 3284 def update!(**args) @algorithm_version = args[:algorithm_version] if args.key?(:algorithm_version) @device_model = args[:device_model] if args.key?(:device_model) @feature_version = args[:feature_version] if args.key?(:feature_version) @firmware_version = args[:firmware_version] if args.key?(:firmware_version) @service_version = args[:service_version] if args.key?(:service_version) end |