Class: Google::Apis::HealthV4::MetricsSummary
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::MetricsSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Summary metrics for an exercise.
Instance Attribute Summary collapse
-
#active_zone_minutes ⇒ Fixnum
Optional.
-
#average_heart_rate_beats_per_minute ⇒ Fixnum
Optional.
-
#average_pace_seconds_per_meter ⇒ Float
Optional.
-
#average_speed_millimeters_per_second ⇒ Float
Optional.
-
#calories_kcal ⇒ Float
Optional.
-
#distance_millimeters ⇒ Float
Optional.
-
#elevation_gain_millimeters ⇒ Float
Optional.
-
#heart_rate_zone_durations ⇒ Google::Apis::HealthV4::TimeInHeartRateZones
Time spent in each heart rate zone.
-
#mobility_metrics ⇒ Google::Apis::HealthV4::MobilityMetrics
Mobility workouts specific metrics Corresponds to the JSON property
mobilityMetrics. -
#run_vo2_max ⇒ Float
Optional.
-
#steps ⇒ Fixnum
Optional.
-
#total_swim_lengths ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricsSummary
constructor
A new instance of MetricsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricsSummary
Returns a new instance of MetricsSummary.
2418 2419 2420 |
# File 'lib/google/apis/health_v4/classes.rb', line 2418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_zone_minutes ⇒ Fixnum
Optional. Total active zone minutes for the exercise.
Corresponds to the JSON property activeZoneMinutes
2358 2359 2360 |
# File 'lib/google/apis/health_v4/classes.rb', line 2358 def active_zone_minutes @active_zone_minutes end |
#average_heart_rate_beats_per_minute ⇒ Fixnum
Optional. Average heart rate during the exercise.
Corresponds to the JSON property averageHeartRateBeatsPerMinute
2363 2364 2365 |
# File 'lib/google/apis/health_v4/classes.rb', line 2363 def average_heart_rate_beats_per_minute @average_heart_rate_beats_per_minute end |
#average_pace_seconds_per_meter ⇒ Float
Optional. Average pace in seconds per meter.
Corresponds to the JSON property averagePaceSecondsPerMeter
2368 2369 2370 |
# File 'lib/google/apis/health_v4/classes.rb', line 2368 def average_pace_seconds_per_meter @average_pace_seconds_per_meter end |
#average_speed_millimeters_per_second ⇒ Float
Optional. Average speed in millimeters per second.
Corresponds to the JSON property averageSpeedMillimetersPerSecond
2373 2374 2375 |
# File 'lib/google/apis/health_v4/classes.rb', line 2373 def average_speed_millimeters_per_second @average_speed_millimeters_per_second end |
#calories_kcal ⇒ Float
Optional. Total calories burned by the user during the exercise.
Corresponds to the JSON property caloriesKcal
2378 2379 2380 |
# File 'lib/google/apis/health_v4/classes.rb', line 2378 def calories_kcal @calories_kcal end |
#distance_millimeters ⇒ Float
Optional. Total distance covered by the user during the exercise.
Corresponds to the JSON property distanceMillimeters
2383 2384 2385 |
# File 'lib/google/apis/health_v4/classes.rb', line 2383 def distance_millimeters @distance_millimeters end |
#elevation_gain_millimeters ⇒ Float
Optional. Total elevation gain during the exercise.
Corresponds to the JSON property elevationGainMillimeters
2388 2389 2390 |
# File 'lib/google/apis/health_v4/classes.rb', line 2388 def elevation_gain_millimeters @elevation_gain_millimeters end |
#heart_rate_zone_durations ⇒ Google::Apis::HealthV4::TimeInHeartRateZones
Time spent in each heart rate zone.
Corresponds to the JSON property heartRateZoneDurations
2393 2394 2395 |
# File 'lib/google/apis/health_v4/classes.rb', line 2393 def heart_rate_zone_durations @heart_rate_zone_durations end |
#mobility_metrics ⇒ Google::Apis::HealthV4::MobilityMetrics
Mobility workouts specific metrics
Corresponds to the JSON property mobilityMetrics
2398 2399 2400 |
# File 'lib/google/apis/health_v4/classes.rb', line 2398 def mobility_metrics @mobility_metrics end |
#run_vo2_max ⇒ Float
Optional. Run VO2 max value for the exercise. Only present in the running
exercises at the top level as in the summary of the whole exercise.
Corresponds to the JSON property runVo2Max
2404 2405 2406 |
# File 'lib/google/apis/health_v4/classes.rb', line 2404 def run_vo2_max @run_vo2_max end |
#steps ⇒ Fixnum
Optional. Total steps taken during the exercise.
Corresponds to the JSON property steps
2409 2410 2411 |
# File 'lib/google/apis/health_v4/classes.rb', line 2409 def steps @steps end |
#total_swim_lengths ⇒ Float
Optional. Number of full pool lengths completed during the exercise. Only
present in the swimming exercises at the top level as in the summary of the
whole exercise.
Corresponds to the JSON property totalSwimLengths
2416 2417 2418 |
# File 'lib/google/apis/health_v4/classes.rb', line 2416 def total_swim_lengths @total_swim_lengths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 |
# File 'lib/google/apis/health_v4/classes.rb', line 2423 def update!(**args) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @average_heart_rate_beats_per_minute = args[:average_heart_rate_beats_per_minute] if args.key?(:average_heart_rate_beats_per_minute) @average_pace_seconds_per_meter = args[:average_pace_seconds_per_meter] if args.key?(:average_pace_seconds_per_meter) @average_speed_millimeters_per_second = args[:average_speed_millimeters_per_second] if args.key?(:average_speed_millimeters_per_second) @calories_kcal = args[:calories_kcal] if args.key?(:calories_kcal) @distance_millimeters = args[:distance_millimeters] if args.key?(:distance_millimeters) @elevation_gain_millimeters = args[:elevation_gain_millimeters] if args.key?(:elevation_gain_millimeters) @heart_rate_zone_durations = args[:heart_rate_zone_durations] if args.key?(:heart_rate_zone_durations) @mobility_metrics = args[:mobility_metrics] if args.key?(:mobility_metrics) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @steps = args[:steps] if args.key?(:steps) @total_swim_lengths = args[:total_swim_lengths] if args.key?(:total_swim_lengths) end |