Class: Google::Apis::HealthV4::MobilityMetrics
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::MobilityMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Mobility workouts specific metrics
Instance Attribute Summary collapse
-
#avg_cadence_steps_per_minute ⇒ Float
Optional.
-
#avg_ground_contact_time_duration ⇒ String
Optional.
-
#avg_stride_length_millimeters ⇒ Fixnum
Optional.
-
#avg_vertical_oscillation_millimeters ⇒ Fixnum
Optional.
-
#avg_vertical_ratio ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobilityMetrics
constructor
A new instance of MobilityMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobilityMetrics
Returns a new instance of MobilityMetrics.
2472 2473 2474 |
# File 'lib/google/apis/health_v4/classes.rb', line 2472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_cadence_steps_per_minute ⇒ Float
Optional. Cadence is a measure of the frequency of your foot strikes. Steps /
min in real time during workout.
Corresponds to the JSON property avgCadenceStepsPerMinute
2447 2448 2449 |
# File 'lib/google/apis/health_v4/classes.rb', line 2447 def avg_cadence_steps_per_minute @avg_cadence_steps_per_minute end |
#avg_ground_contact_time_duration ⇒ String
Optional. The ground contact time for a particular stride is the amount of
time for which the foot was in contact with the ground on that stride
Corresponds to the JSON property avgGroundContactTimeDuration
2453 2454 2455 |
# File 'lib/google/apis/health_v4/classes.rb', line 2453 def avg_ground_contact_time_duration @avg_ground_contact_time_duration end |
#avg_stride_length_millimeters ⇒ Fixnum
Optional. Stride length is a measure of the distance covered by a single
stride
Corresponds to the JSON property avgStrideLengthMillimeters
2459 2460 2461 |
# File 'lib/google/apis/health_v4/classes.rb', line 2459 def avg_stride_length_millimeters @avg_stride_length_millimeters end |
#avg_vertical_oscillation_millimeters ⇒ Fixnum
Optional. Distance off the ground your center of mass moves with each stride
while running
Corresponds to the JSON property avgVerticalOscillationMillimeters
2465 2466 2467 |
# File 'lib/google/apis/health_v4/classes.rb', line 2465 def avg_vertical_oscillation_millimeters @avg_vertical_oscillation_millimeters end |
#avg_vertical_ratio ⇒ Float
Optional. Vertical oscillation/stride length between [5.0, 11.0].
Corresponds to the JSON property avgVerticalRatio
2470 2471 2472 |
# File 'lib/google/apis/health_v4/classes.rb', line 2470 def avg_vertical_ratio @avg_vertical_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2477 2478 2479 2480 2481 2482 2483 |
# File 'lib/google/apis/health_v4/classes.rb', line 2477 def update!(**args) @avg_cadence_steps_per_minute = args[:avg_cadence_steps_per_minute] if args.key?(:avg_cadence_steps_per_minute) @avg_ground_contact_time_duration = args[:avg_ground_contact_time_duration] if args.key?(:avg_ground_contact_time_duration) @avg_stride_length_millimeters = args[:avg_stride_length_millimeters] if args.key?(:avg_stride_length_millimeters) @avg_vertical_oscillation_millimeters = args[:avg_vertical_oscillation_millimeters] if args.key?(:avg_vertical_oscillation_millimeters) @avg_vertical_ratio = args[:avg_vertical_ratio] if args.key?(:avg_vertical_ratio) end |