Class: Google::Apis::HealthV4::MobilityMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Mobility workouts specific metrics

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobilityMetrics

Returns a new instance of MobilityMetrics.



2418
2419
2420
# File 'lib/google/apis/health_v4/classes.rb', line 2418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avg_cadence_steps_per_minuteFloat

Optional. Cadence is a measure of the frequency of your foot strikes. Steps / min in real time during workout. Corresponds to the JSON property avgCadenceStepsPerMinute

Returns:

  • (Float)


2393
2394
2395
# File 'lib/google/apis/health_v4/classes.rb', line 2393

def avg_cadence_steps_per_minute
  @avg_cadence_steps_per_minute
end

#avg_ground_contact_time_durationString

Optional. The ground contact time for a particular stride is the amount of time for which the foot was in contact with the ground on that stride Corresponds to the JSON property avgGroundContactTimeDuration

Returns:

  • (String)


2399
2400
2401
# File 'lib/google/apis/health_v4/classes.rb', line 2399

def avg_ground_contact_time_duration
  @avg_ground_contact_time_duration
end

#avg_stride_length_millimetersFixnum

Optional. Stride length is a measure of the distance covered by a single stride Corresponds to the JSON property avgStrideLengthMillimeters

Returns:

  • (Fixnum)


2405
2406
2407
# File 'lib/google/apis/health_v4/classes.rb', line 2405

def avg_stride_length_millimeters
  @avg_stride_length_millimeters
end

#avg_vertical_oscillation_millimetersFixnum

Optional. Distance off the ground your center of mass moves with each stride while running Corresponds to the JSON property avgVerticalOscillationMillimeters

Returns:

  • (Fixnum)


2411
2412
2413
# File 'lib/google/apis/health_v4/classes.rb', line 2411

def avg_vertical_oscillation_millimeters
  @avg_vertical_oscillation_millimeters
end

#avg_vertical_ratioFloat

Optional. Vertical oscillation/stride length between [5.0, 11.0]. Corresponds to the JSON property avgVerticalRatio

Returns:

  • (Float)


2416
2417
2418
# File 'lib/google/apis/health_v4/classes.rb', line 2416

def avg_vertical_ratio
  @avg_vertical_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2423
2424
2425
2426
2427
2428
2429
# File 'lib/google/apis/health_v4/classes.rb', line 2423

def update!(**args)
  @avg_cadence_steps_per_minute = args[:avg_cadence_steps_per_minute] if args.key?(:avg_cadence_steps_per_minute)
  @avg_ground_contact_time_duration = args[:avg_ground_contact_time_duration] if args.key?(:avg_ground_contact_time_duration)
  @avg_stride_length_millimeters = args[:avg_stride_length_millimeters] if args.key?(:avg_stride_length_millimeters)
  @avg_vertical_oscillation_millimeters = args[:avg_vertical_oscillation_millimeters] if args.key?(:avg_vertical_oscillation_millimeters)
  @avg_vertical_ratio = args[:avg_vertical_ratio] if args.key?(:avg_vertical_ratio)
end