Class: Google::Apis::HealthV4::ObservationSampleTime
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ObservationSampleTime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents a sample time of an observed data point.
Instance Attribute Summary collapse
-
#civil_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#physical_time ⇒ String
Required.
-
#utc_offset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObservationSampleTime
constructor
A new instance of ObservationSampleTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObservationSampleTime
Returns a new instance of ObservationSampleTime.
3711 3712 3713 |
# File 'lib/google/apis/health_v4/classes.rb', line 3711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#civil_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilTime
3698 3699 3700 |
# File 'lib/google/apis/health_v4/classes.rb', line 3698 def civil_time @civil_time end |
#physical_time ⇒ String
Required. The time of the observation.
Corresponds to the JSON property physicalTime
3703 3704 3705 |
# File 'lib/google/apis/health_v4/classes.rb', line 3703 def physical_time @physical_time end |
#utc_offset ⇒ String
Required. The offset of the user's local time during the observation relative
to the Coordinated Universal Time (UTC).
Corresponds to the JSON property utcOffset
3709 3710 3711 |
# File 'lib/google/apis/health_v4/classes.rb', line 3709 def utc_offset @utc_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3716 3717 3718 3719 3720 |
# File 'lib/google/apis/health_v4/classes.rb', line 3716 def update!(**args) @civil_time = args[:civil_time] if args.key?(:civil_time) @physical_time = args[:physical_time] if args.key?(:physical_time) @utc_offset = args[:utc_offset] if args.key?(:utc_offset) end |