Class: Google::Apis::HealthV4::ObservationTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a time interval of an observed data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObservationTimeInterval

Returns a new instance of ObservationTimeInterval.



2566
2567
2568
# File 'lib/google/apis/health_v4/classes.rb', line 2566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



2535
2536
2537
# File 'lib/google/apis/health_v4/classes.rb', line 2535

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



2542
2543
2544
# File 'lib/google/apis/health_v4/classes.rb', line 2542

def civil_start_time
  @civil_start_time
end

#end_timeString

Required. Observed interval end time. Corresponds to the JSON property endTime

Returns:

  • (String)


2547
2548
2549
# File 'lib/google/apis/health_v4/classes.rb', line 2547

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the observation relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


2553
2554
2555
# File 'lib/google/apis/health_v4/classes.rb', line 2553

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. Observed interval start time. Corresponds to the JSON property startTime

Returns:

  • (String)


2558
2559
2560
# File 'lib/google/apis/health_v4/classes.rb', line 2558

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the observation relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


2564
2565
2566
# File 'lib/google/apis/health_v4/classes.rb', line 2564

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/google/apis/health_v4/classes.rb', line 2571

def update!(**args)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end