Class: Google::Apis::HealthV4::ObservationTimeInterval
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ObservationTimeInterval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents a time interval of an observed data point.
Instance Attribute Summary collapse
-
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#end_time ⇒ String
Required.
-
#end_utc_offset ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#start_utc_offset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObservationTimeInterval
constructor
A new instance of ObservationTimeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObservationTimeInterval
Returns a new instance of ObservationTimeInterval.
2560 2561 2562 |
# File 'lib/google/apis/health_v4/classes.rb', line 2560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilEndTime
2529 2530 2531 |
# File 'lib/google/apis/health_v4/classes.rb', line 2529 def civil_end_time @civil_end_time end |
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilStartTime
2536 2537 2538 |
# File 'lib/google/apis/health_v4/classes.rb', line 2536 def civil_start_time @civil_start_time end |
#end_time ⇒ String
Required. Observed interval end time.
Corresponds to the JSON property endTime
2541 2542 2543 |
# File 'lib/google/apis/health_v4/classes.rb', line 2541 def end_time @end_time end |
#end_utc_offset ⇒ String
Required. The offset of the user's local time at the end of the observation
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property endUtcOffset
2547 2548 2549 |
# File 'lib/google/apis/health_v4/classes.rb', line 2547 def end_utc_offset @end_utc_offset end |
#start_time ⇒ String
Required. Observed interval start time.
Corresponds to the JSON property startTime
2552 2553 2554 |
# File 'lib/google/apis/health_v4/classes.rb', line 2552 def start_time @start_time end |
#start_utc_offset ⇒ String
Required. The offset of the user's local time at the start of the observation
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property startUtcOffset
2558 2559 2560 |
# File 'lib/google/apis/health_v4/classes.rb', line 2558 def start_utc_offset @start_utc_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2565 2566 2567 2568 2569 2570 2571 2572 |
# File 'lib/google/apis/health_v4/classes.rb', line 2565 def update!(**args) @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time) @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time) @end_time = args[:end_time] if args.key?(:end_time) @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset) @start_time = args[:start_time] if args.key?(:start_time) @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset) end |