Class: Google::Apis::HealthV4::ObservationTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a time interval of an observed data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObservationTimeInterval

Returns a new instance of ObservationTimeInterval.



2506
2507
2508
# File 'lib/google/apis/health_v4/classes.rb', line 2506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



2475
2476
2477
# File 'lib/google/apis/health_v4/classes.rb', line 2475

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



2482
2483
2484
# File 'lib/google/apis/health_v4/classes.rb', line 2482

def civil_start_time
  @civil_start_time
end

#end_timeString

Required. Observed interval end time. Corresponds to the JSON property endTime

Returns:

  • (String)


2487
2488
2489
# File 'lib/google/apis/health_v4/classes.rb', line 2487

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the observation relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


2493
2494
2495
# File 'lib/google/apis/health_v4/classes.rb', line 2493

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. Observed interval start time. Corresponds to the JSON property startTime

Returns:

  • (String)


2498
2499
2500
# File 'lib/google/apis/health_v4/classes.rb', line 2498

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the observation relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


2504
2505
2506
# File 'lib/google/apis/health_v4/classes.rb', line 2504

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2511
2512
2513
2514
2515
2516
2517
2518
# File 'lib/google/apis/health_v4/classes.rb', line 2511

def update!(**args)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end