Class: Google::Apis::HealthV4::OutOfBedSegment
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::OutOfBedSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
A time interval to represent an out-of-bed segment.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Required.
-
#end_utc_offset ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#start_utc_offset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OutOfBedSegment
constructor
A new instance of OutOfBedSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OutOfBedSegment
Returns a new instance of OutOfBedSegment.
3866 3867 3868 |
# File 'lib/google/apis/health_v4/classes.rb', line 3866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Required. Segment end time.
Corresponds to the JSON property endTime
3847 3848 3849 |
# File 'lib/google/apis/health_v4/classes.rb', line 3847 def end_time @end_time end |
#end_utc_offset ⇒ String
Required. The offset of the user's local time at the end of the segment
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property endUtcOffset
3853 3854 3855 |
# File 'lib/google/apis/health_v4/classes.rb', line 3853 def end_utc_offset @end_utc_offset end |
#start_time ⇒ String
Required. Segment tart time.
Corresponds to the JSON property startTime
3858 3859 3860 |
# File 'lib/google/apis/health_v4/classes.rb', line 3858 def start_time @start_time end |
#start_utc_offset ⇒ String
Required. The offset of the user's local time at the start of the segment
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property startUtcOffset
3864 3865 3866 |
# File 'lib/google/apis/health_v4/classes.rb', line 3864 def start_utc_offset @start_utc_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3871 3872 3873 3874 3875 3876 |
# File 'lib/google/apis/health_v4/classes.rb', line 3871 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset) @start_time = args[:start_time] if args.key?(:start_time) @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset) end |