Class: Google::Apis::HealthV4::OutOfBedSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

A time interval to represent an out-of-bed segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OutOfBedSegment

Returns a new instance of OutOfBedSegment.



3783
3784
3785
# File 'lib/google/apis/health_v4/classes.rb', line 3783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Required. Segment end time. Corresponds to the JSON property endTime

Returns:

  • (String)


3764
3765
3766
# File 'lib/google/apis/health_v4/classes.rb', line 3764

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the segment relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


3770
3771
3772
# File 'lib/google/apis/health_v4/classes.rb', line 3770

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. Segment tart time. Corresponds to the JSON property startTime

Returns:

  • (String)


3775
3776
3777
# File 'lib/google/apis/health_v4/classes.rb', line 3775

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the segment relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


3781
3782
3783
# File 'lib/google/apis/health_v4/classes.rb', line 3781

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3788
3789
3790
3791
3792
3793
# File 'lib/google/apis/health_v4/classes.rb', line 3788

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end