Class: Google::Apis::HealthV4::OutOfBedSegment
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::OutOfBedSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
A time interval to represent an out-of-bed segment.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Required.
-
#end_utc_offset ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#start_utc_offset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OutOfBedSegment
constructor
A new instance of OutOfBedSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OutOfBedSegment
Returns a new instance of OutOfBedSegment.
2669 2670 2671 |
# File 'lib/google/apis/health_v4/classes.rb', line 2669 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Required. Segment end time.
Corresponds to the JSON property endTime
2650 2651 2652 |
# File 'lib/google/apis/health_v4/classes.rb', line 2650 def end_time @end_time end |
#end_utc_offset ⇒ String
Required. The offset of the user's local time at the end of the segment
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property endUtcOffset
2656 2657 2658 |
# File 'lib/google/apis/health_v4/classes.rb', line 2656 def end_utc_offset @end_utc_offset end |
#start_time ⇒ String
Required. Segment tart time.
Corresponds to the JSON property startTime
2661 2662 2663 |
# File 'lib/google/apis/health_v4/classes.rb', line 2661 def start_time @start_time end |
#start_utc_offset ⇒ String
Required. The offset of the user's local time at the start of the segment
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property startUtcOffset
2667 2668 2669 |
# File 'lib/google/apis/health_v4/classes.rb', line 2667 def start_utc_offset @start_utc_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2674 2675 2676 2677 2678 2679 |
# File 'lib/google/apis/health_v4/classes.rb', line 2674 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset) @start_time = args[:start_time] if args.key?(:start_time) @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset) end |