Class: Google::Apis::HealthV4::OutOfBedSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

A time interval to represent an out-of-bed segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OutOfBedSegment

Returns a new instance of OutOfBedSegment.



2663
2664
2665
# File 'lib/google/apis/health_v4/classes.rb', line 2663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Required. Segment end time. Corresponds to the JSON property endTime

Returns:

  • (String)


2644
2645
2646
# File 'lib/google/apis/health_v4/classes.rb', line 2644

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the segment relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


2650
2651
2652
# File 'lib/google/apis/health_v4/classes.rb', line 2650

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. Segment tart time. Corresponds to the JSON property startTime

Returns:

  • (String)


2655
2656
2657
# File 'lib/google/apis/health_v4/classes.rb', line 2655

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the segment relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


2661
2662
2663
# File 'lib/google/apis/health_v4/classes.rb', line 2661

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2668
2669
2670
2671
2672
2673
# File 'lib/google/apis/health_v4/classes.rb', line 2668

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end