Class: Google::Apis::HealthV4::OxygenSaturation
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::OxygenSaturation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Captures the user's instantaneous oxygen saturation percentage (SpO2).
Instance Attribute Summary collapse
-
#percentage ⇒ Float
Required.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OxygenSaturation
constructor
A new instance of OxygenSaturation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OxygenSaturation
Returns a new instance of OxygenSaturation.
2636 2637 2638 |
# File 'lib/google/apis/health_v4/classes.rb', line 2636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percentage ⇒ Float
Required. The oxygen saturation percentage. Valid values are from 0 to 100.
Corresponds to the JSON property percentage
2629 2630 2631 |
# File 'lib/google/apis/health_v4/classes.rb', line 2629 def percentage @percentage end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
2634 2635 2636 |
# File 'lib/google/apis/health_v4/classes.rb', line 2634 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2641 2642 2643 2644 |
# File 'lib/google/apis/health_v4/classes.rb', line 2641 def update!(**args) @percentage = args[:percentage] if args.key?(:percentage) @sample_time = args[:sample_time] if args.key?(:sample_time) end |