Class: Google::Apis::HealthV4::PairedDevice
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::PairedDevice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
User's Paired 1P Device The PairedDevice details include information about the device type, battery status, battery level, last sync time, device version, mac address, and features.
Instance Attribute Summary collapse
-
#battery_level ⇒ Fixnum
Output only.
-
#battery_status ⇒ String
Output only.
-
#device_type ⇒ String
Output only.
-
#device_version ⇒ String
Output only.
-
#features ⇒ Array<String>
Output only.
-
#last_sync_time ⇒ String
Output only.
-
#mac_address ⇒ String
Output only.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PairedDevice
constructor
A new instance of PairedDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PairedDevice
Returns a new instance of PairedDevice.
4118 4119 4120 |
# File 'lib/google/apis/health_v4/classes.rb', line 4118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#battery_level ⇒ Fixnum
Output only. The battery level of the device.
Corresponds to the JSON property batteryLevel
4030 4031 4032 |
# File 'lib/google/apis/health_v4/classes.rb', line 4030 def battery_level @battery_level end |
#battery_status ⇒ String
Output only. The battery status of the device. Supported: High | Medium | Low |
Empty
Corresponds to the JSON property batteryStatus
4036 4037 4038 |
# File 'lib/google/apis/health_v4/classes.rb', line 4036 def battery_status @battery_status end |
#device_type ⇒ String
Output only. The device type. Supported: TRACKER | SCALE
Corresponds to the JSON property deviceType
4041 4042 4043 |
# File 'lib/google/apis/health_v4/classes.rb', line 4041 def device_type @device_type end |
#device_version ⇒ String
Output only. The product name of the device
Corresponds to the JSON property deviceVersion
4046 4047 4048 |
# File 'lib/google/apis/health_v4/classes.rb', line 4046 def device_version @device_version end |
#features ⇒ Array<String>
Output only. Lists of unique features supported by the device. Comprehensive
list of supported features: Fitness Tracking - ACTIVE_MINUTES: Legacy
active minutes. - AUTOSTRIDE: Automatic stride length calculation. -
BIKE_ONBOARDING: Cycling UI support. - CALORIES: Daily burned calories. -
DISTANCE: Daily distance tracking. - ELEVATION: Floors climbed. -
INACTIVITY_ALERTS: Reminders to move. - SEDENTARY_TIME: Tracks inactive
time. - STEPS: Daily steps. - SWIM: Swim tracking (laps/strokes). -
AUTORUN: Automatic run detection. - ACTIVE_ZONE_MINUTES: Active Zone
Minutes (AZM). Heart Rate & Health - HEART_RATE: Continuous heart rate (
PPG). - BAT_SIGNAL: High/Low Heart Rate Alerts. Advanced Sensors - SPO2
: Blood oxygen saturation. - NIGHTTIME_OXYGEN_SATURATION: Sleep SpO2. -
ESTIMATED_OXYGEN_VARIATION: Estimated Oxygen Variation. - EDA:
Electrodermal Activity (stress). - SKIN_TEMPERATURE: Skin temperature
variation. - INTERNAL_DEVICE_TEMPERATURE: Internal device temperature. **
Sleep & Wellness** - SLEEP: Basic sleep tracking. - SMART_SLEEP: Advanced
sleep tracking (stages/score). - BEDTIME_REMINDER: Bedtime reminders. -
SOUNDSCAPE: Snore and noise detection. Advanced Workouts - WB: Custom
Workout Builder. - AUTOCUES: Auto Cues / Auto Lap. - DWR_RUN: Daily Run
Recommendations. - ADVANCED_RUNNING: Advanced Running Dynamics (e.g., GCT,
VO). GPS & Location - GPS: Built-in GPS. - CONNECTED_GPS: Connected
GPS (uses phone). - LOCATION_HINT: Location helper. Payments & NFC -
PAYMENTS: NFC payments (Fitbit Pay/Google Wallet). - FELICA: FeliCa support
(Japan payments/transit). Activity Detection - GROK: SmartTrack
automatic activity detection. - RETRO_AR: Retroactive Activity Recognition
prompts. Smart Features & UI - ALARMS: Silent alarms. -
BLE_MUSIC_CONTROL: BLE music control. - MUSIC: Direct music storage/control.
YOUTUBE_MUSIC_SUPPORTED: YouTube Music support. -GALLERY: App Gallery.TUTORIAL_SUPPORTED: On-screen tutorials. -SMILEY_EMOTE: Legacy Zip face.MOBILE_TO_DEVICE_DEEPLINK: Mobile to device settings deep link. -HIDE_GALLERY: Option to hide Gallery. -HIDE_GOAL_SELECTION: Option to hide goal selection. -DIGITAL_WARRANTY_SUPPORTED: Digital warranty display. -DIRECT_DEVICE_SETTINGS_SUPPORTED: Direct device settings management. Gym HR Broadcasting -ASPEN_SUPPORTED: Broadcast HR to gym equipment. -ASPEN_REMOTE_UI_SUPPORTED: Remote UI for HR sharing. Privacy & Security -FINITE_IMPROBABILITY: BLE Resolvable Private Address (RPA) privacy. -DOMAIN_KEY_SYNC: Domain key synchronization. BLE Protocol -BONDING: Secure BLE bonding. -ADVERTISES_SERIAL: Advertises serial number. -STATUS_CHARACTERISTIC: BLE Status Characteristic. -TRACKER_CHANNEL_CHARACTERISTIC: BLE Tracker Channel Characteristic. -PING_CHARACTERISTIC: BLE Ping Characteristic. Cellular & Wi-Fi -MOBILE_DATA: LTE cellular support. -SINGLE_AP_WIFI: Single AP Wi-Fi. -MULTI_AP_WIFI: Multi AP Wi-Fi. -WIFI_FWUP: Firmware updates over Wi-Fi. ** Data Sync & Transfer** -APP_SYNC: Background app sync. -LIVE_DATA: Real- time data streaming. -EVENT_BASED_SYNC_SUPPORTED: Event-based sync. -TIME_SERVICE: Time synchronization service. -REMOTE_FILE_PROVIDER: Remote file transfer. -DIRECT_COMMS_ALARMS: Direct communication for alarms. -DIRECT_COMMS_EXERCISE: Direct communication for exercise. -DIRECT_COMMS_BATTERY_ALERTS: Direct communication for battery alerts. ** Google Integrations** -PARROT_TREE_SUPPORTED: Find My Device support. Corresponds to the JSON propertyfeatures
4099 4100 4101 |
# File 'lib/google/apis/health_v4/classes.rb', line 4099 def features @features end |
#last_sync_time ⇒ String
Output only. The time of last sync with the Fitbit mobile application.
Corresponds to the JSON property lastSyncTime
4104 4105 4106 |
# File 'lib/google/apis/health_v4/classes.rb', line 4104 def last_sync_time @last_sync_time end |
#mac_address ⇒ String
Output only. Mac ID number of the device.
Corresponds to the JSON property macAddress
4109 4110 4111 |
# File 'lib/google/apis/health_v4/classes.rb', line 4109 def mac_address @mac_address end |
#name ⇒ String
Identifier. The resource name of this Device resource. Format: users/user/
pairedDevices/paired_device`Example:users/1234567890/pairedDevices/123
orusers/me/pairedDevices/123
Corresponds to the JSON propertyname`
4116 4117 4118 |
# File 'lib/google/apis/health_v4/classes.rb', line 4116 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 |
# File 'lib/google/apis/health_v4/classes.rb', line 4123 def update!(**args) @battery_level = args[:battery_level] if args.key?(:battery_level) @battery_status = args[:battery_status] if args.key?(:battery_status) @device_type = args[:device_type] if args.key?(:device_type) @device_version = args[:device_version] if args.key?(:device_version) @features = args[:features] if args.key?(:features) @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time) @mac_address = args[:mac_address] if args.key?(:mac_address) @name = args[:name] if args.key?(:name) end |