Class: Google::Apis::HealthV4::Profile
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Profile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Profile details.
Instance Attribute Summary collapse
-
#age ⇒ Fixnum
Optional.
-
#auto_running_stride_length_mm ⇒ Fixnum
Output only.
-
#auto_walking_stride_length_mm ⇒ Fixnum
Output only.
-
#membership_start_date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday.
-
#name ⇒ String
Identifier.
-
#user_configured_running_stride_length_mm ⇒ Fixnum
Optional.
-
#user_configured_walking_stride_length_mm ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Profile
constructor
A new instance of Profile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Profile
Returns a new instance of Profile.
4000 4001 4002 |
# File 'lib/google/apis/health_v4/classes.rb', line 4000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age ⇒ Fixnum
Optional. The age in years based on the user's birth date. Updates to this
field are currently not supported.
Corresponds to the JSON property age
3943 3944 3945 |
# File 'lib/google/apis/health_v4/classes.rb', line 3943 def age @age end |
#auto_running_stride_length_mm ⇒ Fixnum
Output only. The automatically calculated running stride length, in
millimeters. The user must consent to one of the following access scopes to
access this field: - https://www.googleapis.com/auth/googlehealth.
activity_and_fitness.readonly - https://www.googleapis.com/auth/googlehealth.
activity_and_fitness
Corresponds to the JSON property autoRunningStrideLengthMm
3952 3953 3954 |
# File 'lib/google/apis/health_v4/classes.rb', line 3952 def auto_running_stride_length_mm @auto_running_stride_length_mm end |
#auto_walking_stride_length_mm ⇒ Fixnum
Output only. The automatically calculated walking stride length, in
millimeters. The user must consent to one of the following access scopes to
access this field: - https://www.googleapis.com/auth/googlehealth.
activity_and_fitness.readonly - https://www.googleapis.com/auth/googlehealth.
activity_and_fitness
Corresponds to the JSON property autoWalkingStrideLengthMm
3961 3962 3963 |
# File 'lib/google/apis/health_v4/classes.rb', line 3961 def auto_walking_stride_length_mm @auto_walking_stride_length_mm end |
#membership_start_date ⇒ Google::Apis::HealthV4::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property membershipStartDate
3973 3974 3975 |
# File 'lib/google/apis/health_v4/classes.rb', line 3973 def membership_start_date @membership_start_date end |
#name ⇒ String
Identifier. The resource name of this Profile resource. Format: users/user/
profile Example: users/1234567890/profile or users/me/profile The user
ID is a system-generated Google Health API user ID, a string of 1-63
characters consisting of lowercase and uppercase letters, numbers, and hyphens.
The literal me can also be used to refer to the authenticated user.
Corresponds to the JSON property name
3982 3983 3984 |
# File 'lib/google/apis/health_v4/classes.rb', line 3982 def name @name end |
#user_configured_running_stride_length_mm ⇒ Fixnum
Optional. The user's user configured running stride length, in millimeters.
The user must consent to one of the following access scopes to access this
field: - https://www.googleapis.com/auth/googlehealth.activity_and_fitness.
readonly - https://www.googleapis.com/auth/googlehealth.activity_and_fitness
Corresponds to the JSON property userConfiguredRunningStrideLengthMm
3990 3991 3992 |
# File 'lib/google/apis/health_v4/classes.rb', line 3990 def user_configured_running_stride_length_mm @user_configured_running_stride_length_mm end |
#user_configured_walking_stride_length_mm ⇒ Fixnum
Optional. The user's user configured walking stride length, in millimeters.
The user must consent to one of the following access scopes to access this
field: - https://www.googleapis.com/auth/googlehealth.activity_and_fitness.
readonly - https://www.googleapis.com/auth/googlehealth.activity_and_fitness
Corresponds to the JSON property userConfiguredWalkingStrideLengthMm
3998 3999 4000 |
# File 'lib/google/apis/health_v4/classes.rb', line 3998 def user_configured_walking_stride_length_mm @user_configured_walking_stride_length_mm end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4005 4006 4007 4008 4009 4010 4011 4012 4013 |
# File 'lib/google/apis/health_v4/classes.rb', line 4005 def update!(**args) @age = args[:age] if args.key?(:age) @auto_running_stride_length_mm = args[:auto_running_stride_length_mm] if args.key?(:auto_running_stride_length_mm) @auto_walking_stride_length_mm = args[:auto_walking_stride_length_mm] if args.key?(:auto_walking_stride_length_mm) @membership_start_date = args[:membership_start_date] if args.key?(:membership_start_date) @name = args[:name] if args.key?(:name) @user_configured_running_stride_length_mm = args[:user_configured_running_stride_length_mm] if args.key?(:user_configured_running_stride_length_mm) @user_configured_walking_stride_length_mm = args[:user_configured_walking_stride_length_mm] if args.key?(:user_configured_walking_stride_length_mm) end |