Class: Google::Apis::HealthV4::ReconcileDataPointsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Response containing the list of reconciled DataPoints.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReconcileDataPointsResponse

Returns a new instance of ReconcileDataPointsResponse.



2796
2797
2798
# File 'lib/google/apis/health_v4/classes.rb', line 2796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_pointsArray<Google::Apis::HealthV4::ReconciledDataPoint>

Data points matching the query Corresponds to the JSON property dataPoints



2789
2790
2791
# File 'lib/google/apis/health_v4/classes.rb', line 2789

def data_points
  @data_points
end

#next_page_tokenString

Next page token, empty if the response is complete Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2794
2795
2796
# File 'lib/google/apis/health_v4/classes.rb', line 2794

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2801
2802
2803
2804
# File 'lib/google/apis/health_v4/classes.rb', line 2801

def update!(**args)
  @data_points = args[:data_points] if args.key?(:data_points)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end