Class: Google::Apis::HealthV4::ReconcileDataPointsResponse
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ReconcileDataPointsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Response containing the list of reconciled DataPoints.
Instance Attribute Summary collapse
-
#data_points ⇒ Array<Google::Apis::HealthV4::ReconciledDataPoint>
Data points matching the query Corresponds to the JSON property
dataPoints. -
#next_page_token ⇒ String
Next page token, empty if the response is complete Corresponds to the JSON property
nextPageToken.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReconcileDataPointsResponse
constructor
A new instance of ReconcileDataPointsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReconcileDataPointsResponse
Returns a new instance of ReconcileDataPointsResponse.
2742 2743 2744 |
# File 'lib/google/apis/health_v4/classes.rb', line 2742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_points ⇒ Array<Google::Apis::HealthV4::ReconciledDataPoint>
Data points matching the query
Corresponds to the JSON property dataPoints
2735 2736 2737 |
# File 'lib/google/apis/health_v4/classes.rb', line 2735 def data_points @data_points end |
#next_page_token ⇒ String
Next page token, empty if the response is complete
Corresponds to the JSON property nextPageToken
2740 2741 2742 |
# File 'lib/google/apis/health_v4/classes.rb', line 2740 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2747 2748 2749 2750 |
# File 'lib/google/apis/health_v4/classes.rb', line 2747 def update!(**args) @data_points = args[:data_points] if args.key?(:data_points) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |