Class: Google::Apis::HealthV4::ReconciledDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ReconciledDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
A reconciled computed or recorded metric.
Instance Attribute Summary collapse
-
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurned
Energy burned as part of an activity, excluding the basal energy burn.
-
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutes
Record of active minutes in a given time interval.
-
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutes
Record of active zone minutes in a given time interval.
-
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevel
Internal type to capture activity level during a certain time interval.
-
#altitude ⇒ Google::Apis::HealthV4::Altitude
Captures the altitude gain (i.e. deltas), and not level above sea, for a user in millimeters.
-
#basal_energy_burned ⇒ Google::Apis::HealthV4::BasalEnergyBurned
Number of calories burned due to basal metabolic rate (BMR) over a period of time.
-
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucose
Represents a blood glucose level measurement.
-
#body_fat ⇒ Google::Apis::HealthV4::BodyFat
Body fat measurement.
-
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperature
Core body temperature measurement, distinct from peripheral body temperature, reflects the temperature of the body's internal organs.
-
#daily_heart_rate_variability ⇒ Google::Apis::HealthV4::DailyHeartRateVariability
Represents the daily heart rate variability data type.
-
#daily_heart_rate_zones ⇒ Google::Apis::HealthV4::DailyHeartRateZones
User's heart rate zone thresholds based on the Karvonen algorithm for a specific day.
-
#daily_oxygen_saturation ⇒ Google::Apis::HealthV4::DailyOxygenSaturation
A daily oxygen saturation (SpO2) record.
-
#daily_respiratory_rate ⇒ Google::Apis::HealthV4::DailyRespiratoryRate
A daily average respiratory rate (breaths per minute) for a day of the year.
-
#daily_resting_heart_rate ⇒ Google::Apis::HealthV4::DailyRestingHeartRate
Measures the daily resting heart rate for a user, calculated using the all day heart rate measurements.
-
#daily_sleep_temperature_derivations ⇒ Google::Apis::HealthV4::DailySleepTemperatureDerivations
Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep.
-
#daily_vo2_max ⇒ Google::Apis::HealthV4::DailyVo2Max
Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise.
-
#data_point_name ⇒ String
Identifier.
-
#distance ⇒ Google::Apis::HealthV4::Distance
Distance traveled over an interval of time.
-
#exercise ⇒ Google::Apis::HealthV4::Exercise
An exercise that stores information about a physical activity.
-
#floors ⇒ Google::Apis::HealthV4::Floors
Gained elevation measured in floors over the time interval Corresponds to the JSON property
floors. -
#heart_rate ⇒ Google::Apis::HealthV4::HeartRate
A heart rate measurement.
-
#heart_rate_variability ⇒ Google::Apis::HealthV4::HeartRateVariability
Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).
-
#height ⇒ Google::Apis::HealthV4::Height
Body height measurement.
-
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLog
Holds information about a user logged hydration.
-
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLog
Holds information about food logged by a user.
-
#oxygen_saturation ⇒ Google::Apis::HealthV4::OxygenSaturation
Captures the user's instantaneous oxygen saturation percentage (SpO2).
-
#respiratory_rate_sleep_summary ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummary
Records respiratory rate details during sleep.
-
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2Max
VO2 max value calculated based on the user's running activity.
-
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriod
SedentaryPeriod SedentaryPeriod data represents the periods of time that the user was sedentary (i.e. not moving while wearing the device).
-
#sleep ⇒ Google::Apis::HealthV4::Sleep
A sleep session possibly including stages.
-
#steps ⇒ Google::Apis::HealthV4::Steps
Step count over the time interval.
-
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsData
Swim lengths data over the time interval.
-
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZone
Time in heart rate zone record.
-
#vo2_max ⇒ Google::Apis::HealthV4::Vo2Max
VO2 max measurement.
-
#weight ⇒ Google::Apis::HealthV4::Weight
Body weight measurement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReconciledDataPoint
constructor
A new instance of ReconciledDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReconciledDataPoint
Returns a new instance of ReconciledDataPoint.
4456 4457 4458 |
# File 'lib/google/apis/health_v4/classes.rb', line 4456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurned
Energy burned as part of an activity, excluding the basal energy burn.
Corresponds to the JSON property activeEnergyBurned
4248 4249 4250 |
# File 'lib/google/apis/health_v4/classes.rb', line 4248 def active_energy_burned @active_energy_burned end |
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutes
Record of active minutes in a given time interval.
Corresponds to the JSON property activeMinutes
4253 4254 4255 |
# File 'lib/google/apis/health_v4/classes.rb', line 4253 def active_minutes @active_minutes end |
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutes
Record of active zone minutes in a given time interval.
Corresponds to the JSON property activeZoneMinutes
4258 4259 4260 |
# File 'lib/google/apis/health_v4/classes.rb', line 4258 def active_zone_minutes @active_zone_minutes end |
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevel
Internal type to capture activity level during a certain time interval.
Corresponds to the JSON property activityLevel
4263 4264 4265 |
# File 'lib/google/apis/health_v4/classes.rb', line 4263 def activity_level @activity_level end |
#altitude ⇒ Google::Apis::HealthV4::Altitude
Captures the altitude gain (i.e. deltas), and not level above sea, for a user
in millimeters.
Corresponds to the JSON property altitude
4269 4270 4271 |
# File 'lib/google/apis/health_v4/classes.rb', line 4269 def altitude @altitude end |
#basal_energy_burned ⇒ Google::Apis::HealthV4::BasalEnergyBurned
Number of calories burned due to basal metabolic rate (BMR) over a period of
time.
Corresponds to the JSON property basalEnergyBurned
4275 4276 4277 |
# File 'lib/google/apis/health_v4/classes.rb', line 4275 def basal_energy_burned @basal_energy_burned end |
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucose
Represents a blood glucose level measurement. LINT: LEGACY_NAMES
Corresponds to the JSON property bloodGlucose
4280 4281 4282 |
# File 'lib/google/apis/health_v4/classes.rb', line 4280 def blood_glucose @blood_glucose end |
#body_fat ⇒ Google::Apis::HealthV4::BodyFat
Body fat measurement.
Corresponds to the JSON property bodyFat
4285 4286 4287 |
# File 'lib/google/apis/health_v4/classes.rb', line 4285 def body_fat @body_fat end |
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperature
Core body temperature measurement, distinct from peripheral body temperature,
reflects the temperature of the body's internal organs.
Corresponds to the JSON property coreBodyTemperature
4291 4292 4293 |
# File 'lib/google/apis/health_v4/classes.rb', line 4291 def core_body_temperature @core_body_temperature end |
#daily_heart_rate_variability ⇒ Google::Apis::HealthV4::DailyHeartRateVariability
Represents the daily heart rate variability data type. At least one of the
following fields must be set: - average_heart_rate_variability_milliseconds -
non_rem_heart_rate_beats_per_minute - entropy -
deep_sleep_root_mean_square_of_successive_differences_milliseconds
Corresponds to the JSON property dailyHeartRateVariability
4299 4300 4301 |
# File 'lib/google/apis/health_v4/classes.rb', line 4299 def daily_heart_rate_variability @daily_heart_rate_variability end |
#daily_heart_rate_zones ⇒ Google::Apis::HealthV4::DailyHeartRateZones
User's heart rate zone thresholds based on the Karvonen algorithm for a
specific day.
Corresponds to the JSON property dailyHeartRateZones
4305 4306 4307 |
# File 'lib/google/apis/health_v4/classes.rb', line 4305 def daily_heart_rate_zones @daily_heart_rate_zones end |
#daily_oxygen_saturation ⇒ Google::Apis::HealthV4::DailyOxygenSaturation
A daily oxygen saturation (SpO2) record. Represents the user's daily oxygen
saturation summary, typically calculated during sleep.
Corresponds to the JSON property dailyOxygenSaturation
4311 4312 4313 |
# File 'lib/google/apis/health_v4/classes.rb', line 4311 def daily_oxygen_saturation @daily_oxygen_saturation end |
#daily_respiratory_rate ⇒ Google::Apis::HealthV4::DailyRespiratoryRate
A daily average respiratory rate (breaths per minute) for a day of the year.
One data point per day calculated for the main sleep.
Corresponds to the JSON property dailyRespiratoryRate
4317 4318 4319 |
# File 'lib/google/apis/health_v4/classes.rb', line 4317 def daily_respiratory_rate @daily_respiratory_rate end |
#daily_resting_heart_rate ⇒ Google::Apis::HealthV4::DailyRestingHeartRate
Measures the daily resting heart rate for a user, calculated using the all day
heart rate measurements.
Corresponds to the JSON property dailyRestingHeartRate
4323 4324 4325 |
# File 'lib/google/apis/health_v4/classes.rb', line 4323 def daily_resting_heart_rate @daily_resting_heart_rate end |
#daily_sleep_temperature_derivations ⇒ Google::Apis::HealthV4::DailySleepTemperatureDerivations
Provides derived sleep temperature values, calculated from skin or internal
device temperature readings during sleep.
Corresponds to the JSON property dailySleepTemperatureDerivations
4329 4330 4331 |
# File 'lib/google/apis/health_v4/classes.rb', line 4329 def daily_sleep_temperature_derivations @daily_sleep_temperature_derivations end |
#daily_vo2_max ⇒ Google::Apis::HealthV4::DailyVo2Max
Contains a daily summary of the user's VO2 max (cardio fitness score), which
is the maximum rate of oxygen the body can use during exercise.
Corresponds to the JSON property dailyVo2Max
4335 4336 4337 |
# File 'lib/google/apis/health_v4/classes.rb', line 4335 def daily_vo2_max @daily_vo2_max end |
#data_point_name ⇒ String
Identifier. Data point name, only supported for the subset of identifiable
data types. For the majority of the data types, individual data points do not
need to be identified and this field would be empty. Format: users/user/
dataTypes/data_type/dataPoints/data_pointExample: `users/abcd1234/
dataTypes/sleep/dataPoints/a1b2c3d4-e5f6-7890-1234-567890abcdef` Theuser
ID is a system-generated identifier, as described in Identity.health_user_id.
Thedata_typeID corresponds to the kebab-case version of the field names
in the DataPoint data union field, e.g. `heart-rate` for the `heart_rate`
field. Thedata_point`ID can be client-provided or system-generated. If
client-provided, it must be a string of 4-63 characters, containing only
lowercase letters, numbers, and hyphens.
Corresponds to the JSON propertydataPointName`
4350 4351 4352 |
# File 'lib/google/apis/health_v4/classes.rb', line 4350 def data_point_name @data_point_name end |
#distance ⇒ Google::Apis::HealthV4::Distance
Distance traveled over an interval of time.
Corresponds to the JSON property distance
4355 4356 4357 |
# File 'lib/google/apis/health_v4/classes.rb', line 4355 def distance @distance end |
#exercise ⇒ Google::Apis::HealthV4::Exercise
An exercise that stores information about a physical activity.
Corresponds to the JSON property exercise
4360 4361 4362 |
# File 'lib/google/apis/health_v4/classes.rb', line 4360 def exercise @exercise end |
#floors ⇒ Google::Apis::HealthV4::Floors
Gained elevation measured in floors over the time interval
Corresponds to the JSON property floors
4365 4366 4367 |
# File 'lib/google/apis/health_v4/classes.rb', line 4365 def floors @floors end |
#heart_rate ⇒ Google::Apis::HealthV4::HeartRate
A heart rate measurement.
Corresponds to the JSON property heartRate
4370 4371 4372 |
# File 'lib/google/apis/health_v4/classes.rb', line 4370 def heart_rate @heart_rate end |
#heart_rate_variability ⇒ Google::Apis::HealthV4::HeartRateVariability
Captures user's heart rate variability (HRV) as measured by the root mean
square of successive differences (RMSSD) between normal heartbeats or by
standard deviation of the inter-beat intervals (SDNN).
Corresponds to the JSON property heartRateVariability
4377 4378 4379 |
# File 'lib/google/apis/health_v4/classes.rb', line 4377 def heart_rate_variability @heart_rate_variability end |
#height ⇒ Google::Apis::HealthV4::Height
Body height measurement.
Corresponds to the JSON property height
4382 4383 4384 |
# File 'lib/google/apis/health_v4/classes.rb', line 4382 def height @height end |
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLog
Holds information about a user logged hydration.
Corresponds to the JSON property hydrationLog
4387 4388 4389 |
# File 'lib/google/apis/health_v4/classes.rb', line 4387 def hydration_log @hydration_log end |
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLog
Holds information about food logged by a user. There are two ways of creating
a nutrition log based on the food type: 1. Identified food: Using the food
field, which is a reference to a Food resource. In this case fields nutrients
, energy, energy_from_fat, total_carbohydrate, total_fat,
food_display_name will be populated based on the referenced food. 2.
Anonymous food: Using the food_display_name field and setting the nutrients
, energy, energy_from_fat, total_carbohydrate, total_fat fields
manually. The identified food is preferred over the anonymous food. Nutrition
logs created from anonymous food are not editable.
Corresponds to the JSON property nutritionLog
4400 4401 4402 |
# File 'lib/google/apis/health_v4/classes.rb', line 4400 def nutrition_log @nutrition_log end |
#oxygen_saturation ⇒ Google::Apis::HealthV4::OxygenSaturation
Captures the user's instantaneous oxygen saturation percentage (SpO2).
Corresponds to the JSON property oxygenSaturation
4405 4406 4407 |
# File 'lib/google/apis/health_v4/classes.rb', line 4405 def oxygen_saturation @oxygen_saturation end |
#respiratory_rate_sleep_summary ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummary
Records respiratory rate details during sleep. Can have multiple per day if
the user sleeps multiple times.
Corresponds to the JSON property respiratoryRateSleepSummary
4411 4412 4413 |
# File 'lib/google/apis/health_v4/classes.rb', line 4411 def respiratory_rate_sleep_summary @respiratory_rate_sleep_summary end |
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2Max
VO2 max value calculated based on the user's running activity. Value stored in
ml/kg/min.
Corresponds to the JSON property runVo2Max
4417 4418 4419 |
# File 'lib/google/apis/health_v4/classes.rb', line 4417 def run_vo2_max @run_vo2_max end |
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriod
SedentaryPeriod SedentaryPeriod data represents the periods of time that the
user was sedentary (i.e. not moving while wearing the device).
Corresponds to the JSON property sedentaryPeriod
4423 4424 4425 |
# File 'lib/google/apis/health_v4/classes.rb', line 4423 def sedentary_period @sedentary_period end |
#sleep ⇒ Google::Apis::HealthV4::Sleep
A sleep session possibly including stages.
Corresponds to the JSON property sleep
4428 4429 4430 |
# File 'lib/google/apis/health_v4/classes.rb', line 4428 def sleep @sleep end |
#steps ⇒ Google::Apis::HealthV4::Steps
Step count over the time interval.
Corresponds to the JSON property steps
4433 4434 4435 |
# File 'lib/google/apis/health_v4/classes.rb', line 4433 def steps @steps end |
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsData
Swim lengths data over the time interval.
Corresponds to the JSON property swimLengthsData
4438 4439 4440 |
# File 'lib/google/apis/health_v4/classes.rb', line 4438 def swim_lengths_data @swim_lengths_data end |
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZone
Time in heart rate zone record. It's an interval spent in specific heart rate
zone.
Corresponds to the JSON property timeInHeartRateZone
4444 4445 4446 |
# File 'lib/google/apis/health_v4/classes.rb', line 4444 def time_in_heart_rate_zone @time_in_heart_rate_zone end |
#vo2_max ⇒ Google::Apis::HealthV4::Vo2Max
VO2 max measurement.
Corresponds to the JSON property vo2Max
4449 4450 4451 |
# File 'lib/google/apis/health_v4/classes.rb', line 4449 def vo2_max @vo2_max end |
#weight ⇒ Google::Apis::HealthV4::Weight
Body weight measurement.
Corresponds to the JSON property weight
4454 4455 4456 |
# File 'lib/google/apis/health_v4/classes.rb', line 4454 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/google/apis/health_v4/classes.rb', line 4461 def update!(**args) @active_energy_burned = args[:active_energy_burned] if args.key?(:active_energy_burned) @active_minutes = args[:active_minutes] if args.key?(:active_minutes) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @activity_level = args[:activity_level] if args.key?(:activity_level) @altitude = args[:altitude] if args.key?(:altitude) @basal_energy_burned = args[:basal_energy_burned] if args.key?(:basal_energy_burned) @blood_glucose = args[:blood_glucose] if args.key?(:blood_glucose) @body_fat = args[:body_fat] if args.key?(:body_fat) @core_body_temperature = args[:core_body_temperature] if args.key?(:core_body_temperature) @daily_heart_rate_variability = args[:daily_heart_rate_variability] if args.key?(:daily_heart_rate_variability) @daily_heart_rate_zones = args[:daily_heart_rate_zones] if args.key?(:daily_heart_rate_zones) @daily_oxygen_saturation = args[:daily_oxygen_saturation] if args.key?(:daily_oxygen_saturation) @daily_respiratory_rate = args[:daily_respiratory_rate] if args.key?(:daily_respiratory_rate) @daily_resting_heart_rate = args[:daily_resting_heart_rate] if args.key?(:daily_resting_heart_rate) @daily_sleep_temperature_derivations = args[:daily_sleep_temperature_derivations] if args.key?(:daily_sleep_temperature_derivations) @daily_vo2_max = args[:daily_vo2_max] if args.key?(:daily_vo2_max) @data_point_name = args[:data_point_name] if args.key?(:data_point_name) @distance = args[:distance] if args.key?(:distance) @exercise = args[:exercise] if args.key?(:exercise) @floors = args[:floors] if args.key?(:floors) @heart_rate = args[:heart_rate] if args.key?(:heart_rate) @heart_rate_variability = args[:heart_rate_variability] if args.key?(:heart_rate_variability) @height = args[:height] if args.key?(:height) @hydration_log = args[:hydration_log] if args.key?(:hydration_log) @nutrition_log = args[:nutrition_log] if args.key?(:nutrition_log) @oxygen_saturation = args[:oxygen_saturation] if args.key?(:oxygen_saturation) @respiratory_rate_sleep_summary = args[:respiratory_rate_sleep_summary] if args.key?(:respiratory_rate_sleep_summary) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period) @sleep = args[:sleep] if args.key?(:sleep) @steps = args[:steps] if args.key?(:steps) @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data) @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone) @vo2_max = args[:vo2_max] if args.key?(:vo2_max) @weight = args[:weight] if args.key?(:weight) end |