Class: Google::Apis::HealthV4::ReconciledDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::ReconciledDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
A reconciled computed or recorded metric.
Instance Attribute Summary collapse
-
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurned
Energy burned as part of an activity, excluding the basal energy burn.
-
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutes
Record of active minutes in a given time interval.
-
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutes
Record of active zone minutes in a given time interval.
-
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevel
Internal type to capture activity level during a certain time interval.
-
#altitude ⇒ Google::Apis::HealthV4::Altitude
Captures the altitude gain (i.e. deltas), and not level above sea, for a user in millimeters.
-
#basal_energy_burned ⇒ Google::Apis::HealthV4::BasalEnergyBurned
Number of calories burned due to basal metabolic rate (BMR) over a period of time.
-
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucose
Represents a blood glucose level measurement.
-
#body_fat ⇒ Google::Apis::HealthV4::BodyFat
Body fat measurement.
-
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperature
Core body temperature measurement, distinct from peripheral body temperature, reflects the temperature of the body's internal organs.
-
#daily_heart_rate_variability ⇒ Google::Apis::HealthV4::DailyHeartRateVariability
Represents the daily heart rate variability data type.
-
#daily_heart_rate_zones ⇒ Google::Apis::HealthV4::DailyHeartRateZones
User's heart rate zone thresholds based on the Karvonen algorithm for a specific day.
-
#daily_oxygen_saturation ⇒ Google::Apis::HealthV4::DailyOxygenSaturation
A daily oxygen saturation (SpO2) record.
-
#daily_respiratory_rate ⇒ Google::Apis::HealthV4::DailyRespiratoryRate
A daily average respiratory rate (breaths per minute) for a day of the year.
-
#daily_resting_heart_rate ⇒ Google::Apis::HealthV4::DailyRestingHeartRate
Measures the daily resting heart rate for a user, calculated using the all day heart rate measurements.
-
#daily_sleep_temperature_derivations ⇒ Google::Apis::HealthV4::DailySleepTemperatureDerivations
Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep.
-
#daily_vo2_max ⇒ Google::Apis::HealthV4::DailyVo2Max
Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise.
-
#data_point_name ⇒ String
Identifier.
-
#distance ⇒ Google::Apis::HealthV4::Distance
Distance traveled over an interval of time.
-
#exercise ⇒ Google::Apis::HealthV4::Exercise
An exercise that stores information about a physical activity.
-
#floors ⇒ Google::Apis::HealthV4::Floors
Gained elevation measured in floors over the time interval Corresponds to the JSON property
floors. -
#heart_rate ⇒ Google::Apis::HealthV4::HeartRate
A heart rate measurement.
-
#heart_rate_variability ⇒ Google::Apis::HealthV4::HeartRateVariability
Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).
-
#height ⇒ Google::Apis::HealthV4::Height
Body height measurement.
-
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLog
Holds information about a user logged hydration.
-
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLog
Holds information about a user logged food.
-
#oxygen_saturation ⇒ Google::Apis::HealthV4::OxygenSaturation
Captures the user's instantaneous oxygen saturation percentage (SpO2).
-
#respiratory_rate_sleep_summary ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummary
Records respiratory rate details during sleep.
-
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2Max
VO2 max value calculated based on the user's running activity.
-
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriod
SedentaryPeriod SedentaryPeriod data represents the periods of time that the user was sedentary (i.e. not moving while wearing the device).
-
#sleep ⇒ Google::Apis::HealthV4::Sleep
A sleep session possibly including stages.
-
#steps ⇒ Google::Apis::HealthV4::Steps
Step count over the time interval.
-
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsData
Swim lengths data over the time interval.
-
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZone
Time in heart rate zone record.
-
#vo2_max ⇒ Google::Apis::HealthV4::Vo2Max
VO2 max measurement.
-
#weight ⇒ Google::Apis::HealthV4::Weight
Body weight measurement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReconciledDataPoint
constructor
A new instance of ReconciledDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReconciledDataPoint
Returns a new instance of ReconciledDataPoint.
4256 4257 4258 |
# File 'lib/google/apis/health_v4/classes.rb', line 4256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurned
Energy burned as part of an activity, excluding the basal energy burn.
Corresponds to the JSON property activeEnergyBurned
4048 4049 4050 |
# File 'lib/google/apis/health_v4/classes.rb', line 4048 def active_energy_burned @active_energy_burned end |
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutes
Record of active minutes in a given time interval.
Corresponds to the JSON property activeMinutes
4053 4054 4055 |
# File 'lib/google/apis/health_v4/classes.rb', line 4053 def active_minutes @active_minutes end |
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutes
Record of active zone minutes in a given time interval.
Corresponds to the JSON property activeZoneMinutes
4058 4059 4060 |
# File 'lib/google/apis/health_v4/classes.rb', line 4058 def active_zone_minutes @active_zone_minutes end |
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevel
Internal type to capture activity level during a certain time interval.
Corresponds to the JSON property activityLevel
4063 4064 4065 |
# File 'lib/google/apis/health_v4/classes.rb', line 4063 def activity_level @activity_level end |
#altitude ⇒ Google::Apis::HealthV4::Altitude
Captures the altitude gain (i.e. deltas), and not level above sea, for a user
in millimeters.
Corresponds to the JSON property altitude
4069 4070 4071 |
# File 'lib/google/apis/health_v4/classes.rb', line 4069 def altitude @altitude end |
#basal_energy_burned ⇒ Google::Apis::HealthV4::BasalEnergyBurned
Number of calories burned due to basal metabolic rate (BMR) over a period of
time.
Corresponds to the JSON property basalEnergyBurned
4075 4076 4077 |
# File 'lib/google/apis/health_v4/classes.rb', line 4075 def basal_energy_burned @basal_energy_burned end |
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucose
Represents a blood glucose level measurement. LINT: LEGACY_NAMES
Corresponds to the JSON property bloodGlucose
4080 4081 4082 |
# File 'lib/google/apis/health_v4/classes.rb', line 4080 def blood_glucose @blood_glucose end |
#body_fat ⇒ Google::Apis::HealthV4::BodyFat
Body fat measurement.
Corresponds to the JSON property bodyFat
4085 4086 4087 |
# File 'lib/google/apis/health_v4/classes.rb', line 4085 def body_fat @body_fat end |
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperature
Core body temperature measurement, distinct from peripheral body temperature,
reflects the temperature of the body's internal organs.
Corresponds to the JSON property coreBodyTemperature
4091 4092 4093 |
# File 'lib/google/apis/health_v4/classes.rb', line 4091 def core_body_temperature @core_body_temperature end |
#daily_heart_rate_variability ⇒ Google::Apis::HealthV4::DailyHeartRateVariability
Represents the daily heart rate variability data type. At least one of the
following fields must be set: - average_heart_rate_variability_milliseconds -
non_rem_heart_rate_beats_per_minute - entropy -
deep_sleep_root_mean_square_of_successive_differences_milliseconds
Corresponds to the JSON property dailyHeartRateVariability
4099 4100 4101 |
# File 'lib/google/apis/health_v4/classes.rb', line 4099 def daily_heart_rate_variability @daily_heart_rate_variability end |
#daily_heart_rate_zones ⇒ Google::Apis::HealthV4::DailyHeartRateZones
User's heart rate zone thresholds based on the Karvonen algorithm for a
specific day.
Corresponds to the JSON property dailyHeartRateZones
4105 4106 4107 |
# File 'lib/google/apis/health_v4/classes.rb', line 4105 def daily_heart_rate_zones @daily_heart_rate_zones end |
#daily_oxygen_saturation ⇒ Google::Apis::HealthV4::DailyOxygenSaturation
A daily oxygen saturation (SpO2) record. Represents the user's daily oxygen
saturation summary, typically calculated during sleep.
Corresponds to the JSON property dailyOxygenSaturation
4111 4112 4113 |
# File 'lib/google/apis/health_v4/classes.rb', line 4111 def daily_oxygen_saturation @daily_oxygen_saturation end |
#daily_respiratory_rate ⇒ Google::Apis::HealthV4::DailyRespiratoryRate
A daily average respiratory rate (breaths per minute) for a day of the year.
One data point per day calculated for the main sleep.
Corresponds to the JSON property dailyRespiratoryRate
4117 4118 4119 |
# File 'lib/google/apis/health_v4/classes.rb', line 4117 def daily_respiratory_rate @daily_respiratory_rate end |
#daily_resting_heart_rate ⇒ Google::Apis::HealthV4::DailyRestingHeartRate
Measures the daily resting heart rate for a user, calculated using the all day
heart rate measurements.
Corresponds to the JSON property dailyRestingHeartRate
4123 4124 4125 |
# File 'lib/google/apis/health_v4/classes.rb', line 4123 def daily_resting_heart_rate @daily_resting_heart_rate end |
#daily_sleep_temperature_derivations ⇒ Google::Apis::HealthV4::DailySleepTemperatureDerivations
Provides derived sleep temperature values, calculated from skin or internal
device temperature readings during sleep.
Corresponds to the JSON property dailySleepTemperatureDerivations
4129 4130 4131 |
# File 'lib/google/apis/health_v4/classes.rb', line 4129 def daily_sleep_temperature_derivations @daily_sleep_temperature_derivations end |
#daily_vo2_max ⇒ Google::Apis::HealthV4::DailyVo2Max
Contains a daily summary of the user's VO2 max (cardio fitness score), which
is the maximum rate of oxygen the body can use during exercise.
Corresponds to the JSON property dailyVo2Max
4135 4136 4137 |
# File 'lib/google/apis/health_v4/classes.rb', line 4135 def daily_vo2_max @daily_vo2_max end |
#data_point_name ⇒ String
Identifier. Data point name, only supported for the subset of identifiable
data types. For the majority of the data types, individual data points do not
need to be identified and this field would be empty. Format: users/user/
dataTypes/data_type/dataPoints/data_pointExample: `users/abcd1234/
dataTypes/sleep/dataPoints/a1b2c3d4-e5f6-7890-1234-567890abcdef` Theuser
ID is a system-generated identifier, as described in Identity.health_user_id.
Thedata_typeID corresponds to the kebab-case version of the field names
in the DataPoint data union field, e.g. `total-calories` for the `
total_calories` field. Thedata_point`ID can be client-provided or system-
generated. If client-provided, it must be a string of 4-63 characters,
containing only lowercase letters, numbers, and hyphens.
Corresponds to the JSON propertydataPointName`
4150 4151 4152 |
# File 'lib/google/apis/health_v4/classes.rb', line 4150 def data_point_name @data_point_name end |
#distance ⇒ Google::Apis::HealthV4::Distance
Distance traveled over an interval of time.
Corresponds to the JSON property distance
4155 4156 4157 |
# File 'lib/google/apis/health_v4/classes.rb', line 4155 def distance @distance end |
#exercise ⇒ Google::Apis::HealthV4::Exercise
An exercise that stores information about a physical activity.
Corresponds to the JSON property exercise
4160 4161 4162 |
# File 'lib/google/apis/health_v4/classes.rb', line 4160 def exercise @exercise end |
#floors ⇒ Google::Apis::HealthV4::Floors
Gained elevation measured in floors over the time interval
Corresponds to the JSON property floors
4165 4166 4167 |
# File 'lib/google/apis/health_v4/classes.rb', line 4165 def floors @floors end |
#heart_rate ⇒ Google::Apis::HealthV4::HeartRate
A heart rate measurement.
Corresponds to the JSON property heartRate
4170 4171 4172 |
# File 'lib/google/apis/health_v4/classes.rb', line 4170 def heart_rate @heart_rate end |
#heart_rate_variability ⇒ Google::Apis::HealthV4::HeartRateVariability
Captures user's heart rate variability (HRV) as measured by the root mean
square of successive differences (RMSSD) between normal heartbeats or by
standard deviation of the inter-beat intervals (SDNN).
Corresponds to the JSON property heartRateVariability
4177 4178 4179 |
# File 'lib/google/apis/health_v4/classes.rb', line 4177 def heart_rate_variability @heart_rate_variability end |
#height ⇒ Google::Apis::HealthV4::Height
Body height measurement.
Corresponds to the JSON property height
4182 4183 4184 |
# File 'lib/google/apis/health_v4/classes.rb', line 4182 def height @height end |
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLog
Holds information about a user logged hydration.
Corresponds to the JSON property hydrationLog
4187 4188 4189 |
# File 'lib/google/apis/health_v4/classes.rb', line 4187 def hydration_log @hydration_log end |
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLog
Holds information about a user logged food. There are two ways of creating a
nutrition log based on the food type: 1. Identified food: Using the food field,
which is a reference to a Food resource. In this case fields nutrients,
energy, energy_from_fat, total_carbohydrate, total_fat,
food_display_name will be populated based on the referenced food. 2.
Anonymous food: Using the food_display_name field and setting the nutrients
, energy, energy_from_fat, total_carbohydrate, total_fat fields
manually. The identified food is preferred over the anonymous food. Nutrition
logs created from anonymous food are not be editable.
Corresponds to the JSON property nutritionLog
4200 4201 4202 |
# File 'lib/google/apis/health_v4/classes.rb', line 4200 def nutrition_log @nutrition_log end |
#oxygen_saturation ⇒ Google::Apis::HealthV4::OxygenSaturation
Captures the user's instantaneous oxygen saturation percentage (SpO2).
Corresponds to the JSON property oxygenSaturation
4205 4206 4207 |
# File 'lib/google/apis/health_v4/classes.rb', line 4205 def oxygen_saturation @oxygen_saturation end |
#respiratory_rate_sleep_summary ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummary
Records respiratory rate details during sleep. Can have multiple per day if
the user sleeps multiple times.
Corresponds to the JSON property respiratoryRateSleepSummary
4211 4212 4213 |
# File 'lib/google/apis/health_v4/classes.rb', line 4211 def respiratory_rate_sleep_summary @respiratory_rate_sleep_summary end |
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2Max
VO2 max value calculated based on the user's running activity. Value stored in
ml/kg/min.
Corresponds to the JSON property runVo2Max
4217 4218 4219 |
# File 'lib/google/apis/health_v4/classes.rb', line 4217 def run_vo2_max @run_vo2_max end |
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriod
SedentaryPeriod SedentaryPeriod data represents the periods of time that the
user was sedentary (i.e. not moving while wearing the device).
Corresponds to the JSON property sedentaryPeriod
4223 4224 4225 |
# File 'lib/google/apis/health_v4/classes.rb', line 4223 def sedentary_period @sedentary_period end |
#sleep ⇒ Google::Apis::HealthV4::Sleep
A sleep session possibly including stages.
Corresponds to the JSON property sleep
4228 4229 4230 |
# File 'lib/google/apis/health_v4/classes.rb', line 4228 def sleep @sleep end |
#steps ⇒ Google::Apis::HealthV4::Steps
Step count over the time interval.
Corresponds to the JSON property steps
4233 4234 4235 |
# File 'lib/google/apis/health_v4/classes.rb', line 4233 def steps @steps end |
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsData
Swim lengths data over the time interval.
Corresponds to the JSON property swimLengthsData
4238 4239 4240 |
# File 'lib/google/apis/health_v4/classes.rb', line 4238 def swim_lengths_data @swim_lengths_data end |
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZone
Time in heart rate zone record. It's an interval spent in specific heart rate
zone.
Corresponds to the JSON property timeInHeartRateZone
4244 4245 4246 |
# File 'lib/google/apis/health_v4/classes.rb', line 4244 def time_in_heart_rate_zone @time_in_heart_rate_zone end |
#vo2_max ⇒ Google::Apis::HealthV4::Vo2Max
VO2 max measurement.
Corresponds to the JSON property vo2Max
4249 4250 4251 |
# File 'lib/google/apis/health_v4/classes.rb', line 4249 def vo2_max @vo2_max end |
#weight ⇒ Google::Apis::HealthV4::Weight
Body weight measurement.
Corresponds to the JSON property weight
4254 4255 4256 |
# File 'lib/google/apis/health_v4/classes.rb', line 4254 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 4297 |
# File 'lib/google/apis/health_v4/classes.rb', line 4261 def update!(**args) @active_energy_burned = args[:active_energy_burned] if args.key?(:active_energy_burned) @active_minutes = args[:active_minutes] if args.key?(:active_minutes) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @activity_level = args[:activity_level] if args.key?(:activity_level) @altitude = args[:altitude] if args.key?(:altitude) @basal_energy_burned = args[:basal_energy_burned] if args.key?(:basal_energy_burned) @blood_glucose = args[:blood_glucose] if args.key?(:blood_glucose) @body_fat = args[:body_fat] if args.key?(:body_fat) @core_body_temperature = args[:core_body_temperature] if args.key?(:core_body_temperature) @daily_heart_rate_variability = args[:daily_heart_rate_variability] if args.key?(:daily_heart_rate_variability) @daily_heart_rate_zones = args[:daily_heart_rate_zones] if args.key?(:daily_heart_rate_zones) @daily_oxygen_saturation = args[:daily_oxygen_saturation] if args.key?(:daily_oxygen_saturation) @daily_respiratory_rate = args[:daily_respiratory_rate] if args.key?(:daily_respiratory_rate) @daily_resting_heart_rate = args[:daily_resting_heart_rate] if args.key?(:daily_resting_heart_rate) @daily_sleep_temperature_derivations = args[:daily_sleep_temperature_derivations] if args.key?(:daily_sleep_temperature_derivations) @daily_vo2_max = args[:daily_vo2_max] if args.key?(:daily_vo2_max) @data_point_name = args[:data_point_name] if args.key?(:data_point_name) @distance = args[:distance] if args.key?(:distance) @exercise = args[:exercise] if args.key?(:exercise) @floors = args[:floors] if args.key?(:floors) @heart_rate = args[:heart_rate] if args.key?(:heart_rate) @heart_rate_variability = args[:heart_rate_variability] if args.key?(:heart_rate_variability) @height = args[:height] if args.key?(:height) @hydration_log = args[:hydration_log] if args.key?(:hydration_log) @nutrition_log = args[:nutrition_log] if args.key?(:nutrition_log) @oxygen_saturation = args[:oxygen_saturation] if args.key?(:oxygen_saturation) @respiratory_rate_sleep_summary = args[:respiratory_rate_sleep_summary] if args.key?(:respiratory_rate_sleep_summary) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period) @sleep = args[:sleep] if args.key?(:sleep) @steps = args[:steps] if args.key?(:steps) @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data) @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone) @vo2_max = args[:vo2_max] if args.key?(:vo2_max) @weight = args[:weight] if args.key?(:weight) end |