Class: Google::Apis::HealthV4::ReconciledDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

A reconciled computed or recorded metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReconciledDataPoint

Returns a new instance of ReconciledDataPoint.



2999
3000
3001
# File 'lib/google/apis/health_v4/classes.rb', line 2999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_minutesGoogle::Apis::HealthV4::ActiveMinutes

Record of active minutes in a given time interval. Corresponds to the JSON property activeMinutes



2820
2821
2822
# File 'lib/google/apis/health_v4/classes.rb', line 2820

def active_minutes
  @active_minutes
end

#active_zone_minutesGoogle::Apis::HealthV4::ActiveZoneMinutes

Record of active zone minutes in a given time interval. Corresponds to the JSON property activeZoneMinutes



2825
2826
2827
# File 'lib/google/apis/health_v4/classes.rb', line 2825

def active_zone_minutes
  @active_zone_minutes
end

#activity_levelGoogle::Apis::HealthV4::ActivityLevel

Internal type to capture activity level during a certain time interval. Corresponds to the JSON property activityLevel



2830
2831
2832
# File 'lib/google/apis/health_v4/classes.rb', line 2830

def activity_level
  @activity_level
end

#altitudeGoogle::Apis::HealthV4::Altitude

Captures the altitude gain (i.e. deltas), and not level above sea, for a user in millimeters. Corresponds to the JSON property altitude



2836
2837
2838
# File 'lib/google/apis/health_v4/classes.rb', line 2836

def altitude
  @altitude
end

#basal_energy_burnedGoogle::Apis::HealthV4::BasalEnergyBurned

Number of calories burned due to basal metabolic rate (BMR) over a period of time. Corresponds to the JSON property basalEnergyBurned



2842
2843
2844
# File 'lib/google/apis/health_v4/classes.rb', line 2842

def basal_energy_burned
  @basal_energy_burned
end

#body_fatGoogle::Apis::HealthV4::BodyFat

Body fat measurement. Corresponds to the JSON property bodyFat



2847
2848
2849
# File 'lib/google/apis/health_v4/classes.rb', line 2847

def body_fat
  @body_fat
end

#daily_heart_rate_variabilityGoogle::Apis::HealthV4::DailyHeartRateVariability

Represents the daily heart rate variability data type. At least one of the following fields must be set: - average_heart_rate_variability_milliseconds - non_rem_heart_rate_beats_per_minute - entropy - deep_sleep_root_mean_square_of_successive_differences_milliseconds Corresponds to the JSON property dailyHeartRateVariability



2855
2856
2857
# File 'lib/google/apis/health_v4/classes.rb', line 2855

def daily_heart_rate_variability
  @daily_heart_rate_variability
end

#daily_heart_rate_zonesGoogle::Apis::HealthV4::DailyHeartRateZones

User's heart rate zone thresholds based on the Karvonen algorithm for a specific day. Corresponds to the JSON property dailyHeartRateZones



2861
2862
2863
# File 'lib/google/apis/health_v4/classes.rb', line 2861

def daily_heart_rate_zones
  @daily_heart_rate_zones
end

#daily_oxygen_saturationGoogle::Apis::HealthV4::DailyOxygenSaturation

A daily oxygen saturation (SpO2) record. Represents the user's daily oxygen saturation summary, typically calculated during sleep. Corresponds to the JSON property dailyOxygenSaturation



2867
2868
2869
# File 'lib/google/apis/health_v4/classes.rb', line 2867

def daily_oxygen_saturation
  @daily_oxygen_saturation
end

#daily_respiratory_rateGoogle::Apis::HealthV4::DailyRespiratoryRate

A daily average respiratory rate (breaths per minute) for a day of the year. One data point per day calculated for the main sleep. Corresponds to the JSON property dailyRespiratoryRate



2873
2874
2875
# File 'lib/google/apis/health_v4/classes.rb', line 2873

def daily_respiratory_rate
  @daily_respiratory_rate
end

#daily_resting_heart_rateGoogle::Apis::HealthV4::DailyRestingHeartRate

Measures the daily resting heart rate for a user, calculated using the all day heart rate measurements. Corresponds to the JSON property dailyRestingHeartRate



2879
2880
2881
# File 'lib/google/apis/health_v4/classes.rb', line 2879

def daily_resting_heart_rate
  @daily_resting_heart_rate
end

#daily_sleep_temperature_derivationsGoogle::Apis::HealthV4::DailySleepTemperatureDerivations

Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep. Corresponds to the JSON property dailySleepTemperatureDerivations



2885
2886
2887
# File 'lib/google/apis/health_v4/classes.rb', line 2885

def daily_sleep_temperature_derivations
  @daily_sleep_temperature_derivations
end

#daily_vo2_maxGoogle::Apis::HealthV4::DailyVo2Max

Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise. Corresponds to the JSON property dailyVo2Max



2891
2892
2893
# File 'lib/google/apis/health_v4/classes.rb', line 2891

def daily_vo2_max
  @daily_vo2_max
end

#data_point_nameString

Identifier. Data point name, only supported for the subset of identifiable data types. For the majority of the data types, individual data points do not need to be identified and this field would be empty. Format: users/user/ dataTypes/data_type/dataPoints/data_pointExample: `users/abcd1234/ dataTypes/sleep/dataPoints/a1b2c3d4-e5f6-7890-1234-567890abcdef` Theuser ID is a system-generated identifier, as described in Identity.health_user_id. Thedata_typeID corresponds to the kebab-case version of the field names in the DataPoint data union field, e.g. `total-calories` for the ` total_calories` field. Thedata_point`ID can be client-provided or system- generated. If client-provided, it must be a string of 4-63 characters, containing only lowercase letters, numbers, and hyphens. Corresponds to the JSON propertydataPointName`

Returns:

  • (String)


2906
2907
2908
# File 'lib/google/apis/health_v4/classes.rb', line 2906

def data_point_name
  @data_point_name
end

#distanceGoogle::Apis::HealthV4::Distance

Distance traveled over an interval of time. Corresponds to the JSON property distance



2911
2912
2913
# File 'lib/google/apis/health_v4/classes.rb', line 2911

def distance
  @distance
end

#exerciseGoogle::Apis::HealthV4::Exercise

An exercise that stores information about a physical activity. Corresponds to the JSON property exercise



2916
2917
2918
# File 'lib/google/apis/health_v4/classes.rb', line 2916

def exercise
  @exercise
end

#floorsGoogle::Apis::HealthV4::Floors

Gained elevation measured in floors over the time interval Corresponds to the JSON property floors



2921
2922
2923
# File 'lib/google/apis/health_v4/classes.rb', line 2921

def floors
  @floors
end

#heart_rateGoogle::Apis::HealthV4::HeartRate

A heart rate measurement. Corresponds to the JSON property heartRate



2926
2927
2928
# File 'lib/google/apis/health_v4/classes.rb', line 2926

def heart_rate
  @heart_rate
end

#heart_rate_variabilityGoogle::Apis::HealthV4::HeartRateVariability

Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN). Corresponds to the JSON property heartRateVariability



2933
2934
2935
# File 'lib/google/apis/health_v4/classes.rb', line 2933

def heart_rate_variability
  @heart_rate_variability
end

#heightGoogle::Apis::HealthV4::Height

Body height measurement. Corresponds to the JSON property height



2938
2939
2940
# File 'lib/google/apis/health_v4/classes.rb', line 2938

def height
  @height
end

#hydration_logGoogle::Apis::HealthV4::HydrationLog

Holds information about a user logged hydration. Corresponds to the JSON property hydrationLog



2943
2944
2945
# File 'lib/google/apis/health_v4/classes.rb', line 2943

def hydration_log
  @hydration_log
end

#oxygen_saturationGoogle::Apis::HealthV4::OxygenSaturation

Captures the user's instantaneous oxygen saturation percentage (SpO2). Corresponds to the JSON property oxygenSaturation



2948
2949
2950
# File 'lib/google/apis/health_v4/classes.rb', line 2948

def oxygen_saturation
  @oxygen_saturation
end

#respiratory_rate_sleep_summaryGoogle::Apis::HealthV4::RespiratoryRateSleepSummary

Records respiratory rate details during sleep. Can have multiple per day if the user sleeps multiple times. Corresponds to the JSON property respiratoryRateSleepSummary



2954
2955
2956
# File 'lib/google/apis/health_v4/classes.rb', line 2954

def respiratory_rate_sleep_summary
  @respiratory_rate_sleep_summary
end

#run_vo2_maxGoogle::Apis::HealthV4::RunVo2Max

VO2 max value calculated based on the user's running activity. Value stored in ml/kg/min. Corresponds to the JSON property runVo2Max



2960
2961
2962
# File 'lib/google/apis/health_v4/classes.rb', line 2960

def run_vo2_max
  @run_vo2_max
end

#sedentary_periodGoogle::Apis::HealthV4::SedentaryPeriod

SedentaryPeriod SedentaryPeriod data represents the periods of time that the user was sedentary (i.e. not moving while wearing the device). Corresponds to the JSON property sedentaryPeriod



2966
2967
2968
# File 'lib/google/apis/health_v4/classes.rb', line 2966

def sedentary_period
  @sedentary_period
end

#sleepGoogle::Apis::HealthV4::Sleep

A sleep session possibly including stages. Corresponds to the JSON property sleep



2971
2972
2973
# File 'lib/google/apis/health_v4/classes.rb', line 2971

def sleep
  @sleep
end

#stepsGoogle::Apis::HealthV4::Steps

Step count over the time interval. Corresponds to the JSON property steps



2976
2977
2978
# File 'lib/google/apis/health_v4/classes.rb', line 2976

def steps
  @steps
end

#swim_lengths_dataGoogle::Apis::HealthV4::SwimLengthsData

Swim lengths data over the time interval. Corresponds to the JSON property swimLengthsData



2981
2982
2983
# File 'lib/google/apis/health_v4/classes.rb', line 2981

def swim_lengths_data
  @swim_lengths_data
end

#time_in_heart_rate_zoneGoogle::Apis::HealthV4::TimeInHeartRateZone

Time in heart rate zone record. It's an interval spent in specific heart rate zone. Corresponds to the JSON property timeInHeartRateZone



2987
2988
2989
# File 'lib/google/apis/health_v4/classes.rb', line 2987

def time_in_heart_rate_zone
  @time_in_heart_rate_zone
end

#vo2_maxGoogle::Apis::HealthV4::Vo2Max

VO2 max measurement. Corresponds to the JSON property vo2Max



2992
2993
2994
# File 'lib/google/apis/health_v4/classes.rb', line 2992

def vo2_max
  @vo2_max
end

#weightGoogle::Apis::HealthV4::Weight

Body weight measurement. Corresponds to the JSON property weight



2997
2998
2999
# File 'lib/google/apis/health_v4/classes.rb', line 2997

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
# File 'lib/google/apis/health_v4/classes.rb', line 3004

def update!(**args)
  @active_minutes = args[:active_minutes] if args.key?(:active_minutes)
  @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes)
  @activity_level = args[:activity_level] if args.key?(:activity_level)
  @altitude = args[:altitude] if args.key?(:altitude)
  @basal_energy_burned = args[:basal_energy_burned] if args.key?(:basal_energy_burned)
  @body_fat = args[:body_fat] if args.key?(:body_fat)
  @daily_heart_rate_variability = args[:daily_heart_rate_variability] if args.key?(:daily_heart_rate_variability)
  @daily_heart_rate_zones = args[:daily_heart_rate_zones] if args.key?(:daily_heart_rate_zones)
  @daily_oxygen_saturation = args[:daily_oxygen_saturation] if args.key?(:daily_oxygen_saturation)
  @daily_respiratory_rate = args[:daily_respiratory_rate] if args.key?(:daily_respiratory_rate)
  @daily_resting_heart_rate = args[:daily_resting_heart_rate] if args.key?(:daily_resting_heart_rate)
  @daily_sleep_temperature_derivations = args[:daily_sleep_temperature_derivations] if args.key?(:daily_sleep_temperature_derivations)
  @daily_vo2_max = args[:daily_vo2_max] if args.key?(:daily_vo2_max)
  @data_point_name = args[:data_point_name] if args.key?(:data_point_name)
  @distance = args[:distance] if args.key?(:distance)
  @exercise = args[:exercise] if args.key?(:exercise)
  @floors = args[:floors] if args.key?(:floors)
  @heart_rate = args[:heart_rate] if args.key?(:heart_rate)
  @heart_rate_variability = args[:heart_rate_variability] if args.key?(:heart_rate_variability)
  @height = args[:height] if args.key?(:height)
  @hydration_log = args[:hydration_log] if args.key?(:hydration_log)
  @oxygen_saturation = args[:oxygen_saturation] if args.key?(:oxygen_saturation)
  @respiratory_rate_sleep_summary = args[:respiratory_rate_sleep_summary] if args.key?(:respiratory_rate_sleep_summary)
  @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max)
  @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period)
  @sleep = args[:sleep] if args.key?(:sleep)
  @steps = args[:steps] if args.key?(:steps)
  @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data)
  @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone)
  @vo2_max = args[:vo2_max] if args.key?(:vo2_max)
  @weight = args[:weight] if args.key?(:weight)
end