Class: Google::Apis::HealthV4::RespiratoryRateSleepSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Records respiratory rate details during sleep. Can have multiple per day if the user sleeps multiple times.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RespiratoryRateSleepSummary

Returns a new instance of RespiratoryRateSleepSummary.



4413
4414
4415
# File 'lib/google/apis/health_v4/classes.rb', line 4413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deep_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property deepSleepStats



4391
4392
4393
# File 'lib/google/apis/health_v4/classes.rb', line 4391

def deep_sleep_stats
  @deep_sleep_stats
end

#full_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property fullSleepStats



4396
4397
4398
# File 'lib/google/apis/health_v4/classes.rb', line 4396

def full_sleep_stats
  @full_sleep_stats
end

#light_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property lightSleepStats



4401
4402
4403
# File 'lib/google/apis/health_v4/classes.rb', line 4401

def light_sleep_stats
  @light_sleep_stats
end

#rem_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property remSleepStats



4406
4407
4408
# File 'lib/google/apis/health_v4/classes.rb', line 4406

def rem_sleep_stats
  @rem_sleep_stats
end

#sample_timeGoogle::Apis::HealthV4::ObservationSampleTime

Represents a sample time of an observed data point. Corresponds to the JSON property sampleTime



4411
4412
4413
# File 'lib/google/apis/health_v4/classes.rb', line 4411

def sample_time
  @sample_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4418
4419
4420
4421
4422
4423
4424
# File 'lib/google/apis/health_v4/classes.rb', line 4418

def update!(**args)
  @deep_sleep_stats = args[:deep_sleep_stats] if args.key?(:deep_sleep_stats)
  @full_sleep_stats = args[:full_sleep_stats] if args.key?(:full_sleep_stats)
  @light_sleep_stats = args[:light_sleep_stats] if args.key?(:light_sleep_stats)
  @rem_sleep_stats = args[:rem_sleep_stats] if args.key?(:rem_sleep_stats)
  @sample_time = args[:sample_time] if args.key?(:sample_time)
end