Class: Google::Apis::HealthV4::RespiratoryRateSleepSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Records respiratory rate details during sleep. Can have multiple per day if the user sleeps multiple times.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RespiratoryRateSleepSummary

Returns a new instance of RespiratoryRateSleepSummary.



3069
3070
3071
# File 'lib/google/apis/health_v4/classes.rb', line 3069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deep_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property deepSleepStats



3047
3048
3049
# File 'lib/google/apis/health_v4/classes.rb', line 3047

def deep_sleep_stats
  @deep_sleep_stats
end

#full_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property fullSleepStats



3052
3053
3054
# File 'lib/google/apis/health_v4/classes.rb', line 3052

def full_sleep_stats
  @full_sleep_stats
end

#light_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property lightSleepStats



3057
3058
3059
# File 'lib/google/apis/health_v4/classes.rb', line 3057

def light_sleep_stats
  @light_sleep_stats
end

#rem_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property remSleepStats



3062
3063
3064
# File 'lib/google/apis/health_v4/classes.rb', line 3062

def rem_sleep_stats
  @rem_sleep_stats
end

#sample_timeGoogle::Apis::HealthV4::ObservationSampleTime

Represents a sample time of an observed data point. Corresponds to the JSON property sampleTime



3067
3068
3069
# File 'lib/google/apis/health_v4/classes.rb', line 3067

def sample_time
  @sample_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3074
3075
3076
3077
3078
3079
3080
# File 'lib/google/apis/health_v4/classes.rb', line 3074

def update!(**args)
  @deep_sleep_stats = args[:deep_sleep_stats] if args.key?(:deep_sleep_stats)
  @full_sleep_stats = args[:full_sleep_stats] if args.key?(:full_sleep_stats)
  @light_sleep_stats = args[:light_sleep_stats] if args.key?(:light_sleep_stats)
  @rem_sleep_stats = args[:rem_sleep_stats] if args.key?(:rem_sleep_stats)
  @sample_time = args[:sample_time] if args.key?(:sample_time)
end