Class: Google::Apis::HealthV4::RespiratoryRateSleepSummary
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::RespiratoryRateSleepSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Records respiratory rate details during sleep. Can have multiple per day if the user sleeps multiple times.
Instance Attribute Summary collapse
-
#deep_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
-
#full_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
-
#light_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
-
#rem_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RespiratoryRateSleepSummary
constructor
A new instance of RespiratoryRateSleepSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RespiratoryRateSleepSummary
Returns a new instance of RespiratoryRateSleepSummary.
3063 3064 3065 |
# File 'lib/google/apis/health_v4/classes.rb', line 3063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deep_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
Corresponds to the JSON property deepSleepStats
3041 3042 3043 |
# File 'lib/google/apis/health_v4/classes.rb', line 3041 def deep_sleep_stats @deep_sleep_stats end |
#full_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
Corresponds to the JSON property fullSleepStats
3046 3047 3048 |
# File 'lib/google/apis/health_v4/classes.rb', line 3046 def full_sleep_stats @full_sleep_stats end |
#light_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
Corresponds to the JSON property lightSleepStats
3051 3052 3053 |
# File 'lib/google/apis/health_v4/classes.rb', line 3051 def light_sleep_stats @light_sleep_stats end |
#rem_sleep_stats ⇒ Google::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics
Respiratory rate statistics for a given sleep stage.
Corresponds to the JSON property remSleepStats
3056 3057 3058 |
# File 'lib/google/apis/health_v4/classes.rb', line 3056 def rem_sleep_stats @rem_sleep_stats end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
3061 3062 3063 |
# File 'lib/google/apis/health_v4/classes.rb', line 3061 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3068 3069 3070 3071 3072 3073 3074 |
# File 'lib/google/apis/health_v4/classes.rb', line 3068 def update!(**args) @deep_sleep_stats = args[:deep_sleep_stats] if args.key?(:deep_sleep_stats) @full_sleep_stats = args[:full_sleep_stats] if args.key?(:full_sleep_stats) @light_sleep_stats = args[:light_sleep_stats] if args.key?(:light_sleep_stats) @rem_sleep_stats = args[:rem_sleep_stats] if args.key?(:rem_sleep_stats) @sample_time = args[:sample_time] if args.key?(:sample_time) end |