Class: Google::Apis::HealthV4::RespiratoryRateSleepSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Records respiratory rate details during sleep. Can have multiple per day if the user sleeps multiple times.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RespiratoryRateSleepSummary

Returns a new instance of RespiratoryRateSleepSummary.



3002
3003
3004
# File 'lib/google/apis/health_v4/classes.rb', line 3002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deep_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property deepSleepStats



2980
2981
2982
# File 'lib/google/apis/health_v4/classes.rb', line 2980

def deep_sleep_stats
  @deep_sleep_stats
end

#full_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property fullSleepStats



2985
2986
2987
# File 'lib/google/apis/health_v4/classes.rb', line 2985

def full_sleep_stats
  @full_sleep_stats
end

#light_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property lightSleepStats



2990
2991
2992
# File 'lib/google/apis/health_v4/classes.rb', line 2990

def light_sleep_stats
  @light_sleep_stats
end

#rem_sleep_statsGoogle::Apis::HealthV4::RespiratoryRateSleepSummaryStatistics

Respiratory rate statistics for a given sleep stage. Corresponds to the JSON property remSleepStats



2995
2996
2997
# File 'lib/google/apis/health_v4/classes.rb', line 2995

def rem_sleep_stats
  @rem_sleep_stats
end

#sample_timeGoogle::Apis::HealthV4::ObservationSampleTime

Represents a sample time of an observed data point. Corresponds to the JSON property sampleTime



3000
3001
3002
# File 'lib/google/apis/health_v4/classes.rb', line 3000

def sample_time
  @sample_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3007
3008
3009
3010
3011
3012
3013
# File 'lib/google/apis/health_v4/classes.rb', line 3007

def update!(**args)
  @deep_sleep_stats = args[:deep_sleep_stats] if args.key?(:deep_sleep_stats)
  @full_sleep_stats = args[:full_sleep_stats] if args.key?(:full_sleep_stats)
  @light_sleep_stats = args[:light_sleep_stats] if args.key?(:light_sleep_stats)
  @rem_sleep_stats = args[:rem_sleep_stats] if args.key?(:rem_sleep_stats)
  @sample_time = args[:sample_time] if args.key?(:sample_time)
end