Class: Google::Apis::HealthV4::RollUpDataPointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Request to roll up data points by physical time intervals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollUpDataPointsRequest

Returns a new instance of RollUpDataPointsRequest.



4525
4526
4527
# File 'lib/google/apis/health_v4/classes.rb', line 4525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_familyString

Optional. The data source family name to roll up. If empty, data points from all available data sources will be rolled up. Format: users/me/ dataSourceFamilies/data_source_family`The supported values are: -users/me/ dataSourceFamilies/all-sources- default value -users/me/dataSourceFamilies/ google-wearables- tracker devices -users/me/dataSourceFamilies/google- sources- Google first party sources Corresponds to the JSON propertydataSourceFamily`

Returns:

  • (String)


4495
4496
4497
# File 'lib/google/apis/health_v4/classes.rb', line 4495

def data_source_family
  @data_source_family
end

#page_sizeFixnum

Optional. The maximum number of data points to return. If unspecified, at most 1440 data points will be returned. The maximum page size is 10000; values above that will be truncated accordingly. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


4502
4503
4504
# File 'lib/google/apis/health_v4/classes.rb', line 4502

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token from a previous request, if any. All other request fields need to be the same as in the initial request when the page token is specified. Corresponds to the JSON property pageToken

Returns:

  • (String)


4509
4510
4511
# File 'lib/google/apis/health_v4/classes.rb', line 4509

def page_token
  @page_token
end

#rangeGoogle::Apis::HealthV4::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property range



4517
4518
4519
# File 'lib/google/apis/health_v4/classes.rb', line 4517

def range
  @range
end

#window_sizeString

Required. The size of the time window to group data points into before applying the aggregation functions. Must be at least 1 second. Corresponds to the JSON property windowSize

Returns:

  • (String)


4523
4524
4525
# File 'lib/google/apis/health_v4/classes.rb', line 4523

def window_size
  @window_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4530
4531
4532
4533
4534
4535
4536
# File 'lib/google/apis/health_v4/classes.rb', line 4530

def update!(**args)
  @data_source_family = args[:data_source_family] if args.key?(:data_source_family)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @range = args[:range] if args.key?(:range)
  @window_size = args[:window_size] if args.key?(:window_size)
end