Class: Google::Apis::HealthV4::RollUpDataPointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Request to roll up data points by physical time intervals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollUpDataPointsRequest

Returns a new instance of RollUpDataPointsRequest.



3181
3182
3183
# File 'lib/google/apis/health_v4/classes.rb', line 3181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_familyString

Optional. The data source family name to roll up. If empty, data points from all available data sources will be rolled up. Format: users/me/ dataSourceFamilies/data_source_family`The supported values are: -users/me/ dataSourceFamilies/all-sources- default value -users/me/dataSourceFamilies/ google-wearables- tracker devices -users/me/dataSourceFamilies/google- sources- Google first party sources Corresponds to the JSON propertydataSourceFamily`

Returns:

  • (String)


3151
3152
3153
# File 'lib/google/apis/health_v4/classes.rb', line 3151

def data_source_family
  @data_source_family
end

#page_sizeFixnum

Optional. The maximum number of data points to return. If unspecified, at most 1440 data points will be returned. The maximum page size is 10000; values above that will be truncated accordingly. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


3158
3159
3160
# File 'lib/google/apis/health_v4/classes.rb', line 3158

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token from a previous request, if any. All other request fields need to be the same as in the initial request when the page token is specified. Corresponds to the JSON property pageToken

Returns:

  • (String)


3165
3166
3167
# File 'lib/google/apis/health_v4/classes.rb', line 3165

def page_token
  @page_token
end

#rangeGoogle::Apis::HealthV4::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property range



3173
3174
3175
# File 'lib/google/apis/health_v4/classes.rb', line 3173

def range
  @range
end

#window_sizeString

Required. The size of the time window to group data points into before applying the aggregation functions. Corresponds to the JSON property windowSize

Returns:

  • (String)


3179
3180
3181
# File 'lib/google/apis/health_v4/classes.rb', line 3179

def window_size
  @window_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3186
3187
3188
3189
3190
3191
3192
# File 'lib/google/apis/health_v4/classes.rb', line 3186

def update!(**args)
  @data_source_family = args[:data_source_family] if args.key?(:data_source_family)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @range = args[:range] if args.key?(:range)
  @window_size = args[:window_size] if args.key?(:window_size)
end