Class: Google::Apis::HealthV4::RollUpDataPointsRequest
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::RollUpDataPointsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Request to roll up data points by physical time intervals.
Instance Attribute Summary collapse
-
#data_source_family ⇒ String
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#range ⇒ Google::Apis::HealthV4::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#window_size ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollUpDataPointsRequest
constructor
A new instance of RollUpDataPointsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollUpDataPointsRequest
Returns a new instance of RollUpDataPointsRequest.
3175 3176 3177 |
# File 'lib/google/apis/health_v4/classes.rb', line 3175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_source_family ⇒ String
Optional. The data source family name to roll up. If empty, data points from
all available data sources will be rolled up. Format: users/me/
dataSourceFamilies/data_source_family`The supported values are: -users/me/
dataSourceFamilies/all-sources- default value -users/me/dataSourceFamilies/
google-wearables- tracker devices -users/me/dataSourceFamilies/google-
sources- Google first party sources
Corresponds to the JSON propertydataSourceFamily`
3145 3146 3147 |
# File 'lib/google/apis/health_v4/classes.rb', line 3145 def data_source_family @data_source_family end |
#page_size ⇒ Fixnum
Optional. The maximum number of data points to return. If unspecified, at most
1440 data points will be returned. The maximum page size is 10000; values
above that will be truncated accordingly.
Corresponds to the JSON property pageSize
3152 3153 3154 |
# File 'lib/google/apis/health_v4/classes.rb', line 3152 def page_size @page_size end |
#page_token ⇒ String
Optional. The next_page_token from a previous request, if any. All other
request fields need to be the same as in the initial request when the page
token is specified.
Corresponds to the JSON property pageToken
3159 3160 3161 |
# File 'lib/google/apis/health_v4/classes.rb', line 3159 def page_token @page_token end |
#range ⇒ Google::Apis::HealthV4::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property range
3167 3168 3169 |
# File 'lib/google/apis/health_v4/classes.rb', line 3167 def range @range end |
#window_size ⇒ String
Required. The size of the time window to group data points into before
applying the aggregation functions.
Corresponds to the JSON property windowSize
3173 3174 3175 |
# File 'lib/google/apis/health_v4/classes.rb', line 3173 def window_size @window_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3180 3181 3182 3183 3184 3185 3186 |
# File 'lib/google/apis/health_v4/classes.rb', line 3180 def update!(**args) @data_source_family = args[:data_source_family] if args.key?(:data_source_family) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @range = args[:range] if args.key?(:range) @window_size = args[:window_size] if args.key?(:window_size) end |