Class: Google::Apis::HealthV4::RollUpDataPointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Request to roll up data points by physical time intervals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollUpDataPointsRequest

Returns a new instance of RollUpDataPointsRequest.



3114
3115
3116
# File 'lib/google/apis/health_v4/classes.rb', line 3114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_familyString

Optional. The data source family name to roll up. If empty, data points from all available data sources will be rolled up. Format: users/me/ dataSourceFamilies/data_source_family`The supported values are: -users/me/ dataSourceFamilies/all-sources- default value -users/me/dataSourceFamilies/ google-wearables- tracker devices -users/me/dataSourceFamilies/google- sources- Google first party sources Corresponds to the JSON propertydataSourceFamily`

Returns:

  • (String)


3084
3085
3086
# File 'lib/google/apis/health_v4/classes.rb', line 3084

def data_source_family
  @data_source_family
end

#page_sizeFixnum

Optional. The maximum number of data points to return. If unspecified, at most 1440 data points will be returned. The maximum page size is 10000; values above that will be truncated accordingly. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


3091
3092
3093
# File 'lib/google/apis/health_v4/classes.rb', line 3091

def page_size
  @page_size
end

#page_tokenString

Optional. The next_page_token from a previous request, if any. All other request fields need to be the same as in the initial request when the page token is specified. Corresponds to the JSON property pageToken

Returns:

  • (String)


3098
3099
3100
# File 'lib/google/apis/health_v4/classes.rb', line 3098

def page_token
  @page_token
end

#rangeGoogle::Apis::HealthV4::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property range



3106
3107
3108
# File 'lib/google/apis/health_v4/classes.rb', line 3106

def range
  @range
end

#window_sizeString

Required. The size of the time window to group data points into before applying the aggregation functions. Corresponds to the JSON property windowSize

Returns:

  • (String)


3112
3113
3114
# File 'lib/google/apis/health_v4/classes.rb', line 3112

def window_size
  @window_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3119
3120
3121
3122
3123
3124
3125
# File 'lib/google/apis/health_v4/classes.rb', line 3119

def update!(**args)
  @data_source_family = args[:data_source_family] if args.key?(:data_source_family)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @range = args[:range] if args.key?(:range)
  @window_size = args[:window_size] if args.key?(:window_size)
end