Class: Google::Apis::HealthV4::RollUpDataPointsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Response containing the list of rolled up data points.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollUpDataPointsResponse

Returns a new instance of RollUpDataPointsResponse.



3143
3144
3145
# File 'lib/google/apis/health_v4/classes.rb', line 3143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3136
3137
3138
# File 'lib/google/apis/health_v4/classes.rb', line 3136

def next_page_token
  @next_page_token
end

#rollup_data_pointsArray<Google::Apis::HealthV4::RollupDataPoint>

Values for each aggregation time window. Corresponds to the JSON property rollupDataPoints



3141
3142
3143
# File 'lib/google/apis/health_v4/classes.rb', line 3141

def rollup_data_points
  @rollup_data_points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3148
3149
3150
3151
# File 'lib/google/apis/health_v4/classes.rb', line 3148

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @rollup_data_points = args[:rollup_data_points] if args.key?(:rollup_data_points)
end