Class: Google::Apis::HealthV4::RollupDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::RollupDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Value of a rollup for a single physical time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.
Instance Attribute Summary collapse
-
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurnedRollupValue
Represents the result of the rollup of active energy burned.
-
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
-
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
-
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
-
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
-
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucoseRollupValue
Represents the result of the rollup of the blood glucose data type.
-
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
-
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data type.
-
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperatureRollupValue
Represents the result of the rollup of the core body temperature data type.
-
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
-
#end_time ⇒ String
End time of the window this value aggregates over Corresponds to the JSON property
endTime. -
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
-
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
-
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
-
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLogRollupValue
Represents the result of the rollup of the nutrition log data type.
-
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability personal range.
-
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
-
#start_time ⇒ String
Start time of the window this value aggregates over Corresponds to the JSON property
startTime. -
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
-
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
-
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
-
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories.
-
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollupDataPoint
constructor
A new instance of RollupDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollupDataPoint
Returns a new instance of RollupDataPoint.
4690 4691 4692 |
# File 'lib/google/apis/health_v4/classes.rb', line 4690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_energy_burned ⇒ Google::Apis::HealthV4::ActiveEnergyBurnedRollupValue
Represents the result of the rollup of active energy burned.
Corresponds to the JSON property activeEnergyBurned
4575 4576 4577 |
# File 'lib/google/apis/health_v4/classes.rb', line 4575 def active_energy_burned @active_energy_burned end |
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
Corresponds to the JSON property activeMinutes
4580 4581 4582 |
# File 'lib/google/apis/health_v4/classes.rb', line 4580 def active_minutes @active_minutes end |
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
Corresponds to the JSON property activeZoneMinutes
4585 4586 4587 |
# File 'lib/google/apis/health_v4/classes.rb', line 4585 def active_zone_minutes @active_zone_minutes end |
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
Corresponds to the JSON property activityLevel
4590 4591 4592 |
# File 'lib/google/apis/health_v4/classes.rb', line 4590 def activity_level @activity_level end |
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
Corresponds to the JSON property altitude
4595 4596 4597 |
# File 'lib/google/apis/health_v4/classes.rb', line 4595 def altitude @altitude end |
#blood_glucose ⇒ Google::Apis::HealthV4::BloodGlucoseRollupValue
Represents the result of the rollup of the blood glucose data type. LINT:
LEGACY_NAMES
Corresponds to the JSON property bloodGlucose
4601 4602 4603 |
# File 'lib/google/apis/health_v4/classes.rb', line 4601 def blood_glucose @blood_glucose end |
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
Corresponds to the JSON property bodyFat
4606 4607 4608 |
# File 'lib/google/apis/health_v4/classes.rb', line 4606 def body_fat @body_fat end |
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data
type.
Corresponds to the JSON property caloriesInHeartRateZone
4612 4613 4614 |
# File 'lib/google/apis/health_v4/classes.rb', line 4612 def calories_in_heart_rate_zone @calories_in_heart_rate_zone end |
#core_body_temperature ⇒ Google::Apis::HealthV4::CoreBodyTemperatureRollupValue
Represents the result of the rollup of the core body temperature data type.
Corresponds to the JSON property coreBodyTemperature
4617 4618 4619 |
# File 'lib/google/apis/health_v4/classes.rb', line 4617 def core_body_temperature @core_body_temperature end |
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
Corresponds to the JSON property distance
4622 4623 4624 |
# File 'lib/google/apis/health_v4/classes.rb', line 4622 def distance @distance end |
#end_time ⇒ String
End time of the window this value aggregates over
Corresponds to the JSON property endTime
4627 4628 4629 |
# File 'lib/google/apis/health_v4/classes.rb', line 4627 def end_time @end_time end |
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
Corresponds to the JSON property floors
4632 4633 4634 |
# File 'lib/google/apis/health_v4/classes.rb', line 4632 def floors @floors end |
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
Corresponds to the JSON property heartRate
4637 4638 4639 |
# File 'lib/google/apis/health_v4/classes.rb', line 4637 def heart_rate @heart_rate end |
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
Corresponds to the JSON property hydrationLog
4642 4643 4644 |
# File 'lib/google/apis/health_v4/classes.rb', line 4642 def hydration_log @hydration_log end |
#nutrition_log ⇒ Google::Apis::HealthV4::NutritionLogRollupValue
Represents the result of the rollup of the nutrition log data type.
Corresponds to the JSON property nutritionLog
4647 4648 4649 |
# File 'lib/google/apis/health_v4/classes.rb', line 4647 def nutrition_log @nutrition_log end |
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability
personal range.
Corresponds to the JSON property runVo2Max
4653 4654 4655 |
# File 'lib/google/apis/health_v4/classes.rb', line 4653 def run_vo2_max @run_vo2_max end |
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
Corresponds to the JSON property sedentaryPeriod
4658 4659 4660 |
# File 'lib/google/apis/health_v4/classes.rb', line 4658 def sedentary_period @sedentary_period end |
#start_time ⇒ String
Start time of the window this value aggregates over
Corresponds to the JSON property startTime
4663 4664 4665 |
# File 'lib/google/apis/health_v4/classes.rb', line 4663 def start_time @start_time end |
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
Corresponds to the JSON property steps
4668 4669 4670 |
# File 'lib/google/apis/health_v4/classes.rb', line 4668 def steps @steps end |
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
Corresponds to the JSON property swimLengthsData
4673 4674 4675 |
# File 'lib/google/apis/health_v4/classes.rb', line 4673 def swim_lengths_data @swim_lengths_data end |
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
Corresponds to the JSON property timeInHeartRateZone
4678 4679 4680 |
# File 'lib/google/apis/health_v4/classes.rb', line 4678 def time_in_heart_rate_zone @time_in_heart_rate_zone end |
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories.
Corresponds to the JSON property totalCalories
4683 4684 4685 |
# File 'lib/google/apis/health_v4/classes.rb', line 4683 def total_calories @total_calories end |
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Corresponds to the JSON property weight
4688 4689 4690 |
# File 'lib/google/apis/health_v4/classes.rb', line 4688 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4695 4696 4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 |
# File 'lib/google/apis/health_v4/classes.rb', line 4695 def update!(**args) @active_energy_burned = args[:active_energy_burned] if args.key?(:active_energy_burned) @active_minutes = args[:active_minutes] if args.key?(:active_minutes) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @activity_level = args[:activity_level] if args.key?(:activity_level) @altitude = args[:altitude] if args.key?(:altitude) @blood_glucose = args[:blood_glucose] if args.key?(:blood_glucose) @body_fat = args[:body_fat] if args.key?(:body_fat) @calories_in_heart_rate_zone = args[:calories_in_heart_rate_zone] if args.key?(:calories_in_heart_rate_zone) @core_body_temperature = args[:core_body_temperature] if args.key?(:core_body_temperature) @distance = args[:distance] if args.key?(:distance) @end_time = args[:end_time] if args.key?(:end_time) @floors = args[:floors] if args.key?(:floors) @heart_rate = args[:heart_rate] if args.key?(:heart_rate) @hydration_log = args[:hydration_log] if args.key?(:hydration_log) @nutrition_log = args[:nutrition_log] if args.key?(:nutrition_log) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period) @start_time = args[:start_time] if args.key?(:start_time) @steps = args[:steps] if args.key?(:steps) @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data) @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone) @total_calories = args[:total_calories] if args.key?(:total_calories) @weight = args[:weight] if args.key?(:weight) end |