Class: Google::Apis::HealthV4::RollupDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Value of a rollup for a single physical time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollupDataPoint

Returns a new instance of RollupDataPoint.



4607
4608
4609
# File 'lib/google/apis/health_v4/classes.rb', line 4607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_energy_burnedGoogle::Apis::HealthV4::ActiveEnergyBurnedRollupValue

Represents the result of the rollup of active energy burned. Corresponds to the JSON property activeEnergyBurned



4492
4493
4494
# File 'lib/google/apis/health_v4/classes.rb', line 4492

def active_energy_burned
  @active_energy_burned
end

#active_minutesGoogle::Apis::HealthV4::ActiveMinutesRollupValue

Represents the result of the rollup of the active minutes data type. Corresponds to the JSON property activeMinutes



4497
4498
4499
# File 'lib/google/apis/health_v4/classes.rb', line 4497

def active_minutes
  @active_minutes
end

#active_zone_minutesGoogle::Apis::HealthV4::ActiveZoneMinutesRollupValue

Represents the result of the rollup of the active zone minutes data type. Corresponds to the JSON property activeZoneMinutes



4502
4503
4504
# File 'lib/google/apis/health_v4/classes.rb', line 4502

def active_zone_minutes
  @active_zone_minutes
end

#activity_levelGoogle::Apis::HealthV4::ActivityLevelRollupValue

Represents the result of the rollup of the activity level data type. Corresponds to the JSON property activityLevel



4507
4508
4509
# File 'lib/google/apis/health_v4/classes.rb', line 4507

def activity_level
  @activity_level
end

#altitudeGoogle::Apis::HealthV4::AltitudeRollupValue

Represents the result of the rollup of the user's altitude. Corresponds to the JSON property altitude



4512
4513
4514
# File 'lib/google/apis/health_v4/classes.rb', line 4512

def altitude
  @altitude
end

#blood_glucoseGoogle::Apis::HealthV4::BloodGlucoseRollupValue

Represents the result of the rollup of the blood glucose data type. LINT: LEGACY_NAMES Corresponds to the JSON property bloodGlucose



4518
4519
4520
# File 'lib/google/apis/health_v4/classes.rb', line 4518

def blood_glucose
  @blood_glucose
end

#body_fatGoogle::Apis::HealthV4::BodyFatRollupValue

Represents the result of the rollup of the body fat data type. Corresponds to the JSON property bodyFat



4523
4524
4525
# File 'lib/google/apis/health_v4/classes.rb', line 4523

def body_fat
  @body_fat
end

#calories_in_heart_rate_zoneGoogle::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue

Represents the result of the rollup of the calories in heart rate zone data type. Corresponds to the JSON property caloriesInHeartRateZone



4529
4530
4531
# File 'lib/google/apis/health_v4/classes.rb', line 4529

def calories_in_heart_rate_zone
  @calories_in_heart_rate_zone
end

#core_body_temperatureGoogle::Apis::HealthV4::CoreBodyTemperatureRollupValue

Represents the result of the rollup of the core body temperature data type. Corresponds to the JSON property coreBodyTemperature



4534
4535
4536
# File 'lib/google/apis/health_v4/classes.rb', line 4534

def core_body_temperature
  @core_body_temperature
end

#distanceGoogle::Apis::HealthV4::DistanceRollupValue

Result of the rollup of the user's distance. Corresponds to the JSON property distance



4539
4540
4541
# File 'lib/google/apis/health_v4/classes.rb', line 4539

def distance
  @distance
end

#end_timeString

End time of the window this value aggregates over Corresponds to the JSON property endTime

Returns:

  • (String)


4544
4545
4546
# File 'lib/google/apis/health_v4/classes.rb', line 4544

def end_time
  @end_time
end

#floorsGoogle::Apis::HealthV4::FloorsRollupValue

Represents the result of the rollup of the user's floors. Corresponds to the JSON property floors



4549
4550
4551
# File 'lib/google/apis/health_v4/classes.rb', line 4549

def floors
  @floors
end

#heart_rateGoogle::Apis::HealthV4::HeartRateRollupValue

Represents the result of the rollup of the heart rate data type. Corresponds to the JSON property heartRate



4554
4555
4556
# File 'lib/google/apis/health_v4/classes.rb', line 4554

def heart_rate
  @heart_rate
end

#hydration_logGoogle::Apis::HealthV4::HydrationLogRollupValue

Represents the result of the rollup of the hydration log data type. Corresponds to the JSON property hydrationLog



4559
4560
4561
# File 'lib/google/apis/health_v4/classes.rb', line 4559

def hydration_log
  @hydration_log
end

#nutrition_logGoogle::Apis::HealthV4::NutritionLogRollupValue

Represents the result of the rollup of the nutrition log data type. Corresponds to the JSON property nutritionLog



4564
4565
4566
# File 'lib/google/apis/health_v4/classes.rb', line 4564

def nutrition_log
  @nutrition_log
end

#run_vo2_maxGoogle::Apis::HealthV4::RunVo2MaxRollupValue

Represents the result of the rollup of the user's daily heart rate variability personal range. Corresponds to the JSON property runVo2Max



4570
4571
4572
# File 'lib/google/apis/health_v4/classes.rb', line 4570

def run_vo2_max
  @run_vo2_max
end

#sedentary_periodGoogle::Apis::HealthV4::SedentaryPeriodRollupValue

Represents the result of the rollup of the user's sedentary periods. Corresponds to the JSON property sedentaryPeriod



4575
4576
4577
# File 'lib/google/apis/health_v4/classes.rb', line 4575

def sedentary_period
  @sedentary_period
end

#start_timeString

Start time of the window this value aggregates over Corresponds to the JSON property startTime

Returns:

  • (String)


4580
4581
4582
# File 'lib/google/apis/health_v4/classes.rb', line 4580

def start_time
  @start_time
end

#stepsGoogle::Apis::HealthV4::StepsRollupValue

Represents the result of the rollup of the steps data type. Corresponds to the JSON property steps



4585
4586
4587
# File 'lib/google/apis/health_v4/classes.rb', line 4585

def steps
  @steps
end

#swim_lengths_dataGoogle::Apis::HealthV4::SwimLengthsDataRollupValue

Represents the result of the rollup of the swim lengths data type. Corresponds to the JSON property swimLengthsData



4590
4591
4592
# File 'lib/google/apis/health_v4/classes.rb', line 4590

def swim_lengths_data
  @swim_lengths_data
end

#time_in_heart_rate_zoneGoogle::Apis::HealthV4::TimeInHeartRateZoneRollupValue

Represents the result of the rollup of the time in heart rate zone data type. Corresponds to the JSON property timeInHeartRateZone



4595
4596
4597
# File 'lib/google/apis/health_v4/classes.rb', line 4595

def time_in_heart_rate_zone
  @time_in_heart_rate_zone
end

#total_caloriesGoogle::Apis::HealthV4::TotalCaloriesRollupValue

Represents the result of the rollup of the user's total calories. Corresponds to the JSON property totalCalories



4600
4601
4602
# File 'lib/google/apis/health_v4/classes.rb', line 4600

def total_calories
  @total_calories
end

#weightGoogle::Apis::HealthV4::WeightRollupValue

Represents the result of the rollup of the weight data type. Corresponds to the JSON property weight



4605
4606
4607
# File 'lib/google/apis/health_v4/classes.rb', line 4605

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
4632
4633
4634
4635
4636
# File 'lib/google/apis/health_v4/classes.rb', line 4612

def update!(**args)
  @active_energy_burned = args[:active_energy_burned] if args.key?(:active_energy_burned)
  @active_minutes = args[:active_minutes] if args.key?(:active_minutes)
  @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes)
  @activity_level = args[:activity_level] if args.key?(:activity_level)
  @altitude = args[:altitude] if args.key?(:altitude)
  @blood_glucose = args[:blood_glucose] if args.key?(:blood_glucose)
  @body_fat = args[:body_fat] if args.key?(:body_fat)
  @calories_in_heart_rate_zone = args[:calories_in_heart_rate_zone] if args.key?(:calories_in_heart_rate_zone)
  @core_body_temperature = args[:core_body_temperature] if args.key?(:core_body_temperature)
  @distance = args[:distance] if args.key?(:distance)
  @end_time = args[:end_time] if args.key?(:end_time)
  @floors = args[:floors] if args.key?(:floors)
  @heart_rate = args[:heart_rate] if args.key?(:heart_rate)
  @hydration_log = args[:hydration_log] if args.key?(:hydration_log)
  @nutrition_log = args[:nutrition_log] if args.key?(:nutrition_log)
  @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max)
  @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period)
  @start_time = args[:start_time] if args.key?(:start_time)
  @steps = args[:steps] if args.key?(:steps)
  @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data)
  @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone)
  @total_calories = args[:total_calories] if args.key?(:total_calories)
  @weight = args[:weight] if args.key?(:weight)
end