Class: Google::Apis::HealthV4::RollupDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::RollupDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Value of a rollup for a single physical time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.
Instance Attribute Summary collapse
-
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
-
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
-
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
-
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
-
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
-
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data type.
-
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
-
#end_time ⇒ String
End time of the window this value aggregates over Corresponds to the JSON property
endTime. -
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
-
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
-
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
-
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability personal range.
-
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
-
#start_time ⇒ String
Start time of the window this value aggregates over Corresponds to the JSON property
startTime. -
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
-
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
-
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
-
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories.
-
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollupDataPoint
constructor
A new instance of RollupDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollupDataPoint
Returns a new instance of RollupDataPoint.
3325 3326 3327 |
# File 'lib/google/apis/health_v4/classes.rb', line 3325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_minutes ⇒ Google::Apis::HealthV4::ActiveMinutesRollupValue
Represents the result of the rollup of the active minutes data type.
Corresponds to the JSON property activeMinutes
3231 3232 3233 |
# File 'lib/google/apis/health_v4/classes.rb', line 3231 def active_minutes @active_minutes end |
#active_zone_minutes ⇒ Google::Apis::HealthV4::ActiveZoneMinutesRollupValue
Represents the result of the rollup of the active zone minutes data type.
Corresponds to the JSON property activeZoneMinutes
3236 3237 3238 |
# File 'lib/google/apis/health_v4/classes.rb', line 3236 def active_zone_minutes @active_zone_minutes end |
#activity_level ⇒ Google::Apis::HealthV4::ActivityLevelRollupValue
Represents the result of the rollup of the activity level data type.
Corresponds to the JSON property activityLevel
3241 3242 3243 |
# File 'lib/google/apis/health_v4/classes.rb', line 3241 def activity_level @activity_level end |
#altitude ⇒ Google::Apis::HealthV4::AltitudeRollupValue
Represents the result of the rollup of the user's altitude.
Corresponds to the JSON property altitude
3246 3247 3248 |
# File 'lib/google/apis/health_v4/classes.rb', line 3246 def altitude @altitude end |
#body_fat ⇒ Google::Apis::HealthV4::BodyFatRollupValue
Represents the result of the rollup of the body fat data type.
Corresponds to the JSON property bodyFat
3251 3252 3253 |
# File 'lib/google/apis/health_v4/classes.rb', line 3251 def body_fat @body_fat end |
#calories_in_heart_rate_zone ⇒ Google::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue
Represents the result of the rollup of the calories in heart rate zone data
type.
Corresponds to the JSON property caloriesInHeartRateZone
3257 3258 3259 |
# File 'lib/google/apis/health_v4/classes.rb', line 3257 def calories_in_heart_rate_zone @calories_in_heart_rate_zone end |
#distance ⇒ Google::Apis::HealthV4::DistanceRollupValue
Result of the rollup of the user's distance.
Corresponds to the JSON property distance
3262 3263 3264 |
# File 'lib/google/apis/health_v4/classes.rb', line 3262 def distance @distance end |
#end_time ⇒ String
End time of the window this value aggregates over
Corresponds to the JSON property endTime
3267 3268 3269 |
# File 'lib/google/apis/health_v4/classes.rb', line 3267 def end_time @end_time end |
#floors ⇒ Google::Apis::HealthV4::FloorsRollupValue
Represents the result of the rollup of the user's floors.
Corresponds to the JSON property floors
3272 3273 3274 |
# File 'lib/google/apis/health_v4/classes.rb', line 3272 def floors @floors end |
#heart_rate ⇒ Google::Apis::HealthV4::HeartRateRollupValue
Represents the result of the rollup of the heart rate data type.
Corresponds to the JSON property heartRate
3277 3278 3279 |
# File 'lib/google/apis/health_v4/classes.rb', line 3277 def heart_rate @heart_rate end |
#hydration_log ⇒ Google::Apis::HealthV4::HydrationLogRollupValue
Represents the result of the rollup of the hydration log data type.
Corresponds to the JSON property hydrationLog
3282 3283 3284 |
# File 'lib/google/apis/health_v4/classes.rb', line 3282 def hydration_log @hydration_log end |
#run_vo2_max ⇒ Google::Apis::HealthV4::RunVo2MaxRollupValue
Represents the result of the rollup of the user's daily heart rate variability
personal range.
Corresponds to the JSON property runVo2Max
3288 3289 3290 |
# File 'lib/google/apis/health_v4/classes.rb', line 3288 def run_vo2_max @run_vo2_max end |
#sedentary_period ⇒ Google::Apis::HealthV4::SedentaryPeriodRollupValue
Represents the result of the rollup of the user's sedentary periods.
Corresponds to the JSON property sedentaryPeriod
3293 3294 3295 |
# File 'lib/google/apis/health_v4/classes.rb', line 3293 def sedentary_period @sedentary_period end |
#start_time ⇒ String
Start time of the window this value aggregates over
Corresponds to the JSON property startTime
3298 3299 3300 |
# File 'lib/google/apis/health_v4/classes.rb', line 3298 def start_time @start_time end |
#steps ⇒ Google::Apis::HealthV4::StepsRollupValue
Represents the result of the rollup of the steps data type.
Corresponds to the JSON property steps
3303 3304 3305 |
# File 'lib/google/apis/health_v4/classes.rb', line 3303 def steps @steps end |
#swim_lengths_data ⇒ Google::Apis::HealthV4::SwimLengthsDataRollupValue
Represents the result of the rollup of the swim lengths data type.
Corresponds to the JSON property swimLengthsData
3308 3309 3310 |
# File 'lib/google/apis/health_v4/classes.rb', line 3308 def swim_lengths_data @swim_lengths_data end |
#time_in_heart_rate_zone ⇒ Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
Represents the result of the rollup of the time in heart rate zone data type.
Corresponds to the JSON property timeInHeartRateZone
3313 3314 3315 |
# File 'lib/google/apis/health_v4/classes.rb', line 3313 def time_in_heart_rate_zone @time_in_heart_rate_zone end |
#total_calories ⇒ Google::Apis::HealthV4::TotalCaloriesRollupValue
Represents the result of the rollup of the user's total calories.
Corresponds to the JSON property totalCalories
3318 3319 3320 |
# File 'lib/google/apis/health_v4/classes.rb', line 3318 def total_calories @total_calories end |
#weight ⇒ Google::Apis::HealthV4::WeightRollupValue
Represents the result of the rollup of the weight data type.
Corresponds to the JSON property weight
3323 3324 3325 |
# File 'lib/google/apis/health_v4/classes.rb', line 3323 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 3349 3350 |
# File 'lib/google/apis/health_v4/classes.rb', line 3330 def update!(**args) @active_minutes = args[:active_minutes] if args.key?(:active_minutes) @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes) @activity_level = args[:activity_level] if args.key?(:activity_level) @altitude = args[:altitude] if args.key?(:altitude) @body_fat = args[:body_fat] if args.key?(:body_fat) @calories_in_heart_rate_zone = args[:calories_in_heart_rate_zone] if args.key?(:calories_in_heart_rate_zone) @distance = args[:distance] if args.key?(:distance) @end_time = args[:end_time] if args.key?(:end_time) @floors = args[:floors] if args.key?(:floors) @heart_rate = args[:heart_rate] if args.key?(:heart_rate) @hydration_log = args[:hydration_log] if args.key?(:hydration_log) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period) @start_time = args[:start_time] if args.key?(:start_time) @steps = args[:steps] if args.key?(:steps) @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data) @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone) @total_calories = args[:total_calories] if args.key?(:total_calories) @weight = args[:weight] if args.key?(:weight) end |