Class: Google::Apis::HealthV4::RollupDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Value of a rollup for a single physical time interval (aggregation window)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollupDataPoint

Returns a new instance of RollupDataPoint.



3316
3317
3318
# File 'lib/google/apis/health_v4/classes.rb', line 3316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_minutesGoogle::Apis::HealthV4::ActiveMinutesRollupValue

Represents the result of the rollup of the active minutes data type. Corresponds to the JSON property activeMinutes



3222
3223
3224
# File 'lib/google/apis/health_v4/classes.rb', line 3222

def active_minutes
  @active_minutes
end

#active_zone_minutesGoogle::Apis::HealthV4::ActiveZoneMinutesRollupValue

Represents the result of the rollup of the active zone minutes data type. Corresponds to the JSON property activeZoneMinutes



3227
3228
3229
# File 'lib/google/apis/health_v4/classes.rb', line 3227

def active_zone_minutes
  @active_zone_minutes
end

#activity_levelGoogle::Apis::HealthV4::ActivityLevelRollupValue

Represents the result of the rollup of the activity level data type. Corresponds to the JSON property activityLevel



3232
3233
3234
# File 'lib/google/apis/health_v4/classes.rb', line 3232

def activity_level
  @activity_level
end

#altitudeGoogle::Apis::HealthV4::AltitudeRollupValue

Represents the result of the rollup of the user's altitude. Corresponds to the JSON property altitude



3237
3238
3239
# File 'lib/google/apis/health_v4/classes.rb', line 3237

def altitude
  @altitude
end

#body_fatGoogle::Apis::HealthV4::BodyFatRollupValue

Represents the result of the rollup of the body fat data type. Corresponds to the JSON property bodyFat



3242
3243
3244
# File 'lib/google/apis/health_v4/classes.rb', line 3242

def body_fat
  @body_fat
end

#calories_in_heart_rate_zoneGoogle::Apis::HealthV4::CaloriesInHeartRateZoneRollupValue

Represents the result of the rollup of the calories in heart rate zone data type. Corresponds to the JSON property caloriesInHeartRateZone



3248
3249
3250
# File 'lib/google/apis/health_v4/classes.rb', line 3248

def calories_in_heart_rate_zone
  @calories_in_heart_rate_zone
end

#distanceGoogle::Apis::HealthV4::DistanceRollupValue

Result of the rollup of the user's distance. Corresponds to the JSON property distance



3253
3254
3255
# File 'lib/google/apis/health_v4/classes.rb', line 3253

def distance
  @distance
end

#end_timeString

End time of the window this value aggregates over Corresponds to the JSON property endTime

Returns:

  • (String)


3258
3259
3260
# File 'lib/google/apis/health_v4/classes.rb', line 3258

def end_time
  @end_time
end

#floorsGoogle::Apis::HealthV4::FloorsRollupValue

Represents the result of the rollup of the user's floors. Corresponds to the JSON property floors



3263
3264
3265
# File 'lib/google/apis/health_v4/classes.rb', line 3263

def floors
  @floors
end

#heart_rateGoogle::Apis::HealthV4::HeartRateRollupValue

Represents the result of the rollup of the heart rate data type. Corresponds to the JSON property heartRate



3268
3269
3270
# File 'lib/google/apis/health_v4/classes.rb', line 3268

def heart_rate
  @heart_rate
end

#hydration_logGoogle::Apis::HealthV4::HydrationLogRollupValue

Represents the result of the rollup of the hydration log data type. Corresponds to the JSON property hydrationLog



3273
3274
3275
# File 'lib/google/apis/health_v4/classes.rb', line 3273

def hydration_log
  @hydration_log
end

#run_vo2_maxGoogle::Apis::HealthV4::RunVo2MaxRollupValue

Represents the result of the rollup of the user's daily heart rate variability personal range. Corresponds to the JSON property runVo2Max



3279
3280
3281
# File 'lib/google/apis/health_v4/classes.rb', line 3279

def run_vo2_max
  @run_vo2_max
end

#sedentary_periodGoogle::Apis::HealthV4::SedentaryPeriodRollupValue

Represents the result of the rollup of the user's sedentary periods. Corresponds to the JSON property sedentaryPeriod



3284
3285
3286
# File 'lib/google/apis/health_v4/classes.rb', line 3284

def sedentary_period
  @sedentary_period
end

#start_timeString

Start time of the window this value aggregates over Corresponds to the JSON property startTime

Returns:

  • (String)


3289
3290
3291
# File 'lib/google/apis/health_v4/classes.rb', line 3289

def start_time
  @start_time
end

#stepsGoogle::Apis::HealthV4::StepsRollupValue

Represents the result of the rollup of the steps data type. Corresponds to the JSON property steps



3294
3295
3296
# File 'lib/google/apis/health_v4/classes.rb', line 3294

def steps
  @steps
end

#swim_lengths_dataGoogle::Apis::HealthV4::SwimLengthsDataRollupValue

Represents the result of the rollup of the swim lengths data type. Corresponds to the JSON property swimLengthsData



3299
3300
3301
# File 'lib/google/apis/health_v4/classes.rb', line 3299

def swim_lengths_data
  @swim_lengths_data
end

#time_in_heart_rate_zoneGoogle::Apis::HealthV4::TimeInHeartRateZoneRollupValue

Represents the result of the rollup of the time in heart rate zone data type. Corresponds to the JSON property timeInHeartRateZone



3304
3305
3306
# File 'lib/google/apis/health_v4/classes.rb', line 3304

def time_in_heart_rate_zone
  @time_in_heart_rate_zone
end

#total_caloriesGoogle::Apis::HealthV4::TotalCaloriesRollupValue

Represents the result of the rollup of the user's total calories. Corresponds to the JSON property totalCalories



3309
3310
3311
# File 'lib/google/apis/health_v4/classes.rb', line 3309

def total_calories
  @total_calories
end

#weightGoogle::Apis::HealthV4::WeightRollupValue

Represents the result of the rollup of the weight data type. Corresponds to the JSON property weight



3314
3315
3316
# File 'lib/google/apis/health_v4/classes.rb', line 3314

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
# File 'lib/google/apis/health_v4/classes.rb', line 3321

def update!(**args)
  @active_minutes = args[:active_minutes] if args.key?(:active_minutes)
  @active_zone_minutes = args[:active_zone_minutes] if args.key?(:active_zone_minutes)
  @activity_level = args[:activity_level] if args.key?(:activity_level)
  @altitude = args[:altitude] if args.key?(:altitude)
  @body_fat = args[:body_fat] if args.key?(:body_fat)
  @calories_in_heart_rate_zone = args[:calories_in_heart_rate_zone] if args.key?(:calories_in_heart_rate_zone)
  @distance = args[:distance] if args.key?(:distance)
  @end_time = args[:end_time] if args.key?(:end_time)
  @floors = args[:floors] if args.key?(:floors)
  @heart_rate = args[:heart_rate] if args.key?(:heart_rate)
  @hydration_log = args[:hydration_log] if args.key?(:hydration_log)
  @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max)
  @sedentary_period = args[:sedentary_period] if args.key?(:sedentary_period)
  @start_time = args[:start_time] if args.key?(:start_time)
  @steps = args[:steps] if args.key?(:steps)
  @swim_lengths_data = args[:swim_lengths_data] if args.key?(:swim_lengths_data)
  @time_in_heart_rate_zone = args[:time_in_heart_rate_zone] if args.key?(:time_in_heart_rate_zone)
  @total_calories = args[:total_calories] if args.key?(:total_calories)
  @weight = args[:weight] if args.key?(:weight)
end