Class: Google::Apis::HealthV4::RunVo2Max
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::RunVo2Max
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
VO2 max value calculated based on the user's running activity. Value stored in ml/kg/min.
Instance Attribute Summary collapse
-
#run_vo2_max ⇒ Float
Required.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunVo2Max
constructor
A new instance of RunVo2Max.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunVo2Max
Returns a new instance of RunVo2Max.
3298 3299 3300 |
# File 'lib/google/apis/health_v4/classes.rb', line 3298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#run_vo2_max ⇒ Float
Required. Run VO2 max value in ml/kg/min.
Corresponds to the JSON property runVo2Max
3291 3292 3293 |
# File 'lib/google/apis/health_v4/classes.rb', line 3291 def run_vo2_max @run_vo2_max end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
3296 3297 3298 |
# File 'lib/google/apis/health_v4/classes.rb', line 3296 def sample_time @sample_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3303 3304 3305 3306 |
# File 'lib/google/apis/health_v4/classes.rb', line 3303 def update!(**args) @run_vo2_max = args[:run_vo2_max] if args.key?(:run_vo2_max) @sample_time = args[:sample_time] if args.key?(:sample_time) end |