Class: Google::Apis::HealthV4::SedentaryPeriod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

SedentaryPeriod SedentaryPeriod data represents the periods of time that the user was sedentary (i.e. not moving while wearing the device).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SedentaryPeriod

Returns a new instance of SedentaryPeriod.



3421
3422
3423
# File 'lib/google/apis/health_v4/classes.rb', line 3421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



3419
3420
3421
# File 'lib/google/apis/health_v4/classes.rb', line 3419

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3426
3427
3428
# File 'lib/google/apis/health_v4/classes.rb', line 3426

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
end