Class: Google::Apis::HealthV4::SedentaryPeriodRollupValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SedentaryPeriodRollupValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the result of the rollup of the user's sedentary periods.
Instance Attribute Summary collapse
-
#duration_sum ⇒ String
The total time user spent sedentary during the interval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SedentaryPeriodRollupValue
constructor
A new instance of SedentaryPeriodRollupValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SedentaryPeriodRollupValue
Returns a new instance of SedentaryPeriodRollupValue.
4726 4727 4728 |
# File 'lib/google/apis/health_v4/classes.rb', line 4726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration_sum ⇒ String
The total time user spent sedentary during the interval.
Corresponds to the JSON property durationSum
4724 4725 4726 |
# File 'lib/google/apis/health_v4/classes.rb', line 4724 def duration_sum @duration_sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4731 4732 4733 |
# File 'lib/google/apis/health_v4/classes.rb', line 4731 def update!(**args) @duration_sum = args[:duration_sum] if args.key?(:duration_sum) end |