Class: Google::Apis::HealthV4::SedentaryPeriodRollupValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SedentaryPeriodRollupValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the result of the rollup of the user's sedentary periods.
Instance Attribute Summary collapse
-
#duration_sum ⇒ String
The total time user spent sedentary during the interval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SedentaryPeriodRollupValue
constructor
A new instance of SedentaryPeriodRollupValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SedentaryPeriodRollupValue
Returns a new instance of SedentaryPeriodRollupValue.
3370 3371 3372 |
# File 'lib/google/apis/health_v4/classes.rb', line 3370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration_sum ⇒ String
The total time user spent sedentary during the interval.
Corresponds to the JSON property durationSum
3368 3369 3370 |
# File 'lib/google/apis/health_v4/classes.rb', line 3368 def duration_sum @duration_sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3375 3376 3377 |
# File 'lib/google/apis/health_v4/classes.rb', line 3375 def update!(**args) @duration_sum = args[:duration_sum] if args.key?(:duration_sum) end |