Class: Google::Apis::HealthV4::Serving
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Serving
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents different properties and information about the serving of a specific food.
Instance Attribute Summary collapse
-
#amount ⇒ Float
Optional.
-
#food_measurement_unit ⇒ String
Required.
-
#food_measurement_unit_display_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Serving
constructor
A new instance of Serving.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Serving
Returns a new instance of Serving.
4840 4841 4842 |
# File 'lib/google/apis/health_v4/classes.rb', line 4840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount ⇒ Float
Optional. The number of servings.
Corresponds to the JSON property amount
4827 4828 4829 |
# File 'lib/google/apis/health_v4/classes.rb', line 4827 def amount @amount end |
#food_measurement_unit ⇒ String
Required. Food measurement unit
Corresponds to the JSON property foodMeasurementUnit
4832 4833 4834 |
# File 'lib/google/apis/health_v4/classes.rb', line 4832 def food_measurement_unit @food_measurement_unit end |
#food_measurement_unit_display_name ⇒ String
Output only. Legacy measurement unit for serving size in singular form (e.g. "
piece", "gram").
Corresponds to the JSON property foodMeasurementUnitDisplayName
4838 4839 4840 |
# File 'lib/google/apis/health_v4/classes.rb', line 4838 def food_measurement_unit_display_name @food_measurement_unit_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4845 4846 4847 4848 4849 |
# File 'lib/google/apis/health_v4/classes.rb', line 4845 def update!(**args) @amount = args[:amount] if args.key?(:amount) @food_measurement_unit = args[:food_measurement_unit] if args.key?(:food_measurement_unit) @food_measurement_unit_display_name = args[:food_measurement_unit_display_name] if args.key?(:food_measurement_unit_display_name) end |