Class: Google::Apis::HealthV4::SessionTimeInterval
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SessionTimeInterval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents a time interval of session data point, which bundles multiple observed metrics together.
Instance Attribute Summary collapse
-
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
-
#end_time ⇒ String
Required.
-
#end_utc_offset ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#start_utc_offset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionTimeInterval
constructor
A new instance of SessionTimeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionTimeInterval
Returns a new instance of SessionTimeInterval.
5018 5019 5020 |
# File 'lib/google/apis/health_v4/classes.rb', line 5018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#civil_end_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilEndTime
4987 4988 4989 |
# File 'lib/google/apis/health_v4/classes.rb', line 4987 def civil_end_time @civil_end_time end |
#civil_start_time ⇒ Google::Apis::HealthV4::CivilDateTime
Civil time representation similar to google.type.DateTime, but ensures that
neither the timezone nor the UTC offset can be set to avoid confusion between
civil and physical time queries.
Corresponds to the JSON property civilStartTime
4994 4995 4996 |
# File 'lib/google/apis/health_v4/classes.rb', line 4994 def civil_start_time @civil_start_time end |
#end_time ⇒ String
Required. The end time of the observed session.
Corresponds to the JSON property endTime
4999 5000 5001 |
# File 'lib/google/apis/health_v4/classes.rb', line 4999 def end_time @end_time end |
#end_utc_offset ⇒ String
Required. The offset of the user's local time at the end of the session
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property endUtcOffset
5005 5006 5007 |
# File 'lib/google/apis/health_v4/classes.rb', line 5005 def end_utc_offset @end_utc_offset end |
#start_time ⇒ String
Required. The start time of the observed session.
Corresponds to the JSON property startTime
5010 5011 5012 |
# File 'lib/google/apis/health_v4/classes.rb', line 5010 def start_time @start_time end |
#start_utc_offset ⇒ String
Required. The offset of the user's local time at the start of the session
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property startUtcOffset
5016 5017 5018 |
# File 'lib/google/apis/health_v4/classes.rb', line 5016 def start_utc_offset @start_utc_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5023 5024 5025 5026 5027 5028 5029 5030 |
# File 'lib/google/apis/health_v4/classes.rb', line 5023 def update!(**args) @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time) @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time) @end_time = args[:end_time] if args.key?(:end_time) @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset) @start_time = args[:start_time] if args.key?(:start_time) @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset) end |