Class: Google::Apis::HealthV4::SessionTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a time interval of session data point, which bundles multiple observed metrics together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionTimeInterval

Returns a new instance of SessionTimeInterval.



4903
4904
4905
# File 'lib/google/apis/health_v4/classes.rb', line 4903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



4872
4873
4874
# File 'lib/google/apis/health_v4/classes.rb', line 4872

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



4879
4880
4881
# File 'lib/google/apis/health_v4/classes.rb', line 4879

def civil_start_time
  @civil_start_time
end

#end_timeString

Required. The end time of the observed session. Corresponds to the JSON property endTime

Returns:

  • (String)


4884
4885
4886
# File 'lib/google/apis/health_v4/classes.rb', line 4884

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


4890
4891
4892
# File 'lib/google/apis/health_v4/classes.rb', line 4890

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. The start time of the observed session. Corresponds to the JSON property startTime

Returns:

  • (String)


4895
4896
4897
# File 'lib/google/apis/health_v4/classes.rb', line 4895

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


4901
4902
4903
# File 'lib/google/apis/health_v4/classes.rb', line 4901

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4908
4909
4910
4911
4912
4913
4914
4915
# File 'lib/google/apis/health_v4/classes.rb', line 4908

def update!(**args)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end