Class: Google::Apis::HealthV4::SessionTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a time interval of session data point, which bundles multiple observed metrics together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionTimeInterval

Returns a new instance of SessionTimeInterval.



4893
4894
4895
# File 'lib/google/apis/health_v4/classes.rb', line 4893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



4862
4863
4864
# File 'lib/google/apis/health_v4/classes.rb', line 4862

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



4869
4870
4871
# File 'lib/google/apis/health_v4/classes.rb', line 4869

def civil_start_time
  @civil_start_time
end

#end_timeString

Required. The end time of the observed session. Corresponds to the JSON property endTime

Returns:

  • (String)


4874
4875
4876
# File 'lib/google/apis/health_v4/classes.rb', line 4874

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


4880
4881
4882
# File 'lib/google/apis/health_v4/classes.rb', line 4880

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. The start time of the observed session. Corresponds to the JSON property startTime

Returns:

  • (String)


4885
4886
4887
# File 'lib/google/apis/health_v4/classes.rb', line 4885

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


4891
4892
4893
# File 'lib/google/apis/health_v4/classes.rb', line 4891

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4898
4899
4900
4901
4902
4903
4904
4905
# File 'lib/google/apis/health_v4/classes.rb', line 4898

def update!(**args)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end