Class: Google::Apis::HealthV4::SessionTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a time interval of session data point, which bundles multiple observed metrics together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionTimeInterval

Returns a new instance of SessionTimeInterval.



4810
4811
4812
# File 'lib/google/apis/health_v4/classes.rb', line 4810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



4779
4780
4781
# File 'lib/google/apis/health_v4/classes.rb', line 4779

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



4786
4787
4788
# File 'lib/google/apis/health_v4/classes.rb', line 4786

def civil_start_time
  @civil_start_time
end

#end_timeString

Required. The end time of the observed session. Corresponds to the JSON property endTime

Returns:

  • (String)


4791
4792
4793
# File 'lib/google/apis/health_v4/classes.rb', line 4791

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


4797
4798
4799
# File 'lib/google/apis/health_v4/classes.rb', line 4797

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. The start time of the observed session. Corresponds to the JSON property startTime

Returns:

  • (String)


4802
4803
4804
# File 'lib/google/apis/health_v4/classes.rb', line 4802

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


4808
4809
4810
# File 'lib/google/apis/health_v4/classes.rb', line 4808

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4815
4816
4817
4818
4819
4820
4821
4822
# File 'lib/google/apis/health_v4/classes.rb', line 4815

def update!(**args)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end