Class: Google::Apis::HealthV4::SessionTimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents a time interval of session data point, which bundles multiple observed metrics together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionTimeInterval

Returns a new instance of SessionTimeInterval.



3482
3483
3484
# File 'lib/google/apis/health_v4/classes.rb', line 3482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#civil_end_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilEndTime



3451
3452
3453
# File 'lib/google/apis/health_v4/classes.rb', line 3451

def civil_end_time
  @civil_end_time
end

#civil_start_timeGoogle::Apis::HealthV4::CivilDateTime

Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries. Corresponds to the JSON property civilStartTime



3458
3459
3460
# File 'lib/google/apis/health_v4/classes.rb', line 3458

def civil_start_time
  @civil_start_time
end

#end_timeString

Required. The end time of the observed session. Corresponds to the JSON property endTime

Returns:

  • (String)


3463
3464
3465
# File 'lib/google/apis/health_v4/classes.rb', line 3463

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


3469
3470
3471
# File 'lib/google/apis/health_v4/classes.rb', line 3469

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. The start time of the observed session. Corresponds to the JSON property startTime

Returns:

  • (String)


3474
3475
3476
# File 'lib/google/apis/health_v4/classes.rb', line 3474

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the session relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


3480
3481
3482
# File 'lib/google/apis/health_v4/classes.rb', line 3480

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3487
3488
3489
3490
3491
3492
3493
3494
# File 'lib/google/apis/health_v4/classes.rb', line 3487

def update!(**args)
  @civil_end_time = args[:civil_end_time] if args.key?(:civil_end_time)
  @civil_start_time = args[:civil_start_time] if args.key?(:civil_start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end