Class: Google::Apis::HealthV4::Settings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Settings details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Settings

Returns a new instance of Settings.



5014
5015
5016
# File 'lib/google/apis/health_v4/classes.rb', line 5014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_stride_enabledBoolean Also known as: auto_stride_enabled?

Optional. True if the user's stride length is determined automatically. Updates to this field are currently not supported. Corresponds to the JSON property autoStrideEnabled

Returns:

  • (Boolean)


4926
4927
4928
# File 'lib/google/apis/health_v4/classes.rb', line 4926

def auto_stride_enabled
  @auto_stride_enabled
end

#distance_unitString

Optional. The measurement unit defined in the user's account settings. Updates to this field are currently not supported. Corresponds to the JSON property distanceUnit

Returns:

  • (String)


4933
4934
4935
# File 'lib/google/apis/health_v4/classes.rb', line 4933

def distance_unit
  @distance_unit
end

#food_language_codeString

Output only. The food language code derived from the user's food database. Possible values: 'en-US', 'en-GB', 'de-DE', 'es-ES', 'fr-FR', 'zh- CN', 'zh-TW', 'ja-JP', 'en-AU', 'en-CA', 'it-IT', 'ko-KR', 'es- MX', 'en-IN', 'en-SG', 'en-PH', 'en-IE', 'fr-CA'. Updates to this field are currently not supported. Corresponds to the JSON property foodLanguageCode

Returns:

  • (String)


4942
4943
4944
# File 'lib/google/apis/health_v4/classes.rb', line 4942

def food_language_code
  @food_language_code
end

#glucose_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property glucoseUnit

Returns:

  • (String)


4947
4948
4949
# File 'lib/google/apis/health_v4/classes.rb', line 4947

def glucose_unit
  @glucose_unit
end

#height_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property heightUnit

Returns:

  • (String)


4952
4953
4954
# File 'lib/google/apis/health_v4/classes.rb', line 4952

def height_unit
  @height_unit
end

#language_localeString

Optional. The locale defined in the user's account settings. Updates to this field are currently not supported. Corresponds to the JSON property languageLocale

Returns:

  • (String)


4958
4959
4960
# File 'lib/google/apis/health_v4/classes.rb', line 4958

def language_locale
  @language_locale
end

#nameString

Identifier. The resource name of this Settings resource. Format: users/user/ settings Example: users/1234567890/settings or users/me/settings The user ID is a system-generated Google Health API user ID, a string of 1-63 characters consisting of lowercase and uppercase letters, numbers, and hyphens. The literal me can also be used to refer to the authenticated user. Corresponds to the JSON property name

Returns:

  • (String)


4967
4968
4969
# File 'lib/google/apis/health_v4/classes.rb', line 4967

def name
  @name
end

#stride_length_running_typeString

Optional. The stride length type defined in the user's account settings for running. Updates to this field are currently not supported. Corresponds to the JSON property strideLengthRunningType

Returns:

  • (String)


4973
4974
4975
# File 'lib/google/apis/health_v4/classes.rb', line 4973

def stride_length_running_type
  @stride_length_running_type
end

#stride_length_walking_typeString

Optional. The stride length type defined in the user's account settings for walking. Updates to this field are currently not supported. Corresponds to the JSON property strideLengthWalkingType

Returns:

  • (String)


4979
4980
4981
# File 'lib/google/apis/health_v4/classes.rb', line 4979

def stride_length_walking_type
  @stride_length_walking_type
end

#swim_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property swimUnit

Returns:

  • (String)


4984
4985
4986
# File 'lib/google/apis/health_v4/classes.rb', line 4984

def swim_unit
  @swim_unit
end

#temperature_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property temperatureUnit

Returns:

  • (String)


4989
4990
4991
# File 'lib/google/apis/health_v4/classes.rb', line 4989

def temperature_unit
  @temperature_unit
end

#time_zoneString

Optional. The timezone defined in the user's account settings. This follows the IANA Time Zone Database. Updates to this field are currently not supported. Corresponds to the JSON property timeZone

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/health_v4/classes.rb', line 4996

def time_zone
  @time_zone
end

#utc_offsetString

Optional. The user's timezone offset relative to UTC. Updates to this field are currently not supported. Corresponds to the JSON property utcOffset

Returns:

  • (String)


5002
5003
5004
# File 'lib/google/apis/health_v4/classes.rb', line 5002

def utc_offset
  @utc_offset
end

#water_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property waterUnit

Returns:

  • (String)


5007
5008
5009
# File 'lib/google/apis/health_v4/classes.rb', line 5007

def water_unit
  @water_unit
end

#weight_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property weightUnit

Returns:

  • (String)


5012
5013
5014
# File 'lib/google/apis/health_v4/classes.rb', line 5012

def weight_unit
  @weight_unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
# File 'lib/google/apis/health_v4/classes.rb', line 5019

def update!(**args)
  @auto_stride_enabled = args[:auto_stride_enabled] if args.key?(:auto_stride_enabled)
  @distance_unit = args[:distance_unit] if args.key?(:distance_unit)
  @food_language_code = args[:food_language_code] if args.key?(:food_language_code)
  @glucose_unit = args[:glucose_unit] if args.key?(:glucose_unit)
  @height_unit = args[:height_unit] if args.key?(:height_unit)
  @language_locale = args[:language_locale] if args.key?(:language_locale)
  @name = args[:name] if args.key?(:name)
  @stride_length_running_type = args[:stride_length_running_type] if args.key?(:stride_length_running_type)
  @stride_length_walking_type = args[:stride_length_walking_type] if args.key?(:stride_length_walking_type)
  @swim_unit = args[:swim_unit] if args.key?(:swim_unit)
  @temperature_unit = args[:temperature_unit] if args.key?(:temperature_unit)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
  @water_unit = args[:water_unit] if args.key?(:water_unit)
  @weight_unit = args[:weight_unit] if args.key?(:weight_unit)
end