Class: Google::Apis::HealthV4::Settings
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Settings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Settings details.
Instance Attribute Summary collapse
-
#auto_stride_enabled ⇒ Boolean
(also: #auto_stride_enabled?)
Optional.
-
#distance_unit ⇒ String
Optional.
-
#food_language_code ⇒ String
Output only.
-
#glucose_unit ⇒ String
Optional.
-
#height_unit ⇒ String
Optional.
-
#language_locale ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#stride_length_running_type ⇒ String
Optional.
-
#stride_length_walking_type ⇒ String
Optional.
-
#swim_unit ⇒ String
Optional.
-
#temperature_unit ⇒ String
Optional.
-
#time_zone ⇒ String
Optional.
-
#utc_offset ⇒ String
Optional.
-
#water_unit ⇒ String
Optional.
-
#weight_unit ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Settings
constructor
A new instance of Settings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Settings
Returns a new instance of Settings.
5004 5005 5006 |
# File 'lib/google/apis/health_v4/classes.rb', line 5004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_stride_enabled ⇒ Boolean Also known as: auto_stride_enabled?
Optional. True if the user's stride length is determined automatically.
Updates to this field are currently not supported.
Corresponds to the JSON property autoStrideEnabled
4916 4917 4918 |
# File 'lib/google/apis/health_v4/classes.rb', line 4916 def auto_stride_enabled @auto_stride_enabled end |
#distance_unit ⇒ String
Optional. The measurement unit defined in the user's account settings. Updates
to this field are currently not supported.
Corresponds to the JSON property distanceUnit
4923 4924 4925 |
# File 'lib/google/apis/health_v4/classes.rb', line 4923 def distance_unit @distance_unit end |
#food_language_code ⇒ String
Output only. The food language code derived from the user's food database.
Possible values: 'en-US', 'en-GB', 'de-DE', 'es-ES', 'fr-FR', 'zh-
CN', 'zh-TW', 'ja-JP', 'en-AU', 'en-CA', 'it-IT', 'ko-KR', 'es-
MX', 'en-IN', 'en-SG', 'en-PH', 'en-IE', 'fr-CA'. Updates to this
field are currently not supported.
Corresponds to the JSON property foodLanguageCode
4932 4933 4934 |
# File 'lib/google/apis/health_v4/classes.rb', line 4932 def food_language_code @food_language_code end |
#glucose_unit ⇒ String
Optional. The measurement unit defined in the user's account settings.
Corresponds to the JSON property glucoseUnit
4937 4938 4939 |
# File 'lib/google/apis/health_v4/classes.rb', line 4937 def glucose_unit @glucose_unit end |
#height_unit ⇒ String
Optional. The measurement unit defined in the user's account settings.
Corresponds to the JSON property heightUnit
4942 4943 4944 |
# File 'lib/google/apis/health_v4/classes.rb', line 4942 def height_unit @height_unit end |
#language_locale ⇒ String
Optional. The locale defined in the user's account settings. Updates to this
field are currently not supported.
Corresponds to the JSON property languageLocale
4948 4949 4950 |
# File 'lib/google/apis/health_v4/classes.rb', line 4948 def language_locale @language_locale end |
#name ⇒ String
Identifier. The resource name of this Settings resource. Format: users/user/
settings Example: users/1234567890/settings or users/me/settings The
user ID is a system-generated Google Health API user ID, a string of 1-63
characters consisting of lowercase and uppercase letters, numbers, and hyphens.
The literal me can also be used to refer to the authenticated user.
Corresponds to the JSON property name
4957 4958 4959 |
# File 'lib/google/apis/health_v4/classes.rb', line 4957 def name @name end |
#stride_length_running_type ⇒ String
Optional. The stride length type defined in the user's account settings for
running. Updates to this field are currently not supported.
Corresponds to the JSON property strideLengthRunningType
4963 4964 4965 |
# File 'lib/google/apis/health_v4/classes.rb', line 4963 def stride_length_running_type @stride_length_running_type end |
#stride_length_walking_type ⇒ String
Optional. The stride length type defined in the user's account settings for
walking. Updates to this field are currently not supported.
Corresponds to the JSON property strideLengthWalkingType
4969 4970 4971 |
# File 'lib/google/apis/health_v4/classes.rb', line 4969 def stride_length_walking_type @stride_length_walking_type end |
#swim_unit ⇒ String
Optional. The measurement unit defined in the user's account settings.
Corresponds to the JSON property swimUnit
4974 4975 4976 |
# File 'lib/google/apis/health_v4/classes.rb', line 4974 def swim_unit @swim_unit end |
#temperature_unit ⇒ String
Optional. The measurement unit defined in the user's account settings.
Corresponds to the JSON property temperatureUnit
4979 4980 4981 |
# File 'lib/google/apis/health_v4/classes.rb', line 4979 def temperature_unit @temperature_unit end |
#time_zone ⇒ String
Optional. The timezone defined in the user's account settings. This follows
the IANA Time Zone Database. Updates to
this field are currently not supported.
Corresponds to the JSON property timeZone
4986 4987 4988 |
# File 'lib/google/apis/health_v4/classes.rb', line 4986 def time_zone @time_zone end |
#utc_offset ⇒ String
Optional. The user's timezone offset relative to UTC. Updates to this field
are currently not supported.
Corresponds to the JSON property utcOffset
4992 4993 4994 |
# File 'lib/google/apis/health_v4/classes.rb', line 4992 def utc_offset @utc_offset end |
#water_unit ⇒ String
Optional. The measurement unit defined in the user's account settings.
Corresponds to the JSON property waterUnit
4997 4998 4999 |
# File 'lib/google/apis/health_v4/classes.rb', line 4997 def water_unit @water_unit end |
#weight_unit ⇒ String
Optional. The measurement unit defined in the user's account settings.
Corresponds to the JSON property weightUnit
5002 5003 5004 |
# File 'lib/google/apis/health_v4/classes.rb', line 5002 def weight_unit @weight_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 |
# File 'lib/google/apis/health_v4/classes.rb', line 5009 def update!(**args) @auto_stride_enabled = args[:auto_stride_enabled] if args.key?(:auto_stride_enabled) @distance_unit = args[:distance_unit] if args.key?(:distance_unit) @food_language_code = args[:food_language_code] if args.key?(:food_language_code) @glucose_unit = args[:glucose_unit] if args.key?(:glucose_unit) @height_unit = args[:height_unit] if args.key?(:height_unit) @language_locale = args[:language_locale] if args.key?(:language_locale) @name = args[:name] if args.key?(:name) @stride_length_running_type = args[:stride_length_running_type] if args.key?(:stride_length_running_type) @stride_length_walking_type = args[:stride_length_walking_type] if args.key?(:stride_length_walking_type) @swim_unit = args[:swim_unit] if args.key?(:swim_unit) @temperature_unit = args[:temperature_unit] if args.key?(:temperature_unit) @time_zone = args[:time_zone] if args.key?(:time_zone) @utc_offset = args[:utc_offset] if args.key?(:utc_offset) @water_unit = args[:water_unit] if args.key?(:water_unit) @weight_unit = args[:weight_unit] if args.key?(:weight_unit) end |