Class: Google::Apis::HealthV4::Settings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Settings details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Settings

Returns a new instance of Settings.



3593
3594
3595
# File 'lib/google/apis/health_v4/classes.rb', line 3593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_stride_enabledBoolean Also known as: auto_stride_enabled?

Optional. True if the user's stride length is determined automatically. Updates to this field are currently not supported. Corresponds to the JSON property autoStrideEnabled

Returns:

  • (Boolean)


3514
3515
3516
# File 'lib/google/apis/health_v4/classes.rb', line 3514

def auto_stride_enabled
  @auto_stride_enabled
end

#distance_unitString

Optional. The measurement unit defined in the user's account settings. Updates to this field are currently not supported. Corresponds to the JSON property distanceUnit

Returns:

  • (String)


3521
3522
3523
# File 'lib/google/apis/health_v4/classes.rb', line 3521

def distance_unit
  @distance_unit
end

#glucose_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property glucoseUnit

Returns:

  • (String)


3526
3527
3528
# File 'lib/google/apis/health_v4/classes.rb', line 3526

def glucose_unit
  @glucose_unit
end

#height_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property heightUnit

Returns:

  • (String)


3531
3532
3533
# File 'lib/google/apis/health_v4/classes.rb', line 3531

def height_unit
  @height_unit
end

#language_localeString

Optional. The locale defined in the user's account settings. Updates to this field are currently not supported. Corresponds to the JSON property languageLocale

Returns:

  • (String)


3537
3538
3539
# File 'lib/google/apis/health_v4/classes.rb', line 3537

def language_locale
  @language_locale
end

#nameString

Identifier. The resource name of this Settings resource. Format: users/user/ settings Example: users/1234567890/settings or users/me/settings The user ID is a system-generated Google Health API user ID, a string of 1-63 characters consisting of lowercase and uppercase letters, numbers, and hyphens. The literal me can also be used to refer to the authenticated user. Corresponds to the JSON property name

Returns:

  • (String)


3546
3547
3548
# File 'lib/google/apis/health_v4/classes.rb', line 3546

def name
  @name
end

#stride_length_running_typeString

Optional. The stride length type defined in the user's account settings for running. Updates to this field are currently not supported. Corresponds to the JSON property strideLengthRunningType

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/health_v4/classes.rb', line 3552

def stride_length_running_type
  @stride_length_running_type
end

#stride_length_walking_typeString

Optional. The stride length type defined in the user's account settings for walking. Updates to this field are currently not supported. Corresponds to the JSON property strideLengthWalkingType

Returns:

  • (String)


3558
3559
3560
# File 'lib/google/apis/health_v4/classes.rb', line 3558

def stride_length_walking_type
  @stride_length_walking_type
end

#swim_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property swimUnit

Returns:

  • (String)


3563
3564
3565
# File 'lib/google/apis/health_v4/classes.rb', line 3563

def swim_unit
  @swim_unit
end

#temperature_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property temperatureUnit

Returns:

  • (String)


3568
3569
3570
# File 'lib/google/apis/health_v4/classes.rb', line 3568

def temperature_unit
  @temperature_unit
end

#time_zoneString

Optional. The timezone defined in the user's account settings. This follows the IANA Time Zone Database. Updates to this field are currently not supported. Corresponds to the JSON property timeZone

Returns:

  • (String)


3575
3576
3577
# File 'lib/google/apis/health_v4/classes.rb', line 3575

def time_zone
  @time_zone
end

#utc_offsetString

Optional. The user's timezone offset relative to UTC. Updates to this field are currently not supported. Corresponds to the JSON property utcOffset

Returns:

  • (String)


3581
3582
3583
# File 'lib/google/apis/health_v4/classes.rb', line 3581

def utc_offset
  @utc_offset
end

#water_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property waterUnit

Returns:

  • (String)


3586
3587
3588
# File 'lib/google/apis/health_v4/classes.rb', line 3586

def water_unit
  @water_unit
end

#weight_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property weightUnit

Returns:

  • (String)


3591
3592
3593
# File 'lib/google/apis/health_v4/classes.rb', line 3591

def weight_unit
  @weight_unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
# File 'lib/google/apis/health_v4/classes.rb', line 3598

def update!(**args)
  @auto_stride_enabled = args[:auto_stride_enabled] if args.key?(:auto_stride_enabled)
  @distance_unit = args[:distance_unit] if args.key?(:distance_unit)
  @glucose_unit = args[:glucose_unit] if args.key?(:glucose_unit)
  @height_unit = args[:height_unit] if args.key?(:height_unit)
  @language_locale = args[:language_locale] if args.key?(:language_locale)
  @name = args[:name] if args.key?(:name)
  @stride_length_running_type = args[:stride_length_running_type] if args.key?(:stride_length_running_type)
  @stride_length_walking_type = args[:stride_length_walking_type] if args.key?(:stride_length_walking_type)
  @swim_unit = args[:swim_unit] if args.key?(:swim_unit)
  @temperature_unit = args[:temperature_unit] if args.key?(:temperature_unit)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
  @water_unit = args[:water_unit] if args.key?(:water_unit)
  @weight_unit = args[:weight_unit] if args.key?(:weight_unit)
end