Class: Google::Apis::HealthV4::Settings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Settings details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Settings

Returns a new instance of Settings.



3584
3585
3586
# File 'lib/google/apis/health_v4/classes.rb', line 3584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_stride_enabledBoolean Also known as: auto_stride_enabled?

Optional. True if the user's stride length is determined automatically. Updates to this field are currently not supported. Corresponds to the JSON property autoStrideEnabled

Returns:

  • (Boolean)


3505
3506
3507
# File 'lib/google/apis/health_v4/classes.rb', line 3505

def auto_stride_enabled
  @auto_stride_enabled
end

#distance_unitString

Optional. The measurement unit defined in the user's account settings. Updates to this field are currently not supported. Corresponds to the JSON property distanceUnit

Returns:

  • (String)


3512
3513
3514
# File 'lib/google/apis/health_v4/classes.rb', line 3512

def distance_unit
  @distance_unit
end

#glucose_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property glucoseUnit

Returns:

  • (String)


3517
3518
3519
# File 'lib/google/apis/health_v4/classes.rb', line 3517

def glucose_unit
  @glucose_unit
end

#height_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property heightUnit

Returns:

  • (String)


3522
3523
3524
# File 'lib/google/apis/health_v4/classes.rb', line 3522

def height_unit
  @height_unit
end

#language_localeString

Optional. The locale defined in the user's account settings. Updates to this field are currently not supported. Corresponds to the JSON property languageLocale

Returns:

  • (String)


3528
3529
3530
# File 'lib/google/apis/health_v4/classes.rb', line 3528

def language_locale
  @language_locale
end

#nameString

Identifier. The resource name of this Settings resource. Format: users/user/ settings Example: users/1234567890/settings or users/me/settings The user ID is a system-generated Google Health API user ID, a string of 1-63 characters consisting of lowercase and uppercase letters, numbers, and hyphens. The literal me can also be used to refer to the authenticated user. Corresponds to the JSON property name

Returns:

  • (String)


3537
3538
3539
# File 'lib/google/apis/health_v4/classes.rb', line 3537

def name
  @name
end

#stride_length_running_typeString

Optional. The stride length type defined in the user's account settings for running. Updates to this field are currently not supported. Corresponds to the JSON property strideLengthRunningType

Returns:

  • (String)


3543
3544
3545
# File 'lib/google/apis/health_v4/classes.rb', line 3543

def stride_length_running_type
  @stride_length_running_type
end

#stride_length_walking_typeString

Optional. The stride length type defined in the user's account settings for walking. Updates to this field are currently not supported. Corresponds to the JSON property strideLengthWalkingType

Returns:

  • (String)


3549
3550
3551
# File 'lib/google/apis/health_v4/classes.rb', line 3549

def stride_length_walking_type
  @stride_length_walking_type
end

#swim_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property swimUnit

Returns:

  • (String)


3554
3555
3556
# File 'lib/google/apis/health_v4/classes.rb', line 3554

def swim_unit
  @swim_unit
end

#temperature_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property temperatureUnit

Returns:

  • (String)


3559
3560
3561
# File 'lib/google/apis/health_v4/classes.rb', line 3559

def temperature_unit
  @temperature_unit
end

#time_zoneString

Optional. The timezone defined in the user's account settings. This follows the IANA Time Zone Database. Updates to this field are currently not supported. Corresponds to the JSON property timeZone

Returns:

  • (String)


3566
3567
3568
# File 'lib/google/apis/health_v4/classes.rb', line 3566

def time_zone
  @time_zone
end

#utc_offsetString

Optional. The user's timezone offset relative to UTC. Updates to this field are currently not supported. Corresponds to the JSON property utcOffset

Returns:

  • (String)


3572
3573
3574
# File 'lib/google/apis/health_v4/classes.rb', line 3572

def utc_offset
  @utc_offset
end

#water_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property waterUnit

Returns:

  • (String)


3577
3578
3579
# File 'lib/google/apis/health_v4/classes.rb', line 3577

def water_unit
  @water_unit
end

#weight_unitString

Optional. The measurement unit defined in the user's account settings. Corresponds to the JSON property weightUnit

Returns:

  • (String)


3582
3583
3584
# File 'lib/google/apis/health_v4/classes.rb', line 3582

def weight_unit
  @weight_unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
# File 'lib/google/apis/health_v4/classes.rb', line 3589

def update!(**args)
  @auto_stride_enabled = args[:auto_stride_enabled] if args.key?(:auto_stride_enabled)
  @distance_unit = args[:distance_unit] if args.key?(:distance_unit)
  @glucose_unit = args[:glucose_unit] if args.key?(:glucose_unit)
  @height_unit = args[:height_unit] if args.key?(:height_unit)
  @language_locale = args[:language_locale] if args.key?(:language_locale)
  @name = args[:name] if args.key?(:name)
  @stride_length_running_type = args[:stride_length_running_type] if args.key?(:stride_length_running_type)
  @stride_length_walking_type = args[:stride_length_walking_type] if args.key?(:stride_length_walking_type)
  @swim_unit = args[:swim_unit] if args.key?(:swim_unit)
  @temperature_unit = args[:temperature_unit] if args.key?(:temperature_unit)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
  @water_unit = args[:water_unit] if args.key?(:water_unit)
  @weight_unit = args[:weight_unit] if args.key?(:weight_unit)
end