Class: Google::Apis::HealthV4::SleepMetadata
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SleepMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Additional information about how the sleep was processed.
Instance Attribute Summary collapse
-
#external_id ⇒ String
Optional.
-
#manually_edited ⇒ Boolean
(also: #manually_edited?)
Output only.
-
#nap ⇒ Boolean
(also: #nap?)
Output only.
-
#processed ⇒ Boolean
(also: #processed?)
Output only.
-
#stages_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SleepMetadata
constructor
A new instance of SleepMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SleepMetadata
Returns a new instance of SleepMetadata.
5041 5042 5043 |
# File 'lib/google/apis/health_v4/classes.rb', line 5041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_id ⇒ String
Optional. Sleep identifier relevant in the context of the data source.
Corresponds to the JSON property externalId
5015 5016 5017 |
# File 'lib/google/apis/health_v4/classes.rb', line 5015 def external_id @external_id end |
#manually_edited ⇒ Boolean Also known as: manually_edited?
Output only. Some sleeps autodetected by algorithms can be manually edited by
users.
Corresponds to the JSON property manuallyEdited
5021 5022 5023 |
# File 'lib/google/apis/health_v4/classes.rb', line 5021 def manually_edited @manually_edited end |
#nap ⇒ Boolean Also known as: nap?
Output only. Naps are sleeps without stages and relatively short durations.
Corresponds to the JSON property nap
5027 5028 5029 |
# File 'lib/google/apis/health_v4/classes.rb', line 5027 def nap @nap end |
#processed ⇒ Boolean Also known as: processed?
Output only. Sleep and sleep stages algorithms finished processing.
Corresponds to the JSON property processed
5033 5034 5035 |
# File 'lib/google/apis/health_v4/classes.rb', line 5033 def processed @processed end |
#stages_status ⇒ String
Output only. Sleep stages algorithm processing status.
Corresponds to the JSON property stagesStatus
5039 5040 5041 |
# File 'lib/google/apis/health_v4/classes.rb', line 5039 def stages_status @stages_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5046 5047 5048 5049 5050 5051 5052 |
# File 'lib/google/apis/health_v4/classes.rb', line 5046 def update!(**args) @external_id = args[:external_id] if args.key?(:external_id) @manually_edited = args[:manually_edited] if args.key?(:manually_edited) @nap = args[:nap] if args.key?(:nap) @processed = args[:processed] if args.key?(:processed) @stages_status = args[:stages_status] if args.key?(:stages_status) end |