Class: Google::Apis::HealthV4::SleepMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Additional information about how the sleep was processed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SleepMetadata

Returns a new instance of SleepMetadata.



3703
3704
3705
# File 'lib/google/apis/health_v4/classes.rb', line 3703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_idString

Optional. Sleep identifier relevant in the context of the data source. Corresponds to the JSON property externalId

Returns:

  • (String)


3677
3678
3679
# File 'lib/google/apis/health_v4/classes.rb', line 3677

def external_id
  @external_id
end

#manually_editedBoolean Also known as: manually_edited?

Output only. Some sleeps autodetected by algorithms can be manually edited by users. Corresponds to the JSON property manuallyEdited

Returns:

  • (Boolean)


3683
3684
3685
# File 'lib/google/apis/health_v4/classes.rb', line 3683

def manually_edited
  @manually_edited
end

#napBoolean Also known as: nap?

Output only. Naps are sleeps without stages and relatively short durations. Corresponds to the JSON property nap

Returns:

  • (Boolean)


3689
3690
3691
# File 'lib/google/apis/health_v4/classes.rb', line 3689

def nap
  @nap
end

#processedBoolean Also known as: processed?

Output only. Sleep and sleep stages algorithms finished processing. Corresponds to the JSON property processed

Returns:

  • (Boolean)


3695
3696
3697
# File 'lib/google/apis/health_v4/classes.rb', line 3695

def processed
  @processed
end

#stages_statusString

Output only. Sleep stages algorithm processing status. Corresponds to the JSON property stagesStatus

Returns:

  • (String)


3701
3702
3703
# File 'lib/google/apis/health_v4/classes.rb', line 3701

def stages_status
  @stages_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3708
3709
3710
3711
3712
3713
3714
# File 'lib/google/apis/health_v4/classes.rb', line 3708

def update!(**args)
  @external_id = args[:external_id] if args.key?(:external_id)
  @manually_edited = args[:manually_edited] if args.key?(:manually_edited)
  @nap = args[:nap] if args.key?(:nap)
  @processed = args[:processed] if args.key?(:processed)
  @stages_status = args[:stages_status] if args.key?(:stages_status)
end