Class: Google::Apis::HealthV4::SleepStage
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SleepStage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Sleep stage segment.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Required.
-
#end_utc_offset ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#start_utc_offset ⇒ String
Required.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SleepStage
constructor
A new instance of SleepStage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SleepStage
Returns a new instance of SleepStage.
5323 5324 5325 |
# File 'lib/google/apis/health_v4/classes.rb', line 5323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Creation time of this sleep stages segment.
Corresponds to the JSON property createTime
5289 5290 5291 |
# File 'lib/google/apis/health_v4/classes.rb', line 5289 def create_time @create_time end |
#end_time ⇒ String
Required. Sleep stage end time.
Corresponds to the JSON property endTime
5294 5295 5296 |
# File 'lib/google/apis/health_v4/classes.rb', line 5294 def end_time @end_time end |
#end_utc_offset ⇒ String
Required. The offset of the user's local time at the end of the sleep stage
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property endUtcOffset
5300 5301 5302 |
# File 'lib/google/apis/health_v4/classes.rb', line 5300 def end_utc_offset @end_utc_offset end |
#start_time ⇒ String
Required. Sleep stage start time.
Corresponds to the JSON property startTime
5305 5306 5307 |
# File 'lib/google/apis/health_v4/classes.rb', line 5305 def start_time @start_time end |
#start_utc_offset ⇒ String
Required. The offset of the user's local time at the start of the sleep stage
relative to the Coordinated Universal Time (UTC).
Corresponds to the JSON property startUtcOffset
5311 5312 5313 |
# File 'lib/google/apis/health_v4/classes.rb', line 5311 def start_utc_offset @start_utc_offset end |
#type ⇒ String
Required. Sleep stage type: AWAKE, DEEP, REM, LIGHT etc.
Corresponds to the JSON property type
5316 5317 5318 |
# File 'lib/google/apis/health_v4/classes.rb', line 5316 def type @type end |
#update_time ⇒ String
Output only. Last update time of this sleep stages segment.
Corresponds to the JSON property updateTime
5321 5322 5323 |
# File 'lib/google/apis/health_v4/classes.rb', line 5321 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5328 5329 5330 5331 5332 5333 5334 5335 5336 |
# File 'lib/google/apis/health_v4/classes.rb', line 5328 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset) @start_time = args[:start_time] if args.key?(:start_time) @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |