Class: Google::Apis::HealthV4::SleepStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Sleep stage segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SleepStage

Returns a new instance of SleepStage.



5182
5183
5184
# File 'lib/google/apis/health_v4/classes.rb', line 5182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this sleep stages segment. Corresponds to the JSON property createTime

Returns:

  • (String)


5148
5149
5150
# File 'lib/google/apis/health_v4/classes.rb', line 5148

def create_time
  @create_time
end

#end_timeString

Required. Sleep stage end time. Corresponds to the JSON property endTime

Returns:

  • (String)


5153
5154
5155
# File 'lib/google/apis/health_v4/classes.rb', line 5153

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the sleep stage relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


5159
5160
5161
# File 'lib/google/apis/health_v4/classes.rb', line 5159

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. Sleep stage start time. Corresponds to the JSON property startTime

Returns:

  • (String)


5164
5165
5166
# File 'lib/google/apis/health_v4/classes.rb', line 5164

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the sleep stage relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


5170
5171
5172
# File 'lib/google/apis/health_v4/classes.rb', line 5170

def start_utc_offset
  @start_utc_offset
end

#typeString

Required. Sleep stage type: AWAKE, DEEP, REM, LIGHT etc. Corresponds to the JSON property type

Returns:

  • (String)


5175
5176
5177
# File 'lib/google/apis/health_v4/classes.rb', line 5175

def type
  @type
end

#update_timeString

Output only. Last update time of this sleep stages segment. Corresponds to the JSON property updateTime

Returns:

  • (String)


5180
5181
5182
# File 'lib/google/apis/health_v4/classes.rb', line 5180

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5187
5188
5189
5190
5191
5192
5193
5194
5195
# File 'lib/google/apis/health_v4/classes.rb', line 5187

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end