Class: Google::Apis::HealthV4::SleepStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Sleep stage segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SleepStage

Returns a new instance of SleepStage.



5096
5097
5098
# File 'lib/google/apis/health_v4/classes.rb', line 5096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this sleep stages segment. Corresponds to the JSON property createTime

Returns:

  • (String)


5062
5063
5064
# File 'lib/google/apis/health_v4/classes.rb', line 5062

def create_time
  @create_time
end

#end_timeString

Required. Sleep stage end time. Corresponds to the JSON property endTime

Returns:

  • (String)


5067
5068
5069
# File 'lib/google/apis/health_v4/classes.rb', line 5067

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the sleep stage relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


5073
5074
5075
# File 'lib/google/apis/health_v4/classes.rb', line 5073

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. Sleep stage start time. Corresponds to the JSON property startTime

Returns:

  • (String)


5078
5079
5080
# File 'lib/google/apis/health_v4/classes.rb', line 5078

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the sleep stage relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


5084
5085
5086
# File 'lib/google/apis/health_v4/classes.rb', line 5084

def start_utc_offset
  @start_utc_offset
end

#typeString

Required. Sleep stage type: AWAKE, DEEP, REM, LIGHT etc. Corresponds to the JSON property type

Returns:

  • (String)


5089
5090
5091
# File 'lib/google/apis/health_v4/classes.rb', line 5089

def type
  @type
end

#update_timeString

Output only. Last update time of this sleep stages segment. Corresponds to the JSON property updateTime

Returns:

  • (String)


5094
5095
5096
# File 'lib/google/apis/health_v4/classes.rb', line 5094

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5101
5102
5103
5104
5105
5106
5107
5108
5109
# File 'lib/google/apis/health_v4/classes.rb', line 5101

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end