Class: Google::Apis::HealthV4::SleepStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Sleep stage segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SleepStage

Returns a new instance of SleepStage.



3767
3768
3769
# File 'lib/google/apis/health_v4/classes.rb', line 3767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation time of this sleep stages segment. Corresponds to the JSON property createTime

Returns:

  • (String)


3733
3734
3735
# File 'lib/google/apis/health_v4/classes.rb', line 3733

def create_time
  @create_time
end

#end_timeString

Required. Sleep stage end time. Corresponds to the JSON property endTime

Returns:

  • (String)


3738
3739
3740
# File 'lib/google/apis/health_v4/classes.rb', line 3738

def end_time
  @end_time
end

#end_utc_offsetString

Required. The offset of the user's local time at the end of the sleep stage relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


3744
3745
3746
# File 'lib/google/apis/health_v4/classes.rb', line 3744

def end_utc_offset
  @end_utc_offset
end

#start_timeString

Required. Sleep stage start time. Corresponds to the JSON property startTime

Returns:

  • (String)


3749
3750
3751
# File 'lib/google/apis/health_v4/classes.rb', line 3749

def start_time
  @start_time
end

#start_utc_offsetString

Required. The offset of the user's local time at the start of the sleep stage relative to the Coordinated Universal Time (UTC). Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


3755
3756
3757
# File 'lib/google/apis/health_v4/classes.rb', line 3755

def start_utc_offset
  @start_utc_offset
end

#typeString

Required. Sleep stage type: AWAKE, DEEP, REM, LIGHT etc. Corresponds to the JSON property type

Returns:

  • (String)


3760
3761
3762
# File 'lib/google/apis/health_v4/classes.rb', line 3760

def type
  @type
end

#update_timeString

Output only. Last update time of this sleep stages segment. Corresponds to the JSON property updateTime

Returns:

  • (String)


3765
3766
3767
# File 'lib/google/apis/health_v4/classes.rb', line 3765

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3772
3773
3774
3775
3776
3777
3778
3779
3780
# File 'lib/google/apis/health_v4/classes.rb', line 3772

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end