Class: Google::Apis::HealthV4::SplitSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents splits or laps recorded within an exercise. Lap events partition a workout into segments based on criteria like distance, time, or calories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitSummary

Returns a new instance of SplitSummary.



5311
5312
5313
# File 'lib/google/apis/health_v4/classes.rb', line 5311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_durationString

Output only. Lap time excluding the pauses. Corresponds to the JSON property activeDuration

Returns:

  • (String)


5278
5279
5280
# File 'lib/google/apis/health_v4/classes.rb', line 5278

def active_duration
  @active_duration
end

#end_timeString

Required. Lap end time Corresponds to the JSON property endTime

Returns:

  • (String)


5283
5284
5285
# File 'lib/google/apis/health_v4/classes.rb', line 5283

def end_time
  @end_time
end

#end_utc_offsetString

Required. Lap end time offset from UTC Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


5288
5289
5290
# File 'lib/google/apis/health_v4/classes.rb', line 5288

def end_utc_offset
  @end_utc_offset
end

#metrics_summaryGoogle::Apis::HealthV4::MetricsSummary

Summary metrics for an exercise. Corresponds to the JSON property metricsSummary



5293
5294
5295
# File 'lib/google/apis/health_v4/classes.rb', line 5293

def metrics_summary
  @metrics_summary
end

#split_typeString

Required. Method used to split the exercise laps. Users may manually mark the lap as complete even if the tracking is automatic. Corresponds to the JSON property splitType

Returns:

  • (String)


5299
5300
5301
# File 'lib/google/apis/health_v4/classes.rb', line 5299

def split_type
  @split_type
end

#start_timeString

Required. Lap start time Corresponds to the JSON property startTime

Returns:

  • (String)


5304
5305
5306
# File 'lib/google/apis/health_v4/classes.rb', line 5304

def start_time
  @start_time
end

#start_utc_offsetString

Required. Lap start time offset from UTC Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


5309
5310
5311
# File 'lib/google/apis/health_v4/classes.rb', line 5309

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5316
5317
5318
5319
5320
5321
5322
5323
5324
# File 'lib/google/apis/health_v4/classes.rb', line 5316

def update!(**args)
  @active_duration = args[:active_duration] if args.key?(:active_duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @metrics_summary = args[:metrics_summary] if args.key?(:metrics_summary)
  @split_type = args[:split_type] if args.key?(:split_type)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end