Class: Google::Apis::HealthV4::SplitSummary
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SplitSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents splits or laps recorded within an exercise. Lap events partition a workout into segments based on criteria like distance, time, or calories.
Instance Attribute Summary collapse
-
#active_duration ⇒ String
Output only.
-
#end_time ⇒ String
Required.
-
#end_utc_offset ⇒ String
Required.
-
#metrics_summary ⇒ Google::Apis::HealthV4::MetricsSummary
Summary metrics for an exercise.
-
#split_type ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#start_utc_offset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SplitSummary
constructor
A new instance of SplitSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SplitSummary
Returns a new instance of SplitSummary.
5291 5292 5293 |
# File 'lib/google/apis/health_v4/classes.rb', line 5291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_duration ⇒ String
Output only. Lap time excluding the pauses.
Corresponds to the JSON property activeDuration
5258 5259 5260 |
# File 'lib/google/apis/health_v4/classes.rb', line 5258 def active_duration @active_duration end |
#end_time ⇒ String
Required. Lap end time
Corresponds to the JSON property endTime
5263 5264 5265 |
# File 'lib/google/apis/health_v4/classes.rb', line 5263 def end_time @end_time end |
#end_utc_offset ⇒ String
Required. Lap end time offset from UTC
Corresponds to the JSON property endUtcOffset
5268 5269 5270 |
# File 'lib/google/apis/health_v4/classes.rb', line 5268 def end_utc_offset @end_utc_offset end |
#metrics_summary ⇒ Google::Apis::HealthV4::MetricsSummary
Summary metrics for an exercise.
Corresponds to the JSON property metricsSummary
5273 5274 5275 |
# File 'lib/google/apis/health_v4/classes.rb', line 5273 def metrics_summary @metrics_summary end |
#split_type ⇒ String
Required. Method used to split the exercise laps. Users may manually mark the
lap as complete even if the tracking is automatic.
Corresponds to the JSON property splitType
5279 5280 5281 |
# File 'lib/google/apis/health_v4/classes.rb', line 5279 def split_type @split_type end |
#start_time ⇒ String
Required. Lap start time
Corresponds to the JSON property startTime
5284 5285 5286 |
# File 'lib/google/apis/health_v4/classes.rb', line 5284 def start_time @start_time end |
#start_utc_offset ⇒ String
Required. Lap start time offset from UTC
Corresponds to the JSON property startUtcOffset
5289 5290 5291 |
# File 'lib/google/apis/health_v4/classes.rb', line 5289 def start_utc_offset @start_utc_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5296 5297 5298 5299 5300 5301 5302 5303 5304 |
# File 'lib/google/apis/health_v4/classes.rb', line 5296 def update!(**args) @active_duration = args[:active_duration] if args.key?(:active_duration) @end_time = args[:end_time] if args.key?(:end_time) @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset) @metrics_summary = args[:metrics_summary] if args.key?(:metrics_summary) @split_type = args[:split_type] if args.key?(:split_type) @start_time = args[:start_time] if args.key?(:start_time) @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset) end |