Class: Google::Apis::HealthV4::SplitSummary
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SplitSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents splits or laps recorded within an exercise. Lap events partition a workout into segments based on criteria like distance, time, or calories.
Instance Attribute Summary collapse
-
#active_duration ⇒ String
Output only.
-
#end_time ⇒ String
Required.
-
#end_utc_offset ⇒ String
Required.
-
#metrics_summary ⇒ Google::Apis::HealthV4::MetricsSummary
Summary metrics for an exercise.
-
#split_type ⇒ String
Required.
-
#start_time ⇒ String
Required.
-
#start_utc_offset ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SplitSummary
constructor
A new instance of SplitSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SplitSummary
Returns a new instance of SplitSummary.
5208 5209 5210 |
# File 'lib/google/apis/health_v4/classes.rb', line 5208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_duration ⇒ String
Output only. Lap time excluding the pauses.
Corresponds to the JSON property activeDuration
5175 5176 5177 |
# File 'lib/google/apis/health_v4/classes.rb', line 5175 def active_duration @active_duration end |
#end_time ⇒ String
Required. Lap end time
Corresponds to the JSON property endTime
5180 5181 5182 |
# File 'lib/google/apis/health_v4/classes.rb', line 5180 def end_time @end_time end |
#end_utc_offset ⇒ String
Required. Lap end time offset from UTC
Corresponds to the JSON property endUtcOffset
5185 5186 5187 |
# File 'lib/google/apis/health_v4/classes.rb', line 5185 def end_utc_offset @end_utc_offset end |
#metrics_summary ⇒ Google::Apis::HealthV4::MetricsSummary
Summary metrics for an exercise.
Corresponds to the JSON property metricsSummary
5190 5191 5192 |
# File 'lib/google/apis/health_v4/classes.rb', line 5190 def metrics_summary @metrics_summary end |
#split_type ⇒ String
Required. Method used to split the exercise laps. Users may manually mark the
lap as complete even if the tracking is automatic.
Corresponds to the JSON property splitType
5196 5197 5198 |
# File 'lib/google/apis/health_v4/classes.rb', line 5196 def split_type @split_type end |
#start_time ⇒ String
Required. Lap start time
Corresponds to the JSON property startTime
5201 5202 5203 |
# File 'lib/google/apis/health_v4/classes.rb', line 5201 def start_time @start_time end |
#start_utc_offset ⇒ String
Required. Lap start time offset from UTC
Corresponds to the JSON property startUtcOffset
5206 5207 5208 |
# File 'lib/google/apis/health_v4/classes.rb', line 5206 def start_utc_offset @start_utc_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5213 5214 5215 5216 5217 5218 5219 5220 5221 |
# File 'lib/google/apis/health_v4/classes.rb', line 5213 def update!(**args) @active_duration = args[:active_duration] if args.key?(:active_duration) @end_time = args[:end_time] if args.key?(:end_time) @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset) @metrics_summary = args[:metrics_summary] if args.key?(:metrics_summary) @split_type = args[:split_type] if args.key?(:split_type) @start_time = args[:start_time] if args.key?(:start_time) @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset) end |