Class: Google::Apis::HealthV4::SplitSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents splits or laps recorded within an exercise. Lap events partition a workout into segments based on criteria like distance, time, or calories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitSummary

Returns a new instance of SplitSummary.



5205
5206
5207
# File 'lib/google/apis/health_v4/classes.rb', line 5205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_durationString

Output only. Lap time excluding the pauses. Corresponds to the JSON property activeDuration

Returns:

  • (String)


5172
5173
5174
# File 'lib/google/apis/health_v4/classes.rb', line 5172

def active_duration
  @active_duration
end

#end_timeString

Required. Lap end time Corresponds to the JSON property endTime

Returns:

  • (String)


5177
5178
5179
# File 'lib/google/apis/health_v4/classes.rb', line 5177

def end_time
  @end_time
end

#end_utc_offsetString

Required. Lap end time offset from UTC Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


5182
5183
5184
# File 'lib/google/apis/health_v4/classes.rb', line 5182

def end_utc_offset
  @end_utc_offset
end

#metrics_summaryGoogle::Apis::HealthV4::MetricsSummary

Summary metrics for an exercise. Corresponds to the JSON property metricsSummary



5187
5188
5189
# File 'lib/google/apis/health_v4/classes.rb', line 5187

def metrics_summary
  @metrics_summary
end

#split_typeString

Required. Method used to split the exercise laps. Users may manually mark the lap as complete even if the tracking is automatic. Corresponds to the JSON property splitType

Returns:

  • (String)


5193
5194
5195
# File 'lib/google/apis/health_v4/classes.rb', line 5193

def split_type
  @split_type
end

#start_timeString

Required. Lap start time Corresponds to the JSON property startTime

Returns:

  • (String)


5198
5199
5200
# File 'lib/google/apis/health_v4/classes.rb', line 5198

def start_time
  @start_time
end

#start_utc_offsetString

Required. Lap start time offset from UTC Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


5203
5204
5205
# File 'lib/google/apis/health_v4/classes.rb', line 5203

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5210
5211
5212
5213
5214
5215
5216
5217
5218
# File 'lib/google/apis/health_v4/classes.rb', line 5210

def update!(**args)
  @active_duration = args[:active_duration] if args.key?(:active_duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @metrics_summary = args[:metrics_summary] if args.key?(:metrics_summary)
  @split_type = args[:split_type] if args.key?(:split_type)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end