Class: Google::Apis::HealthV4::SplitSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents splits or laps recorded within an exercise. Lap events partition a workout into segments based on criteria like distance, time, or calories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitSummary

Returns a new instance of SplitSummary.



3867
3868
3869
# File 'lib/google/apis/health_v4/classes.rb', line 3867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_durationString

Output only. Lap time excluding the pauses. Corresponds to the JSON property activeDuration

Returns:

  • (String)


3834
3835
3836
# File 'lib/google/apis/health_v4/classes.rb', line 3834

def active_duration
  @active_duration
end

#end_timeString

Required. Lap end time Corresponds to the JSON property endTime

Returns:

  • (String)


3839
3840
3841
# File 'lib/google/apis/health_v4/classes.rb', line 3839

def end_time
  @end_time
end

#end_utc_offsetString

Required. Lap end time offset from UTC Corresponds to the JSON property endUtcOffset

Returns:

  • (String)


3844
3845
3846
# File 'lib/google/apis/health_v4/classes.rb', line 3844

def end_utc_offset
  @end_utc_offset
end

#metrics_summaryGoogle::Apis::HealthV4::MetricsSummary

Summary metrics for an exercise. Corresponds to the JSON property metricsSummary



3849
3850
3851
# File 'lib/google/apis/health_v4/classes.rb', line 3849

def metrics_summary
  @metrics_summary
end

#split_typeString

Required. Method used to split the exercise laps. Users may manually mark the lap as complete even if the tracking is automatic. Corresponds to the JSON property splitType

Returns:

  • (String)


3855
3856
3857
# File 'lib/google/apis/health_v4/classes.rb', line 3855

def split_type
  @split_type
end

#start_timeString

Required. Lap start time Corresponds to the JSON property startTime

Returns:

  • (String)


3860
3861
3862
# File 'lib/google/apis/health_v4/classes.rb', line 3860

def start_time
  @start_time
end

#start_utc_offsetString

Required. Lap start time offset from UTC Corresponds to the JSON property startUtcOffset

Returns:

  • (String)


3865
3866
3867
# File 'lib/google/apis/health_v4/classes.rb', line 3865

def start_utc_offset
  @start_utc_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3872
3873
3874
3875
3876
3877
3878
3879
3880
# File 'lib/google/apis/health_v4/classes.rb', line 3872

def update!(**args)
  @active_duration = args[:active_duration] if args.key?(:active_duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @end_utc_offset = args[:end_utc_offset] if args.key?(:end_utc_offset)
  @metrics_summary = args[:metrics_summary] if args.key?(:metrics_summary)
  @split_type = args[:split_type] if args.key?(:split_type)
  @start_time = args[:start_time] if args.key?(:start_time)
  @start_utc_offset = args[:start_utc_offset] if args.key?(:start_utc_offset)
end