Class: Google::Apis::HealthV4::SubscriberConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Configuration for a subscriber. A notification is sent to a subscription ONLY if the subscriber has a config for the data type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriberConfig

Returns a new instance of SubscriberConfig.



4094
4095
4096
# File 'lib/google/apis/health_v4/classes.rb', line 4094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typesArray<String>

Required. See Google Health API data types for the list of supported data types. Values should be in kebab-case. Corresponds to the JSON property dataTypes

Returns:

  • (Array<String>)


4087
4088
4089
# File 'lib/google/apis/health_v4/classes.rb', line 4087

def data_types
  @data_types
end

#subscription_create_policyString

Required. Policy for subscription creation. Corresponds to the JSON property subscriptionCreatePolicy

Returns:

  • (String)


4092
4093
4094
# File 'lib/google/apis/health_v4/classes.rb', line 4092

def subscription_create_policy
  @subscription_create_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4099
4100
4101
4102
# File 'lib/google/apis/health_v4/classes.rb', line 4099

def update!(**args)
  @data_types = args[:data_types] if args.key?(:data_types)
  @subscription_create_policy = args[:subscription_create_policy] if args.key?(:subscription_create_policy)
end