Class: Google::Apis::HealthV4::SwimLengthsData
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::SwimLengthsData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Swim lengths data over the time interval.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
-
#stroke_count ⇒ Fixnum
Required.
-
#swim_stroke_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SwimLengthsData
constructor
A new instance of SwimLengthsData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SwimLengthsData
Returns a new instance of SwimLengthsData.
4053 4054 4055 |
# File 'lib/google/apis/health_v4/classes.rb', line 4053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
4041 4042 4043 |
# File 'lib/google/apis/health_v4/classes.rb', line 4041 def interval @interval end |
#stroke_count ⇒ Fixnum
Required. Number of strokes in the lap.
Corresponds to the JSON property strokeCount
4046 4047 4048 |
# File 'lib/google/apis/health_v4/classes.rb', line 4046 def stroke_count @stroke_count end |
#swim_stroke_type ⇒ String
Required. Swim stroke type.
Corresponds to the JSON property swimStrokeType
4051 4052 4053 |
# File 'lib/google/apis/health_v4/classes.rb', line 4051 def swim_stroke_type @swim_stroke_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4058 4059 4060 4061 4062 |
# File 'lib/google/apis/health_v4/classes.rb', line 4058 def update!(**args) @interval = args[:interval] if args.key?(:interval) @stroke_count = args[:stroke_count] if args.key?(:stroke_count) @swim_stroke_type = args[:swim_stroke_type] if args.key?(:swim_stroke_type) end |