Class: Google::Apis::HealthV4::TimeInHeartRateZone

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Time in heart rate zone record. It's an interval spent in specific heart rate zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeInHeartRateZone

Returns a new instance of TimeInHeartRateZone.



4170
4171
4172
# File 'lib/google/apis/health_v4/classes.rb', line 4170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#heart_rate_zone_typeString

Required. Heart rate zone type. Corresponds to the JSON property heartRateZoneType

Returns:

  • (String)


4163
4164
4165
# File 'lib/google/apis/health_v4/classes.rb', line 4163

def heart_rate_zone_type
  @heart_rate_zone_type
end

#intervalGoogle::Apis::HealthV4::ObservationTimeInterval

Represents a time interval of an observed data point. Corresponds to the JSON property interval



4168
4169
4170
# File 'lib/google/apis/health_v4/classes.rb', line 4168

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4175
4176
4177
4178
# File 'lib/google/apis/health_v4/classes.rb', line 4175

def update!(**args)
  @heart_rate_zone_type = args[:heart_rate_zone_type] if args.key?(:heart_rate_zone_type)
  @interval = args[:interval] if args.key?(:interval)
end