Class: Google::Apis::HealthV4::TimeInHeartRateZone
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::TimeInHeartRateZone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Time in heart rate zone record. It's an interval spent in specific heart rate zone.
Instance Attribute Summary collapse
-
#heart_rate_zone_type ⇒ String
Required.
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeInHeartRateZone
constructor
A new instance of TimeInHeartRateZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeInHeartRateZone
Returns a new instance of TimeInHeartRateZone.
4160 4161 4162 |
# File 'lib/google/apis/health_v4/classes.rb', line 4160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#heart_rate_zone_type ⇒ String
Required. Heart rate zone type.
Corresponds to the JSON property heartRateZoneType
4153 4154 4155 |
# File 'lib/google/apis/health_v4/classes.rb', line 4153 def heart_rate_zone_type @heart_rate_zone_type end |
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
4158 4159 4160 |
# File 'lib/google/apis/health_v4/classes.rb', line 4158 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4165 4166 4167 4168 |
# File 'lib/google/apis/health_v4/classes.rb', line 4165 def update!(**args) @heart_rate_zone_type = args[:heart_rate_zone_type] if args.key?(:heart_rate_zone_type) @interval = args[:interval] if args.key?(:interval) end |