Class: Google::Apis::HealthV4::TimeInHeartRateZone
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::TimeInHeartRateZone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Time in heart rate zone record. It's an interval spent in specific heart rate zone.
Instance Attribute Summary collapse
-
#heart_rate_zone_type ⇒ String
Required.
-
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeInHeartRateZone
constructor
A new instance of TimeInHeartRateZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeInHeartRateZone
Returns a new instance of TimeInHeartRateZone.
4099 4100 4101 |
# File 'lib/google/apis/health_v4/classes.rb', line 4099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#heart_rate_zone_type ⇒ String
Required. Heart rate zone type.
Corresponds to the JSON property heartRateZoneType
4092 4093 4094 |
# File 'lib/google/apis/health_v4/classes.rb', line 4092 def heart_rate_zone_type @heart_rate_zone_type end |
#interval ⇒ Google::Apis::HealthV4::ObservationTimeInterval
Represents a time interval of an observed data point.
Corresponds to the JSON property interval
4097 4098 4099 |
# File 'lib/google/apis/health_v4/classes.rb', line 4097 def interval @interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4104 4105 4106 4107 |
# File 'lib/google/apis/health_v4/classes.rb', line 4104 def update!(**args) @heart_rate_zone_type = args[:heart_rate_zone_type] if args.key?(:heart_rate_zone_type) @interval = args[:interval] if args.key?(:interval) end |