Class: Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the result of the rollup of the time in heart rate zone data type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeInHeartRateZoneRollupValue

Returns a new instance of TimeInHeartRateZoneRollupValue.



5565
5566
5567
# File 'lib/google/apis/health_v4/classes.rb', line 5565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_in_heart_rate_zonesArray<Google::Apis::HealthV4::TimeInHeartRateZoneValue>

List of time spent in each heart rate zone. Corresponds to the JSON property timeInHeartRateZones



5563
5564
5565
# File 'lib/google/apis/health_v4/classes.rb', line 5563

def time_in_heart_rate_zones
  @time_in_heart_rate_zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5570
5571
5572
# File 'lib/google/apis/health_v4/classes.rb', line 5570

def update!(**args)
  @time_in_heart_rate_zones = args[:time_in_heart_rate_zones] if args.key?(:time_in_heart_rate_zones)
end