Class: Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::TimeInHeartRateZoneRollupValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the result of the rollup of the time in heart rate zone data type.
Instance Attribute Summary collapse
-
#time_in_heart_rate_zones ⇒ Array<Google::Apis::HealthV4::TimeInHeartRateZoneValue>
List of time spent in each heart rate zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeInHeartRateZoneRollupValue
constructor
A new instance of TimeInHeartRateZoneRollupValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeInHeartRateZoneRollupValue
Returns a new instance of TimeInHeartRateZoneRollupValue.
4119 4120 4121 |
# File 'lib/google/apis/health_v4/classes.rb', line 4119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#time_in_heart_rate_zones ⇒ Array<Google::Apis::HealthV4::TimeInHeartRateZoneValue>
List of time spent in each heart rate zone.
Corresponds to the JSON property timeInHeartRateZones
4117 4118 4119 |
# File 'lib/google/apis/health_v4/classes.rb', line 4117 def time_in_heart_rate_zones @time_in_heart_rate_zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4124 4125 4126 |
# File 'lib/google/apis/health_v4/classes.rb', line 4124 def update!(**args) @time_in_heart_rate_zones = args[:time_in_heart_rate_zones] if args.key?(:time_in_heart_rate_zones) end |