Class: Google::Apis::HealthV4::TimeInHeartRateZoneValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the total time spent in a specific heart rate zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeInHeartRateZoneValue

Returns a new instance of TimeInHeartRateZoneValue.



5592
5593
5594
# File 'lib/google/apis/health_v4/classes.rb', line 5592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The total time spent in the specified heart rate zone. Corresponds to the JSON property duration

Returns:

  • (String)


5585
5586
5587
# File 'lib/google/apis/health_v4/classes.rb', line 5585

def duration
  @duration
end

#heart_rate_zoneString

The heart rate zone. Corresponds to the JSON property heartRateZone

Returns:

  • (String)


5590
5591
5592
# File 'lib/google/apis/health_v4/classes.rb', line 5590

def heart_rate_zone
  @heart_rate_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5597
5598
5599
5600
# File 'lib/google/apis/health_v4/classes.rb', line 5597

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone)
end