Class: Google::Apis::HealthV4::TimeInHeartRateZoneValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::TimeInHeartRateZoneValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the total time spent in a specific heart rate zone.
Instance Attribute Summary collapse
-
#duration ⇒ String
The total time spent in the specified heart rate zone.
-
#heart_rate_zone ⇒ String
The heart rate zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeInHeartRateZoneValue
constructor
A new instance of TimeInHeartRateZoneValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeInHeartRateZoneValue
Returns a new instance of TimeInHeartRateZoneValue.
4214 4215 4216 |
# File 'lib/google/apis/health_v4/classes.rb', line 4214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
The total time spent in the specified heart rate zone.
Corresponds to the JSON property duration
4207 4208 4209 |
# File 'lib/google/apis/health_v4/classes.rb', line 4207 def duration @duration end |
#heart_rate_zone ⇒ String
The heart rate zone.
Corresponds to the JSON property heartRateZone
4212 4213 4214 |
# File 'lib/google/apis/health_v4/classes.rb', line 4212 def heart_rate_zone @heart_rate_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4219 4220 4221 4222 |
# File 'lib/google/apis/health_v4/classes.rb', line 4219 def update!(**args) @duration = args[:duration] if args.key?(:duration) @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone) end |