Class: Google::Apis::HealthV4::TimeInHeartRateZoneValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::TimeInHeartRateZoneValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the total time spent in a specific heart rate zone.
Instance Attribute Summary collapse
-
#duration ⇒ String
The total time spent in the specified heart rate zone.
-
#heart_rate_zone ⇒ String
The heart rate zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeInHeartRateZoneValue
constructor
A new instance of TimeInHeartRateZoneValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeInHeartRateZoneValue
Returns a new instance of TimeInHeartRateZoneValue.
4204 4205 4206 |
# File 'lib/google/apis/health_v4/classes.rb', line 4204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
The total time spent in the specified heart rate zone.
Corresponds to the JSON property duration
4197 4198 4199 |
# File 'lib/google/apis/health_v4/classes.rb', line 4197 def duration @duration end |
#heart_rate_zone ⇒ String
The heart rate zone.
Corresponds to the JSON property heartRateZone
4202 4203 4204 |
# File 'lib/google/apis/health_v4/classes.rb', line 4202 def heart_rate_zone @heart_rate_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4209 4210 4211 4212 |
# File 'lib/google/apis/health_v4/classes.rb', line 4209 def update!(**args) @duration = args[:duration] if args.key?(:duration) @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone) end |