Class: Google::Apis::HealthV4::TimeInHeartRateZoneValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb

Overview

Represents the total time spent in a specific heart rate zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeInHeartRateZoneValue

Returns a new instance of TimeInHeartRateZoneValue.



4143
4144
4145
# File 'lib/google/apis/health_v4/classes.rb', line 4143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The total time spent in the specified heart rate zone. Corresponds to the JSON property duration

Returns:

  • (String)


4136
4137
4138
# File 'lib/google/apis/health_v4/classes.rb', line 4136

def duration
  @duration
end

#heart_rate_zoneString

The heart rate zone. Corresponds to the JSON property heartRateZone

Returns:

  • (String)


4141
4142
4143
# File 'lib/google/apis/health_v4/classes.rb', line 4141

def heart_rate_zone
  @heart_rate_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4148
4149
4150
4151
# File 'lib/google/apis/health_v4/classes.rb', line 4148

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone)
end