Class: Google::Apis::HealthV4::TimeInHeartRateZoneValue
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::TimeInHeartRateZoneValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Represents the total time spent in a specific heart rate zone.
Instance Attribute Summary collapse
-
#duration ⇒ String
The total time spent in the specified heart rate zone.
-
#heart_rate_zone ⇒ String
The heart rate zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeInHeartRateZoneValue
constructor
A new instance of TimeInHeartRateZoneValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeInHeartRateZoneValue
Returns a new instance of TimeInHeartRateZoneValue.
4143 4144 4145 |
# File 'lib/google/apis/health_v4/classes.rb', line 4143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
The total time spent in the specified heart rate zone.
Corresponds to the JSON property duration
4136 4137 4138 |
# File 'lib/google/apis/health_v4/classes.rb', line 4136 def duration @duration end |
#heart_rate_zone ⇒ String
The heart rate zone.
Corresponds to the JSON property heartRateZone
4141 4142 4143 |
# File 'lib/google/apis/health_v4/classes.rb', line 4141 def heart_rate_zone @heart_rate_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4148 4149 4150 4151 |
# File 'lib/google/apis/health_v4/classes.rb', line 4148 def update!(**args) @duration = args[:duration] if args.key?(:duration) @heart_rate_zone = args[:heart_rate_zone] if args.key?(:heart_rate_zone) end |