Class: Google::Apis::HealthV4::Vo2Max
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Vo2Max
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
VO2 max measurement.
Instance Attribute Summary collapse
-
#measurement_method ⇒ String
Optional.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#vo2_max ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Vo2Max
constructor
A new instance of Vo2Max.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Vo2Max
Returns a new instance of Vo2Max.
4362 4363 4364 |
# File 'lib/google/apis/health_v4/classes.rb', line 4362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#measurement_method ⇒ String
Optional. The method used to measure the VO2 max value.
Corresponds to the JSON property measurementMethod
4349 4350 4351 |
# File 'lib/google/apis/health_v4/classes.rb', line 4349 def measurement_method @measurement_method end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
4354 4355 4356 |
# File 'lib/google/apis/health_v4/classes.rb', line 4354 def sample_time @sample_time end |
#vo2_max ⇒ Float
Required. VO2 max value measured as in ml consumed oxygen / kg of body weight /
min.
Corresponds to the JSON property vo2Max
4360 4361 4362 |
# File 'lib/google/apis/health_v4/classes.rb', line 4360 def vo2_max @vo2_max end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4367 4368 4369 4370 4371 |
# File 'lib/google/apis/health_v4/classes.rb', line 4367 def update!(**args) @measurement_method = args[:measurement_method] if args.key?(:measurement_method) @sample_time = args[:sample_time] if args.key?(:sample_time) @vo2_max = args[:vo2_max] if args.key?(:vo2_max) end |