Class: Google::Apis::HealthV4::Weight
- Inherits:
-
Object
- Object
- Google::Apis::HealthV4::Weight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/health_v4/classes.rb,
lib/google/apis/health_v4/representations.rb,
lib/google/apis/health_v4/representations.rb
Overview
Body weight measurement.
Instance Attribute Summary collapse
-
#notes ⇒ String
Optional.
-
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
-
#weight_grams ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Weight
constructor
A new instance of Weight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Weight
Returns a new instance of Weight.
4402 4403 4404 |
# File 'lib/google/apis/health_v4/classes.rb', line 4402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#notes ⇒ String
Optional. Standard free-form notes captured at manual logging.
Corresponds to the JSON property notes
4390 4391 4392 |
# File 'lib/google/apis/health_v4/classes.rb', line 4390 def notes @notes end |
#sample_time ⇒ Google::Apis::HealthV4::ObservationSampleTime
Represents a sample time of an observed data point.
Corresponds to the JSON property sampleTime
4395 4396 4397 |
# File 'lib/google/apis/health_v4/classes.rb', line 4395 def sample_time @sample_time end |
#weight_grams ⇒ Float
Required. Weight of a user in grams.
Corresponds to the JSON property weightGrams
4400 4401 4402 |
# File 'lib/google/apis/health_v4/classes.rb', line 4400 def weight_grams @weight_grams end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4407 4408 4409 4410 4411 |
# File 'lib/google/apis/health_v4/classes.rb', line 4407 def update!(**args) @notes = args[:notes] if args.key?(:notes) @sample_time = args[:sample_time] if args.key?(:sample_time) @weight_grams = args[:weight_grams] if args.key?(:weight_grams) end |